Class: OCI::ObjectStorage::Models::UpdateBucketDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/models/update_bucket_details.rb

Overview

To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

Constant Summary collapse

PUBLIC_ACCESS_TYPE_ENUM =
[
  PUBLIC_ACCESS_TYPE_NO_PUBLIC_ACCESS = 'NoPublicAccess'.freeze,
  PUBLIC_ACCESS_TYPE_OBJECT_READ = 'ObjectRead'.freeze,
  PUBLIC_ACCESS_TYPE_OBJECT_READ_WITHOUT_LIST = 'ObjectReadWithoutList'.freeze
].freeze
VERSIONING_ENUM =
[
  VERSIONING_ENABLED = 'Enabled'.freeze,
  VERSIONING_SUSPENDED = 'Suspended'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateBucketDetails

Initializes the object

Options Hash (attributes):

  • :namespace (String)

    The value to assign to the #namespace property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :name (String)

    The value to assign to the #name property

  • :metadata (Hash<String, String>)

    The value to assign to the #metadata property

  • :public_access_type (String)

    The value to assign to the #public_access_type property

  • :object_events_enabled (BOOLEAN)

    The value to assign to the #object_events_enabled property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :kms_key_id (String)

    The value to assign to the #kms_key_id property

  • :versioning (String)

    The value to assign to the #versioning property

  • :auto_tiering (String)

    The value to assign to the #auto_tiering property



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 149

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.namespace = attributes[:'namespace'] if attributes[:'namespace']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self. = attributes[:'metadata'] if attributes[:'metadata']

  self.public_access_type = attributes[:'publicAccessType'] if attributes[:'publicAccessType']

  raise 'You cannot provide both :publicAccessType and :public_access_type' if attributes.key?(:'publicAccessType') && attributes.key?(:'public_access_type')

  self.public_access_type = attributes[:'public_access_type'] if attributes[:'public_access_type']

  self.object_events_enabled = attributes[:'objectEventsEnabled'] unless attributes[:'objectEventsEnabled'].nil?

  raise 'You cannot provide both :objectEventsEnabled and :object_events_enabled' if attributes.key?(:'objectEventsEnabled') && attributes.key?(:'object_events_enabled')

  self.object_events_enabled = attributes[:'object_events_enabled'] unless attributes[:'object_events_enabled'].nil?

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.versioning = attributes[:'versioning'] if attributes[:'versioning']

  self.auto_tiering = attributes[:'autoTiering'] if attributes[:'autoTiering']

  raise 'You cannot provide both :autoTiering and :auto_tiering' if attributes.key?(:'autoTiering') && attributes.key?(:'auto_tiering')

  self.auto_tiering = attributes[:'auto_tiering'] if attributes[:'auto_tiering']
end

Instance Attribute Details

#auto_tieringString

The auto tiering status on the bucket. If in state InfrequentAccess, objects are transitioned automatically between the ‘Standard’ and ‘InfrequentAccess’ tiers based on the access pattern of the objects. When auto tiering is Disabled, there will be no automatic transitions between storage tiers.



92
93
94
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 92

def auto_tiering
  @auto_tiering
end

#compartment_idString

The compartmentId for the compartment to move the bucket to.



30
31
32
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 30

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}



70
71
72
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 70

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`



63
64
65
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 63

def freeform_tags
  @freeform_tags
end

#kms_key_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Key Management master encryption key to associate with the specified bucket. If this value is empty, the Update operation will remove the associated key, if there is one, from the bucket. (The bucket will continue to be encrypted, but with an encryption key managed by Oracle.)



78
79
80
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 78

def kms_key_id
  @kms_key_id
end

#metadataHash<String, String>

Arbitrary string, up to 4KB, of keys and values for user-defined metadata.



41
42
43
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 41

def 
  
end

#nameString

The name of the bucket. Valid characters are uppercase or lowercase letters, numbers, hyphens, underscores, and periods. Bucket names must be unique within an Object Storage namespace. Avoid entering confidential information. Example: my-new-bucket1



37
38
39
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 37

def name
  @name
end

#namespaceString

The Object Storage namespace in which the bucket lives.



26
27
28
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 26

def namespace
  @namespace
end

#object_events_enabledBOOLEAN

Whether or not events are emitted for object state changes in this bucket. By default, objectEventsEnabled is set to false. Set objectEventsEnabled to true to emit events for object state changes. For more information about events, see [Overview of Events](docs.cloud.oracle.com/Content/Events/Concepts/eventsoverview.htm).



56
57
58
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 56

def object_events_enabled
  @object_events_enabled
end

#public_access_typeString

The type of public access enabled on this bucket. A bucket is set to NoPublicAccess by default, which only allows an authenticated caller to access the bucket and its contents. When ObjectRead is enabled on the bucket, public access is allowed for the GetObject, HeadObject, and ListObjects operations. When ObjectReadWithoutList is enabled on the bucket, public access is allowed for the GetObject and HeadObject operations.



49
50
51
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 49

def public_access_type
  @public_access_type
end

#versioningString

The versioning status on the bucket. If in state Enabled, multiple versions of the same object can be kept in the bucket. When the object is overwritten or deleted, previous versions will still be available. When versioning is Suspended, the previous versions will still remain but new versions will no longer be created when overwitten or deleted. Versioning cannot be disabled on a bucket once enabled.



85
86
87
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 85

def versioning
  @versioning
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 95

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'namespace': :'namespace',
    'compartment_id': :'compartmentId',
    'name': :'name',
    'metadata': :'metadata',
    'public_access_type': :'publicAccessType',
    'object_events_enabled': :'objectEventsEnabled',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'kms_key_id': :'kmsKeyId',
    'versioning': :'versioning',
    'auto_tiering': :'autoTiering'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 114

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'namespace': :'String',
    'compartment_id': :'String',
    'name': :'String',
    'metadata': :'Hash<String, String>',
    'public_access_type': :'String',
    'object_events_enabled': :'BOOLEAN',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'kms_key_id': :'String',
    'versioning': :'String',
    'auto_tiering': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 229

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    namespace == other.namespace &&
    compartment_id == other.compartment_id &&
    name == other.name &&
     == other. &&
    public_access_type == other.public_access_type &&
    object_events_enabled == other.object_events_enabled &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    kms_key_id == other.kms_key_id &&
    versioning == other.versioning &&
    auto_tiering == other.auto_tiering
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 269

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


249
250
251
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 249

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



258
259
260
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 258

def hash
  [namespace, compartment_id, name, , public_access_type, object_events_enabled, freeform_tags, defined_tags, kms_key_id, versioning, auto_tiering].hash
end

#to_hashHash

Returns the object in the form of hash



302
303
304
305
306
307
308
309
310
311
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 302

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



296
297
298
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 296

def to_s
  to_hash.to_s
end