Method: OCI::ObjectStorage::Models::UpdateBucketDetails#name

Defined in:
lib/oci/object_storage/models/update_bucket_details.rb

#nameString

The name of the bucket. Valid characters are uppercase or lowercase letters, numbers, hyphens, underscores, and periods. Bucket names must be unique within an Object Storage namespace. Avoid entering confidential information. Example: my-new-bucket1

Returns:

  • (String)


37
38
39
# File 'lib/oci/object_storage/models/update_bucket_details.rb', line 37

def name
  @name
end