Class: OCI::ObjectStorage::Models::WorkRequestResource
- Inherits:
-
Object
- Object
- OCI::ObjectStorage::Models::WorkRequestResource
- Defined in:
- lib/oci/object_storage/models/work_request_resource.rb
Overview
WorkRequestResource model.
Constant Summary collapse
- ACTION_TYPE_ENUM =
rubocop:disable Metrics/LineLength
[ ACTION_TYPE_CREATED = 'CREATED'.freeze, ACTION_TYPE_UPDATED = 'UPDATED'.freeze, ACTION_TYPE_DELETED = 'DELETED'.freeze, ACTION_TYPE_RELATED = 'RELATED'.freeze, ACTION_TYPE_IN_PROGRESS = 'IN_PROGRESS'.freeze, ACTION_TYPE_READ = 'READ'.freeze, ACTION_TYPE_WRITTEN = 'WRITTEN'.freeze, ACTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action_type ⇒ String
The status that a work request can present.
-
#entity_type ⇒ String
The resource type the work request is affects.
-
#entity_uri ⇒ String
The URI path that the user can do a GET on to access the resource metadata.
-
#identifier ⇒ String
The identifier of the resource the work request affects.
-
#metadata ⇒ Hash<String, String>
The metadata of the resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequestResource
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequestResource
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.action_type = attributes[:'actionType'] if attributes[:'actionType'] raise 'You cannot provide both :actionType and :action_type' if attributes.key?(:'actionType') && attributes.key?(:'action_type') self.action_type = attributes[:'action_type'] if attributes[:'action_type'] self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.entity_uri = attributes[:'entityUri'] if attributes[:'entityUri'] raise 'You cannot provide both :entityUri and :entity_uri' if attributes.key?(:'entityUri') && attributes.key?(:'entity_uri') self.entity_uri = attributes[:'entity_uri'] if attributes[:'entity_uri'] self. = attributes[:'metadata'] if attributes[:'metadata'] end |
Instance Attribute Details
#action_type ⇒ String
The status that a work request can present
23 24 25 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 23 def action_type @action_type end |
#entity_type ⇒ String
The resource type the work request is affects.
27 28 29 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 27 def entity_type @entity_type end |
#entity_uri ⇒ String
The URI path that the user can do a GET on to access the resource metadata
35 36 37 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 35 def entity_uri @entity_uri end |
#identifier ⇒ String
The identifier of the resource the work request affects.
31 32 33 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 31 def identifier @identifier end |
#metadata ⇒ Hash<String, String>
The metadata of the resource.
39 40 41 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 39 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'action_type': :'actionType', 'entity_type': :'entityType', 'identifier': :'identifier', 'entity_uri': :'entityUri', 'metadata': :'metadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'action_type': :'String', 'entity_type': :'String', 'identifier': :'String', 'entity_uri': :'String', 'metadata': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 129 def ==(other) return true if equal?(other) self.class == other.class && action_type == other.action_type && entity_type == other.entity_type && identifier == other.identifier && entity_uri == other.entity_uri && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 162 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
142 143 144 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 142 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 151 def hash [action_type, entity_type, identifier, entity_uri, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
188 189 190 |
# File 'lib/oci/object_storage/models/work_request_resource.rb', line 188 def to_s to_hash.to_s end |