Class: OCI::ObjectStorage::ObjectStorageClientCompositeOperations

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/object_storage/object_storage_client_composite_operations.rb

Overview

This class provides a wrapper around ObjectStorageClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(service_client = OCI::ObjectStorage::ObjectStorageClient.new) ⇒ ObjectStorageClientCompositeOperations

Initializes a new ObjectStorageClientCompositeOperations



20
21
22
# File 'lib/oci/object_storage/object_storage_client_composite_operations.rb', line 20

def initialize(service_client = OCI::ObjectStorage::ObjectStorageClient.new)
  @service_client = service_client
end

Instance Attribute Details

#service_clientOCI::ObjectStorage::ObjectStorageClient (readonly)

The OCI::ObjectStorage::ObjectStorageClient used to communicate with the service_client



14
15
16
# File 'lib/oci/object_storage/object_storage_client_composite_operations.rb', line 14

def service_client
  @service_client
end

Instance Method Details

#copy_object_and_wait_for_state(namespace_name, bucket_name, copy_object_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::ObjectStorage::ObjectStorageClient#copy_object and then waits for the Models::WorkRequest to enter the given state(s).



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/object_storage/object_storage_client_composite_operations.rb', line 43

def copy_object_and_wait_for_state(namespace_name, bucket_name, copy_object_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.copy_object(namespace_name, bucket_name, copy_object_details, base_operation_opts)
  use_util = OCI::ObjectStorage::Util.respond_to?(:wait_on_work_request)

  return operation_result if wait_for_states.empty? && !use_util

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.headers['opc-work-request-id']

  begin
    if use_util
      waiter_result = OCI::ObjectStorage::Util.wait_on_work_request(
        @service_client,
        wait_for_resource_id,
        max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
        max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
      )
    else
      waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until(
        eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) },
        max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
        max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
      )
    end
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#reencrypt_bucket_and_wait_for_state(namespace_name, bucket_name, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::ObjectStorage::ObjectStorageClient#reencrypt_bucket and then waits for the Models::WorkRequest to enter the given state(s).



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/oci/object_storage/object_storage_client_composite_operations.rb', line 95

def reencrypt_bucket_and_wait_for_state(namespace_name, bucket_name, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.reencrypt_bucket(namespace_name, bucket_name, base_operation_opts)
  use_util = OCI::ObjectStorage::Util.respond_to?(:wait_on_work_request)

  return operation_result if wait_for_states.empty? && !use_util

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.headers['opc-work-request-id']

  begin
    if use_util
      waiter_result = OCI::ObjectStorage::Util.wait_on_work_request(
        @service_client,
        wait_for_resource_id,
        max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
        max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
      )
    else
      waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until(
        eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) },
        max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
        max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
      )
    end
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end