Class: OCI::Oce::Models::CreateOceInstanceDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/oce/models/create_oce_instance_details.rb

Overview

The information about new OceInstance.

Constant Summary collapse

INSTANCE_USAGE_TYPE_ENUM =
[
  INSTANCE_USAGE_TYPE_PRIMARY = 'PRIMARY'.freeze,
  INSTANCE_USAGE_TYPE_NONPRIMARY = 'NONPRIMARY'.freeze
].freeze
INSTANCE_ACCESS_TYPE_ENUM =
[
  INSTANCE_ACCESS_TYPE_PUBLIC = 'PUBLIC'.freeze,
  INSTANCE_ACCESS_TYPE_PRIVATE = 'PRIVATE'.freeze
].freeze
INSTANCE_LICENSE_TYPE_ENUM =
[
  INSTANCE_LICENSE_TYPE_NEW = 'NEW'.freeze,
  INSTANCE_LICENSE_TYPE_BYOL = 'BYOL'.freeze,
  INSTANCE_LICENSE_TYPE_PREMIUM = 'PREMIUM'.freeze,
  INSTANCE_LICENSE_TYPE_STARTER = 'STARTER'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateOceInstanceDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 166

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId']

  raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id')

  self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id']

  self.idcs_access_token = attributes[:'idcsAccessToken'] if attributes[:'idcsAccessToken']

  raise 'You cannot provide both :idcsAccessToken and :idcs_access_token' if attributes.key?(:'idcsAccessToken') && attributes.key?(:'idcs_access_token')

  self.idcs_access_token = attributes[:'idcs_access_token'] if attributes[:'idcs_access_token']

  self.identity_stripe = attributes[:'identityStripe'] if attributes[:'identityStripe']

  raise 'You cannot provide both :identityStripe and :identity_stripe' if attributes.key?(:'identityStripe') && attributes.key?(:'identity_stripe')

  self.identity_stripe = attributes[:'identity_stripe'] if attributes[:'identity_stripe']

  self.tenancy_name = attributes[:'tenancyName'] if attributes[:'tenancyName']

  raise 'You cannot provide both :tenancyName and :tenancy_name' if attributes.key?(:'tenancyName') && attributes.key?(:'tenancy_name')

  self.tenancy_name = attributes[:'tenancy_name'] if attributes[:'tenancy_name']

  self.instance_usage_type = attributes[:'instanceUsageType'] if attributes[:'instanceUsageType']

  raise 'You cannot provide both :instanceUsageType and :instance_usage_type' if attributes.key?(:'instanceUsageType') && attributes.key?(:'instance_usage_type')

  self.instance_usage_type = attributes[:'instance_usage_type'] if attributes[:'instance_usage_type']

  self.object_storage_namespace = attributes[:'objectStorageNamespace'] if attributes[:'objectStorageNamespace']

  raise 'You cannot provide both :objectStorageNamespace and :object_storage_namespace' if attributes.key?(:'objectStorageNamespace') && attributes.key?(:'object_storage_namespace')

  self.object_storage_namespace = attributes[:'object_storage_namespace'] if attributes[:'object_storage_namespace']

  self.admin_email = attributes[:'adminEmail'] if attributes[:'adminEmail']

  raise 'You cannot provide both :adminEmail and :admin_email' if attributes.key?(:'adminEmail') && attributes.key?(:'admin_email')

  self.admin_email = attributes[:'admin_email'] if attributes[:'admin_email']

  self.upgrade_schedule = attributes[:'upgradeSchedule'] if attributes[:'upgradeSchedule']

  raise 'You cannot provide both :upgradeSchedule and :upgrade_schedule' if attributes.key?(:'upgradeSchedule') && attributes.key?(:'upgrade_schedule')

  self.upgrade_schedule = attributes[:'upgrade_schedule'] if attributes[:'upgrade_schedule']

  self.waf_primary_domain = attributes[:'wafPrimaryDomain'] if attributes[:'wafPrimaryDomain']

  raise 'You cannot provide both :wafPrimaryDomain and :waf_primary_domain' if attributes.key?(:'wafPrimaryDomain') && attributes.key?(:'waf_primary_domain')

  self.waf_primary_domain = attributes[:'waf_primary_domain'] if attributes[:'waf_primary_domain']

  self.instance_access_type = attributes[:'instanceAccessType'] if attributes[:'instanceAccessType']

  raise 'You cannot provide both :instanceAccessType and :instance_access_type' if attributes.key?(:'instanceAccessType') && attributes.key?(:'instance_access_type')

  self.instance_access_type = attributes[:'instance_access_type'] if attributes[:'instance_access_type']

  self.instance_license_type = attributes[:'instanceLicenseType'] if attributes[:'instanceLicenseType']

  raise 'You cannot provide both :instanceLicenseType and :instance_license_type' if attributes.key?(:'instanceLicenseType') && attributes.key?(:'instance_license_type')

  self.instance_license_type = attributes[:'instance_license_type'] if attributes[:'instance_license_type']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#admin_emailString

[Required] Admin Email for Notification

Returns:

  • (String)


64
65
66
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 64

def admin_email
  @admin_email
end

#compartment_idString

[Required] Compartment Identifier

Returns:

  • (String)


33
34
35
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 33

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


94
95
96
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 94

def defined_tags
  @defined_tags
end

#descriptionString

OceInstance description

Returns:

  • (String)


29
30
31
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 29

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


88
89
90
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 88

def freeform_tags
  @freeform_tags
end

#idcs_access_tokenString

[Required] Identity Cloud Service access token identifying a stripe and service administrator user

Returns:

  • (String)


45
46
47
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 45

def idcs_access_token
  @idcs_access_token
end

#identity_stripeOCI::Oce::Models::IdentityStripeDetails



48
49
50
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 48

def identity_stripe
  @identity_stripe
end

#instance_access_typeString

Flag indicating whether the instance access is private or public

Returns:

  • (String)


78
79
80
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 78

def instance_access_type
  @instance_access_type
end

#instance_license_typeString

Flag indicating whether the instance license is new cloud or bring your own license

Returns:

  • (String)


82
83
84
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 82

def instance_license_type
  @instance_license_type
end

#instance_usage_typeString

Instance type based on its usage

Returns:

  • (String)


56
57
58
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 56

def instance_usage_type
  @instance_usage_type
end

#nameString

[Required] OceInstance Name

Returns:

  • (String)


37
38
39
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 37

def name
  @name
end

#object_storage_namespaceString

[Required] Object Storage Namespace of Tenancy

Returns:

  • (String)


60
61
62
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 60

def object_storage_namespace
  @object_storage_namespace
end

#tenancy_idString

[Required] Tenancy Identifier

Returns:

  • (String)


41
42
43
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 41

def tenancy_id
  @tenancy_id
end

#tenancy_nameString

[Required] Tenancy Name

Returns:

  • (String)


52
53
54
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 52

def tenancy_name
  @tenancy_name
end

#upgrade_scheduleString

Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version

Returns:

  • (String)


70
71
72
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 70

def upgrade_schedule
  @upgrade_schedule
end

#waf_primary_domainString

Web Application Firewall(WAF) primary domain

Returns:

  • (String)


74
75
76
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 74

def waf_primary_domain
  @waf_primary_domain
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 97

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'compartment_id': :'compartmentId',
    'name': :'name',
    'tenancy_id': :'tenancyId',
    'idcs_access_token': :'idcsAccessToken',
    'identity_stripe': :'identityStripe',
    'tenancy_name': :'tenancyName',
    'instance_usage_type': :'instanceUsageType',
    'object_storage_namespace': :'objectStorageNamespace',
    'admin_email': :'adminEmail',
    'upgrade_schedule': :'upgradeSchedule',
    'waf_primary_domain': :'wafPrimaryDomain',
    'instance_access_type': :'instanceAccessType',
    'instance_license_type': :'instanceLicenseType',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 121

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'compartment_id': :'String',
    'name': :'String',
    'tenancy_id': :'String',
    'idcs_access_token': :'String',
    'identity_stripe': :'OCI::Oce::Models::IdentityStripeDetails',
    'tenancy_name': :'String',
    'instance_usage_type': :'String',
    'object_storage_namespace': :'String',
    'admin_email': :'String',
    'upgrade_schedule': :'String',
    'waf_primary_domain': :'String',
    'instance_access_type': :'String',
    'instance_license_type': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 292

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    name == other.name &&
    tenancy_id == other.tenancy_id &&
    idcs_access_token == other.idcs_access_token &&
    identity_stripe == other.identity_stripe &&
    tenancy_name == other.tenancy_name &&
    instance_usage_type == other.instance_usage_type &&
    object_storage_namespace == other.object_storage_namespace &&
    admin_email == other.admin_email &&
    upgrade_schedule == other.upgrade_schedule &&
    waf_primary_domain == other.waf_primary_domain &&
    instance_access_type == other.instance_access_type &&
    instance_license_type == other.instance_license_type &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 337

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


317
318
319
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 317

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



326
327
328
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 326

def hash
  [description, compartment_id, name, tenancy_id, idcs_access_token, identity_stripe, tenancy_name, instance_usage_type, object_storage_namespace, admin_email, upgrade_schedule, waf_primary_domain, instance_access_type, instance_license_type, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



370
371
372
373
374
375
376
377
378
379
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 370

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



364
365
366
# File 'lib/oci/oce/models/create_oce_instance_details.rb', line 364

def to_s
  to_hash.to_s
end