Class: OCI::Oce::Models::OceInstance
- Inherits:
-
Object
- Object
- OCI::Oce::Models::OceInstance
- Defined in:
- lib/oci/oce/models/oce_instance.rb
Overview
Details of OceInstance.
Constant Summary collapse
- UPGRADE_SCHEDULE_ENUM =
[ UPGRADE_SCHEDULE_UPGRADE_IMMEDIATELY = 'UPGRADE_IMMEDIATELY'.freeze, UPGRADE_SCHEDULE_DELAYED_UPGRADE = 'DELAYED_UPGRADE'.freeze, UPGRADE_SCHEDULE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- INSTANCE_USAGE_TYPE_ENUM =
[ INSTANCE_USAGE_TYPE_PRIMARY = 'PRIMARY'.freeze, INSTANCE_USAGE_TYPE_NONPRIMARY = 'NONPRIMARY'.freeze, INSTANCE_USAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- INSTANCE_ACCESS_TYPE_ENUM =
[ INSTANCE_ACCESS_TYPE_PUBLIC = 'PUBLIC'.freeze, INSTANCE_ACCESS_TYPE_PRIVATE = 'PRIVATE'.freeze, INSTANCE_ACCESS_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- INSTANCE_LICENSE_TYPE_ENUM =
[ INSTANCE_LICENSE_TYPE_NEW = 'NEW'.freeze, INSTANCE_LICENSE_TYPE_BYOL = 'BYOL'.freeze, INSTANCE_LICENSE_TYPE_PREMIUM = 'PREMIUM'.freeze, INSTANCE_LICENSE_TYPE_STARTER = 'STARTER'.freeze, INSTANCE_LICENSE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_DETAILS_ENUM =
[ LIFECYCLE_DETAILS_STANDBY = 'STANDBY'.freeze, LIFECYCLE_DETAILS_FAILOVER = 'FAILOVER'.freeze, LIFECYCLE_DETAILS_DOWN = 'DOWN'.freeze, LIFECYCLE_DETAILS_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_DETAILS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#add_on_features ⇒ Array<String>
a list of add-on features for the ocm instance.
-
#admin_email ⇒ String
**[Required]** Admin Email for Notification.
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
OceInstance description, can be updated.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#guid ⇒ String
**[Required]** Unique GUID identifier that is immutable on creation.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#idcs_tenancy ⇒ String
**[Required]** IDCS Tenancy Identifier.
- #identity_stripe ⇒ OCI::Oce::Models::IdentityStripeDetails
-
#instance_access_type ⇒ String
Flag indicating whether the instance access is private or public.
-
#instance_license_type ⇒ String
Flag indicating whether the instance license is new cloud or bring your own license.
-
#instance_usage_type ⇒ String
Instance type based on its usage.
-
#lifecycle_details ⇒ String
Details of the current state of the instance lifecycle.
-
#lifecycle_state ⇒ String
The current state of the instance lifecycle.
-
#name ⇒ String
**[Required]** OceInstance Name.
-
#object_storage_namespace ⇒ String
**[Required]** Object Storage Namespace of tenancy.
-
#service ⇒ Hash<String, Object>
SERVICE data.
-
#state_message ⇒ String
An message describing the current state in more detail.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#tenancy_id ⇒ String
**[Required]** Tenancy Identifier.
-
#tenancy_name ⇒ String
**[Required]** Tenancy Name.
-
#time_created ⇒ DateTime
The time the the OceInstance was created.
-
#time_updated ⇒ DateTime
The time the OceInstance was updated.
-
#upgrade_schedule ⇒ String
Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version.
-
#waf_primary_domain ⇒ String
Web Application Firewall(WAF) primary domain.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OceInstance
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OceInstance
Initializes the object
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/oci/oce/models/oce_instance.rb', line 268 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.guid = attributes[:'guid'] if attributes[:'guid'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId'] raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id') self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id'] self.idcs_tenancy = attributes[:'idcsTenancy'] if attributes[:'idcsTenancy'] raise 'You cannot provide both :idcsTenancy and :idcs_tenancy' if attributes.key?(:'idcsTenancy') && attributes.key?(:'idcs_tenancy') self.idcs_tenancy = attributes[:'idcs_tenancy'] if attributes[:'idcs_tenancy'] self.tenancy_name = attributes[:'tenancyName'] if attributes[:'tenancyName'] raise 'You cannot provide both :tenancyName and :tenancy_name' if attributes.key?(:'tenancyName') && attributes.key?(:'tenancy_name') self.tenancy_name = attributes[:'tenancy_name'] if attributes[:'tenancy_name'] self.upgrade_schedule = attributes[:'upgradeSchedule'] if attributes[:'upgradeSchedule'] raise 'You cannot provide both :upgradeSchedule and :upgrade_schedule' if attributes.key?(:'upgradeSchedule') && attributes.key?(:'upgrade_schedule') self.upgrade_schedule = attributes[:'upgrade_schedule'] if attributes[:'upgrade_schedule'] self.identity_stripe = attributes[:'identityStripe'] if attributes[:'identityStripe'] raise 'You cannot provide both :identityStripe and :identity_stripe' if attributes.key?(:'identityStripe') && attributes.key?(:'identity_stripe') self.identity_stripe = attributes[:'identity_stripe'] if attributes[:'identity_stripe'] self.instance_usage_type = attributes[:'instanceUsageType'] if attributes[:'instanceUsageType'] raise 'You cannot provide both :instanceUsageType and :instance_usage_type' if attributes.key?(:'instanceUsageType') && attributes.key?(:'instance_usage_type') self.instance_usage_type = attributes[:'instance_usage_type'] if attributes[:'instance_usage_type'] self.add_on_features = attributes[:'addOnFeatures'] if attributes[:'addOnFeatures'] raise 'You cannot provide both :addOnFeatures and :add_on_features' if attributes.key?(:'addOnFeatures') && attributes.key?(:'add_on_features') self.add_on_features = attributes[:'add_on_features'] if attributes[:'add_on_features'] self.object_storage_namespace = attributes[:'objectStorageNamespace'] if attributes[:'objectStorageNamespace'] raise 'You cannot provide both :objectStorageNamespace and :object_storage_namespace' if attributes.key?(:'objectStorageNamespace') && attributes.key?(:'object_storage_namespace') self.object_storage_namespace = attributes[:'object_storage_namespace'] if attributes[:'object_storage_namespace'] self.admin_email = attributes[:'adminEmail'] if attributes[:'adminEmail'] raise 'You cannot provide both :adminEmail and :admin_email' if attributes.key?(:'adminEmail') && attributes.key?(:'admin_email') self.admin_email = attributes[:'admin_email'] if attributes[:'admin_email'] self.waf_primary_domain = attributes[:'wafPrimaryDomain'] if attributes[:'wafPrimaryDomain'] raise 'You cannot provide both :wafPrimaryDomain and :waf_primary_domain' if attributes.key?(:'wafPrimaryDomain') && attributes.key?(:'waf_primary_domain') self.waf_primary_domain = attributes[:'waf_primary_domain'] if attributes[:'waf_primary_domain'] self.instance_access_type = attributes[:'instanceAccessType'] if attributes[:'instanceAccessType'] raise 'You cannot provide both :instanceAccessType and :instance_access_type' if attributes.key?(:'instanceAccessType') && attributes.key?(:'instance_access_type') self.instance_access_type = attributes[:'instance_access_type'] if attributes[:'instance_access_type'] self.instance_license_type = attributes[:'instanceLicenseType'] if attributes[:'instanceLicenseType'] raise 'You cannot provide both :instanceLicenseType and :instance_license_type' if attributes.key?(:'instanceLicenseType') && attributes.key?(:'instance_license_type') self.instance_license_type = attributes[:'instance_license_type'] if attributes[:'instance_license_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'stateMessage'] if attributes[:'stateMessage'] raise 'You cannot provide both :stateMessage and :state_message' if attributes.key?(:'stateMessage') && attributes.key?(:'state_message') self. = attributes[:'state_message'] if attributes[:'state_message'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.service = attributes[:'service'] if attributes[:'service'] end |
Instance Attribute Details
#add_on_features ⇒ Array<String>
a list of add-on features for the ocm instance
102 103 104 |
# File 'lib/oci/oce/models/oce_instance.rb', line 102 def add_on_features @add_on_features end |
#admin_email ⇒ String
**[Required]** Admin Email for Notification
110 111 112 |
# File 'lib/oci/oce/models/oce_instance.rb', line 110 def admin_email @admin_email end |
#compartment_id ⇒ String
**[Required]** Compartment Identifier
69 70 71 |
# File 'lib/oci/oce/models/oce_instance.rb', line 69 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
154 155 156 |
# File 'lib/oci/oce/models/oce_instance.rb', line 154 def @defined_tags end |
#description ⇒ String
OceInstance description, can be updated
65 66 67 |
# File 'lib/oci/oce/models/oce_instance.rb', line 65 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
148 149 150 |
# File 'lib/oci/oce/models/oce_instance.rb', line 148 def @freeform_tags end |
#guid ⇒ String
**[Required]** Unique GUID identifier that is immutable on creation
61 62 63 |
# File 'lib/oci/oce/models/oce_instance.rb', line 61 def guid @guid end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
57 58 59 |
# File 'lib/oci/oce/models/oce_instance.rb', line 57 def id @id end |
#idcs_tenancy ⇒ String
**[Required]** IDCS Tenancy Identifier
81 82 83 |
# File 'lib/oci/oce/models/oce_instance.rb', line 81 def idcs_tenancy @idcs_tenancy end |
#identity_stripe ⇒ OCI::Oce::Models::IdentityStripeDetails
94 95 96 |
# File 'lib/oci/oce/models/oce_instance.rb', line 94 def identity_stripe @identity_stripe end |
#instance_access_type ⇒ String
Flag indicating whether the instance access is private or public
118 119 120 |
# File 'lib/oci/oce/models/oce_instance.rb', line 118 def instance_access_type @instance_access_type end |
#instance_license_type ⇒ String
Flag indicating whether the instance license is new cloud or bring your own license
122 123 124 |
# File 'lib/oci/oce/models/oce_instance.rb', line 122 def instance_license_type @instance_license_type end |
#instance_usage_type ⇒ String
Instance type based on its usage
98 99 100 |
# File 'lib/oci/oce/models/oce_instance.rb', line 98 def instance_usage_type @instance_usage_type end |
#lifecycle_details ⇒ String
Details of the current state of the instance lifecycle
138 139 140 |
# File 'lib/oci/oce/models/oce_instance.rb', line 138 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the instance lifecycle.
134 135 136 |
# File 'lib/oci/oce/models/oce_instance.rb', line 134 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** OceInstance Name
73 74 75 |
# File 'lib/oci/oce/models/oce_instance.rb', line 73 def name @name end |
#object_storage_namespace ⇒ String
**[Required]** Object Storage Namespace of tenancy
106 107 108 |
# File 'lib/oci/oce/models/oce_instance.rb', line 106 def object_storage_namespace @object_storage_namespace end |
#service ⇒ Hash<String, Object>
SERVICE data. Example: `{"IDCS": "value"}`
166 167 168 |
# File 'lib/oci/oce/models/oce_instance.rb', line 166 def service @service end |
#state_message ⇒ String
An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
142 143 144 |
# File 'lib/oci/oce/models/oce_instance.rb', line 142 def @state_message end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
160 161 162 |
# File 'lib/oci/oce/models/oce_instance.rb', line 160 def @system_tags end |
#tenancy_id ⇒ String
**[Required]** Tenancy Identifier
77 78 79 |
# File 'lib/oci/oce/models/oce_instance.rb', line 77 def tenancy_id @tenancy_id end |
#tenancy_name ⇒ String
**[Required]** Tenancy Name
85 86 87 |
# File 'lib/oci/oce/models/oce_instance.rb', line 85 def tenancy_name @tenancy_name end |
#time_created ⇒ DateTime
The time the the OceInstance was created. An RFC3339 formatted datetime string
126 127 128 |
# File 'lib/oci/oce/models/oce_instance.rb', line 126 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the OceInstance was updated. An RFC3339 formatted datetime string
130 131 132 |
# File 'lib/oci/oce/models/oce_instance.rb', line 130 def time_updated @time_updated end |
#upgrade_schedule ⇒ String
Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version
91 92 93 |
# File 'lib/oci/oce/models/oce_instance.rb', line 91 def upgrade_schedule @upgrade_schedule end |
#waf_primary_domain ⇒ String
Web Application Firewall(WAF) primary domain
114 115 116 |
# File 'lib/oci/oce/models/oce_instance.rb', line 114 def waf_primary_domain @waf_primary_domain end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/oce/models/oce_instance.rb', line 169 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'guid': :'guid', 'description': :'description', 'compartment_id': :'compartmentId', 'name': :'name', 'tenancy_id': :'tenancyId', 'idcs_tenancy': :'idcsTenancy', 'tenancy_name': :'tenancyName', 'upgrade_schedule': :'upgradeSchedule', 'identity_stripe': :'identityStripe', 'instance_usage_type': :'instanceUsageType', 'add_on_features': :'addOnFeatures', 'object_storage_namespace': :'objectStorageNamespace', 'admin_email': :'adminEmail', 'waf_primary_domain': :'wafPrimaryDomain', 'instance_access_type': :'instanceAccessType', 'instance_license_type': :'instanceLicenseType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'state_message': :'stateMessage', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'service': :'service' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/oce/models/oce_instance.rb', line 203 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'guid': :'String', 'description': :'String', 'compartment_id': :'String', 'name': :'String', 'tenancy_id': :'String', 'idcs_tenancy': :'String', 'tenancy_name': :'String', 'upgrade_schedule': :'String', 'identity_stripe': :'OCI::Oce::Models::IdentityStripeDetails', 'instance_usage_type': :'String', 'add_on_features': :'Array<String>', 'object_storage_namespace': :'String', 'admin_email': :'String', 'waf_primary_domain': :'String', 'instance_access_type': :'String', 'instance_license_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'state_message': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'service': :'Hash<String, Object>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/oci/oce/models/oce_instance.rb', line 496 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && guid == other.guid && description == other.description && compartment_id == other.compartment_id && name == other.name && tenancy_id == other.tenancy_id && idcs_tenancy == other.idcs_tenancy && tenancy_name == other.tenancy_name && upgrade_schedule == other.upgrade_schedule && identity_stripe == other.identity_stripe && instance_usage_type == other.instance_usage_type && add_on_features == other.add_on_features && object_storage_namespace == other.object_storage_namespace && admin_email == other.admin_email && waf_primary_domain == other.waf_primary_domain && instance_access_type == other.instance_access_type && instance_license_type == other.instance_license_type && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. && == other. && service == other.service end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/oci/oce/models/oce_instance.rb', line 551 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
531 532 533 |
# File 'lib/oci/oce/models/oce_instance.rb', line 531 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
540 541 542 |
# File 'lib/oci/oce/models/oce_instance.rb', line 540 def hash [id, guid, description, compartment_id, name, tenancy_id, idcs_tenancy, tenancy_name, upgrade_schedule, identity_stripe, instance_usage_type, add_on_features, object_storage_namespace, admin_email, waf_primary_domain, instance_access_type, instance_license_type, time_created, time_updated, lifecycle_state, lifecycle_details, , , , , service].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
584 585 586 587 588 589 590 591 592 593 |
# File 'lib/oci/oce/models/oce_instance.rb', line 584 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
578 579 580 |
# File 'lib/oci/oce/models/oce_instance.rb', line 578 def to_s to_hash.to_s end |