Class: OCI::Oce::Models::UpdateOceInstanceDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/oce/models/update_oce_instance_details.rb

Overview

The information to be updated.

Constant Summary collapse

INSTANCE_LICENSE_TYPE_ENUM =
[
  INSTANCE_LICENSE_TYPE_NEW = 'NEW'.freeze,
  INSTANCE_LICENSE_TYPE_BYOL = 'BYOL'.freeze,
  INSTANCE_LICENSE_TYPE_PREMIUM = 'PREMIUM'.freeze,
  INSTANCE_LICENSE_TYPE_STARTER = 'STARTER'.freeze
].freeze
INSTANCE_USAGE_TYPE_ENUM =
[
  INSTANCE_USAGE_TYPE_PRIMARY = 'PRIMARY'.freeze,
  INSTANCE_USAGE_TYPE_NONPRIMARY = 'NONPRIMARY'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateOceInstanceDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :description (String)

    The value to assign to the #description property

  • :waf_primary_domain (String)

    The value to assign to the #waf_primary_domain property

  • :instance_license_type (String)

    The value to assign to the #instance_license_type property

  • :instance_usage_type (String)

    The value to assign to the #instance_usage_type property

  • :add_on_features (Array<String>)

    The value to assign to the #add_on_features property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 97

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.waf_primary_domain = attributes[:'wafPrimaryDomain'] if attributes[:'wafPrimaryDomain']

  raise 'You cannot provide both :wafPrimaryDomain and :waf_primary_domain' if attributes.key?(:'wafPrimaryDomain') && attributes.key?(:'waf_primary_domain')

  self.waf_primary_domain = attributes[:'waf_primary_domain'] if attributes[:'waf_primary_domain']

  self.instance_license_type = attributes[:'instanceLicenseType'] if attributes[:'instanceLicenseType']

  raise 'You cannot provide both :instanceLicenseType and :instance_license_type' if attributes.key?(:'instanceLicenseType') && attributes.key?(:'instance_license_type')

  self.instance_license_type = attributes[:'instance_license_type'] if attributes[:'instance_license_type']

  self.instance_usage_type = attributes[:'instanceUsageType'] if attributes[:'instanceUsageType']

  raise 'You cannot provide both :instanceUsageType and :instance_usage_type' if attributes.key?(:'instanceUsageType') && attributes.key?(:'instance_usage_type')

  self.instance_usage_type = attributes[:'instance_usage_type'] if attributes[:'instance_usage_type']

  self.add_on_features = attributes[:'addOnFeatures'] if attributes[:'addOnFeatures']

  raise 'You cannot provide both :addOnFeatures and :add_on_features' if attributes.key?(:'addOnFeatures') && attributes.key?(:'add_on_features')

  self.add_on_features = attributes[:'add_on_features'] if attributes[:'add_on_features']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#add_on_featuresArray<String>

a list of add-on features for the ocm instance

Returns:

  • (Array<String>)


40
41
42
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 40

def add_on_features
  @add_on_features
end

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


52
53
54
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 52

def defined_tags
  @defined_tags
end

#descriptionString

OceInstance description

Returns:

  • (String)


24
25
26
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 24

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


46
47
48
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 46

def freeform_tags
  @freeform_tags
end

#instance_license_typeString

Flag indicating whether the instance license is new cloud or bring your own license

Returns:

  • (String)


32
33
34
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 32

def instance_license_type
  @instance_license_type
end

#instance_usage_typeString

Instance type based on its usage

Returns:

  • (String)


36
37
38
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 36

def instance_usage_type
  @instance_usage_type
end

#waf_primary_domainString

Web Application Firewall(WAF) primary domain

Returns:

  • (String)


28
29
30
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 28

def waf_primary_domain
  @waf_primary_domain
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 55

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'waf_primary_domain': :'wafPrimaryDomain',
    'instance_license_type': :'instanceLicenseType',
    'instance_usage_type': :'instanceUsageType',
    'add_on_features': :'addOnFeatures',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 70

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'waf_primary_domain': :'String',
    'instance_license_type': :'String',
    'instance_usage_type': :'String',
    'add_on_features': :'Array<String>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 165

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    waf_primary_domain == other.waf_primary_domain &&
    instance_license_type == other.instance_license_type &&
    instance_usage_type == other.instance_usage_type &&
    add_on_features == other.add_on_features &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 201

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


181
182
183
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 181

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



190
191
192
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 190

def hash
  [description, waf_primary_domain, instance_license_type, instance_usage_type, add_on_features, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



228
229
230
# File 'lib/oci/oce/models/update_oce_instance_details.rb', line 228

def to_s
  to_hash.to_s
end