Class: OCI::Ocvp::Models::CreateEsxiHostDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ocvp/models/create_esxi_host_details.rb

Overview

Details of the ESXi host to add to the SDDC.

Constant Summary collapse

CURRENT_SKU_ENUM =
[
  CURRENT_SKU_HOUR = 'HOUR'.freeze,
  CURRENT_SKU_MONTH = 'MONTH'.freeze,
  CURRENT_SKU_ONE_YEAR = 'ONE_YEAR'.freeze,
  CURRENT_SKU_THREE_YEARS = 'THREE_YEARS'.freeze
].freeze
NEXT_SKU_ENUM =
[
  NEXT_SKU_HOUR = 'HOUR'.freeze,
  NEXT_SKU_MONTH = 'MONTH'.freeze,
  NEXT_SKU_ONE_YEAR = 'ONE_YEAR'.freeze,
  NEXT_SKU_THREE_YEARS = 'THREE_YEARS'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateEsxiHostDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :sddc_id (String)

    The value to assign to the #sddc_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :current_sku (String)

    The value to assign to the #current_sku property

  • :next_sku (String)

    The value to assign to the #next_sku property

  • :compute_availability_domain (String)

    The value to assign to the #compute_availability_domain property

  • :failed_esxi_host_id (String)

    The value to assign to the #failed_esxi_host_id property

  • :host_shape_name (String)

    The value to assign to the #host_shape_name property

  • :host_ocpu_count (Float)

    The value to assign to the #host_ocpu_count property

  • :capacity_reservation_id (String)

    The value to assign to the #capacity_reservation_id property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 158

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.sddc_id = attributes[:'sddcId'] if attributes[:'sddcId']

  raise 'You cannot provide both :sddcId and :sddc_id' if attributes.key?(:'sddcId') && attributes.key?(:'sddc_id')

  self.sddc_id = attributes[:'sddc_id'] if attributes[:'sddc_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.current_sku = attributes[:'currentSku'] if attributes[:'currentSku']
  self.current_sku = "MONTH" if current_sku.nil? && !attributes.key?(:'currentSku') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :currentSku and :current_sku' if attributes.key?(:'currentSku') && attributes.key?(:'current_sku')

  self.current_sku = attributes[:'current_sku'] if attributes[:'current_sku']
  self.current_sku = "MONTH" if current_sku.nil? && !attributes.key?(:'currentSku') && !attributes.key?(:'current_sku') # rubocop:disable Style/StringLiterals

  self.next_sku = attributes[:'nextSku'] if attributes[:'nextSku']

  raise 'You cannot provide both :nextSku and :next_sku' if attributes.key?(:'nextSku') && attributes.key?(:'next_sku')

  self.next_sku = attributes[:'next_sku'] if attributes[:'next_sku']

  self.compute_availability_domain = attributes[:'computeAvailabilityDomain'] if attributes[:'computeAvailabilityDomain']

  raise 'You cannot provide both :computeAvailabilityDomain and :compute_availability_domain' if attributes.key?(:'computeAvailabilityDomain') && attributes.key?(:'compute_availability_domain')

  self.compute_availability_domain = attributes[:'compute_availability_domain'] if attributes[:'compute_availability_domain']

  self.failed_esxi_host_id = attributes[:'failedEsxiHostId'] if attributes[:'failedEsxiHostId']

  raise 'You cannot provide both :failedEsxiHostId and :failed_esxi_host_id' if attributes.key?(:'failedEsxiHostId') && attributes.key?(:'failed_esxi_host_id')

  self.failed_esxi_host_id = attributes[:'failed_esxi_host_id'] if attributes[:'failed_esxi_host_id']

  self.host_shape_name = attributes[:'hostShapeName'] if attributes[:'hostShapeName']

  raise 'You cannot provide both :hostShapeName and :host_shape_name' if attributes.key?(:'hostShapeName') && attributes.key?(:'host_shape_name')

  self.host_shape_name = attributes[:'host_shape_name'] if attributes[:'host_shape_name']

  self.host_ocpu_count = attributes[:'hostOcpuCount'] if attributes[:'hostOcpuCount']

  raise 'You cannot provide both :hostOcpuCount and :host_ocpu_count' if attributes.key?(:'hostOcpuCount') && attributes.key?(:'host_ocpu_count')

  self.host_ocpu_count = attributes[:'host_ocpu_count'] if attributes[:'host_ocpu_count']

  self.capacity_reservation_id = attributes[:'capacityReservationId'] if attributes[:'capacityReservationId']

  raise 'You cannot provide both :capacityReservationId and :capacity_reservation_id' if attributes.key?(:'capacityReservationId') && attributes.key?(:'capacity_reservation_id')

  self.capacity_reservation_id = attributes[:'capacity_reservation_id'] if attributes[:'capacity_reservation_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#capacity_reservation_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Capacity Reservation.

Returns:

  • (String)


85
86
87
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 85

def capacity_reservation_id
  @capacity_reservation_id
end

#compute_availability_domainString

The availability domain to create the ESXi host in. If keep empty, for AD-specific SDDC, new ESXi host will be created in the same availability domain; for multi-AD SDDC, new ESXi host will be auto assigned to the next availability domain following evenly distribution strategy.

Returns:

  • (String)


61
62
63
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 61

def compute_availability_domain
  @compute_availability_domain
end

#current_skuString

The billing option currently used by the ESXi host. list_supported_skus.

Returns:

  • (String)


47
48
49
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 47

def current_sku
  @current_sku
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


101
102
103
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 101

def defined_tags
  @defined_tags
end

#display_nameString

A descriptive name for the ESXi host. It's changeable. Esxi Host name requirements are 1-16 character length limit, Must start with a letter, Must be English letters, numbers, - only, No repeating hyphens, Must be unique within the SDDC.

If this attribute is not specified, the SDDC's `instanceDisplayNamePrefix` attribute is used to name and incrementally number the ESXi host. For example, if you're creating the fourth ESXi host in the SDDC, and `instanceDisplayNamePrefix` is `MySDDC`, the host's display name is `MySDDC-4`.

Avoid entering confidential information.

Returns:

  • (String)


41
42
43
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 41

def display_name
  @display_name
end

#failed_esxi_host_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the ESXi host that is failed. This is an optional parameter. If this parameter is specified, a new ESXi host will be created to replace the failed one, and the `failedEsxiHostId` field will be udpated in the newly created Esxi host.

Returns:

  • (String)


69
70
71
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 69

def failed_esxi_host_id
  @failed_esxi_host_id
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


93
94
95
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 93

def freeform_tags
  @freeform_tags
end

#host_ocpu_countFloat

The OCPU count of the ESXi host.

Returns:

  • (Float)


80
81
82
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 80

def host_ocpu_count
  @host_ocpu_count
end

#host_shape_nameString

The compute shape name of the ESXi host. list_supported_host_shapes.

Returns:

  • (String)


75
76
77
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 75

def host_shape_name
  @host_shape_name
end

#next_skuString

The billing option to switch to after the existing billing cycle ends. If `nextSku` is null or empty, `currentSku` continues to the next billing cycle. list_supported_skus.

Returns:

  • (String)


54
55
56
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 54

def next_sku
  @next_sku
end

#sddc_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the SDDC to add the ESXi host to.

Returns:

  • (String)


28
29
30
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 28

def sddc_id
  @sddc_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 104

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'sddc_id': :'sddcId',
    'display_name': :'displayName',
    'current_sku': :'currentSku',
    'next_sku': :'nextSku',
    'compute_availability_domain': :'computeAvailabilityDomain',
    'failed_esxi_host_id': :'failedEsxiHostId',
    'host_shape_name': :'hostShapeName',
    'host_ocpu_count': :'hostOcpuCount',
    'capacity_reservation_id': :'capacityReservationId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 123

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'sddc_id': :'String',
    'display_name': :'String',
    'current_sku': :'String',
    'next_sku': :'String',
    'compute_availability_domain': :'String',
    'failed_esxi_host_id': :'String',
    'host_shape_name': :'String',
    'host_ocpu_count': :'Float',
    'capacity_reservation_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 256

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    sddc_id == other.sddc_id &&
    display_name == other.display_name &&
    current_sku == other.current_sku &&
    next_sku == other.next_sku &&
    compute_availability_domain == other.compute_availability_domain &&
    failed_esxi_host_id == other.failed_esxi_host_id &&
    host_shape_name == other.host_shape_name &&
    host_ocpu_count == other.host_ocpu_count &&
    capacity_reservation_id == other.capacity_reservation_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 296

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


276
277
278
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 276

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



285
286
287
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 285

def hash
  [sddc_id, display_name, current_sku, next_sku, compute_availability_domain, failed_esxi_host_id, host_shape_name, host_ocpu_count, capacity_reservation_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



329
330
331
332
333
334
335
336
337
338
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 329

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



323
324
325
# File 'lib/oci/ocvp/models/create_esxi_host_details.rb', line 323

def to_s
  to_hash.to_s
end