Class: OCI::Ocvp::Models::CreateSddcDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ocvp/models/create_sddc_details.rb

Overview

Details of the SDDC.

Constant Summary collapse

INITIAL_SKU_ENUM =
[
  INITIAL_SKU_HOUR = 'HOUR'.freeze,
  INITIAL_SKU_MONTH = 'MONTH'.freeze,
  INITIAL_SKU_ONE_YEAR = 'ONE_YEAR'.freeze,
  INITIAL_SKU_THREE_YEARS = 'THREE_YEARS'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateSddcDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 301

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compute_availability_domain = attributes[:'computeAvailabilityDomain'] if attributes[:'computeAvailabilityDomain']

  raise 'You cannot provide both :computeAvailabilityDomain and :compute_availability_domain' if attributes.key?(:'computeAvailabilityDomain') && attributes.key?(:'compute_availability_domain')

  self.compute_availability_domain = attributes[:'compute_availability_domain'] if attributes[:'compute_availability_domain']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.vmware_software_version = attributes[:'vmwareSoftwareVersion'] if attributes[:'vmwareSoftwareVersion']

  raise 'You cannot provide both :vmwareSoftwareVersion and :vmware_software_version' if attributes.key?(:'vmwareSoftwareVersion') && attributes.key?(:'vmware_software_version')

  self.vmware_software_version = attributes[:'vmware_software_version'] if attributes[:'vmware_software_version']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.instance_display_name_prefix = attributes[:'instanceDisplayNamePrefix'] if attributes[:'instanceDisplayNamePrefix']

  raise 'You cannot provide both :instanceDisplayNamePrefix and :instance_display_name_prefix' if attributes.key?(:'instanceDisplayNamePrefix') && attributes.key?(:'instance_display_name_prefix')

  self.instance_display_name_prefix = attributes[:'instance_display_name_prefix'] if attributes[:'instance_display_name_prefix']

  self.esxi_hosts_count = attributes[:'esxiHostsCount'] if attributes[:'esxiHostsCount']

  raise 'You cannot provide both :esxiHostsCount and :esxi_hosts_count' if attributes.key?(:'esxiHostsCount') && attributes.key?(:'esxi_hosts_count')

  self.esxi_hosts_count = attributes[:'esxi_hosts_count'] if attributes[:'esxi_hosts_count']

  self.initial_sku = attributes[:'initialSku'] if attributes[:'initialSku']
  self.initial_sku = "MONTH" if initial_sku.nil? && !attributes.key?(:'initialSku') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :initialSku and :initial_sku' if attributes.key?(:'initialSku') && attributes.key?(:'initial_sku')

  self.initial_sku = attributes[:'initial_sku'] if attributes[:'initial_sku']
  self.initial_sku = "MONTH" if initial_sku.nil? && !attributes.key?(:'initialSku') && !attributes.key?(:'initial_sku') # rubocop:disable Style/StringLiterals

  self.is_hcx_enabled = attributes[:'isHcxEnabled'] unless attributes[:'isHcxEnabled'].nil?
  self.is_hcx_enabled = false if is_hcx_enabled.nil? && !attributes.key?(:'isHcxEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHcxEnabled and :is_hcx_enabled' if attributes.key?(:'isHcxEnabled') && attributes.key?(:'is_hcx_enabled')

  self.is_hcx_enabled = attributes[:'is_hcx_enabled'] unless attributes[:'is_hcx_enabled'].nil?
  self.is_hcx_enabled = false if is_hcx_enabled.nil? && !attributes.key?(:'isHcxEnabled') && !attributes.key?(:'is_hcx_enabled') # rubocop:disable Style/StringLiterals

  self.hcx_vlan_id = attributes[:'hcxVlanId'] if attributes[:'hcxVlanId']

  raise 'You cannot provide both :hcxVlanId and :hcx_vlan_id' if attributes.key?(:'hcxVlanId') && attributes.key?(:'hcx_vlan_id')

  self.hcx_vlan_id = attributes[:'hcx_vlan_id'] if attributes[:'hcx_vlan_id']

  self.is_hcx_enterprise_enabled = attributes[:'isHcxEnterpriseEnabled'] unless attributes[:'isHcxEnterpriseEnabled'].nil?
  self.is_hcx_enterprise_enabled = false if is_hcx_enterprise_enabled.nil? && !attributes.key?(:'isHcxEnterpriseEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHcxEnterpriseEnabled and :is_hcx_enterprise_enabled' if attributes.key?(:'isHcxEnterpriseEnabled') && attributes.key?(:'is_hcx_enterprise_enabled')

  self.is_hcx_enterprise_enabled = attributes[:'is_hcx_enterprise_enabled'] unless attributes[:'is_hcx_enterprise_enabled'].nil?
  self.is_hcx_enterprise_enabled = false if is_hcx_enterprise_enabled.nil? && !attributes.key?(:'isHcxEnterpriseEnabled') && !attributes.key?(:'is_hcx_enterprise_enabled') # rubocop:disable Style/StringLiterals

  self.ssh_authorized_keys = attributes[:'sshAuthorizedKeys'] if attributes[:'sshAuthorizedKeys']

  raise 'You cannot provide both :sshAuthorizedKeys and :ssh_authorized_keys' if attributes.key?(:'sshAuthorizedKeys') && attributes.key?(:'ssh_authorized_keys')

  self.ssh_authorized_keys = attributes[:'ssh_authorized_keys'] if attributes[:'ssh_authorized_keys']

  self.workload_network_cidr = attributes[:'workloadNetworkCidr'] if attributes[:'workloadNetworkCidr']

  raise 'You cannot provide both :workloadNetworkCidr and :workload_network_cidr' if attributes.key?(:'workloadNetworkCidr') && attributes.key?(:'workload_network_cidr')

  self.workload_network_cidr = attributes[:'workload_network_cidr'] if attributes[:'workload_network_cidr']

  self.provisioning_subnet_id = attributes[:'provisioningSubnetId'] if attributes[:'provisioningSubnetId']

  raise 'You cannot provide both :provisioningSubnetId and :provisioning_subnet_id' if attributes.key?(:'provisioningSubnetId') && attributes.key?(:'provisioning_subnet_id')

  self.provisioning_subnet_id = attributes[:'provisioning_subnet_id'] if attributes[:'provisioning_subnet_id']

  self.vsphere_vlan_id = attributes[:'vsphereVlanId'] if attributes[:'vsphereVlanId']

  raise 'You cannot provide both :vsphereVlanId and :vsphere_vlan_id' if attributes.key?(:'vsphereVlanId') && attributes.key?(:'vsphere_vlan_id')

  self.vsphere_vlan_id = attributes[:'vsphere_vlan_id'] if attributes[:'vsphere_vlan_id']

  self.vmotion_vlan_id = attributes[:'vmotionVlanId'] if attributes[:'vmotionVlanId']

  raise 'You cannot provide both :vmotionVlanId and :vmotion_vlan_id' if attributes.key?(:'vmotionVlanId') && attributes.key?(:'vmotion_vlan_id')

  self.vmotion_vlan_id = attributes[:'vmotion_vlan_id'] if attributes[:'vmotion_vlan_id']

  self.vsan_vlan_id = attributes[:'vsanVlanId'] if attributes[:'vsanVlanId']

  raise 'You cannot provide both :vsanVlanId and :vsan_vlan_id' if attributes.key?(:'vsanVlanId') && attributes.key?(:'vsan_vlan_id')

  self.vsan_vlan_id = attributes[:'vsan_vlan_id'] if attributes[:'vsan_vlan_id']

  self.nsx_v_tep_vlan_id = attributes[:'nsxVTepVlanId'] if attributes[:'nsxVTepVlanId']

  raise 'You cannot provide both :nsxVTepVlanId and :nsx_v_tep_vlan_id' if attributes.key?(:'nsxVTepVlanId') && attributes.key?(:'nsx_v_tep_vlan_id')

  self.nsx_v_tep_vlan_id = attributes[:'nsx_v_tep_vlan_id'] if attributes[:'nsx_v_tep_vlan_id']

  self.nsx_edge_v_tep_vlan_id = attributes[:'nsxEdgeVTepVlanId'] if attributes[:'nsxEdgeVTepVlanId']

  raise 'You cannot provide both :nsxEdgeVTepVlanId and :nsx_edge_v_tep_vlan_id' if attributes.key?(:'nsxEdgeVTepVlanId') && attributes.key?(:'nsx_edge_v_tep_vlan_id')

  self.nsx_edge_v_tep_vlan_id = attributes[:'nsx_edge_v_tep_vlan_id'] if attributes[:'nsx_edge_v_tep_vlan_id']

  self.nsx_edge_uplink1_vlan_id = attributes[:'nsxEdgeUplink1VlanId'] if attributes[:'nsxEdgeUplink1VlanId']

  raise 'You cannot provide both :nsxEdgeUplink1VlanId and :nsx_edge_uplink1_vlan_id' if attributes.key?(:'nsxEdgeUplink1VlanId') && attributes.key?(:'nsx_edge_uplink1_vlan_id')

  self.nsx_edge_uplink1_vlan_id = attributes[:'nsx_edge_uplink1_vlan_id'] if attributes[:'nsx_edge_uplink1_vlan_id']

  self.nsx_edge_uplink2_vlan_id = attributes[:'nsxEdgeUplink2VlanId'] if attributes[:'nsxEdgeUplink2VlanId']

  raise 'You cannot provide both :nsxEdgeUplink2VlanId and :nsx_edge_uplink2_vlan_id' if attributes.key?(:'nsxEdgeUplink2VlanId') && attributes.key?(:'nsx_edge_uplink2_vlan_id')

  self.nsx_edge_uplink2_vlan_id = attributes[:'nsx_edge_uplink2_vlan_id'] if attributes[:'nsx_edge_uplink2_vlan_id']

  self.replication_vlan_id = attributes[:'replicationVlanId'] if attributes[:'replicationVlanId']

  raise 'You cannot provide both :replicationVlanId and :replication_vlan_id' if attributes.key?(:'replicationVlanId') && attributes.key?(:'replication_vlan_id')

  self.replication_vlan_id = attributes[:'replication_vlan_id'] if attributes[:'replication_vlan_id']

  self.provisioning_vlan_id = attributes[:'provisioningVlanId'] if attributes[:'provisioningVlanId']

  raise 'You cannot provide both :provisioningVlanId and :provisioning_vlan_id' if attributes.key?(:'provisioningVlanId') && attributes.key?(:'provisioning_vlan_id')

  self.provisioning_vlan_id = attributes[:'provisioning_vlan_id'] if attributes[:'provisioning_vlan_id']

  self.initial_host_shape_name = attributes[:'initialHostShapeName'] if attributes[:'initialHostShapeName']
  self.initial_host_shape_name = "BM.DenseIO2.52" if initial_host_shape_name.nil? && !attributes.key?(:'initialHostShapeName') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :initialHostShapeName and :initial_host_shape_name' if attributes.key?(:'initialHostShapeName') && attributes.key?(:'initial_host_shape_name')

  self.initial_host_shape_name = attributes[:'initial_host_shape_name'] if attributes[:'initial_host_shape_name']
  self.initial_host_shape_name = "BM.DenseIO2.52" if initial_host_shape_name.nil? && !attributes.key?(:'initialHostShapeName') && !attributes.key?(:'initial_host_shape_name') # rubocop:disable Style/StringLiterals

  self.initial_host_ocpu_count = attributes[:'initialHostOcpuCount'] if attributes[:'initialHostOcpuCount']

  raise 'You cannot provide both :initialHostOcpuCount and :initial_host_ocpu_count' if attributes.key?(:'initialHostOcpuCount') && attributes.key?(:'initial_host_ocpu_count')

  self.initial_host_ocpu_count = attributes[:'initial_host_ocpu_count'] if attributes[:'initial_host_ocpu_count']

  self.is_shielded_instance_enabled = attributes[:'isShieldedInstanceEnabled'] unless attributes[:'isShieldedInstanceEnabled'].nil?
  self.is_shielded_instance_enabled = false if is_shielded_instance_enabled.nil? && !attributes.key?(:'isShieldedInstanceEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isShieldedInstanceEnabled and :is_shielded_instance_enabled' if attributes.key?(:'isShieldedInstanceEnabled') && attributes.key?(:'is_shielded_instance_enabled')

  self.is_shielded_instance_enabled = attributes[:'is_shielded_instance_enabled'] unless attributes[:'is_shielded_instance_enabled'].nil?
  self.is_shielded_instance_enabled = false if is_shielded_instance_enabled.nil? && !attributes.key?(:'isShieldedInstanceEnabled') && !attributes.key?(:'is_shielded_instance_enabled') # rubocop:disable Style/StringLiterals

  self.capacity_reservation_id = attributes[:'capacityReservationId'] if attributes[:'capacityReservationId']

  raise 'You cannot provide both :capacityReservationId and :capacity_reservation_id' if attributes.key?(:'capacityReservationId') && attributes.key?(:'capacity_reservation_id')

  self.capacity_reservation_id = attributes[:'capacity_reservation_id'] if attributes[:'capacity_reservation_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#capacity_reservation_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Capacity Reservation.

Returns:

  • (String)


177
178
179
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 177

def capacity_reservation_id
  @capacity_reservation_id
end

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment to contain the SDDC.

Returns:

  • (String)


39
40
41
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 39

def compartment_id
  @compartment_id
end

#compute_availability_domainString

**[Required]** The availability domain to create the SDDC's ESXi hosts in. For multi-AD SDDC deployment, set to `multi-AD`.

Returns:

  • (String)


20
21
22
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 20

def compute_availability_domain
  @compute_availability_domain
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


193
194
195
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 193

def defined_tags
  @defined_tags
end

#display_nameString

A descriptive name for the SDDC. SDDC name requirements are 1-16 character length limit, Must start with a letter, Must be English letters, numbers, - only, No repeating hyphens, Must be unique within the region. Avoid entering confidential information.

Returns:

  • (String)


27
28
29
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 27

def display_name
  @display_name
end

#esxi_hosts_countInteger

**[Required]** The number of ESXi hosts to create in the SDDC. You can add more hosts later (see create_esxi_host).

*Note:* If you later delete EXSi hosts from the SDDC to total less than 3, you are still billed for the 3 minimum recommended ESXi hosts. Also, you cannot add more VMware workloads to the SDDC until it again has at least 3 ESXi hosts.

Returns:

  • (Integer)


59
60
61
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 59

def esxi_hosts_count
  @esxi_hosts_count
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


185
186
187
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 185

def freeform_tags
  @freeform_tags
end

#hcx_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the HCX component of the VMware environment. This value is required only when `isHcxEnabled` is true.

Returns:

  • (String)


76
77
78
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 76

def hcx_vlan_id
  @hcx_vlan_id
end

#initial_host_ocpu_countFloat

The initial OCPU count of the SDDC's ESXi hosts.

Returns:

  • (Float)


167
168
169
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 167

def initial_host_ocpu_count
  @initial_host_ocpu_count
end

#initial_host_shape_nameString

The initial compute shape of the SDDC's ESXi hosts. list_supported_host_shapes.

Returns:

  • (String)


162
163
164
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 162

def initial_host_shape_name
  @initial_host_shape_name
end

#initial_skuString

The billing option selected during SDDC creation. list_supported_skus.

Returns:

  • (String)


65
66
67
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 65

def initial_sku
  @initial_sku
end

#instance_display_name_prefixString

A prefix used in the name of each ESXi host and Compute instance in the SDDC. If this isn't set, the SDDC's `displayName` is used as the prefix.

For example, if the value is `mySDDC`, the ESXi hosts are named `mySDDC-1`, `mySDDC-2`, and so on.

Returns:

  • (String)


48
49
50
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 48

def instance_display_name_prefix
  @instance_display_name_prefix
end

#is_hcx_enabledBOOLEAN

Indicates whether to enable HCX for this SDDC.

Returns:

  • (BOOLEAN)


70
71
72
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 70

def is_hcx_enabled
  @is_hcx_enabled
end

#is_hcx_enterprise_enabledBOOLEAN

Indicates whether to enable HCX Enterprise for this SDDC.

Returns:

  • (BOOLEAN)


81
82
83
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 81

def is_hcx_enterprise_enabled
  @is_hcx_enterprise_enabled
end

#is_shielded_instance_enabledBOOLEAN

Indicates whether shielded instance is enabled for this SDDC.

Returns:

  • (BOOLEAN)


172
173
174
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 172

def is_shielded_instance_enabled
  @is_shielded_instance_enabled
end

#nsx_edge_uplink1_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the NSX Edge Uplink 1 component of the VMware environment.

Returns:

  • (String)


136
137
138
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 136

def nsx_edge_uplink1_vlan_id
  @nsx_edge_uplink1_vlan_id
end

#nsx_edge_uplink2_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the NSX Edge Uplink 2 component of the VMware environment.

*Note:* This VLAN is reserved for future use to deploy public-facing applications on the VMware SDDC.

Returns:

  • (String)


144
145
146
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 144

def nsx_edge_uplink2_vlan_id
  @nsx_edge_uplink2_vlan_id
end

#nsx_edge_v_tep_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the NSX Edge VTEP component of the VMware environment.

Returns:

  • (String)


130
131
132
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 130

def nsx_edge_v_tep_vlan_id
  @nsx_edge_v_tep_vlan_id
end

#nsx_v_tep_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the NSX VTEP component of the VMware environment.

Returns:

  • (String)


124
125
126
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 124

def nsx_v_tep_vlan_id
  @nsx_v_tep_vlan_id
end

#provisioning_subnet_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the management subnet to use for provisioning the SDDC.

Returns:

  • (String)


100
101
102
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 100

def provisioning_subnet_id
  @provisioning_subnet_id
end

#provisioning_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the Provisioning component of the VMware environment.

Returns:

  • (String)


156
157
158
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 156

def provisioning_vlan_id
  @provisioning_vlan_id
end

#replication_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the vSphere Replication component of the VMware environment.

Returns:

  • (String)


150
151
152
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 150

def replication_vlan_id
  @replication_vlan_id
end

#ssh_authorized_keysString

**[Required]** One or more public SSH keys to be included in the `~/.ssh/authorized_keys` file for the default user on each ESXi host. Use a newline character to separate multiple keys. The SSH keys must be in the format required for the `authorized_keys` file

Returns:

  • (String)


88
89
90
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 88

def ssh_authorized_keys
  @ssh_authorized_keys
end

#vmotion_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the vMotion component of the VMware environment.

Returns:

  • (String)


112
113
114
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 112

def vmotion_vlan_id
  @vmotion_vlan_id
end

#vmware_software_versionString

**[Required]** The VMware software bundle to install on the ESXi hosts in the SDDC. To get a list of the available versions, use list_supported_vmware_software_versions.

Returns:

  • (String)


34
35
36
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 34

def vmware_software_version
  @vmware_software_version
end

#vsan_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the vSAN component of the VMware environment.

Returns:

  • (String)


118
119
120
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 118

def vsan_vlan_id
  @vsan_vlan_id
end

#vsphere_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the vSphere component of the VMware environment.

Returns:

  • (String)


106
107
108
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 106

def vsphere_vlan_id
  @vsphere_vlan_id
end

#workload_network_cidrString

The CIDR block for the IP addresses that VMware VMs in the SDDC use to run application workloads.

Returns:

  • (String)


94
95
96
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 94

def workload_network_cidr
  @workload_network_cidr
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 196

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compute_availability_domain': :'computeAvailabilityDomain',
    'display_name': :'displayName',
    'vmware_software_version': :'vmwareSoftwareVersion',
    'compartment_id': :'compartmentId',
    'instance_display_name_prefix': :'instanceDisplayNamePrefix',
    'esxi_hosts_count': :'esxiHostsCount',
    'initial_sku': :'initialSku',
    'is_hcx_enabled': :'isHcxEnabled',
    'hcx_vlan_id': :'hcxVlanId',
    'is_hcx_enterprise_enabled': :'isHcxEnterpriseEnabled',
    'ssh_authorized_keys': :'sshAuthorizedKeys',
    'workload_network_cidr': :'workloadNetworkCidr',
    'provisioning_subnet_id': :'provisioningSubnetId',
    'vsphere_vlan_id': :'vsphereVlanId',
    'vmotion_vlan_id': :'vmotionVlanId',
    'vsan_vlan_id': :'vsanVlanId',
    'nsx_v_tep_vlan_id': :'nsxVTepVlanId',
    'nsx_edge_v_tep_vlan_id': :'nsxEdgeVTepVlanId',
    'nsx_edge_uplink1_vlan_id': :'nsxEdgeUplink1VlanId',
    'nsx_edge_uplink2_vlan_id': :'nsxEdgeUplink2VlanId',
    'replication_vlan_id': :'replicationVlanId',
    'provisioning_vlan_id': :'provisioningVlanId',
    'initial_host_shape_name': :'initialHostShapeName',
    'initial_host_ocpu_count': :'initialHostOcpuCount',
    'is_shielded_instance_enabled': :'isShieldedInstanceEnabled',
    'capacity_reservation_id': :'capacityReservationId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 232

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compute_availability_domain': :'String',
    'display_name': :'String',
    'vmware_software_version': :'String',
    'compartment_id': :'String',
    'instance_display_name_prefix': :'String',
    'esxi_hosts_count': :'Integer',
    'initial_sku': :'String',
    'is_hcx_enabled': :'BOOLEAN',
    'hcx_vlan_id': :'String',
    'is_hcx_enterprise_enabled': :'BOOLEAN',
    'ssh_authorized_keys': :'String',
    'workload_network_cidr': :'String',
    'provisioning_subnet_id': :'String',
    'vsphere_vlan_id': :'String',
    'vmotion_vlan_id': :'String',
    'vsan_vlan_id': :'String',
    'nsx_v_tep_vlan_id': :'String',
    'nsx_edge_v_tep_vlan_id': :'String',
    'nsx_edge_uplink1_vlan_id': :'String',
    'nsx_edge_uplink2_vlan_id': :'String',
    'replication_vlan_id': :'String',
    'provisioning_vlan_id': :'String',
    'initial_host_shape_name': :'String',
    'initial_host_ocpu_count': :'Float',
    'is_shielded_instance_enabled': :'BOOLEAN',
    'capacity_reservation_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 501

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compute_availability_domain == other.compute_availability_domain &&
    display_name == other.display_name &&
    vmware_software_version == other.vmware_software_version &&
    compartment_id == other.compartment_id &&
    instance_display_name_prefix == other.instance_display_name_prefix &&
    esxi_hosts_count == other.esxi_hosts_count &&
    initial_sku == other.initial_sku &&
    is_hcx_enabled == other.is_hcx_enabled &&
    hcx_vlan_id == other.hcx_vlan_id &&
    is_hcx_enterprise_enabled == other.is_hcx_enterprise_enabled &&
    ssh_authorized_keys == other.ssh_authorized_keys &&
    workload_network_cidr == other.workload_network_cidr &&
    provisioning_subnet_id == other.provisioning_subnet_id &&
    vsphere_vlan_id == other.vsphere_vlan_id &&
    vmotion_vlan_id == other.vmotion_vlan_id &&
    vsan_vlan_id == other.vsan_vlan_id &&
    nsx_v_tep_vlan_id == other.nsx_v_tep_vlan_id &&
    nsx_edge_v_tep_vlan_id == other.nsx_edge_v_tep_vlan_id &&
    nsx_edge_uplink1_vlan_id == other.nsx_edge_uplink1_vlan_id &&
    nsx_edge_uplink2_vlan_id == other.nsx_edge_uplink2_vlan_id &&
    replication_vlan_id == other.replication_vlan_id &&
    provisioning_vlan_id == other.provisioning_vlan_id &&
    initial_host_shape_name == other.initial_host_shape_name &&
    initial_host_ocpu_count == other.initial_host_ocpu_count &&
    is_shielded_instance_enabled == other.is_shielded_instance_enabled &&
    capacity_reservation_id == other.capacity_reservation_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 558

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


538
539
540
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 538

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



547
548
549
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 547

def hash
  [compute_availability_domain, display_name, vmware_software_version, compartment_id, instance_display_name_prefix, esxi_hosts_count, initial_sku, is_hcx_enabled, hcx_vlan_id, is_hcx_enterprise_enabled, ssh_authorized_keys, workload_network_cidr, provisioning_subnet_id, vsphere_vlan_id, vmotion_vlan_id, vsan_vlan_id, nsx_v_tep_vlan_id, nsx_edge_v_tep_vlan_id, nsx_edge_uplink1_vlan_id, nsx_edge_uplink2_vlan_id, replication_vlan_id, provisioning_vlan_id, initial_host_shape_name, initial_host_ocpu_count, is_shielded_instance_enabled, capacity_reservation_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



591
592
593
594
595
596
597
598
599
600
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 591

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



585
586
587
# File 'lib/oci/ocvp/models/create_sddc_details.rb', line 585

def to_s
  to_hash.to_s
end