Class: OCI::Ocvp::Models::Sddc

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ocvp/models/sddc.rb

Overview

An [Oracle Cloud VMware Solution](docs.cloud.oracle.com/iaas/Content/VMware/Concepts/ocvsoverview.htm) software-defined data center (SDDC) contains the resources required for a functional VMware environment. Instances in an SDDC (see EsxiHost) run in a virtual cloud network (VCN) and are preconfigured with VMware and storage. Use the vCenter utility to manage and deploy VMware virtual machines (VMs) in the SDDC.

The SDDC uses a single management subnet for provisioning the SDDC. It also uses a set of VLANs for various components of the VMware environment (vSphere, vMotion, vSAN, and so on). See the Core Services API for information about VCN subnets and VLANs.

Constant Summary collapse

INITIAL_SKU_ENUM =
[
  INITIAL_SKU_HOUR = 'HOUR'.freeze,
  INITIAL_SKU_MONTH = 'MONTH'.freeze,
  INITIAL_SKU_ONE_YEAR = 'ONE_YEAR'.freeze,
  INITIAL_SKU_THREE_YEARS = 'THREE_YEARS'.freeze,
  INITIAL_SKU_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Sddc

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
# File 'lib/oci/ocvp/models/sddc.rb', line 629

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compute_availability_domain = attributes[:'computeAvailabilityDomain'] if attributes[:'computeAvailabilityDomain']

  raise 'You cannot provide both :computeAvailabilityDomain and :compute_availability_domain' if attributes.key?(:'computeAvailabilityDomain') && attributes.key?(:'compute_availability_domain')

  self.compute_availability_domain = attributes[:'compute_availability_domain'] if attributes[:'compute_availability_domain']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.instance_display_name_prefix = attributes[:'instanceDisplayNamePrefix'] if attributes[:'instanceDisplayNamePrefix']

  raise 'You cannot provide both :instanceDisplayNamePrefix and :instance_display_name_prefix' if attributes.key?(:'instanceDisplayNamePrefix') && attributes.key?(:'instance_display_name_prefix')

  self.instance_display_name_prefix = attributes[:'instance_display_name_prefix'] if attributes[:'instance_display_name_prefix']

  self.vmware_software_version = attributes[:'vmwareSoftwareVersion'] if attributes[:'vmwareSoftwareVersion']

  raise 'You cannot provide both :vmwareSoftwareVersion and :vmware_software_version' if attributes.key?(:'vmwareSoftwareVersion') && attributes.key?(:'vmware_software_version')

  self.vmware_software_version = attributes[:'vmware_software_version'] if attributes[:'vmware_software_version']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.esxi_hosts_count = attributes[:'esxiHostsCount'] if attributes[:'esxiHostsCount']

  raise 'You cannot provide both :esxiHostsCount and :esxi_hosts_count' if attributes.key?(:'esxiHostsCount') && attributes.key?(:'esxi_hosts_count')

  self.esxi_hosts_count = attributes[:'esxi_hosts_count'] if attributes[:'esxi_hosts_count']

  self.initial_sku = attributes[:'initialSku'] if attributes[:'initialSku']
  self.initial_sku = "MONTH" if initial_sku.nil? && !attributes.key?(:'initialSku') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :initialSku and :initial_sku' if attributes.key?(:'initialSku') && attributes.key?(:'initial_sku')

  self.initial_sku = attributes[:'initial_sku'] if attributes[:'initial_sku']
  self.initial_sku = "MONTH" if initial_sku.nil? && !attributes.key?(:'initialSku') && !attributes.key?(:'initial_sku') # rubocop:disable Style/StringLiterals

  self.vcenter_fqdn = attributes[:'vcenterFqdn'] if attributes[:'vcenterFqdn']

  raise 'You cannot provide both :vcenterFqdn and :vcenter_fqdn' if attributes.key?(:'vcenterFqdn') && attributes.key?(:'vcenter_fqdn')

  self.vcenter_fqdn = attributes[:'vcenter_fqdn'] if attributes[:'vcenter_fqdn']

  self.nsx_manager_fqdn = attributes[:'nsxManagerFqdn'] if attributes[:'nsxManagerFqdn']

  raise 'You cannot provide both :nsxManagerFqdn and :nsx_manager_fqdn' if attributes.key?(:'nsxManagerFqdn') && attributes.key?(:'nsx_manager_fqdn')

  self.nsx_manager_fqdn = attributes[:'nsx_manager_fqdn'] if attributes[:'nsx_manager_fqdn']

  self.vcenter_private_ip_id = attributes[:'vcenterPrivateIpId'] if attributes[:'vcenterPrivateIpId']

  raise 'You cannot provide both :vcenterPrivateIpId and :vcenter_private_ip_id' if attributes.key?(:'vcenterPrivateIpId') && attributes.key?(:'vcenter_private_ip_id')

  self.vcenter_private_ip_id = attributes[:'vcenter_private_ip_id'] if attributes[:'vcenter_private_ip_id']

  self.nsx_manager_private_ip_id = attributes[:'nsxManagerPrivateIpId'] if attributes[:'nsxManagerPrivateIpId']

  raise 'You cannot provide both :nsxManagerPrivateIpId and :nsx_manager_private_ip_id' if attributes.key?(:'nsxManagerPrivateIpId') && attributes.key?(:'nsx_manager_private_ip_id')

  self.nsx_manager_private_ip_id = attributes[:'nsx_manager_private_ip_id'] if attributes[:'nsx_manager_private_ip_id']

  self.vcenter_initial_password = attributes[:'vcenterInitialPassword'] if attributes[:'vcenterInitialPassword']

  raise 'You cannot provide both :vcenterInitialPassword and :vcenter_initial_password' if attributes.key?(:'vcenterInitialPassword') && attributes.key?(:'vcenter_initial_password')

  self.vcenter_initial_password = attributes[:'vcenter_initial_password'] if attributes[:'vcenter_initial_password']

  self.nsx_manager_initial_password = attributes[:'nsxManagerInitialPassword'] if attributes[:'nsxManagerInitialPassword']

  raise 'You cannot provide both :nsxManagerInitialPassword and :nsx_manager_initial_password' if attributes.key?(:'nsxManagerInitialPassword') && attributes.key?(:'nsx_manager_initial_password')

  self.nsx_manager_initial_password = attributes[:'nsx_manager_initial_password'] if attributes[:'nsx_manager_initial_password']

  self.vcenter_username = attributes[:'vcenterUsername'] if attributes[:'vcenterUsername']

  raise 'You cannot provide both :vcenterUsername and :vcenter_username' if attributes.key?(:'vcenterUsername') && attributes.key?(:'vcenter_username')

  self.vcenter_username = attributes[:'vcenter_username'] if attributes[:'vcenter_username']

  self.nsx_manager_username = attributes[:'nsxManagerUsername'] if attributes[:'nsxManagerUsername']

  raise 'You cannot provide both :nsxManagerUsername and :nsx_manager_username' if attributes.key?(:'nsxManagerUsername') && attributes.key?(:'nsx_manager_username')

  self.nsx_manager_username = attributes[:'nsx_manager_username'] if attributes[:'nsx_manager_username']

  self.ssh_authorized_keys = attributes[:'sshAuthorizedKeys'] if attributes[:'sshAuthorizedKeys']

  raise 'You cannot provide both :sshAuthorizedKeys and :ssh_authorized_keys' if attributes.key?(:'sshAuthorizedKeys') && attributes.key?(:'ssh_authorized_keys')

  self.ssh_authorized_keys = attributes[:'ssh_authorized_keys'] if attributes[:'ssh_authorized_keys']

  self.workload_network_cidr = attributes[:'workloadNetworkCidr'] if attributes[:'workloadNetworkCidr']

  raise 'You cannot provide both :workloadNetworkCidr and :workload_network_cidr' if attributes.key?(:'workloadNetworkCidr') && attributes.key?(:'workload_network_cidr')

  self.workload_network_cidr = attributes[:'workload_network_cidr'] if attributes[:'workload_network_cidr']

  self.nsx_overlay_segment_name = attributes[:'nsxOverlaySegmentName'] if attributes[:'nsxOverlaySegmentName']

  raise 'You cannot provide both :nsxOverlaySegmentName and :nsx_overlay_segment_name' if attributes.key?(:'nsxOverlaySegmentName') && attributes.key?(:'nsx_overlay_segment_name')

  self.nsx_overlay_segment_name = attributes[:'nsx_overlay_segment_name'] if attributes[:'nsx_overlay_segment_name']

  self.nsx_edge_uplink_ip_id = attributes[:'nsxEdgeUplinkIpId'] if attributes[:'nsxEdgeUplinkIpId']

  raise 'You cannot provide both :nsxEdgeUplinkIpId and :nsx_edge_uplink_ip_id' if attributes.key?(:'nsxEdgeUplinkIpId') && attributes.key?(:'nsx_edge_uplink_ip_id')

  self.nsx_edge_uplink_ip_id = attributes[:'nsx_edge_uplink_ip_id'] if attributes[:'nsx_edge_uplink_ip_id']

  self.provisioning_subnet_id = attributes[:'provisioningSubnetId'] if attributes[:'provisioningSubnetId']

  raise 'You cannot provide both :provisioningSubnetId and :provisioning_subnet_id' if attributes.key?(:'provisioningSubnetId') && attributes.key?(:'provisioning_subnet_id')

  self.provisioning_subnet_id = attributes[:'provisioning_subnet_id'] if attributes[:'provisioning_subnet_id']

  self.vsphere_vlan_id = attributes[:'vsphereVlanId'] if attributes[:'vsphereVlanId']

  raise 'You cannot provide both :vsphereVlanId and :vsphere_vlan_id' if attributes.key?(:'vsphereVlanId') && attributes.key?(:'vsphere_vlan_id')

  self.vsphere_vlan_id = attributes[:'vsphere_vlan_id'] if attributes[:'vsphere_vlan_id']

  self.vmotion_vlan_id = attributes[:'vmotionVlanId'] if attributes[:'vmotionVlanId']

  raise 'You cannot provide both :vmotionVlanId and :vmotion_vlan_id' if attributes.key?(:'vmotionVlanId') && attributes.key?(:'vmotion_vlan_id')

  self.vmotion_vlan_id = attributes[:'vmotion_vlan_id'] if attributes[:'vmotion_vlan_id']

  self.vsan_vlan_id = attributes[:'vsanVlanId'] if attributes[:'vsanVlanId']

  raise 'You cannot provide both :vsanVlanId and :vsan_vlan_id' if attributes.key?(:'vsanVlanId') && attributes.key?(:'vsan_vlan_id')

  self.vsan_vlan_id = attributes[:'vsan_vlan_id'] if attributes[:'vsan_vlan_id']

  self.nsx_v_tep_vlan_id = attributes[:'nsxVTepVlanId'] if attributes[:'nsxVTepVlanId']

  raise 'You cannot provide both :nsxVTepVlanId and :nsx_v_tep_vlan_id' if attributes.key?(:'nsxVTepVlanId') && attributes.key?(:'nsx_v_tep_vlan_id')

  self.nsx_v_tep_vlan_id = attributes[:'nsx_v_tep_vlan_id'] if attributes[:'nsx_v_tep_vlan_id']

  self.nsx_edge_v_tep_vlan_id = attributes[:'nsxEdgeVTepVlanId'] if attributes[:'nsxEdgeVTepVlanId']

  raise 'You cannot provide both :nsxEdgeVTepVlanId and :nsx_edge_v_tep_vlan_id' if attributes.key?(:'nsxEdgeVTepVlanId') && attributes.key?(:'nsx_edge_v_tep_vlan_id')

  self.nsx_edge_v_tep_vlan_id = attributes[:'nsx_edge_v_tep_vlan_id'] if attributes[:'nsx_edge_v_tep_vlan_id']

  self.nsx_edge_uplink1_vlan_id = attributes[:'nsxEdgeUplink1VlanId'] if attributes[:'nsxEdgeUplink1VlanId']

  raise 'You cannot provide both :nsxEdgeUplink1VlanId and :nsx_edge_uplink1_vlan_id' if attributes.key?(:'nsxEdgeUplink1VlanId') && attributes.key?(:'nsx_edge_uplink1_vlan_id')

  self.nsx_edge_uplink1_vlan_id = attributes[:'nsx_edge_uplink1_vlan_id'] if attributes[:'nsx_edge_uplink1_vlan_id']

  self.nsx_edge_uplink2_vlan_id = attributes[:'nsxEdgeUplink2VlanId'] if attributes[:'nsxEdgeUplink2VlanId']

  raise 'You cannot provide both :nsxEdgeUplink2VlanId and :nsx_edge_uplink2_vlan_id' if attributes.key?(:'nsxEdgeUplink2VlanId') && attributes.key?(:'nsx_edge_uplink2_vlan_id')

  self.nsx_edge_uplink2_vlan_id = attributes[:'nsx_edge_uplink2_vlan_id'] if attributes[:'nsx_edge_uplink2_vlan_id']

  self.replication_vlan_id = attributes[:'replicationVlanId'] if attributes[:'replicationVlanId']

  raise 'You cannot provide both :replicationVlanId and :replication_vlan_id' if attributes.key?(:'replicationVlanId') && attributes.key?(:'replication_vlan_id')

  self.replication_vlan_id = attributes[:'replication_vlan_id'] if attributes[:'replication_vlan_id']

  self.provisioning_vlan_id = attributes[:'provisioningVlanId'] if attributes[:'provisioningVlanId']

  raise 'You cannot provide both :provisioningVlanId and :provisioning_vlan_id' if attributes.key?(:'provisioningVlanId') && attributes.key?(:'provisioning_vlan_id')

  self.provisioning_vlan_id = attributes[:'provisioning_vlan_id'] if attributes[:'provisioning_vlan_id']

  self.hcx_private_ip_id = attributes[:'hcxPrivateIpId'] if attributes[:'hcxPrivateIpId']

  raise 'You cannot provide both :hcxPrivateIpId and :hcx_private_ip_id' if attributes.key?(:'hcxPrivateIpId') && attributes.key?(:'hcx_private_ip_id')

  self.hcx_private_ip_id = attributes[:'hcx_private_ip_id'] if attributes[:'hcx_private_ip_id']

  self.hcx_fqdn = attributes[:'hcxFqdn'] if attributes[:'hcxFqdn']

  raise 'You cannot provide both :hcxFqdn and :hcx_fqdn' if attributes.key?(:'hcxFqdn') && attributes.key?(:'hcx_fqdn')

  self.hcx_fqdn = attributes[:'hcx_fqdn'] if attributes[:'hcx_fqdn']

  self.hcx_initial_password = attributes[:'hcxInitialPassword'] if attributes[:'hcxInitialPassword']

  raise 'You cannot provide both :hcxInitialPassword and :hcx_initial_password' if attributes.key?(:'hcxInitialPassword') && attributes.key?(:'hcx_initial_password')

  self.hcx_initial_password = attributes[:'hcx_initial_password'] if attributes[:'hcx_initial_password']

  self.hcx_vlan_id = attributes[:'hcxVlanId'] if attributes[:'hcxVlanId']

  raise 'You cannot provide both :hcxVlanId and :hcx_vlan_id' if attributes.key?(:'hcxVlanId') && attributes.key?(:'hcx_vlan_id')

  self.hcx_vlan_id = attributes[:'hcx_vlan_id'] if attributes[:'hcx_vlan_id']

  self.is_hcx_enabled = attributes[:'isHcxEnabled'] unless attributes[:'isHcxEnabled'].nil?

  raise 'You cannot provide both :isHcxEnabled and :is_hcx_enabled' if attributes.key?(:'isHcxEnabled') && attributes.key?(:'is_hcx_enabled')

  self.is_hcx_enabled = attributes[:'is_hcx_enabled'] unless attributes[:'is_hcx_enabled'].nil?

  self.hcx_on_prem_key = attributes[:'hcxOnPremKey'] if attributes[:'hcxOnPremKey']

  raise 'You cannot provide both :hcxOnPremKey and :hcx_on_prem_key' if attributes.key?(:'hcxOnPremKey') && attributes.key?(:'hcx_on_prem_key')

  self.hcx_on_prem_key = attributes[:'hcx_on_prem_key'] if attributes[:'hcx_on_prem_key']

  self.is_hcx_enterprise_enabled = attributes[:'isHcxEnterpriseEnabled'] unless attributes[:'isHcxEnterpriseEnabled'].nil?
  self.is_hcx_enterprise_enabled = false if is_hcx_enterprise_enabled.nil? && !attributes.key?(:'isHcxEnterpriseEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHcxEnterpriseEnabled and :is_hcx_enterprise_enabled' if attributes.key?(:'isHcxEnterpriseEnabled') && attributes.key?(:'is_hcx_enterprise_enabled')

  self.is_hcx_enterprise_enabled = attributes[:'is_hcx_enterprise_enabled'] unless attributes[:'is_hcx_enterprise_enabled'].nil?
  self.is_hcx_enterprise_enabled = false if is_hcx_enterprise_enabled.nil? && !attributes.key?(:'isHcxEnterpriseEnabled') && !attributes.key?(:'is_hcx_enterprise_enabled') # rubocop:disable Style/StringLiterals

  self.is_hcx_pending_downgrade = attributes[:'isHcxPendingDowngrade'] unless attributes[:'isHcxPendingDowngrade'].nil?
  self.is_hcx_pending_downgrade = false if is_hcx_pending_downgrade.nil? && !attributes.key?(:'isHcxPendingDowngrade') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHcxPendingDowngrade and :is_hcx_pending_downgrade' if attributes.key?(:'isHcxPendingDowngrade') && attributes.key?(:'is_hcx_pending_downgrade')

  self.is_hcx_pending_downgrade = attributes[:'is_hcx_pending_downgrade'] unless attributes[:'is_hcx_pending_downgrade'].nil?
  self.is_hcx_pending_downgrade = false if is_hcx_pending_downgrade.nil? && !attributes.key?(:'isHcxPendingDowngrade') && !attributes.key?(:'is_hcx_pending_downgrade') # rubocop:disable Style/StringLiterals

  self.hcx_on_prem_licenses = attributes[:'hcxOnPremLicenses'] if attributes[:'hcxOnPremLicenses']

  raise 'You cannot provide both :hcxOnPremLicenses and :hcx_on_prem_licenses' if attributes.key?(:'hcxOnPremLicenses') && attributes.key?(:'hcx_on_prem_licenses')

  self.hcx_on_prem_licenses = attributes[:'hcx_on_prem_licenses'] if attributes[:'hcx_on_prem_licenses']

  self.time_hcx_billing_cycle_end = attributes[:'timeHcxBillingCycleEnd'] if attributes[:'timeHcxBillingCycleEnd']

  raise 'You cannot provide both :timeHcxBillingCycleEnd and :time_hcx_billing_cycle_end' if attributes.key?(:'timeHcxBillingCycleEnd') && attributes.key?(:'time_hcx_billing_cycle_end')

  self.time_hcx_billing_cycle_end = attributes[:'time_hcx_billing_cycle_end'] if attributes[:'time_hcx_billing_cycle_end']

  self.time_hcx_license_status_updated = attributes[:'timeHcxLicenseStatusUpdated'] if attributes[:'timeHcxLicenseStatusUpdated']

  raise 'You cannot provide both :timeHcxLicenseStatusUpdated and :time_hcx_license_status_updated' if attributes.key?(:'timeHcxLicenseStatusUpdated') && attributes.key?(:'time_hcx_license_status_updated')

  self.time_hcx_license_status_updated = attributes[:'time_hcx_license_status_updated'] if attributes[:'time_hcx_license_status_updated']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.initial_host_shape_name = attributes[:'initialHostShapeName'] if attributes[:'initialHostShapeName']

  raise 'You cannot provide both :initialHostShapeName and :initial_host_shape_name' if attributes.key?(:'initialHostShapeName') && attributes.key?(:'initial_host_shape_name')

  self.initial_host_shape_name = attributes[:'initial_host_shape_name'] if attributes[:'initial_host_shape_name']

  self.initial_host_ocpu_count = attributes[:'initialHostOcpuCount'] if attributes[:'initialHostOcpuCount']

  raise 'You cannot provide both :initialHostOcpuCount and :initial_host_ocpu_count' if attributes.key?(:'initialHostOcpuCount') && attributes.key?(:'initial_host_ocpu_count')

  self.initial_host_ocpu_count = attributes[:'initial_host_ocpu_count'] if attributes[:'initial_host_ocpu_count']

  self.is_shielded_instance_enabled = attributes[:'isShieldedInstanceEnabled'] unless attributes[:'isShieldedInstanceEnabled'].nil?
  self.is_shielded_instance_enabled = false if is_shielded_instance_enabled.nil? && !attributes.key?(:'isShieldedInstanceEnabled') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isShieldedInstanceEnabled and :is_shielded_instance_enabled' if attributes.key?(:'isShieldedInstanceEnabled') && attributes.key?(:'is_shielded_instance_enabled')

  self.is_shielded_instance_enabled = attributes[:'is_shielded_instance_enabled'] unless attributes[:'is_shielded_instance_enabled'].nil?
  self.is_shielded_instance_enabled = false if is_shielded_instance_enabled.nil? && !attributes.key?(:'isShieldedInstanceEnabled') && !attributes.key?(:'is_shielded_instance_enabled') # rubocop:disable Style/StringLiterals

  self.capacity_reservation_id = attributes[:'capacityReservationId'] if attributes[:'capacityReservationId']

  raise 'You cannot provide both :capacityReservationId and :capacity_reservation_id' if attributes.key?(:'capacityReservationId') && attributes.key?(:'capacity_reservation_id')

  self.capacity_reservation_id = attributes[:'capacity_reservation_id'] if attributes[:'capacity_reservation_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#capacity_reservation_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Capacity Reservation.

Returns:

  • (String)


439
440
441
# File 'lib/oci/ocvp/models/sddc.rb', line 439

def capacity_reservation_id
  @capacity_reservation_id
end

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the SDDC.

Returns:

  • (String)


88
89
90
# File 'lib/oci/ocvp/models/sddc.rb', line 88

def compartment_id
  @compartment_id
end

#compute_availability_domainString

**[Required]** The availability domain the ESXi hosts are running in. For Multi-AD SDDC, it is `multi-AD`.

Example: `Uocm:PHX-AD-1`, `multi-AD`

Returns:

  • (String)


48
49
50
# File 'lib/oci/ocvp/models/sddc.rb', line 48

def compute_availability_domain
  @compute_availability_domain
end

#defined_tagsHash<String, Hash<String, Object>>

**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


455
456
457
# File 'lib/oci/ocvp/models/sddc.rb', line 455

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** A descriptive name for the SDDC. It must be unique, start with a letter, and contain only letters, digits, whitespaces, dashes and underscores. Avoid entering confidential information.

Returns:

  • (String)


55
56
57
# File 'lib/oci/ocvp/models/sddc.rb', line 55

def display_name
  @display_name
end

#esxi_hosts_countInteger

**[Required]** The number of ESXi hosts in the SDDC.

Returns:

  • (Integer)


92
93
94
# File 'lib/oci/ocvp/models/sddc.rb', line 92

def esxi_hosts_count
  @esxi_hosts_count
end

#freeform_tagsHash<String, String>

**[Required]** Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


447
448
449
# File 'lib/oci/ocvp/models/sddc.rb', line 447

def freeform_tags
  @freeform_tags
end

#hcx_fqdnString

The FQDN for HCX Manager.

Example: `hcx-my-sddc.sddc.us-phoenix-1.oraclecloud.com`

Returns:

  • (String)


338
339
340
# File 'lib/oci/ocvp/models/sddc.rb', line 338

def hcx_fqdn
  @hcx_fqdn
end

#hcx_initial_passwordString

The SDDC includes an administrator username and initial password for HCX Manager. Make sure to change this initial HCX Manager password to a different value.

Returns:

  • (String)


344
345
346
# File 'lib/oci/ocvp/models/sddc.rb', line 344

def hcx_initial_password
  @hcx_initial_password
end

#hcx_on_prem_keyString

The activation keys to use on the on-premises HCX Enterprise appliances you site pair with HCX Manager in your VMware Solution. The number of keys provided depends on the HCX license type. HCX Advanced provides 3 activation keys. HCX Enterprise provides 10 activation keys.

Returns:

  • (String)


372
373
374
# File 'lib/oci/ocvp/models/sddc.rb', line 372

def hcx_on_prem_key
  @hcx_on_prem_key
end

#hcx_on_prem_licensesArray<OCI::Ocvp::Models::HcxLicenseSummary>

The activation licenses to use on the on-premises HCX Enterprise appliance you site pair with HCX Manager in your VMware Solution.



385
386
387
# File 'lib/oci/ocvp/models/sddc.rb', line 385

def hcx_on_prem_licenses
  @hcx_on_prem_licenses
end

#hcx_private_ip_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the `PrivateIp` object that is the virtual IP (VIP) for HCX Manager. For information about `PrivateIp` objects, see the Core Services API.

Returns:

  • (String)


331
332
333
# File 'lib/oci/ocvp/models/sddc.rb', line 331

def hcx_private_ip_id
  @hcx_private_ip_id
end

#hcx_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the HCX component of the VMware environment.

This attribute is not guaranteed to reflect the HCX VLAN currently used by the ESXi hosts in the SDDC. The purpose of this attribute is to show the HCX VLAN that the Oracle Cloud VMware Solution will use for any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.

Therefore, if you change the existing ESXi hosts in the SDDC to use a different VLAN for the HCX component of the VMware environment, you should use update_sddc to update the SDDC's `hcxVlanId` with that new VLAN's OCID.

Returns:

  • (String)


361
362
363
# File 'lib/oci/ocvp/models/sddc.rb', line 361

def hcx_vlan_id
  @hcx_vlan_id
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the SDDC.

Returns:

  • (String)


41
42
43
# File 'lib/oci/ocvp/models/sddc.rb', line 41

def id
  @id
end

#initial_host_ocpu_countFloat

The initial OCPU count of the SDDC's ESXi hosts.

Returns:

  • (Float)


429
430
431
# File 'lib/oci/ocvp/models/sddc.rb', line 429

def initial_host_ocpu_count
  @initial_host_ocpu_count
end

#initial_host_shape_nameString

**[Required]** The initial compute shape of the SDDC's ESXi hosts. list_supported_host_shapes.

Returns:

  • (String)


424
425
426
# File 'lib/oci/ocvp/models/sddc.rb', line 424

def initial_host_shape_name
  @initial_host_shape_name
end

#initial_skuString

The billing option selected during SDDC creation. list_supported_skus.

Returns:

  • (String)


98
99
100
# File 'lib/oci/ocvp/models/sddc.rb', line 98

def initial_sku
  @initial_sku
end

#instance_display_name_prefixString

A prefix used in the name of each ESXi host and Compute instance in the SDDC. If this isn't set, the SDDC's `displayName` is used as the prefix.

For example, if the value is `MySDDC`, the ESXi hosts are named `MySDDC-1`, `MySDDC-2`, and so on.

Returns:

  • (String)


64
65
66
# File 'lib/oci/ocvp/models/sddc.rb', line 64

def instance_display_name_prefix
  @instance_display_name_prefix
end

#is_hcx_enabledBOOLEAN

Indicates whether HCX is enabled for this SDDC.

Returns:

  • (BOOLEAN)


365
366
367
# File 'lib/oci/ocvp/models/sddc.rb', line 365

def is_hcx_enabled
  @is_hcx_enabled
end

#is_hcx_enterprise_enabledBOOLEAN

Indicates whether HCX Enterprise is enabled for this SDDC.

Returns:

  • (BOOLEAN)


376
377
378
# File 'lib/oci/ocvp/models/sddc.rb', line 376

def is_hcx_enterprise_enabled
  @is_hcx_enterprise_enabled
end

#is_hcx_pending_downgradeBOOLEAN

Indicates whether SDDC is pending downgrade from HCX Enterprise to HCX Advanced.

Returns:

  • (BOOLEAN)


380
381
382
# File 'lib/oci/ocvp/models/sddc.rb', line 380

def is_hcx_pending_downgrade
  @is_hcx_pending_downgrade
end

#is_shielded_instance_enabledBOOLEAN

Indicates whether shielded instance is enabled at the SDDC level.

Returns:

  • (BOOLEAN)


434
435
436
# File 'lib/oci/ocvp/models/sddc.rb', line 434

def is_shielded_instance_enabled
  @is_shielded_instance_enabled
end

#lifecycle_stateString

The current state of the SDDC.

Returns:

  • (String)


418
419
420
# File 'lib/oci/ocvp/models/sddc.rb', line 418

def lifecycle_state
  @lifecycle_state
end

#nsx_edge_uplink1_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the NSX Edge Uplink 1 component of the VMware environment.

This attribute is not guaranteed to reflect the NSX Edge Uplink 1 VLAN currently used by the ESXi hosts in the SDDC. The purpose of this attribute is to show the NSX Edge Uplink 1 VLAN that the Oracle Cloud VMware Solution will use for any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.

Therefore, if you change the existing ESXi hosts in the SDDC to use a different VLAN for the NSX Edge Uplink 1 component of the VMware environment, you should use update_sddc to update the SDDC's `nsxEdgeUplink1VlanId` with that new VLAN's OCID.

Returns:

  • (String)


295
296
297
# File 'lib/oci/ocvp/models/sddc.rb', line 295

def nsx_edge_uplink1_vlan_id
  @nsx_edge_uplink1_vlan_id
end

#nsx_edge_uplink2_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the NSX Edge Uplink 2 component of the VMware environment.

This attribute is not guaranteed to reflect the NSX Edge Uplink 2 VLAN currently used by the ESXi hosts in the SDDC. The purpose of this attribute is to show the NSX Edge Uplink 2 VLAN that the Oracle Cloud VMware Solution will use for any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.

Therefore, if you change the existing ESXi hosts in the SDDC to use a different VLAN for the NSX Edge Uplink 2 component of the VMware environment, you should use update_sddc to update the SDDC's `nsxEdgeUplink2VlanId` with that new VLAN's OCID.

Returns:

  • (String)


312
313
314
# File 'lib/oci/ocvp/models/sddc.rb', line 312

def nsx_edge_uplink2_vlan_id
  @nsx_edge_uplink2_vlan_id
end

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the `PrivateIp` object that is the virtual IP (VIP) for the NSX Edge Uplink. Use this OCID as the route target for route table rules when setting up connectivity between the SDDC and other networks. For information about `PrivateIp` objects, see the Core Services API.

Returns:

  • (String)


187
188
189
# File 'lib/oci/ocvp/models/sddc.rb', line 187

def nsx_edge_uplink_ip_id
  @nsx_edge_uplink_ip_id
end

#nsx_edge_v_tep_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the NSX Edge VTEP component of the VMware environment.

This attribute is not guaranteed to reflect the NSX Edge VTEP VLAN currently used by the ESXi hosts in the SDDC. The purpose of this attribute is to show the NSX Edge VTEP VLAN that the Oracle Cloud VMware Solution will use for any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.

Therefore, if you change the existing ESXi hosts in the SDDC to use a different VLAN for the NSX Edge VTEP component of the VMware environment, you should use update_sddc to update the SDDC's `nsxEdgeVTepVlanId` with that new VLAN's OCID.

Returns:

  • (String)


278
279
280
# File 'lib/oci/ocvp/models/sddc.rb', line 278

def nsx_edge_v_tep_vlan_id
  @nsx_edge_v_tep_vlan_id
end

#nsx_manager_fqdnString

**[Required]** The FQDN for NSX Manager.

Example: `nsx-my-sddc.sddc.us-phoenix-1.oraclecloud.com`

Returns:

  • (String)


112
113
114
# File 'lib/oci/ocvp/models/sddc.rb', line 112

def nsx_manager_fqdn
  @nsx_manager_fqdn
end

#nsx_manager_initial_passwordString

The SDDC includes an administrator username and initial password for NSX Manager. Make sure to change this initial NSX Manager password to a different value.

Returns:

  • (String)


138
139
140
# File 'lib/oci/ocvp/models/sddc.rb', line 138

def nsx_manager_initial_password
  @nsx_manager_initial_password
end

#nsx_manager_private_ip_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the `PrivateIp` object that is the virtual IP (VIP) for NSX Manager. For information about `PrivateIp` objects, see the Core Services API.

Returns:

  • (String)


126
127
128
# File 'lib/oci/ocvp/models/sddc.rb', line 126

def nsx_manager_private_ip_id
  @nsx_manager_private_ip_id
end

#nsx_manager_usernameString

The SDDC includes an administrator username and initial password for NSX Manager. You can change this initial username to a different value in NSX Manager.

Returns:

  • (String)


150
151
152
# File 'lib/oci/ocvp/models/sddc.rb', line 150

def nsx_manager_username
  @nsx_manager_username
end

#nsx_overlay_segment_nameString

The VMware NSX overlay workload segment to host your application. Connect to workload portgroup in vCenter to access this overlay segment.

Returns:

  • (String)


179
180
181
# File 'lib/oci/ocvp/models/sddc.rb', line 179

def nsx_overlay_segment_name
  @nsx_overlay_segment_name
end

#nsx_v_tep_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the NSX VTEP component of the VMware environment.

This attribute is not guaranteed to reflect the NSX VTEP VLAN currently used by the ESXi hosts in the SDDC. The purpose of this attribute is to show the NSX VTEP VLAN that the Oracle Cloud VMware Solution will use for any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.

Therefore, if you change the existing ESXi hosts in the SDDC to use a different VLAN for the NSX VTEP component of the VMware environment, you should use update_sddc to update the SDDC's `nsxVTepVlanId` with that new VLAN's OCID.

Returns:

  • (String)


261
262
263
# File 'lib/oci/ocvp/models/sddc.rb', line 261

def nsx_v_tep_vlan_id
  @nsx_v_tep_vlan_id
end

#provisioning_subnet_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the management subnet used to provision the SDDC.

Returns:

  • (String)


193
194
195
# File 'lib/oci/ocvp/models/sddc.rb', line 193

def provisioning_subnet_id
  @provisioning_subnet_id
end

#provisioning_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the Provisioning component of the VMware environment.

Returns:

  • (String)


324
325
326
# File 'lib/oci/ocvp/models/sddc.rb', line 324

def provisioning_vlan_id
  @provisioning_vlan_id
end

#replication_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the vSphere Replication component of the VMware environment.

Returns:

  • (String)


318
319
320
# File 'lib/oci/ocvp/models/sddc.rb', line 318

def replication_vlan_id
  @replication_vlan_id
end

#ssh_authorized_keysString

**[Required]** One or more public SSH keys to be included in the `~/.ssh/authorized_keys` file for the default user on each ESXi host. Use a newline character to separate multiple keys. The SSH keys must be in the format required for the `authorized_keys` file.

This attribute is not guaranteed to reflect the public SSH keys currently installed on the ESXi hosts in the SDDC. The purpose of this attribute is to show the public SSH keys that Oracle Cloud VMware Solution will install on any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.

Therefore, if you upgrade the existing ESXi hosts in the SDDC to use different SSH keys, you should use update_sddc to update the SDDC's `sshAuthorizedKeys` with the new public keys.

Returns:

  • (String)


167
168
169
# File 'lib/oci/ocvp/models/sddc.rb', line 167

def ssh_authorized_keys
  @ssh_authorized_keys
end

#time_createdDateTime

**[Required]** The date and time the SDDC was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


408
409
410
# File 'lib/oci/ocvp/models/sddc.rb', line 408

def time_created
  @time_created
end

#time_hcx_billing_cycle_endDateTime

The date and time current HCX Enterprise billing cycle ends, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


392
393
394
# File 'lib/oci/ocvp/models/sddc.rb', line 392

def time_hcx_billing_cycle_end
  @time_hcx_billing_cycle_end
end

#time_hcx_license_status_updatedDateTime

The date and time the SDDC's HCX on-premise license status was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


400
401
402
# File 'lib/oci/ocvp/models/sddc.rb', line 400

def time_hcx_license_status_updated
  @time_hcx_license_status_updated
end

#time_updatedDateTime

The date and time the SDDC was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


414
415
416
# File 'lib/oci/ocvp/models/sddc.rb', line 414

def time_updated
  @time_updated
end

#vcenter_fqdnString

**[Required]** The FQDN for vCenter.

Example: `vcenter-my-sddc.sddc.us-phoenix-1.oraclecloud.com`

Returns:

  • (String)


105
106
107
# File 'lib/oci/ocvp/models/sddc.rb', line 105

def vcenter_fqdn
  @vcenter_fqdn
end

#vcenter_initial_passwordString

The SDDC includes an administrator username and initial password for vCenter. Make sure to change this initial vCenter password to a different value.

Returns:

  • (String)


132
133
134
# File 'lib/oci/ocvp/models/sddc.rb', line 132

def vcenter_initial_password
  @vcenter_initial_password
end

#vcenter_private_ip_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the `PrivateIp` object that is the virtual IP (VIP) for vCenter. For information about `PrivateIp` objects, see the Core Services API.

Returns:

  • (String)


119
120
121
# File 'lib/oci/ocvp/models/sddc.rb', line 119

def vcenter_private_ip_id
  @vcenter_private_ip_id
end

#vcenter_usernameString

The SDDC includes an administrator username and initial password for vCenter. You can change this initial username to a different value in vCenter.

Returns:

  • (String)


144
145
146
# File 'lib/oci/ocvp/models/sddc.rb', line 144

def vcenter_username
  @vcenter_username
end

#vmotion_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the vMotion component of the VMware environment.

This attribute is not guaranteed to reflect the vMotion VLAN currently used by the ESXi hosts in the SDDC. The purpose of this attribute is to show the vMotion VLAN that the Oracle Cloud VMware Solution will use for any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.

Therefore, if you change the existing ESXi hosts in the SDDC to use a different VLAN for the vMotion component of the VMware environment, you should use update_sddc to update the SDDC's `vmotionVlanId` with that new VLAN's OCID.

Returns:

  • (String)


227
228
229
# File 'lib/oci/ocvp/models/sddc.rb', line 227

def vmotion_vlan_id
  @vmotion_vlan_id
end

#vmware_software_versionString

**[Required]** In general, this is a specific version of bundled VMware software supported by Oracle Cloud VMware Solution (see list_supported_vmware_software_versions).

This attribute is not guaranteed to reflect the version of software currently installed on the ESXi hosts in the SDDC. The purpose of this attribute is to show the version of software that the Oracle Cloud VMware Solution will install on any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.

Therefore, if you upgrade the existing ESXi hosts in the SDDC to use a newer version of bundled VMware software supported by the Oracle Cloud VMware Solution, you should use update_sddc to update the SDDC's `vmwareSoftwareVersion` with that new version.

Returns:

  • (String)


82
83
84
# File 'lib/oci/ocvp/models/sddc.rb', line 82

def vmware_software_version
  @vmware_software_version
end

#vsan_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the vSAN component of the VMware environment.

This attribute is not guaranteed to reflect the vSAN VLAN currently used by the ESXi hosts in the SDDC. The purpose of this attribute is to show the vSAN VLAN that the Oracle Cloud VMware Solution will use for any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.

Therefore, if you change the existing ESXi hosts in the SDDC to use a different VLAN for the vSAN component of the VMware environment, you should use update_sddc to update the SDDC's `vsanVlanId` with that new VLAN's OCID.

Returns:

  • (String)


244
245
246
# File 'lib/oci/ocvp/models/sddc.rb', line 244

def vsan_vlan_id
  @vsan_vlan_id
end

#vsphere_vlan_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the vSphere component of the VMware environment.

This attribute is not guaranteed to reflect the vSphere VLAN currently used by the ESXi hosts in the SDDC. The purpose of this attribute is to show the vSphere VLAN that the Oracle Cloud VMware Solution will use for any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.

Therefore, if you change the existing ESXi hosts in the SDDC to use a different VLAN for the vSphere component of the VMware environment, you should use update_sddc to update the SDDC's `vsphereVlanId` with that new VLAN's OCID.

Returns:

  • (String)


210
211
212
# File 'lib/oci/ocvp/models/sddc.rb', line 210

def vsphere_vlan_id
  @vsphere_vlan_id
end

#workload_network_cidrString

The CIDR block for the IP addresses that VMware VMs in the SDDC use to run application workloads.

Returns:

  • (String)


173
174
175
# File 'lib/oci/ocvp/models/sddc.rb', line 173

def workload_network_cidr
  @workload_network_cidr
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
# File 'lib/oci/ocvp/models/sddc.rb', line 458

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compute_availability_domain': :'computeAvailabilityDomain',
    'display_name': :'displayName',
    'instance_display_name_prefix': :'instanceDisplayNamePrefix',
    'vmware_software_version': :'vmwareSoftwareVersion',
    'compartment_id': :'compartmentId',
    'esxi_hosts_count': :'esxiHostsCount',
    'initial_sku': :'initialSku',
    'vcenter_fqdn': :'vcenterFqdn',
    'nsx_manager_fqdn': :'nsxManagerFqdn',
    'vcenter_private_ip_id': :'vcenterPrivateIpId',
    'nsx_manager_private_ip_id': :'nsxManagerPrivateIpId',
    'vcenter_initial_password': :'vcenterInitialPassword',
    'nsx_manager_initial_password': :'nsxManagerInitialPassword',
    'vcenter_username': :'vcenterUsername',
    'nsx_manager_username': :'nsxManagerUsername',
    'ssh_authorized_keys': :'sshAuthorizedKeys',
    'workload_network_cidr': :'workloadNetworkCidr',
    'nsx_overlay_segment_name': :'nsxOverlaySegmentName',
    'nsx_edge_uplink_ip_id': :'nsxEdgeUplinkIpId',
    'provisioning_subnet_id': :'provisioningSubnetId',
    'vsphere_vlan_id': :'vsphereVlanId',
    'vmotion_vlan_id': :'vmotionVlanId',
    'vsan_vlan_id': :'vsanVlanId',
    'nsx_v_tep_vlan_id': :'nsxVTepVlanId',
    'nsx_edge_v_tep_vlan_id': :'nsxEdgeVTepVlanId',
    'nsx_edge_uplink1_vlan_id': :'nsxEdgeUplink1VlanId',
    'nsx_edge_uplink2_vlan_id': :'nsxEdgeUplink2VlanId',
    'replication_vlan_id': :'replicationVlanId',
    'provisioning_vlan_id': :'provisioningVlanId',
    'hcx_private_ip_id': :'hcxPrivateIpId',
    'hcx_fqdn': :'hcxFqdn',
    'hcx_initial_password': :'hcxInitialPassword',
    'hcx_vlan_id': :'hcxVlanId',
    'is_hcx_enabled': :'isHcxEnabled',
    'hcx_on_prem_key': :'hcxOnPremKey',
    'is_hcx_enterprise_enabled': :'isHcxEnterpriseEnabled',
    'is_hcx_pending_downgrade': :'isHcxPendingDowngrade',
    'hcx_on_prem_licenses': :'hcxOnPremLicenses',
    'time_hcx_billing_cycle_end': :'timeHcxBillingCycleEnd',
    'time_hcx_license_status_updated': :'timeHcxLicenseStatusUpdated',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'initial_host_shape_name': :'initialHostShapeName',
    'initial_host_ocpu_count': :'initialHostOcpuCount',
    'is_shielded_instance_enabled': :'isShieldedInstanceEnabled',
    'capacity_reservation_id': :'capacityReservationId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
# File 'lib/oci/ocvp/models/sddc.rb', line 516

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compute_availability_domain': :'String',
    'display_name': :'String',
    'instance_display_name_prefix': :'String',
    'vmware_software_version': :'String',
    'compartment_id': :'String',
    'esxi_hosts_count': :'Integer',
    'initial_sku': :'String',
    'vcenter_fqdn': :'String',
    'nsx_manager_fqdn': :'String',
    'vcenter_private_ip_id': :'String',
    'nsx_manager_private_ip_id': :'String',
    'vcenter_initial_password': :'String',
    'nsx_manager_initial_password': :'String',
    'vcenter_username': :'String',
    'nsx_manager_username': :'String',
    'ssh_authorized_keys': :'String',
    'workload_network_cidr': :'String',
    'nsx_overlay_segment_name': :'String',
    'nsx_edge_uplink_ip_id': :'String',
    'provisioning_subnet_id': :'String',
    'vsphere_vlan_id': :'String',
    'vmotion_vlan_id': :'String',
    'vsan_vlan_id': :'String',
    'nsx_v_tep_vlan_id': :'String',
    'nsx_edge_v_tep_vlan_id': :'String',
    'nsx_edge_uplink1_vlan_id': :'String',
    'nsx_edge_uplink2_vlan_id': :'String',
    'replication_vlan_id': :'String',
    'provisioning_vlan_id': :'String',
    'hcx_private_ip_id': :'String',
    'hcx_fqdn': :'String',
    'hcx_initial_password': :'String',
    'hcx_vlan_id': :'String',
    'is_hcx_enabled': :'BOOLEAN',
    'hcx_on_prem_key': :'String',
    'is_hcx_enterprise_enabled': :'BOOLEAN',
    'is_hcx_pending_downgrade': :'BOOLEAN',
    'hcx_on_prem_licenses': :'Array<OCI::Ocvp::Models::HcxLicenseSummary>',
    'time_hcx_billing_cycle_end': :'DateTime',
    'time_hcx_license_status_updated': :'DateTime',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'initial_host_shape_name': :'String',
    'initial_host_ocpu_count': :'Float',
    'is_shielded_instance_enabled': :'BOOLEAN',
    'capacity_reservation_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
# File 'lib/oci/ocvp/models/sddc.rb', line 973

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compute_availability_domain == other.compute_availability_domain &&
    display_name == other.display_name &&
    instance_display_name_prefix == other.instance_display_name_prefix &&
    vmware_software_version == other.vmware_software_version &&
    compartment_id == other.compartment_id &&
    esxi_hosts_count == other.esxi_hosts_count &&
    initial_sku == other.initial_sku &&
    vcenter_fqdn == other.vcenter_fqdn &&
    nsx_manager_fqdn == other.nsx_manager_fqdn &&
    vcenter_private_ip_id == other.vcenter_private_ip_id &&
    nsx_manager_private_ip_id == other.nsx_manager_private_ip_id &&
    vcenter_initial_password == other.vcenter_initial_password &&
    nsx_manager_initial_password == other.nsx_manager_initial_password &&
    vcenter_username == other.vcenter_username &&
    nsx_manager_username == other.nsx_manager_username &&
    ssh_authorized_keys == other.ssh_authorized_keys &&
    workload_network_cidr == other.workload_network_cidr &&
    nsx_overlay_segment_name == other.nsx_overlay_segment_name &&
    nsx_edge_uplink_ip_id == other.nsx_edge_uplink_ip_id &&
    provisioning_subnet_id == other.provisioning_subnet_id &&
    vsphere_vlan_id == other.vsphere_vlan_id &&
    vmotion_vlan_id == other.vmotion_vlan_id &&
    vsan_vlan_id == other.vsan_vlan_id &&
    nsx_v_tep_vlan_id == other.nsx_v_tep_vlan_id &&
    nsx_edge_v_tep_vlan_id == other.nsx_edge_v_tep_vlan_id &&
    nsx_edge_uplink1_vlan_id == other.nsx_edge_uplink1_vlan_id &&
    nsx_edge_uplink2_vlan_id == other.nsx_edge_uplink2_vlan_id &&
    replication_vlan_id == other.replication_vlan_id &&
    provisioning_vlan_id == other.provisioning_vlan_id &&
    hcx_private_ip_id == other.hcx_private_ip_id &&
    hcx_fqdn == other.hcx_fqdn &&
    hcx_initial_password == other.hcx_initial_password &&
    hcx_vlan_id == other.hcx_vlan_id &&
    is_hcx_enabled == other.is_hcx_enabled &&
    hcx_on_prem_key == other.hcx_on_prem_key &&
    is_hcx_enterprise_enabled == other.is_hcx_enterprise_enabled &&
    is_hcx_pending_downgrade == other.is_hcx_pending_downgrade &&
    hcx_on_prem_licenses == other.hcx_on_prem_licenses &&
    time_hcx_billing_cycle_end == other.time_hcx_billing_cycle_end &&
    time_hcx_license_status_updated == other.time_hcx_license_status_updated &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    initial_host_shape_name == other.initial_host_shape_name &&
    initial_host_ocpu_count == other.initial_host_ocpu_count &&
    is_shielded_instance_enabled == other.is_shielded_instance_enabled &&
    capacity_reservation_id == other.capacity_reservation_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
# File 'lib/oci/ocvp/models/sddc.rb', line 1052

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


1032
1033
1034
# File 'lib/oci/ocvp/models/sddc.rb', line 1032

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



1041
1042
1043
# File 'lib/oci/ocvp/models/sddc.rb', line 1041

def hash
  [id, compute_availability_domain, display_name, instance_display_name_prefix, vmware_software_version, compartment_id, esxi_hosts_count, initial_sku, vcenter_fqdn, nsx_manager_fqdn, vcenter_private_ip_id, nsx_manager_private_ip_id, vcenter_initial_password, nsx_manager_initial_password, vcenter_username, nsx_manager_username, ssh_authorized_keys, workload_network_cidr, nsx_overlay_segment_name, nsx_edge_uplink_ip_id, provisioning_subnet_id, vsphere_vlan_id, vmotion_vlan_id, vsan_vlan_id, nsx_v_tep_vlan_id, nsx_edge_v_tep_vlan_id, nsx_edge_uplink1_vlan_id, nsx_edge_uplink2_vlan_id, replication_vlan_id, provisioning_vlan_id, hcx_private_ip_id, hcx_fqdn, hcx_initial_password, hcx_vlan_id, is_hcx_enabled, hcx_on_prem_key, is_hcx_enterprise_enabled, is_hcx_pending_downgrade, hcx_on_prem_licenses, time_hcx_billing_cycle_end, time_hcx_license_status_updated, time_created, time_updated, lifecycle_state, initial_host_shape_name, initial_host_ocpu_count, is_shielded_instance_enabled, capacity_reservation_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
# File 'lib/oci/ocvp/models/sddc.rb', line 1085

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



1079
1080
1081
# File 'lib/oci/ocvp/models/sddc.rb', line 1079

def to_s
  to_hash.to_s
end