Class: OCI::Ocvp::Models::UpdateSddcDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/ocvp/models/update_sddc_details.rb

Overview

The SDDC information to be updated.

*Important:* Only the `displayName`, `freeFormTags`, and `definedTags` attributes affect the existing SDDC. Changing the other attributes affects the `Sddc` object, but not the VMware environment currently running on that SDDC. Those other attributes are used by the Oracle Cloud VMware Solution only for new ESXi hosts that you add to this SDDC in the future with create_esxi_host.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateSddcDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 185

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.vmware_software_version = attributes[:'vmwareSoftwareVersion'] if attributes[:'vmwareSoftwareVersion']

  raise 'You cannot provide both :vmwareSoftwareVersion and :vmware_software_version' if attributes.key?(:'vmwareSoftwareVersion') && attributes.key?(:'vmware_software_version')

  self.vmware_software_version = attributes[:'vmware_software_version'] if attributes[:'vmware_software_version']

  self.ssh_authorized_keys = attributes[:'sshAuthorizedKeys'] if attributes[:'sshAuthorizedKeys']

  raise 'You cannot provide both :sshAuthorizedKeys and :ssh_authorized_keys' if attributes.key?(:'sshAuthorizedKeys') && attributes.key?(:'ssh_authorized_keys')

  self.ssh_authorized_keys = attributes[:'ssh_authorized_keys'] if attributes[:'ssh_authorized_keys']

  self.vsphere_vlan_id = attributes[:'vsphereVlanId'] if attributes[:'vsphereVlanId']

  raise 'You cannot provide both :vsphereVlanId and :vsphere_vlan_id' if attributes.key?(:'vsphereVlanId') && attributes.key?(:'vsphere_vlan_id')

  self.vsphere_vlan_id = attributes[:'vsphere_vlan_id'] if attributes[:'vsphere_vlan_id']

  self.vmotion_vlan_id = attributes[:'vmotionVlanId'] if attributes[:'vmotionVlanId']

  raise 'You cannot provide both :vmotionVlanId and :vmotion_vlan_id' if attributes.key?(:'vmotionVlanId') && attributes.key?(:'vmotion_vlan_id')

  self.vmotion_vlan_id = attributes[:'vmotion_vlan_id'] if attributes[:'vmotion_vlan_id']

  self.vsan_vlan_id = attributes[:'vsanVlanId'] if attributes[:'vsanVlanId']

  raise 'You cannot provide both :vsanVlanId and :vsan_vlan_id' if attributes.key?(:'vsanVlanId') && attributes.key?(:'vsan_vlan_id')

  self.vsan_vlan_id = attributes[:'vsan_vlan_id'] if attributes[:'vsan_vlan_id']

  self.nsx_v_tep_vlan_id = attributes[:'nsxVTepVlanId'] if attributes[:'nsxVTepVlanId']

  raise 'You cannot provide both :nsxVTepVlanId and :nsx_v_tep_vlan_id' if attributes.key?(:'nsxVTepVlanId') && attributes.key?(:'nsx_v_tep_vlan_id')

  self.nsx_v_tep_vlan_id = attributes[:'nsx_v_tep_vlan_id'] if attributes[:'nsx_v_tep_vlan_id']

  self.nsx_edge_v_tep_vlan_id = attributes[:'nsxEdgeVTepVlanId'] if attributes[:'nsxEdgeVTepVlanId']

  raise 'You cannot provide both :nsxEdgeVTepVlanId and :nsx_edge_v_tep_vlan_id' if attributes.key?(:'nsxEdgeVTepVlanId') && attributes.key?(:'nsx_edge_v_tep_vlan_id')

  self.nsx_edge_v_tep_vlan_id = attributes[:'nsx_edge_v_tep_vlan_id'] if attributes[:'nsx_edge_v_tep_vlan_id']

  self.nsx_edge_uplink1_vlan_id = attributes[:'nsxEdgeUplink1VlanId'] if attributes[:'nsxEdgeUplink1VlanId']

  raise 'You cannot provide both :nsxEdgeUplink1VlanId and :nsx_edge_uplink1_vlan_id' if attributes.key?(:'nsxEdgeUplink1VlanId') && attributes.key?(:'nsx_edge_uplink1_vlan_id')

  self.nsx_edge_uplink1_vlan_id = attributes[:'nsx_edge_uplink1_vlan_id'] if attributes[:'nsx_edge_uplink1_vlan_id']

  self.nsx_edge_uplink2_vlan_id = attributes[:'nsxEdgeUplink2VlanId'] if attributes[:'nsxEdgeUplink2VlanId']

  raise 'You cannot provide both :nsxEdgeUplink2VlanId and :nsx_edge_uplink2_vlan_id' if attributes.key?(:'nsxEdgeUplink2VlanId') && attributes.key?(:'nsx_edge_uplink2_vlan_id')

  self.nsx_edge_uplink2_vlan_id = attributes[:'nsx_edge_uplink2_vlan_id'] if attributes[:'nsx_edge_uplink2_vlan_id']

  self.replication_vlan_id = attributes[:'replicationVlanId'] if attributes[:'replicationVlanId']

  raise 'You cannot provide both :replicationVlanId and :replication_vlan_id' if attributes.key?(:'replicationVlanId') && attributes.key?(:'replication_vlan_id')

  self.replication_vlan_id = attributes[:'replication_vlan_id'] if attributes[:'replication_vlan_id']

  self.provisioning_vlan_id = attributes[:'provisioningVlanId'] if attributes[:'provisioningVlanId']

  raise 'You cannot provide both :provisioningVlanId and :provisioning_vlan_id' if attributes.key?(:'provisioningVlanId') && attributes.key?(:'provisioning_vlan_id')

  self.provisioning_vlan_id = attributes[:'provisioning_vlan_id'] if attributes[:'provisioning_vlan_id']

  self.hcx_vlan_id = attributes[:'hcxVlanId'] if attributes[:'hcxVlanId']

  raise 'You cannot provide both :hcxVlanId and :hcx_vlan_id' if attributes.key?(:'hcxVlanId') && attributes.key?(:'hcx_vlan_id')

  self.hcx_vlan_id = attributes[:'hcx_vlan_id'] if attributes[:'hcx_vlan_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


116
117
118
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 116

def defined_tags
  @defined_tags
end

#display_nameString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the SDDC. SDDC name requirements are 1-16 character length limit, Must start with a letter, Must be English letters, numbers, - only, No repeating hyphens, Must be unique within the region.

Returns:

  • (String)


21
22
23
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 21

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: `"Finance"`

Returns:

  • (Hash<String, String>)


108
109
110
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 108

def freeform_tags
  @freeform_tags
end

#hcx_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the HCX component of the VMware environment when adding new ESXi hosts to the SDDC. This value can be updated only when `isHcxEnabled` is true.

Returns:

  • (String)


100
101
102
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 100

def hcx_vlan_id
  @hcx_vlan_id
end

#nsx_edge_uplink1_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the NSX Edge Uplink 1 component of the VMware environment when adding new ESXi hosts to the SDDC.

Returns:

  • (String)


74
75
76
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 74

def nsx_edge_uplink1_vlan_id
  @nsx_edge_uplink1_vlan_id
end

#nsx_edge_uplink2_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the NSX Edge Uplink 2 component of the VMware environment when adding new ESXi hosts to the SDDC.

*Note:* This VLAN is reserved for future use to deploy public-facing applications on the VMware SDDC.

Returns:

  • (String)


82
83
84
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 82

def nsx_edge_uplink2_vlan_id
  @nsx_edge_uplink2_vlan_id
end

#nsx_edge_v_tep_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the NSX Edge VTEP component of the VMware environment when adding new ESXi hosts to the SDDC.

Returns:

  • (String)


68
69
70
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 68

def nsx_edge_v_tep_vlan_id
  @nsx_edge_v_tep_vlan_id
end

#nsx_v_tep_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the NSX VTEP component of the VMware environment when adding new ESXi hosts to the SDDC.

Returns:

  • (String)


62
63
64
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 62

def nsx_v_tep_vlan_id
  @nsx_v_tep_vlan_id
end

#provisioning_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the Provisioning component of the VMware environment.

Returns:

  • (String)


94
95
96
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 94

def provisioning_vlan_id
  @provisioning_vlan_id
end

#replication_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN used by the SDDC for the vSphere Replication component of the VMware environment.

Returns:

  • (String)


88
89
90
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 88

def replication_vlan_id
  @replication_vlan_id
end

#ssh_authorized_keysString

One or more public SSH keys to be included in the `~/.ssh/authorized_keys` file for the default user on each ESXi host, only when adding new ESXi hosts to this SDDC. Use a newline character to separate multiple keys. The SSH keys must be in the format required for the `authorized_keys` file.

Returns:

  • (String)


38
39
40
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 38

def ssh_authorized_keys
  @ssh_authorized_keys
end

#vmotion_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the vMotion component of the VMware environment when adding new ESXi hosts to the SDDC.

Returns:

  • (String)


50
51
52
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 50

def vmotion_vlan_id
  @vmotion_vlan_id
end

#vmware_software_versionString

The version of bundled VMware software that the Oracle Cloud VMware Solution will install on any new ESXi hosts that you add to this SDDC in the future.

For the list of versions supported by the Oracle Cloud VMware Solution, see list_supported_vmware_software_versions).

Returns:

  • (String)


30
31
32
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 30

def vmware_software_version
  @vmware_software_version
end

#vsan_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the vSAN component of the VMware environment when adding new ESXi hosts to the SDDC.

Returns:

  • (String)


56
57
58
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 56

def vsan_vlan_id
  @vsan_vlan_id
end

#vsphere_vlan_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VLAN to use for the vSphere component of the VMware environment when adding new ESXi hosts to the SDDC.

Returns:

  • (String)


44
45
46
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 44

def vsphere_vlan_id
  @vsphere_vlan_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 119

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'vmware_software_version': :'vmwareSoftwareVersion',
    'ssh_authorized_keys': :'sshAuthorizedKeys',
    'vsphere_vlan_id': :'vsphereVlanId',
    'vmotion_vlan_id': :'vmotionVlanId',
    'vsan_vlan_id': :'vsanVlanId',
    'nsx_v_tep_vlan_id': :'nsxVTepVlanId',
    'nsx_edge_v_tep_vlan_id': :'nsxEdgeVTepVlanId',
    'nsx_edge_uplink1_vlan_id': :'nsxEdgeUplink1VlanId',
    'nsx_edge_uplink2_vlan_id': :'nsxEdgeUplink2VlanId',
    'replication_vlan_id': :'replicationVlanId',
    'provisioning_vlan_id': :'provisioningVlanId',
    'hcx_vlan_id': :'hcxVlanId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 142

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'vmware_software_version': :'String',
    'ssh_authorized_keys': :'String',
    'vsphere_vlan_id': :'String',
    'vmotion_vlan_id': :'String',
    'vsan_vlan_id': :'String',
    'nsx_v_tep_vlan_id': :'String',
    'nsx_edge_v_tep_vlan_id': :'String',
    'nsx_edge_uplink1_vlan_id': :'String',
    'nsx_edge_uplink2_vlan_id': :'String',
    'replication_vlan_id': :'String',
    'provisioning_vlan_id': :'String',
    'hcx_vlan_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 289

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    vmware_software_version == other.vmware_software_version &&
    ssh_authorized_keys == other.ssh_authorized_keys &&
    vsphere_vlan_id == other.vsphere_vlan_id &&
    vmotion_vlan_id == other.vmotion_vlan_id &&
    vsan_vlan_id == other.vsan_vlan_id &&
    nsx_v_tep_vlan_id == other.nsx_v_tep_vlan_id &&
    nsx_edge_v_tep_vlan_id == other.nsx_edge_v_tep_vlan_id &&
    nsx_edge_uplink1_vlan_id == other.nsx_edge_uplink1_vlan_id &&
    nsx_edge_uplink2_vlan_id == other.nsx_edge_uplink2_vlan_id &&
    replication_vlan_id == other.replication_vlan_id &&
    provisioning_vlan_id == other.provisioning_vlan_id &&
    hcx_vlan_id == other.hcx_vlan_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 333

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


313
314
315
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 313

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



322
323
324
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 322

def hash
  [display_name, vmware_software_version, ssh_authorized_keys, vsphere_vlan_id, vmotion_vlan_id, vsan_vlan_id, nsx_v_tep_vlan_id, nsx_edge_v_tep_vlan_id, nsx_edge_uplink1_vlan_id, nsx_edge_uplink2_vlan_id, replication_vlan_id, provisioning_vlan_id, hcx_vlan_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
369
370
371
372
373
374
375
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 366

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



360
361
362
# File 'lib/oci/ocvp/models/update_sddc_details.rb', line 360

def to_s
  to_hash.to_s
end