Class: OCI::Oda::Models::Bot
- Inherits:
-
Object
- Object
- OCI::Oda::Models::Bot
- Defined in:
- lib/oci/oda/models/bot.rb
Overview
Metadata for a Bot resource.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze ].freeze
- LIFECYCLE_DETAILS_ENUM =
[ LIFECYCLE_DETAILS_PUBLISHED = 'PUBLISHED'.freeze, LIFECYCLE_DETAILS_DRAFT = 'DRAFT'.freeze ].freeze
- MULTILINGUAL_MODE_ENUM =
[ MULTILINGUAL_MODE_NATIVE = 'NATIVE'.freeze, MULTILINGUAL_MODE_TRANSLATION = 'TRANSLATION'.freeze ].freeze
Instance Attribute Summary collapse
-
#base_id ⇒ String
The unique identifier for the base reource (when this resource extends another).
-
#category ⇒ String
The resource's category.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
A short description of the resource.
-
#display_name ⇒ String
**[Required]** The resource's display name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
**[Required]** Unique immutable identifier that was assigned when the resource was created.
-
#lifecycle_details ⇒ String
**[Required]** The resource's publish state.
-
#lifecycle_state ⇒ String
**[Required]** The resource's current state.
-
#multilingual_mode ⇒ String
The multilingual mode for the resource.
-
#name ⇒ String
**[Required]** The reource's name.
-
#namespace ⇒ String
The resource's namespace.
-
#native_language_tags ⇒ Array<String>
A list of native languages supported by this resource.
-
#platform_version ⇒ String
**[Required]** The ODA Platform Version for this resource.
-
#primary_language_tag ⇒ String
The primary language for the resource.
-
#time_created ⇒ DateTime
**[Required]** When the resource was created.
-
#time_updated ⇒ DateTime
**[Required]** When the resource was last updated.
-
#version ⇒ String
**[Required]** The resource's version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Bot
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Bot
Initializes the object
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/oda/models/bot.rb', line 185 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.version = attributes[:'version'] if attributes[:'version'] self.version = "1.0" if version.nil? && !attributes.key?(:'version') # rubocop:disable Style/StringLiterals self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.category = attributes[:'category'] if attributes[:'category'] self.description = attributes[:'description'] if attributes[:'description'] self.namespace = attributes[:'namespace'] if attributes[:'namespace'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.platform_version = attributes[:'platformVersion'] if attributes[:'platformVersion'] raise 'You cannot provide both :platformVersion and :platform_version' if attributes.key?(:'platformVersion') && attributes.key?(:'platform_version') self.platform_version = attributes[:'platform_version'] if attributes[:'platform_version'] self.base_id = attributes[:'baseId'] if attributes[:'baseId'] raise 'You cannot provide both :baseId and :base_id' if attributes.key?(:'baseId') && attributes.key?(:'base_id') self.base_id = attributes[:'base_id'] if attributes[:'base_id'] self.multilingual_mode = attributes[:'multilingualMode'] if attributes[:'multilingualMode'] raise 'You cannot provide both :multilingualMode and :multilingual_mode' if attributes.key?(:'multilingualMode') && attributes.key?(:'multilingual_mode') self.multilingual_mode = attributes[:'multilingual_mode'] if attributes[:'multilingual_mode'] self.primary_language_tag = attributes[:'primaryLanguageTag'] if attributes[:'primaryLanguageTag'] raise 'You cannot provide both :primaryLanguageTag and :primary_language_tag' if attributes.key?(:'primaryLanguageTag') && attributes.key?(:'primary_language_tag') self.primary_language_tag = attributes[:'primary_language_tag'] if attributes[:'primary_language_tag'] self. = attributes[:'nativeLanguageTags'] if attributes[:'nativeLanguageTags'] raise 'You cannot provide both :nativeLanguageTags and :native_language_tags' if attributes.key?(:'nativeLanguageTags') && attributes.key?(:'native_language_tags') self. = attributes[:'native_language_tags'] if attributes[:'native_language_tags'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#base_id ⇒ String
The unique identifier for the base reource (when this resource extends another).
75 76 77 |
# File 'lib/oci/oda/models/bot.rb', line 75 def base_id @base_id end |
#category ⇒ String
The resource's category. This is used to group resource's together.
51 52 53 |
# File 'lib/oci/oda/models/bot.rb', line 51 def category @category end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
107 108 109 |
# File 'lib/oci/oda/models/bot.rb', line 107 def @defined_tags end |
#description ⇒ String
A short description of the resource.
55 56 57 |
# File 'lib/oci/oda/models/bot.rb', line 55 def description @description end |
#display_name ⇒ String
**[Required]** The resource's display name.
47 48 49 |
# File 'lib/oci/oda/models/bot.rb', line 47 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope. Example: `"value"`
101 102 103 |
# File 'lib/oci/oda/models/bot.rb', line 101 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique immutable identifier that was assigned when the resource was created.
32 33 34 |
# File 'lib/oci/oda/models/bot.rb', line 32 def id @id end |
#lifecycle_details ⇒ String
**[Required]** The resource's publish state.
67 68 69 |
# File 'lib/oci/oda/models/bot.rb', line 67 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The resource's current state.
63 64 65 |
# File 'lib/oci/oda/models/bot.rb', line 63 def lifecycle_state @lifecycle_state end |
#multilingual_mode ⇒ String
The multilingual mode for the resource.
79 80 81 |
# File 'lib/oci/oda/models/bot.rb', line 79 def multilingual_mode @multilingual_mode end |
#name ⇒ String
**[Required]** The reource's name. The name can contain only letters, numbers, periods, and underscores. The name must begin with a letter.
37 38 39 |
# File 'lib/oci/oda/models/bot.rb', line 37 def name @name end |
#namespace ⇒ String
The resource's namespace.
59 60 61 |
# File 'lib/oci/oda/models/bot.rb', line 59 def namespace @namespace end |
#native_language_tags ⇒ Array<String>
A list of native languages supported by this resource.
87 88 89 |
# File 'lib/oci/oda/models/bot.rb', line 87 def @native_language_tags end |
#platform_version ⇒ String
**[Required]** The ODA Platform Version for this resource.
71 72 73 |
# File 'lib/oci/oda/models/bot.rb', line 71 def platform_version @platform_version end |
#primary_language_tag ⇒ String
The primary language for the resource.
83 84 85 |
# File 'lib/oci/oda/models/bot.rb', line 83 def primary_language_tag @primary_language_tag end |
#time_created ⇒ DateTime
**[Required]** When the resource was created. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
91 92 93 |
# File 'lib/oci/oda/models/bot.rb', line 91 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** When the resource was last updated. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
95 96 97 |
# File 'lib/oci/oda/models/bot.rb', line 95 def time_updated @time_updated end |
#version ⇒ String
**[Required]** The resource's version. The version can only contain numbers, letters, periods, underscores, dashes or spaces. The version must begin with a letter or a number.
42 43 44 |
# File 'lib/oci/oda/models/bot.rb', line 42 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/oda/models/bot.rb', line 110 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'version': :'version', 'display_name': :'displayName', 'category': :'category', 'description': :'description', 'namespace': :'namespace', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'platform_version': :'platformVersion', 'base_id': :'baseId', 'multilingual_mode': :'multilingualMode', 'primary_language_tag': :'primaryLanguageTag', 'native_language_tags': :'nativeLanguageTags', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/oda/models/bot.rb', line 136 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'version': :'String', 'display_name': :'String', 'category': :'String', 'description': :'String', 'namespace': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'platform_version': :'String', 'base_id': :'String', 'multilingual_mode': :'String', 'primary_language_tag': :'String', 'native_language_tags': :'Array<String>', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/oci/oda/models/bot.rb', line 308 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && version == other.version && display_name == other.display_name && category == other.category && description == other.description && namespace == other.namespace && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && platform_version == other.platform_version && base_id == other.base_id && multilingual_mode == other.multilingual_mode && primary_language_tag == other.primary_language_tag && == other. && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/oci/oda/models/bot.rb', line 355 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
335 336 337 |
# File 'lib/oci/oda/models/bot.rb', line 335 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
344 345 346 |
# File 'lib/oci/oda/models/bot.rb', line 344 def hash [id, name, version, display_name, category, description, namespace, lifecycle_state, lifecycle_details, platform_version, base_id, multilingual_mode, primary_language_tag, , time_created, time_updated, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
388 389 390 391 392 393 394 395 396 397 |
# File 'lib/oci/oda/models/bot.rb', line 388 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
382 383 384 |
# File 'lib/oci/oda/models/bot.rb', line 382 def to_s to_hash.to_s end |