Class: OCI::Oda::Models::ChannelSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/oda/models/channel_summary.rb

Overview

Summary of the Channel.

Constant Summary collapse

CATEGORY_ENUM =
[
  CATEGORY_AGENT = 'AGENT'.freeze,
  CATEGORY_APPLICATION = 'APPLICATION'.freeze,
  CATEGORY_BOT = 'BOT'.freeze,
  CATEGORY_BOT_AS_AGENT = 'BOT_AS_AGENT'.freeze,
  CATEGORY_SYSTEM = 'SYSTEM'.freeze,
  CATEGORY_EVENT = 'EVENT'.freeze,
  CATEGORY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TYPE_ENUM =
[
  TYPE_ANDROID = 'ANDROID'.freeze,
  TYPE_APPEVENT = 'APPEVENT'.freeze,
  TYPE_APPLICATION = 'APPLICATION'.freeze,
  TYPE_CORTANA = 'CORTANA'.freeze,
  TYPE_FACEBOOK = 'FACEBOOK'.freeze,
  TYPE_IOS = 'IOS'.freeze,
  TYPE_MSTEAMS = 'MSTEAMS'.freeze,
  TYPE_OSS = 'OSS'.freeze,
  TYPE_OSVC = 'OSVC'.freeze,
  TYPE_SERVICECLOUD = 'SERVICECLOUD'.freeze,
  TYPE_SLACK = 'SLACK'.freeze,
  TYPE_TEST = 'TEST'.freeze,
  TYPE_TWILIO = 'TWILIO'.freeze,
  TYPE_WEB = 'WEB'.freeze,
  TYPE_WEBHOOK = 'WEBHOOK'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ChannelSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :description (String)

    The value to assign to the #description property

  • :category (String)

    The value to assign to the #category property

  • :type (String)

    The value to assign to the #type property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/oda/models/channel_summary.rb', line 148

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.category = attributes[:'category'] if attributes[:'category']

  self.type = attributes[:'type'] if attributes[:'type']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#categoryString

**[Required]** The category of the Channel.

Returns:

  • (String)


66
67
68
# File 'lib/oci/oda/models/channel_summary.rb', line 66

def category
  @category
end

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


94
95
96
# File 'lib/oci/oda/models/channel_summary.rb', line 94

def defined_tags
  @defined_tags
end

#descriptionString

A short description of the Channel.

Returns:

  • (String)


62
63
64
# File 'lib/oci/oda/models/channel_summary.rb', line 62

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type, or scope. Example: `"value"`

Returns:

  • (Hash<String, String>)


88
89
90
# File 'lib/oci/oda/models/channel_summary.rb', line 88

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** Unique immutable identifier that was assigned when the Channel was created.

Returns:

  • (String)


53
54
55
# File 'lib/oci/oda/models/channel_summary.rb', line 53

def id
  @id
end

#lifecycle_stateString

**[Required]** The Channel's current state.

Returns:

  • (String)


74
75
76
# File 'lib/oci/oda/models/channel_summary.rb', line 74

def lifecycle_state
  @lifecycle_state
end

#nameString

**[Required]** The Channel's name. The name can contain only letters, numbers, periods, and underscores. The name must begin with a letter.

Returns:

  • (String)


58
59
60
# File 'lib/oci/oda/models/channel_summary.rb', line 58

def name
  @name
end

#time_createdDateTime

**[Required]** When the resource was created. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.

Returns:

  • (DateTime)


78
79
80
# File 'lib/oci/oda/models/channel_summary.rb', line 78

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** When the resource was last updated. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.

Returns:

  • (DateTime)


82
83
84
# File 'lib/oci/oda/models/channel_summary.rb', line 82

def time_updated
  @time_updated
end

#typeString

**[Required]** The Channel type.

Returns:

  • (String)


70
71
72
# File 'lib/oci/oda/models/channel_summary.rb', line 70

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/oci/oda/models/channel_summary.rb', line 97

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'description': :'description',
    'category': :'category',
    'type': :'type',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/oda/models/channel_summary.rb', line 115

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'description': :'String',
    'category': :'String',
    'type': :'String',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/oci/oda/models/channel_summary.rb', line 241

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    description == other.description &&
    category == other.category &&
    type == other.type &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/oci/oda/models/channel_summary.rb', line 280

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/oci/oda/models/channel_summary.rb', line 260

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



269
270
271
# File 'lib/oci/oda/models/channel_summary.rb', line 269

def hash
  [id, name, description, category, type, lifecycle_state, time_created, time_updated, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



313
314
315
316
317
318
319
320
321
322
# File 'lib/oci/oda/models/channel_summary.rb', line 313

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



307
308
309
# File 'lib/oci/oda/models/channel_summary.rb', line 307

def to_s
  to_hash.to_s
end