Class: OCI::Oda::Models::CreateAndroidChannelResult
- Inherits:
-
CreateChannelResult
- Object
- CreateChannelResult
- OCI::Oda::Models::CreateAndroidChannelResult
- Defined in:
- lib/oci/oda/models/create_android_channel_result.rb
Overview
The configuration for an Android channel.
Constant Summary
Constants inherited from CreateChannelResult
OCI::Oda::Models::CreateChannelResult::CATEGORY_ENUM, OCI::Oda::Models::CreateChannelResult::LIFECYCLE_STATE_ENUM, OCI::Oda::Models::CreateChannelResult::TYPE_ENUM
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
-
#is_client_authentication_enabled ⇒ BOOLEAN
**[Required]** Whether client authentication is enabled or not.
-
#max_token_expiration_time_in_minutes ⇒ Integer
The maximum time until the token expires (in minutes).
-
#secret_key ⇒ String
**[Required]** The secret key used to verify the authenticity of received messages.
Attributes inherited from CreateChannelResult
#category, #defined_tags, #description, #freeform_tags, #id, #lifecycle_state, #name, #session_expiry_duration_in_milliseconds, #time_created, #time_updated, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAndroidChannelResult
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateChannelResult
Constructor Details
#initialize(attributes = {}) ⇒ CreateAndroidChannelResult
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'ANDROID' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.secret_key = attributes[:'secretKey'] if attributes[:'secretKey'] raise 'You cannot provide both :secretKey and :secret_key' if attributes.key?(:'secretKey') && attributes.key?(:'secret_key') self.secret_key = attributes[:'secret_key'] if attributes[:'secret_key'] self.max_token_expiration_time_in_minutes = attributes[:'maxTokenExpirationTimeInMinutes'] if attributes[:'maxTokenExpirationTimeInMinutes'] raise 'You cannot provide both :maxTokenExpirationTimeInMinutes and :max_token_expiration_time_in_minutes' if attributes.key?(:'maxTokenExpirationTimeInMinutes') && attributes.key?(:'max_token_expiration_time_in_minutes') self.max_token_expiration_time_in_minutes = attributes[:'max_token_expiration_time_in_minutes'] if attributes[:'max_token_expiration_time_in_minutes'] self.is_client_authentication_enabled = attributes[:'isClientAuthenticationEnabled'] unless attributes[:'isClientAuthenticationEnabled'].nil? raise 'You cannot provide both :isClientAuthenticationEnabled and :is_client_authentication_enabled' if attributes.key?(:'isClientAuthenticationEnabled') && attributes.key?(:'is_client_authentication_enabled') self.is_client_authentication_enabled = attributes[:'is_client_authentication_enabled'] unless attributes[:'is_client_authentication_enabled'].nil? self.bot_id = attributes[:'botId'] if attributes[:'botId'] raise 'You cannot provide both :botId and :bot_id' if attributes.key?(:'botId') && attributes.key?(:'bot_id') self.bot_id = attributes[:'bot_id'] if attributes[:'bot_id'] end |
Instance Attribute Details
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
27 28 29 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 27 def bot_id @bot_id end |
#is_client_authentication_enabled ⇒ BOOLEAN
**[Required]** Whether client authentication is enabled or not.
23 24 25 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 23 def is_client_authentication_enabled @is_client_authentication_enabled end |
#max_token_expiration_time_in_minutes ⇒ Integer
The maximum time until the token expires (in minutes).
19 20 21 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 19 def max_token_expiration_time_in_minutes @max_token_expiration_time_in_minutes end |
#secret_key ⇒ String
**[Required]** The secret key used to verify the authenticity of received messages. This is only returned this once. If it is lost the keys will need to be rotated to generate a new key.
15 16 17 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 15 def secret_key @secret_key end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'description': :'description', 'category': :'category', 'type': :'type', 'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'secret_key': :'secretKey', 'max_token_expiration_time_in_minutes': :'maxTokenExpirationTimeInMinutes', 'is_client_authentication_enabled': :'isClientAuthenticationEnabled', 'bot_id': :'botId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'description': :'String', 'category': :'String', 'type': :'String', 'session_expiry_duration_in_milliseconds': :'Integer', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'secret_key': :'String', 'max_token_expiration_time_in_minutes': :'Integer', 'is_client_authentication_enabled': :'BOOLEAN', 'bot_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 137 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && category == other.category && type == other.type && session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && secret_key == other.secret_key && max_token_expiration_time_in_minutes == other.max_token_expiration_time_in_minutes && is_client_authentication_enabled == other.is_client_authentication_enabled && bot_id == other.bot_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 181 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
161 162 163 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 161 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 170 def hash [id, name, description, category, type, session_expiry_duration_in_milliseconds, lifecycle_state, time_created, time_updated, , , secret_key, max_token_expiration_time_in_minutes, is_client_authentication_enabled, bot_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
208 209 210 |
# File 'lib/oci/oda/models/create_android_channel_result.rb', line 208 def to_s to_hash.to_s end |