Class: OCI::Oda::Models::CreateChannelResult

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/oda/models/create_channel_result.rb

Overview

Properties of a Channel. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

CATEGORY_ENUM =
[
  CATEGORY_AGENT = 'AGENT'.freeze,
  CATEGORY_APPLICATION = 'APPLICATION'.freeze,
  CATEGORY_BOT = 'BOT'.freeze,
  CATEGORY_BOT_AS_AGENT = 'BOT_AS_AGENT'.freeze,
  CATEGORY_SYSTEM = 'SYSTEM'.freeze,
  CATEGORY_EVENT = 'EVENT'.freeze,
  CATEGORY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TYPE_ENUM =
[
  TYPE_ANDROID = 'ANDROID'.freeze,
  TYPE_APPEVENT = 'APPEVENT'.freeze,
  TYPE_APPLICATION = 'APPLICATION'.freeze,
  TYPE_CORTANA = 'CORTANA'.freeze,
  TYPE_FACEBOOK = 'FACEBOOK'.freeze,
  TYPE_IOS = 'IOS'.freeze,
  TYPE_MSTEAMS = 'MSTEAMS'.freeze,
  TYPE_OSS = 'OSS'.freeze,
  TYPE_OSVC = 'OSVC'.freeze,
  TYPE_SERVICECLOUD = 'SERVICECLOUD'.freeze,
  TYPE_SLACK = 'SLACK'.freeze,
  TYPE_TEST = 'TEST'.freeze,
  TYPE_TWILIO = 'TWILIO'.freeze,
  TYPE_WEB = 'WEB'.freeze,
  TYPE_WEBHOOK = 'WEBHOOK'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateChannelResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :description (String)

    The value to assign to the #description property

  • :category (String)

    The value to assign to the #category property

  • :type (String)

    The value to assign to the #type property

  • :session_expiry_duration_in_milliseconds (Integer)

    The value to assign to the #session_expiry_duration_in_milliseconds property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/oci/oda/models/create_channel_result.rb', line 185

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.category = attributes[:'category'] if attributes[:'category']

  self.type = attributes[:'type'] if attributes[:'type']

  self.session_expiry_duration_in_milliseconds = attributes[:'sessionExpiryDurationInMilliseconds'] if attributes[:'sessionExpiryDurationInMilliseconds']

  raise 'You cannot provide both :sessionExpiryDurationInMilliseconds and :session_expiry_duration_in_milliseconds' if attributes.key?(:'sessionExpiryDurationInMilliseconds') && attributes.key?(:'session_expiry_duration_in_milliseconds')

  self.session_expiry_duration_in_milliseconds = attributes[:'session_expiry_duration_in_milliseconds'] if attributes[:'session_expiry_duration_in_milliseconds']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#categoryString

**[Required]** The category of the Channel.

Returns:

  • (String)


67
68
69
# File 'lib/oci/oda/models/create_channel_result.rb', line 67

def category
  @category
end

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


99
100
101
# File 'lib/oci/oda/models/create_channel_result.rb', line 99

def defined_tags
  @defined_tags
end

#descriptionString

A short description of the Channel.

Returns:

  • (String)


63
64
65
# File 'lib/oci/oda/models/create_channel_result.rb', line 63

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type, or scope. Example: `"value"`

Returns:

  • (Hash<String, String>)


93
94
95
# File 'lib/oci/oda/models/create_channel_result.rb', line 93

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** Unique immutable identifier that was assigned when the Channel was created.

Returns:

  • (String)


54
55
56
# File 'lib/oci/oda/models/create_channel_result.rb', line 54

def id
  @id
end

#lifecycle_stateString

**[Required]** The Channel's current state.

Returns:

  • (String)


79
80
81
# File 'lib/oci/oda/models/create_channel_result.rb', line 79

def lifecycle_state
  @lifecycle_state
end

#nameString

**[Required]** The Channel's name. The name can contain only letters, numbers, periods, and underscores. The name must begin with a letter.

Returns:

  • (String)


59
60
61
# File 'lib/oci/oda/models/create_channel_result.rb', line 59

def name
  @name
end

#session_expiry_duration_in_millisecondsInteger

The number of milliseconds before a session expires.

Returns:

  • (Integer)


75
76
77
# File 'lib/oci/oda/models/create_channel_result.rb', line 75

def session_expiry_duration_in_milliseconds
  @session_expiry_duration_in_milliseconds
end

#time_createdDateTime

**[Required]** When the resource was created. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.

Returns:

  • (DateTime)


83
84
85
# File 'lib/oci/oda/models/create_channel_result.rb', line 83

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** When the resource was last updated. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.

Returns:

  • (DateTime)


87
88
89
# File 'lib/oci/oda/models/create_channel_result.rb', line 87

def time_updated
  @time_updated
end

#typeString

**[Required]** The Channel type.

Returns:

  • (String)


71
72
73
# File 'lib/oci/oda/models/create_channel_result.rb', line 71

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/oci/oda/models/create_channel_result.rb', line 102

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'description': :'description',
    'category': :'category',
    'type': :'type',
    'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/oci/oda/models/create_channel_result.rb', line 144

def self.get_subtype(object_hash)
  type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Oda::Models::CreateWebChannelResult' if type == 'WEB'
  return 'OCI::Oda::Models::CreateSlackChannelResult' if type == 'SLACK'
  return 'OCI::Oda::Models::CreateWebhookChannelResult' if type == 'WEBHOOK'
  return 'OCI::Oda::Models::CreateAndroidChannelResult' if type == 'ANDROID'
  return 'OCI::Oda::Models::CreateTwilioChannelResult' if type == 'TWILIO'
  return 'OCI::Oda::Models::CreateCortanaChannelResult' if type == 'CORTANA'
  return 'OCI::Oda::Models::CreateServiceCloudChannelResult' if type == 'SERVICECLOUD'
  return 'OCI::Oda::Models::CreateFacebookChannelResult' if type == 'FACEBOOK'
  return 'OCI::Oda::Models::CreateApplicationChannelResult' if type == 'APPLICATION'
  return 'OCI::Oda::Models::CreateIosChannelResult' if type == 'IOS'
  return 'OCI::Oda::Models::CreateMSTeamsChannelResult' if type == 'MSTEAMS'
  return 'OCI::Oda::Models::CreateAppEventChannelResult' if type == 'APPEVENT'
  return 'OCI::Oda::Models::CreateOsvcChannelResult' if type == 'OSVC'
  return 'OCI::Oda::Models::CreateOSSChannelResult' if type == 'OSS'
  return 'OCI::Oda::Models::CreateTestChannelResult' if type == 'TEST'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Oda::Models::CreateChannelResult'
end

.swagger_typesObject

Attribute type mapping.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/oda/models/create_channel_result.rb', line 121

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'description': :'String',
    'category': :'String',
    'type': :'String',
    'session_expiry_duration_in_milliseconds': :'Integer',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/oci/oda/models/create_channel_result.rb', line 284

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    description == other.description &&
    category == other.category &&
    type == other.type &&
    session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/oci/oda/models/create_channel_result.rb', line 324

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


304
305
306
# File 'lib/oci/oda/models/create_channel_result.rb', line 304

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



313
314
315
# File 'lib/oci/oda/models/create_channel_result.rb', line 313

def hash
  [id, name, description, category, type, session_expiry_duration_in_milliseconds, lifecycle_state, time_created, time_updated, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



357
358
359
360
361
362
363
364
365
366
# File 'lib/oci/oda/models/create_channel_result.rb', line 357

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



351
352
353
# File 'lib/oci/oda/models/create_channel_result.rb', line 351

def to_s
  to_hash.to_s
end