Class: OCI::Oda::Models::CreateServiceCloudChannelResult
- Inherits:
-
CreateChannelResult
- Object
- CreateChannelResult
- OCI::Oda::Models::CreateServiceCloudChannelResult
- Defined in:
- lib/oci/oda/models/create_service_cloud_channel_result.rb
Overview
The configuration for a Service Cloud agent channel.
Constant Summary collapse
- CLIENT_TYPE_ENUM =
[ CLIENT_TYPE_WSDL = 'WSDL'.freeze, CLIENT_TYPE_REST = 'REST'.freeze, CLIENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from CreateChannelResult
OCI::Oda::Models::CreateChannelResult::CATEGORY_ENUM, OCI::Oda::Models::CreateChannelResult::LIFECYCLE_STATE_ENUM, OCI::Oda::Models::CreateChannelResult::TYPE_ENUM
Instance Attribute Summary collapse
-
#client_type ⇒ String
**[Required]** The type of Service Cloud client.
-
#domain_name ⇒ String
**[Required]** The domain name.
-
#host_name_prefix ⇒ String
**[Required]** The host prefix.
-
#user_name ⇒ String
**[Required]** The user name for an Oracle B2C Service staff member who has the necessary profile permissions.
Attributes inherited from CreateChannelResult
#category, #defined_tags, #description, #freeform_tags, #id, #lifecycle_state, #name, #session_expiry_duration_in_milliseconds, #time_created, #time_updated, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateServiceCloudChannelResult
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateChannelResult
Constructor Details
#initialize(attributes = {}) ⇒ CreateServiceCloudChannelResult
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'SERVICECLOUD' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.domain_name = attributes[:'domainName'] if attributes[:'domainName'] raise 'You cannot provide both :domainName and :domain_name' if attributes.key?(:'domainName') && attributes.key?(:'domain_name') self.domain_name = attributes[:'domain_name'] if attributes[:'domain_name'] self.host_name_prefix = attributes[:'hostNamePrefix'] if attributes[:'hostNamePrefix'] raise 'You cannot provide both :hostNamePrefix and :host_name_prefix' if attributes.key?(:'hostNamePrefix') && attributes.key?(:'host_name_prefix') self.host_name_prefix = attributes[:'host_name_prefix'] if attributes[:'host_name_prefix'] self.user_name = attributes[:'userName'] if attributes[:'userName'] raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] if attributes[:'user_name'] self.client_type = attributes[:'clientType'] if attributes[:'clientType'] raise 'You cannot provide both :clientType and :client_type' if attributes.key?(:'clientType') && attributes.key?(:'client_type') self.client_type = attributes[:'client_type'] if attributes[:'client_type'] end |
Instance Attribute Details
#client_type ⇒ String
**[Required]** The type of Service Cloud client.
48 49 50 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 48 def client_type @client_type end |
#domain_name ⇒ String
**[Required]** The domain name.
If you have access to Oracle B2C Service, you can derive this value from the URL that you use to launch the Agent Browser User Interface. For example, if the URL is sitename.exampledomain.com, then the host name prefix is sitename and the domain name is exampledomain.com.
If the channel is connecting to Oracle B2C Service version 19A or later, and you have multiple interfaces, then you must include the interface ID in the host (site) name . For example, for the interface that has an ID of 2, you would use something like sitename-2.exampledomain.com.
28 29 30 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 28 def domain_name @domain_name end |
#host_name_prefix ⇒ String
**[Required]** The host prefix.
If you have access to Oracle B2C Service, you can derive this value from the URL that you use to launch the Agent Browser User Interface. For example, if the URL is sitename.exampledomain.com, then the host name prefix is sitename and the domain name is exampledomain.com.
If the channel is connecting to Oracle B2C Service version 19A or later, and you have multiple interfaces, then you must include the interface ID in the host (site) name . For example, for the interface that has an ID of 2, you would use something like sitename-2.exampledomain.com.
40 41 42 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 40 def host_name_prefix @host_name_prefix end |
#user_name ⇒ String
**[Required]** The user name for an Oracle B2C Service staff member who has the necessary profile permissions.
44 45 46 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 44 def user_name @user_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'description': :'description', 'category': :'category', 'type': :'type', 'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'domain_name': :'domainName', 'host_name_prefix': :'hostNamePrefix', 'user_name': :'userName', 'client_type': :'clientType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 74 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'description': :'String', 'category': :'String', 'type': :'String', 'session_expiry_duration_in_milliseconds': :'Integer', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'domain_name': :'String', 'host_name_prefix': :'String', 'user_name': :'String', 'client_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 171 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && category == other.category && type == other.type && session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && domain_name == other.domain_name && host_name_prefix == other.host_name_prefix && user_name == other.user_name && client_type == other.client_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 215 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
195 196 197 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 195 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 204 def hash [id, name, description, category, type, session_expiry_duration_in_milliseconds, lifecycle_state, time_created, time_updated, , , domain_name, host_name_prefix, user_name, client_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
248 249 250 251 252 253 254 255 256 257 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 248 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
242 243 244 |
# File 'lib/oci/oda/models/create_service_cloud_channel_result.rb', line 242 def to_s to_hash.to_s end |