Class: OCI::Oda::Models::CreateSkillDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/oda/models/create_skill_details.rb

Overview

Properties that are required to create a Skill. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

KIND_ENUM =
[
  KIND_NEW = 'NEW'.freeze,
  KIND_CLONE = 'CLONE'.freeze,
  KIND_VERSION = 'VERSION'.freeze,
  KIND_EXTEND = 'EXTEND'.freeze
].freeze
MULTILINGUAL_MODE_ENUM =
[
  MULTILINGUAL_MODE_NATIVE = 'NATIVE'.freeze,
  MULTILINGUAL_MODE_TRANSLATION = 'TRANSLATION'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateSkillDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :kind (String)

    The value to assign to the #kind property

  • :category (String)

    The value to assign to the #category property

  • :description (String)

    The value to assign to the #description property

  • :platform_version (String)

    The value to assign to the #platform_version property

  • :multilingual_mode (String)

    The value to assign to the #multilingual_mode property

  • :primary_language_tag (String)

    The value to assign to the #primary_language_tag property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/oci/oda/models/create_skill_details.rb', line 123

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.kind = attributes[:'kind'] if attributes[:'kind']

  self.category = attributes[:'category'] if attributes[:'category']

  self.description = attributes[:'description'] if attributes[:'description']

  self.platform_version = attributes[:'platformVersion'] if attributes[:'platformVersion']

  raise 'You cannot provide both :platformVersion and :platform_version' if attributes.key?(:'platformVersion') && attributes.key?(:'platform_version')

  self.platform_version = attributes[:'platform_version'] if attributes[:'platform_version']

  self.multilingual_mode = attributes[:'multilingualMode'] if attributes[:'multilingualMode']

  raise 'You cannot provide both :multilingualMode and :multilingual_mode' if attributes.key?(:'multilingualMode') && attributes.key?(:'multilingual_mode')

  self.multilingual_mode = attributes[:'multilingual_mode'] if attributes[:'multilingual_mode']

  self.primary_language_tag = attributes[:'primaryLanguageTag'] if attributes[:'primaryLanguageTag']

  raise 'You cannot provide both :primaryLanguageTag and :primary_language_tag' if attributes.key?(:'primaryLanguageTag') && attributes.key?(:'primary_language_tag')

  self.primary_language_tag = attributes[:'primary_language_tag'] if attributes[:'primary_language_tag']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#categoryString

The resource's category. This is used to group resource's together.

Returns:

  • (String)


29
30
31
# File 'lib/oci/oda/models/create_skill_details.rb', line 29

def category
  @category
end

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


57
58
59
# File 'lib/oci/oda/models/create_skill_details.rb', line 57

def defined_tags
  @defined_tags
end

#descriptionString

A short description of the resource.

Returns:

  • (String)


33
34
35
# File 'lib/oci/oda/models/create_skill_details.rb', line 33

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type, or scope. Example: `"value"`

Returns:

  • (Hash<String, String>)


51
52
53
# File 'lib/oci/oda/models/create_skill_details.rb', line 51

def freeform_tags
  @freeform_tags
end

#kindString

**[Required]** How to create the Skill.

Returns:

  • (String)


25
26
27
# File 'lib/oci/oda/models/create_skill_details.rb', line 25

def kind
  @kind
end

#multilingual_modeString

The multilingual mode for the resource.

Returns:

  • (String)


41
42
43
# File 'lib/oci/oda/models/create_skill_details.rb', line 41

def multilingual_mode
  @multilingual_mode
end

#platform_versionString

The ODA Platform Version for this resource.

Returns:

  • (String)


37
38
39
# File 'lib/oci/oda/models/create_skill_details.rb', line 37

def platform_version
  @platform_version
end

#primary_language_tagString

The primary language for the resource.

Returns:

  • (String)


45
46
47
# File 'lib/oci/oda/models/create_skill_details.rb', line 45

def primary_language_tag
  @primary_language_tag
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/oda/models/create_skill_details.rb', line 60

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'kind',
    'category': :'category',
    'description': :'description',
    'platform_version': :'platformVersion',
    'multilingual_mode': :'multilingualMode',
    'primary_language_tag': :'primaryLanguageTag',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/oda/models/create_skill_details.rb', line 96

def self.get_subtype(object_hash)
  type = object_hash[:'kind'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Oda::Models::CloneSkillDetails' if type == 'CLONE'
  return 'OCI::Oda::Models::CreateNewSkillDetails' if type == 'NEW'
  return 'OCI::Oda::Models::CreateSkillVersionDetails' if type == 'VERSION'
  return 'OCI::Oda::Models::ExtendSkillDetails' if type == 'EXTEND'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Oda::Models::CreateSkillDetails'
end

.swagger_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/oda/models/create_skill_details.rb', line 76

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'String',
    'category': :'String',
    'description': :'String',
    'platform_version': :'String',
    'multilingual_mode': :'String',
    'primary_language_tag': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/oda/models/create_skill_details.rb', line 189

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    kind == other.kind &&
    category == other.category &&
    description == other.description &&
    platform_version == other.platform_version &&
    multilingual_mode == other.multilingual_mode &&
    primary_language_tag == other.primary_language_tag &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/oci/oda/models/create_skill_details.rb', line 226

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/oci/oda/models/create_skill_details.rb', line 206

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



215
216
217
# File 'lib/oci/oda/models/create_skill_details.rb', line 215

def hash
  [kind, category, description, platform_version, multilingual_mode, primary_language_tag, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
# File 'lib/oci/oda/models/create_skill_details.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



253
254
255
# File 'lib/oci/oda/models/create_skill_details.rb', line 253

def to_s
  to_hash.to_s
end