Class: OCI::Oda::Models::CreateSkillParameterDetails
- Inherits:
-
Object
- Object
- OCI::Oda::Models::CreateSkillParameterDetails
- Defined in:
- lib/oci/oda/models/create_skill_parameter_details.rb
Overview
Properties that are required to create a Skill Parameter.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_STRING = 'STRING'.freeze, TYPE_INTEGER = 'INTEGER'.freeze, TYPE_FLOAT = 'FLOAT'.freeze, TYPE_BOOLEAN = 'BOOLEAN'.freeze, TYPE_SECURE = 'SECURE'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the Parameter.
-
#display_name ⇒ String
**[Required]** The display name for the Parameter.
-
#name ⇒ String
**[Required]** The Parameter name.
-
#type ⇒ String
**[Required]** The value type.
-
#value ⇒ String
**[Required]** The current value.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSkillParameterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSkillParameterDetails
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 75 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.type = attributes[:'type'] if attributes[:'type'] self.value = attributes[:'value'] if attributes[:'value'] end |
Instance Attribute Details
#description ⇒ String
A description of the Parameter.
28 29 30 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 28 def description @description end |
#display_name ⇒ String
**[Required]** The display name for the Parameter.
24 25 26 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 24 def display_name @display_name end |
#name ⇒ String
**[Required]** The Parameter name. This must be unique within the parent resource.
20 21 22 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 20 def name @name end |
#type ⇒ String
**[Required]** The value type.
32 33 34 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 32 def type @type end |
#value ⇒ String
**[Required]** The current value. The value will be interpreted based on the `type`.
36 37 38 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 36 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'display_name': :'displayName', 'description': :'description', 'type': :'type', 'value': :'value' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 52 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'display_name': :'String', 'description': :'String', 'type': :'String', 'value': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && display_name == other.display_name && description == other.description && type == other.type && value == other.value end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 134 def hash [name, display_name, description, type, value].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/oda/models/create_skill_parameter_details.rb', line 172 def to_s to_hash.to_s end |