Class: OCI::Oda::Models::CreateWebChannelResult

Inherits:
CreateChannelResult show all
Defined in:
lib/oci/oda/models/create_web_channel_result.rb

Overview

The configuration for a Web channel.

Constant Summary

Constants inherited from CreateChannelResult

OCI::Oda::Models::CreateChannelResult::CATEGORY_ENUM, OCI::Oda::Models::CreateChannelResult::LIFECYCLE_STATE_ENUM, OCI::Oda::Models::CreateChannelResult::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from CreateChannelResult

#category, #defined_tags, #description, #freeform_tags, #id, #lifecycle_state, #name, #session_expiry_duration_in_milliseconds, #time_created, #time_updated, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from CreateChannelResult

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ CreateWebChannelResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id proprety

  • :name (String)

    The value to assign to the #name proprety

  • :description (String)

    The value to assign to the #description proprety

  • :category (String)

    The value to assign to the #category proprety

  • :session_expiry_duration_in_milliseconds (Integer)

    The value to assign to the #session_expiry_duration_in_milliseconds proprety

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state proprety

  • :time_created (DateTime)

    The value to assign to the #time_created proprety

  • :time_updated (DateTime)

    The value to assign to the #time_updated proprety

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags proprety

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags proprety

  • :secret_key (String)

    The value to assign to the #secret_key property

  • :max_token_expiration_time_in_minutes (Integer)

    The value to assign to the #max_token_expiration_time_in_minutes property

  • :is_client_authentication_enabled (BOOLEAN)

    The value to assign to the #is_client_authentication_enabled property

  • :allowed_domains (String)

    The value to assign to the #allowed_domains property

  • :bot_id (String)

    The value to assign to the #bot_id property



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 109

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'WEB'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.secret_key = attributes[:'secretKey'] if attributes[:'secretKey']

  raise 'You cannot provide both :secretKey and :secret_key' if attributes.key?(:'secretKey') && attributes.key?(:'secret_key')

  self.secret_key = attributes[:'secret_key'] if attributes[:'secret_key']

  self.max_token_expiration_time_in_minutes = attributes[:'maxTokenExpirationTimeInMinutes'] if attributes[:'maxTokenExpirationTimeInMinutes']

  raise 'You cannot provide both :maxTokenExpirationTimeInMinutes and :max_token_expiration_time_in_minutes' if attributes.key?(:'maxTokenExpirationTimeInMinutes') && attributes.key?(:'max_token_expiration_time_in_minutes')

  self.max_token_expiration_time_in_minutes = attributes[:'max_token_expiration_time_in_minutes'] if attributes[:'max_token_expiration_time_in_minutes']

  self.is_client_authentication_enabled = attributes[:'isClientAuthenticationEnabled'] unless attributes[:'isClientAuthenticationEnabled'].nil?

  raise 'You cannot provide both :isClientAuthenticationEnabled and :is_client_authentication_enabled' if attributes.key?(:'isClientAuthenticationEnabled') && attributes.key?(:'is_client_authentication_enabled')

  self.is_client_authentication_enabled = attributes[:'is_client_authentication_enabled'] unless attributes[:'is_client_authentication_enabled'].nil?

  self.allowed_domains = attributes[:'allowedDomains'] if attributes[:'allowedDomains']

  raise 'You cannot provide both :allowedDomains and :allowed_domains' if attributes.key?(:'allowedDomains') && attributes.key?(:'allowed_domains')

  self.allowed_domains = attributes[:'allowed_domains'] if attributes[:'allowed_domains']

  self.bot_id = attributes[:'botId'] if attributes[:'botId']

  raise 'You cannot provide both :botId and :bot_id' if attributes.key?(:'botId') && attributes.key?(:'bot_id')

  self.bot_id = attributes[:'bot_id'] if attributes[:'bot_id']
end

Instance Attribute Details

#allowed_domainsString

A comma-delimited whitelist of allowed domains.

The channel will only communicate with the sites from the domains that you add to this list. For example, *.corp.example.com, *.hdr.example.com. Entering a single asterisk (*) allows unrestricted access to the channel from any domain.

Typically, you'd only enter a single asterisk during development. For production, you would add an allowlist of domains.

Returns:

  • (String)


34
35
36
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 34

def allowed_domains
  @allowed_domains
end

#bot_idString

The ID of the Skill or Digital Assistant that the Channel is routed to.

Returns:

  • (String)


38
39
40
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 38

def bot_id
  @bot_id
end

#is_client_authentication_enabledBOOLEAN

**[Required]** Whether client authentication is enabled or not.

Returns:

  • (BOOLEAN)


23
24
25
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 23

def is_client_authentication_enabled
  @is_client_authentication_enabled
end

#max_token_expiration_time_in_minutesInteger

The maximum time until the token expires (in minutes).

Returns:

  • (Integer)


19
20
21
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 19

def max_token_expiration_time_in_minutes
  @max_token_expiration_time_in_minutes
end

#secret_keyString

**[Required]** The secret key used to verify the authenticity of received messages. This is only returned this once. If it is lost the keys will need to be rotated to generate a new key.

Returns:

  • (String)


15
16
17
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 15

def secret_key
  @secret_key
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 41

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'description': :'description',
    'category': :'category',
    'type': :'type',
    'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'secret_key': :'secretKey',
    'max_token_expiration_time_in_minutes': :'maxTokenExpirationTimeInMinutes',
    'is_client_authentication_enabled': :'isClientAuthenticationEnabled',
    'allowed_domains': :'allowedDomains',
    'bot_id': :'botId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 65

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'description': :'String',
    'category': :'String',
    'type': :'String',
    'session_expiry_duration_in_milliseconds': :'Integer',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'secret_key': :'String',
    'max_token_expiration_time_in_minutes': :'Integer',
    'is_client_authentication_enabled': :'BOOLEAN',
    'allowed_domains': :'String',
    'bot_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 157

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    description == other.description &&
    category == other.category &&
    type == other.type &&
    session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    secret_key == other.secret_key &&
    max_token_expiration_time_in_minutes == other.max_token_expiration_time_in_minutes &&
    is_client_authentication_enabled == other.is_client_authentication_enabled &&
    allowed_domains == other.allowed_domains &&
    bot_id == other.bot_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 202

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


182
183
184
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 182

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



191
192
193
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 191

def hash
  [id, name, description, category, type, session_expiry_duration_in_milliseconds, lifecycle_state, time_created, time_updated, freeform_tags, defined_tags, secret_key, max_token_expiration_time_in_minutes, is_client_authentication_enabled, allowed_domains, bot_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
238
239
240
241
242
243
244
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 235

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



229
230
231
# File 'lib/oci/oda/models/create_web_channel_result.rb', line 229

def to_s
  to_hash.to_s
end