Class: OCI::Oda::Models::DigitalAssistant

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/oda/models/digital_assistant.rb

Overview

Digital Assistant metadata.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_DETAILS_ENUM =
[
  LIFECYCLE_DETAILS_PUBLISHED = 'PUBLISHED'.freeze,
  LIFECYCLE_DETAILS_DRAFT = 'DRAFT'.freeze,
  LIFECYCLE_DETAILS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
MULTILINGUAL_MODE_ENUM =
[
  MULTILINGUAL_MODE_NATIVE = 'NATIVE'.freeze,
  MULTILINGUAL_MODE_TRANSLATION = 'TRANSLATION'.freeze,
  MULTILINGUAL_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DigitalAssistant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :version (String)

    The value to assign to the #version property

  • :display_name (String)

    The value to assign to the #display_name property

  • :category (String)

    The value to assign to the #category property

  • :description (String)

    The value to assign to the #description property

  • :namespace (String)

    The value to assign to the #namespace property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :platform_version (String)

    The value to assign to the #platform_version property

  • :base_id (String)

    The value to assign to the #base_id property

  • :multilingual_mode (String)

    The value to assign to the #multilingual_mode property

  • :primary_language_tag (String)

    The value to assign to the #primary_language_tag property

  • :native_language_tags (Array<String>)

    The value to assign to the #native_language_tags property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/oci/oda/models/digital_assistant.rb', line 189

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.version = attributes[:'version'] if attributes[:'version']
  self.version = "1.0" if version.nil? && !attributes.key?(:'version') # rubocop:disable Style/StringLiterals

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.category = attributes[:'category'] if attributes[:'category']

  self.description = attributes[:'description'] if attributes[:'description']

  self.namespace = attributes[:'namespace'] if attributes[:'namespace']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.platform_version = attributes[:'platformVersion'] if attributes[:'platformVersion']

  raise 'You cannot provide both :platformVersion and :platform_version' if attributes.key?(:'platformVersion') && attributes.key?(:'platform_version')

  self.platform_version = attributes[:'platform_version'] if attributes[:'platform_version']

  self.base_id = attributes[:'baseId'] if attributes[:'baseId']

  raise 'You cannot provide both :baseId and :base_id' if attributes.key?(:'baseId') && attributes.key?(:'base_id')

  self.base_id = attributes[:'base_id'] if attributes[:'base_id']

  self.multilingual_mode = attributes[:'multilingualMode'] if attributes[:'multilingualMode']

  raise 'You cannot provide both :multilingualMode and :multilingual_mode' if attributes.key?(:'multilingualMode') && attributes.key?(:'multilingual_mode')

  self.multilingual_mode = attributes[:'multilingual_mode'] if attributes[:'multilingual_mode']

  self.primary_language_tag = attributes[:'primaryLanguageTag'] if attributes[:'primaryLanguageTag']

  raise 'You cannot provide both :primaryLanguageTag and :primary_language_tag' if attributes.key?(:'primaryLanguageTag') && attributes.key?(:'primary_language_tag')

  self.primary_language_tag = attributes[:'primary_language_tag'] if attributes[:'primary_language_tag']

  self.native_language_tags = attributes[:'nativeLanguageTags'] if attributes[:'nativeLanguageTags']

  raise 'You cannot provide both :nativeLanguageTags and :native_language_tags' if attributes.key?(:'nativeLanguageTags') && attributes.key?(:'native_language_tags')

  self.native_language_tags = attributes[:'native_language_tags'] if attributes[:'native_language_tags']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#base_idString

The unique identifier for the base reource (when this resource extends another).

Returns:

  • (String)


79
80
81
# File 'lib/oci/oda/models/digital_assistant.rb', line 79

def base_id
  @base_id
end

#categoryString

The resource's category. This is used to group resource's together.

Returns:

  • (String)


55
56
57
# File 'lib/oci/oda/models/digital_assistant.rb', line 55

def category
  @category
end

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


111
112
113
# File 'lib/oci/oda/models/digital_assistant.rb', line 111

def defined_tags
  @defined_tags
end

#descriptionString

A short description of the resource.

Returns:

  • (String)


59
60
61
# File 'lib/oci/oda/models/digital_assistant.rb', line 59

def description
  @description
end

#display_nameString

**[Required]** The resource's display name.

Returns:

  • (String)


51
52
53
# File 'lib/oci/oda/models/digital_assistant.rb', line 51

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type, or scope. Example: `"value"`

Returns:

  • (Hash<String, String>)


105
106
107
# File 'lib/oci/oda/models/digital_assistant.rb', line 105

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** Unique immutable identifier that was assigned when the resource was created.

Returns:

  • (String)


36
37
38
# File 'lib/oci/oda/models/digital_assistant.rb', line 36

def id
  @id
end

#lifecycle_detailsString

**[Required]** The resource's publish state.

Returns:

  • (String)


71
72
73
# File 'lib/oci/oda/models/digital_assistant.rb', line 71

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The resource's current state.

Returns:

  • (String)


67
68
69
# File 'lib/oci/oda/models/digital_assistant.rb', line 67

def lifecycle_state
  @lifecycle_state
end

#multilingual_modeString

The multilingual mode for the resource.

Returns:

  • (String)


83
84
85
# File 'lib/oci/oda/models/digital_assistant.rb', line 83

def multilingual_mode
  @multilingual_mode
end

#nameString

**[Required]** The reource's name. The name can contain only letters, numbers, periods, and underscores. The name must begin with a letter.

Returns:

  • (String)


41
42
43
# File 'lib/oci/oda/models/digital_assistant.rb', line 41

def name
  @name
end

#namespaceString

The resource's namespace.

Returns:

  • (String)


63
64
65
# File 'lib/oci/oda/models/digital_assistant.rb', line 63

def namespace
  @namespace
end

#native_language_tagsArray<String>

A list of native languages supported by this resource.

Returns:

  • (Array<String>)


91
92
93
# File 'lib/oci/oda/models/digital_assistant.rb', line 91

def native_language_tags
  @native_language_tags
end

#platform_versionString

**[Required]** The ODA Platform Version for this resource.

Returns:

  • (String)


75
76
77
# File 'lib/oci/oda/models/digital_assistant.rb', line 75

def platform_version
  @platform_version
end

#primary_language_tagString

The primary language for the resource.

Returns:

  • (String)


87
88
89
# File 'lib/oci/oda/models/digital_assistant.rb', line 87

def primary_language_tag
  @primary_language_tag
end

#time_createdDateTime

**[Required]** When the resource was created. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.

Returns:

  • (DateTime)


95
96
97
# File 'lib/oci/oda/models/digital_assistant.rb', line 95

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** When the resource was last updated. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.

Returns:

  • (DateTime)


99
100
101
# File 'lib/oci/oda/models/digital_assistant.rb', line 99

def time_updated
  @time_updated
end

#versionString

**[Required]** The resource's version. The version can only contain numbers, letters, periods, underscores, dashes or spaces. The version must begin with a letter or a number.

Returns:

  • (String)


46
47
48
# File 'lib/oci/oda/models/digital_assistant.rb', line 46

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/oda/models/digital_assistant.rb', line 114

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'version': :'version',
    'display_name': :'displayName',
    'category': :'category',
    'description': :'description',
    'namespace': :'namespace',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'platform_version': :'platformVersion',
    'base_id': :'baseId',
    'multilingual_mode': :'multilingualMode',
    'primary_language_tag': :'primaryLanguageTag',
    'native_language_tags': :'nativeLanguageTags',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/oda/models/digital_assistant.rb', line 140

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'version': :'String',
    'display_name': :'String',
    'category': :'String',
    'description': :'String',
    'namespace': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'platform_version': :'String',
    'base_id': :'String',
    'multilingual_mode': :'String',
    'primary_language_tag': :'String',
    'native_language_tags': :'Array<String>',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/oci/oda/models/digital_assistant.rb', line 324

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    version == other.version &&
    display_name == other.display_name &&
    category == other.category &&
    description == other.description &&
    namespace == other.namespace &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    platform_version == other.platform_version &&
    base_id == other.base_id &&
    multilingual_mode == other.multilingual_mode &&
    primary_language_tag == other.primary_language_tag &&
    native_language_tags == other.native_language_tags &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/oci/oda/models/digital_assistant.rb', line 371

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


351
352
353
# File 'lib/oci/oda/models/digital_assistant.rb', line 351

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



360
361
362
# File 'lib/oci/oda/models/digital_assistant.rb', line 360

def hash
  [id, name, version, display_name, category, description, namespace, lifecycle_state, lifecycle_details, platform_version, base_id, multilingual_mode, primary_language_tag, native_language_tags, time_created, time_updated, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



404
405
406
407
408
409
410
411
412
413
# File 'lib/oci/oda/models/digital_assistant.rb', line 404

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



398
399
400
# File 'lib/oci/oda/models/digital_assistant.rb', line 398

def to_s
  to_hash.to_s
end