Class: OCI::Oda::Models::Package
- Inherits:
-
Object
- Object
- OCI::Oda::Models::Package
- Defined in:
- lib/oci/oda/models/package.rb
Overview
Details of `Package` object.
Instance Attribute Summary collapse
-
#default_parameter_values ⇒ OCI::Oda::Models::DefaultParameterValues
This attribute is required.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
**[Required]** Description of the package.
-
#display_name ⇒ String
**[Required]** Display name for the package (displayed in UI and user-facing applications).
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
**[Required]** Unique immutable identifier that was assigned when the Package was registered.
-
#import_contract ⇒ OCI::Oda::Models::ImportContract
This attribute is required.
-
#name ⇒ String
**[Required]** Name of package.
-
#publisher_id ⇒ String
**[Required]** ID of the publisher providing the package.
-
#publisher_metadata ⇒ Array<OCI::Oda::Models::MetadataProperty>
**[Required]** A map of metadata key/value pairs that further describes the publisher and the platform in which the package might be used.
-
#resource_types ⇒ Array<String>
**[Required]** A list of resource types describing the content of the package.
-
#resource_types_metadata ⇒ Array<OCI::Oda::Models::ResourceTypeMetadata>
**[Required]** A map of resource type to metadata key/value map that further describes the content for the resource types in this package..
-
#time_published ⇒ DateTime
**[Required]** When the package was last published.
-
#time_uploaded ⇒ DateTime
**[Required]** When the package was uploaded.
-
#version ⇒ String
**[Required]** Version of the package.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Package
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Package
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/oci/oda/models/package.rb', line 142 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.publisher_id = attributes[:'publisherId'] if attributes[:'publisherId'] raise 'You cannot provide both :publisherId and :publisher_id' if attributes.key?(:'publisherId') && attributes.key?(:'publisher_id') self.publisher_id = attributes[:'publisher_id'] if attributes[:'publisher_id'] self.name = attributes[:'name'] if attributes[:'name'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.version = attributes[:'version'] if attributes[:'version'] self.time_uploaded = attributes[:'timeUploaded'] if attributes[:'timeUploaded'] raise 'You cannot provide both :timeUploaded and :time_uploaded' if attributes.key?(:'timeUploaded') && attributes.key?(:'time_uploaded') self.time_uploaded = attributes[:'time_uploaded'] if attributes[:'time_uploaded'] self.time_published = attributes[:'timePublished'] if attributes[:'timePublished'] raise 'You cannot provide both :timePublished and :time_published' if attributes.key?(:'timePublished') && attributes.key?(:'time_published') self.time_published = attributes[:'time_published'] if attributes[:'time_published'] self.description = attributes[:'description'] if attributes[:'description'] self.resource_types = attributes[:'resourceTypes'] if attributes[:'resourceTypes'] raise 'You cannot provide both :resourceTypes and :resource_types' if attributes.key?(:'resourceTypes') && attributes.key?(:'resource_types') self.resource_types = attributes[:'resource_types'] if attributes[:'resource_types'] self. = attributes[:'resourceTypesMetadata'] if attributes[:'resourceTypesMetadata'] raise 'You cannot provide both :resourceTypesMetadata and :resource_types_metadata' if attributes.key?(:'resourceTypesMetadata') && attributes.key?(:'resource_types_metadata') self. = attributes[:'resource_types_metadata'] if attributes[:'resource_types_metadata'] self. = attributes[:'publisherMetadata'] if attributes[:'publisherMetadata'] raise 'You cannot provide both :publisherMetadata and :publisher_metadata' if attributes.key?(:'publisherMetadata') && attributes.key?(:'publisher_metadata') self. = attributes[:'publisher_metadata'] if attributes[:'publisher_metadata'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.import_contract = attributes[:'importContract'] if attributes[:'importContract'] raise 'You cannot provide both :importContract and :import_contract' if attributes.key?(:'importContract') && attributes.key?(:'import_contract') self.import_contract = attributes[:'import_contract'] if attributes[:'import_contract'] self.default_parameter_values = attributes[:'defaultParameterValues'] if attributes[:'defaultParameterValues'] raise 'You cannot provide both :defaultParameterValues and :default_parameter_values' if attributes.key?(:'defaultParameterValues') && attributes.key?(:'default_parameter_values') self.default_parameter_values = attributes[:'default_parameter_values'] if attributes[:'default_parameter_values'] end |
Instance Attribute Details
#default_parameter_values ⇒ OCI::Oda::Models::DefaultParameterValues
This attribute is required.
73 74 75 |
# File 'lib/oci/oda/models/package.rb', line 73 def default_parameter_values @default_parameter_values end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
65 66 67 |
# File 'lib/oci/oda/models/package.rb', line 65 def @defined_tags end |
#description ⇒ String
**[Required]** Description of the package.
41 42 43 |
# File 'lib/oci/oda/models/package.rb', line 41 def description @description end |
#display_name ⇒ String
**[Required]** Display name for the package (displayed in UI and user-facing applications).
25 26 27 |
# File 'lib/oci/oda/models/package.rb', line 25 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope. Example: `"value"`
59 60 61 |
# File 'lib/oci/oda/models/package.rb', line 59 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique immutable identifier that was assigned when the Package was registered.
12 13 14 |
# File 'lib/oci/oda/models/package.rb', line 12 def id @id end |
#import_contract ⇒ OCI::Oda::Models::ImportContract
This attribute is required.
69 70 71 |
# File 'lib/oci/oda/models/package.rb', line 69 def import_contract @import_contract end |
#name ⇒ String
**[Required]** Name of package.
21 22 23 |
# File 'lib/oci/oda/models/package.rb', line 21 def name @name end |
#publisher_id ⇒ String
**[Required]** ID of the publisher providing the package.
17 18 19 |
# File 'lib/oci/oda/models/package.rb', line 17 def publisher_id @publisher_id end |
#publisher_metadata ⇒ Array<OCI::Oda::Models::MetadataProperty>
**[Required]** A map of metadata key/value pairs that further describes the publisher and the platform in which the package might be used.
53 54 55 |
# File 'lib/oci/oda/models/package.rb', line 53 def @publisher_metadata end |
#resource_types ⇒ Array<String>
**[Required]** A list of resource types describing the content of the package.
45 46 47 |
# File 'lib/oci/oda/models/package.rb', line 45 def resource_types @resource_types end |
#resource_types_metadata ⇒ Array<OCI::Oda::Models::ResourceTypeMetadata>
**[Required]** A map of resource type to metadata key/value map that further describes the content for the resource types in this package.. Keys are resource type names, values are a map of name/value pairs per resource type.
49 50 51 |
# File 'lib/oci/oda/models/package.rb', line 49 def @resource_types_metadata end |
#time_published ⇒ DateTime
**[Required]** When the package was last published. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
37 38 39 |
# File 'lib/oci/oda/models/package.rb', line 37 def time_published @time_published end |
#time_uploaded ⇒ DateTime
**[Required]** When the package was uploaded. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
33 34 35 |
# File 'lib/oci/oda/models/package.rb', line 33 def time_uploaded @time_uploaded end |
#version ⇒ String
**[Required]** Version of the package.
29 30 31 |
# File 'lib/oci/oda/models/package.rb', line 29 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/oda/models/package.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'publisher_id': :'publisherId', 'name': :'name', 'display_name': :'displayName', 'version': :'version', 'time_uploaded': :'timeUploaded', 'time_published': :'timePublished', 'description': :'description', 'resource_types': :'resourceTypes', 'resource_types_metadata': :'resourceTypesMetadata', 'publisher_metadata': :'publisherMetadata', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'import_contract': :'importContract', 'default_parameter_values': :'defaultParameterValues' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/oda/models/package.rb', line 99 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'publisher_id': :'String', 'name': :'String', 'display_name': :'String', 'version': :'String', 'time_uploaded': :'DateTime', 'time_published': :'DateTime', 'description': :'String', 'resource_types': :'Array<String>', 'resource_types_metadata': :'Array<OCI::Oda::Models::ResourceTypeMetadata>', 'publisher_metadata': :'Array<OCI::Oda::Models::MetadataProperty>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'import_contract': :'OCI::Oda::Models::ImportContract', 'default_parameter_values': :'OCI::Oda::Models::DefaultParameterValues' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/oda/models/package.rb', line 230 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && publisher_id == other.publisher_id && name == other.name && display_name == other.display_name && version == other.version && time_uploaded == other.time_uploaded && time_published == other.time_published && description == other.description && resource_types == other.resource_types && == other. && == other. && == other. && == other. && import_contract == other.import_contract && default_parameter_values == other.default_parameter_values end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/oci/oda/models/package.rb', line 274 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
254 255 256 |
# File 'lib/oci/oda/models/package.rb', line 254 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/oci/oda/models/package.rb', line 263 def hash [id, publisher_id, name, display_name, version, time_uploaded, time_published, description, resource_types, , , , , import_contract, default_parameter_values].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
307 308 309 310 311 312 313 314 315 316 |
# File 'lib/oci/oda/models/package.rb', line 307 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
301 302 303 |
# File 'lib/oci/oda/models/package.rb', line 301 def to_s to_hash.to_s end |