Class: OCI::Oda::Models::PackageSummary
- Inherits:
-
Object
- Object
- OCI::Oda::Models::PackageSummary
- Defined in:
- lib/oci/oda/models/package_summary.rb
Overview
Summary of `Package` object.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
**[Required]** Description of the package.
-
#display_name ⇒ String
**[Required]** Display name for the package (displayed in UI and user-facing applications).
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
**[Required]** Unique immutable identifier that was assigned when the Package was registered.
-
#name ⇒ String
**[Required]** Name of package.
-
#publisher_id ⇒ String
**[Required]** ID of the publisher providing the package.
-
#publisher_metadata ⇒ Array<OCI::Oda::Models::MetadataProperty>
**[Required]** A map of metadata key/value pairs that further describes the publisher and the platform in which the package might be used.
-
#resource_types ⇒ Array<String>
**[Required]** A list of resource types describing the content of the package.
-
#resource_types_metadata ⇒ Array<OCI::Oda::Models::ResourceTypeMetadata>
**[Required]** A map of resource type to metadata key/value map that further describes the content for the resource types in this package..
-
#time_published ⇒ DateTime
**[Required]** When the package was last published.
-
#version ⇒ String
**[Required]** Version of the package.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PackageSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PackageSummary
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/oda/models/package_summary.rb', line 121 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.publisher_id = attributes[:'publisherId'] if attributes[:'publisherId'] raise 'You cannot provide both :publisherId and :publisher_id' if attributes.key?(:'publisherId') && attributes.key?(:'publisher_id') self.publisher_id = attributes[:'publisher_id'] if attributes[:'publisher_id'] self.name = attributes[:'name'] if attributes[:'name'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.version = attributes[:'version'] if attributes[:'version'] self.time_published = attributes[:'timePublished'] if attributes[:'timePublished'] raise 'You cannot provide both :timePublished and :time_published' if attributes.key?(:'timePublished') && attributes.key?(:'time_published') self.time_published = attributes[:'time_published'] if attributes[:'time_published'] self.description = attributes[:'description'] if attributes[:'description'] self.resource_types = attributes[:'resourceTypes'] if attributes[:'resourceTypes'] raise 'You cannot provide both :resourceTypes and :resource_types' if attributes.key?(:'resourceTypes') && attributes.key?(:'resource_types') self.resource_types = attributes[:'resource_types'] if attributes[:'resource_types'] self. = attributes[:'resourceTypesMetadata'] if attributes[:'resourceTypesMetadata'] raise 'You cannot provide both :resourceTypesMetadata and :resource_types_metadata' if attributes.key?(:'resourceTypesMetadata') && attributes.key?(:'resource_types_metadata') self. = attributes[:'resource_types_metadata'] if attributes[:'resource_types_metadata'] self. = attributes[:'publisherMetadata'] if attributes[:'publisherMetadata'] raise 'You cannot provide both :publisherMetadata and :publisher_metadata' if attributes.key?(:'publisherMetadata') && attributes.key?(:'publisher_metadata') self. = attributes[:'publisher_metadata'] if attributes[:'publisher_metadata'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
61 62 63 |
# File 'lib/oci/oda/models/package_summary.rb', line 61 def @defined_tags end |
#description ⇒ String
**[Required]** Description of the package.
37 38 39 |
# File 'lib/oci/oda/models/package_summary.rb', line 37 def description @description end |
#display_name ⇒ String
**[Required]** Display name for the package (displayed in UI and user-facing applications).
25 26 27 |
# File 'lib/oci/oda/models/package_summary.rb', line 25 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope. Example: `"value"`
55 56 57 |
# File 'lib/oci/oda/models/package_summary.rb', line 55 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique immutable identifier that was assigned when the Package was registered.
12 13 14 |
# File 'lib/oci/oda/models/package_summary.rb', line 12 def id @id end |
#name ⇒ String
**[Required]** Name of package.
21 22 23 |
# File 'lib/oci/oda/models/package_summary.rb', line 21 def name @name end |
#publisher_id ⇒ String
**[Required]** ID of the publisher providing the package.
17 18 19 |
# File 'lib/oci/oda/models/package_summary.rb', line 17 def publisher_id @publisher_id end |
#publisher_metadata ⇒ Array<OCI::Oda::Models::MetadataProperty>
**[Required]** A map of metadata key/value pairs that further describes the publisher and the platform in which the package might be used.
49 50 51 |
# File 'lib/oci/oda/models/package_summary.rb', line 49 def @publisher_metadata end |
#resource_types ⇒ Array<String>
**[Required]** A list of resource types describing the content of the package.
41 42 43 |
# File 'lib/oci/oda/models/package_summary.rb', line 41 def resource_types @resource_types end |
#resource_types_metadata ⇒ Array<OCI::Oda::Models::ResourceTypeMetadata>
**[Required]** A map of resource type to metadata key/value map that further describes the content for the resource types in this package.. Keys are resource type names, values are a map of name/value pairs per resource type.
45 46 47 |
# File 'lib/oci/oda/models/package_summary.rb', line 45 def @resource_types_metadata end |
#time_published ⇒ DateTime
**[Required]** When the package was last published. A date-time string as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
33 34 35 |
# File 'lib/oci/oda/models/package_summary.rb', line 33 def time_published @time_published end |
#version ⇒ String
**[Required]** Version of the package.
29 30 31 |
# File 'lib/oci/oda/models/package_summary.rb', line 29 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/oda/models/package_summary.rb', line 64 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'publisher_id': :'publisherId', 'name': :'name', 'display_name': :'displayName', 'version': :'version', 'time_published': :'timePublished', 'description': :'description', 'resource_types': :'resourceTypes', 'resource_types_metadata': :'resourceTypesMetadata', 'publisher_metadata': :'publisherMetadata', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/oda/models/package_summary.rb', line 84 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'publisher_id': :'String', 'name': :'String', 'display_name': :'String', 'version': :'String', 'time_published': :'DateTime', 'description': :'String', 'resource_types': :'Array<String>', 'resource_types_metadata': :'Array<OCI::Oda::Models::ResourceTypeMetadata>', 'publisher_metadata': :'Array<OCI::Oda::Models::MetadataProperty>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/oda/models/package_summary.rb', line 191 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && publisher_id == other.publisher_id && name == other.name && display_name == other.display_name && version == other.version && time_published == other.time_published && description == other.description && resource_types == other.resource_types && == other. && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/oci/oda/models/package_summary.rb', line 232 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
212 213 214 |
# File 'lib/oci/oda/models/package_summary.rb', line 212 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/oci/oda/models/package_summary.rb', line 221 def hash [id, publisher_id, name, display_name, version, time_published, description, resource_types, , , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
265 266 267 268 269 270 271 272 273 274 |
# File 'lib/oci/oda/models/package_summary.rb', line 265 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
259 260 261 |
# File 'lib/oci/oda/models/package_summary.rb', line 259 def to_s to_hash.to_s end |