Class: OCI::Oda::Models::SlackChannel
- Defined in:
- lib/oci/oda/models/slack_channel.rb
Overview
The configuration for a Slack channel.
Constant Summary
Constants inherited from Channel
Channel::CATEGORY_ENUM, Channel::LIFECYCLE_STATE_ENUM, Channel::TYPE_ENUM
Instance Attribute Summary collapse
-
#auth_error_url ⇒ String
The URL to redirect to when authentication is unsuccessful.
-
#auth_success_url ⇒ String
The URL to redirect to when authentication is successful.
-
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
-
#client_id ⇒ String
**[Required]** The Slack Client Id for the Slack app.
-
#webhook_url ⇒ String
**[Required]** The URL to use to send messages to this channel.
Attributes inherited from Channel
#category, #defined_tags, #description, #freeform_tags, #id, #lifecycle_state, #name, #session_expiry_duration_in_milliseconds, #time_created, #time_updated, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SlackChannel
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from Channel
Constructor Details
#initialize(attributes = {}) ⇒ SlackChannel
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/oda/models/slack_channel.rb', line 102 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'SLACK' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.client_id = attributes[:'clientId'] if attributes[:'clientId'] raise 'You cannot provide both :clientId and :client_id' if attributes.key?(:'clientId') && attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] if attributes[:'client_id'] self.auth_success_url = attributes[:'authSuccessUrl'] if attributes[:'authSuccessUrl'] raise 'You cannot provide both :authSuccessUrl and :auth_success_url' if attributes.key?(:'authSuccessUrl') && attributes.key?(:'auth_success_url') self.auth_success_url = attributes[:'auth_success_url'] if attributes[:'auth_success_url'] self.auth_error_url = attributes[:'authErrorUrl'] if attributes[:'authErrorUrl'] raise 'You cannot provide both :authErrorUrl and :auth_error_url' if attributes.key?(:'authErrorUrl') && attributes.key?(:'auth_error_url') self.auth_error_url = attributes[:'auth_error_url'] if attributes[:'auth_error_url'] self.bot_id = attributes[:'botId'] if attributes[:'botId'] raise 'You cannot provide both :botId and :bot_id' if attributes.key?(:'botId') && attributes.key?(:'bot_id') self.bot_id = attributes[:'bot_id'] if attributes[:'bot_id'] self.webhook_url = attributes[:'webhookUrl'] if attributes[:'webhookUrl'] raise 'You cannot provide both :webhookUrl and :webhook_url' if attributes.key?(:'webhookUrl') && attributes.key?(:'webhook_url') self.webhook_url = attributes[:'webhook_url'] if attributes[:'webhook_url'] end |
Instance Attribute Details
#auth_error_url ⇒ String
The URL to redirect to when authentication is unsuccessful.
21 22 23 |
# File 'lib/oci/oda/models/slack_channel.rb', line 21 def auth_error_url @auth_error_url end |
#auth_success_url ⇒ String
The URL to redirect to when authentication is successful.
17 18 19 |
# File 'lib/oci/oda/models/slack_channel.rb', line 17 def auth_success_url @auth_success_url end |
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
25 26 27 |
# File 'lib/oci/oda/models/slack_channel.rb', line 25 def bot_id @bot_id end |
#client_id ⇒ String
**[Required]** The Slack Client Id for the Slack app.
13 14 15 |
# File 'lib/oci/oda/models/slack_channel.rb', line 13 def client_id @client_id end |
#webhook_url ⇒ String
**[Required]** The URL to use to send messages to this channel. This will be generally be used to configure a webhook in a 3rd party messaging system to send messages to this channel.
31 32 33 |
# File 'lib/oci/oda/models/slack_channel.rb', line 31 def webhook_url @webhook_url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/oda/models/slack_channel.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'description': :'description', 'category': :'category', 'type': :'type', 'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'client_id': :'clientId', 'auth_success_url': :'authSuccessUrl', 'auth_error_url': :'authErrorUrl', 'bot_id': :'botId', 'webhook_url': :'webhookUrl' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/oda/models/slack_channel.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'description': :'String', 'category': :'String', 'type': :'String', 'session_expiry_duration_in_milliseconds': :'Integer', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'client_id': :'String', 'auth_success_url': :'String', 'auth_error_url': :'String', 'bot_id': :'String', 'webhook_url': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/oda/models/slack_channel.rb', line 150 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && category == other.category && type == other.type && session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && client_id == other.client_id && auth_success_url == other.auth_success_url && auth_error_url == other.auth_error_url && bot_id == other.bot_id && webhook_url == other.webhook_url end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/oda/models/slack_channel.rb', line 195 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
175 176 177 |
# File 'lib/oci/oda/models/slack_channel.rb', line 175 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/oci/oda/models/slack_channel.rb', line 184 def hash [id, name, description, category, type, session_expiry_duration_in_milliseconds, lifecycle_state, time_created, time_updated, , , client_id, auth_success_url, auth_error_url, bot_id, webhook_url].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/oda/models/slack_channel.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
222 223 224 |
# File 'lib/oci/oda/models/slack_channel.rb', line 222 def to_s to_hash.to_s end |