Class: OCI::Oda::Models::TwilioChannel
- Defined in:
- lib/oci/oda/models/twilio_channel.rb
Overview
The configuration for a Twilio channel.
Constant Summary
Constants inherited from Channel
Channel::CATEGORY_ENUM, Channel::LIFECYCLE_STATE_ENUM, Channel::TYPE_ENUM
Instance Attribute Summary collapse
-
#account_sid ⇒ String
**[Required]** The Account SID for the Twilio number.
-
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
-
#is_mms_enabled ⇒ BOOLEAN
**[Required]** Whether MMS is enabled for this channel or not.
-
#original_connectors_url ⇒ String
The original connectors URL (used for backward compatibility).
-
#phone_number ⇒ String
**[Required]** The Twilio phone number.
-
#webhook_url ⇒ String
**[Required]** The URL to use to send messages to this channel.
Attributes inherited from Channel
#category, #defined_tags, #description, #freeform_tags, #id, #lifecycle_state, #name, #session_expiry_duration_in_milliseconds, #time_created, #time_updated, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TwilioChannel
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from Channel
Constructor Details
#initialize(attributes = {}) ⇒ TwilioChannel
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 109 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'TWILIO' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.account_sid = attributes[:'accountSID'] if attributes[:'accountSID'] raise 'You cannot provide both :accountSID and :account_sid' if attributes.key?(:'accountSID') && attributes.key?(:'account_sid') self.account_sid = attributes[:'account_sid'] if attributes[:'account_sid'] self.phone_number = attributes[:'phoneNumber'] if attributes[:'phoneNumber'] raise 'You cannot provide both :phoneNumber and :phone_number' if attributes.key?(:'phoneNumber') && attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] if attributes[:'phone_number'] self.is_mms_enabled = attributes[:'isMmsEnabled'] unless attributes[:'isMmsEnabled'].nil? raise 'You cannot provide both :isMmsEnabled and :is_mms_enabled' if attributes.key?(:'isMmsEnabled') && attributes.key?(:'is_mms_enabled') self.is_mms_enabled = attributes[:'is_mms_enabled'] unless attributes[:'is_mms_enabled'].nil? self.original_connectors_url = attributes[:'originalConnectorsUrl'] if attributes[:'originalConnectorsUrl'] raise 'You cannot provide both :originalConnectorsUrl and :original_connectors_url' if attributes.key?(:'originalConnectorsUrl') && attributes.key?(:'original_connectors_url') self.original_connectors_url = attributes[:'original_connectors_url'] if attributes[:'original_connectors_url'] self.bot_id = attributes[:'botId'] if attributes[:'botId'] raise 'You cannot provide both :botId and :bot_id' if attributes.key?(:'botId') && attributes.key?(:'bot_id') self.bot_id = attributes[:'bot_id'] if attributes[:'bot_id'] self.webhook_url = attributes[:'webhookUrl'] if attributes[:'webhookUrl'] raise 'You cannot provide both :webhookUrl and :webhook_url' if attributes.key?(:'webhookUrl') && attributes.key?(:'webhook_url') self.webhook_url = attributes[:'webhook_url'] if attributes[:'webhook_url'] end |
Instance Attribute Details
#account_sid ⇒ String
**[Required]** The Account SID for the Twilio number.
13 14 15 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 13 def account_sid @account_sid end |
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
29 30 31 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 29 def bot_id @bot_id end |
#is_mms_enabled ⇒ BOOLEAN
**[Required]** Whether MMS is enabled for this channel or not.
21 22 23 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 21 def is_mms_enabled @is_mms_enabled end |
#original_connectors_url ⇒ String
The original connectors URL (used for backward compatibility).
25 26 27 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 25 def original_connectors_url @original_connectors_url end |
#phone_number ⇒ String
**[Required]** The Twilio phone number.
17 18 19 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 17 def phone_number @phone_number end |
#webhook_url ⇒ String
**[Required]** The URL to use to send messages to this channel. This will be generally be used to configure a webhook in a 3rd party messaging system to send messages to this channel.
35 36 37 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 35 def webhook_url @webhook_url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'description': :'description', 'category': :'category', 'type': :'type', 'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'account_sid': :'accountSID', 'phone_number': :'phoneNumber', 'is_mms_enabled': :'isMmsEnabled', 'original_connectors_url': :'originalConnectorsUrl', 'bot_id': :'botId', 'webhook_url': :'webhookUrl' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'description': :'String', 'category': :'String', 'type': :'String', 'session_expiry_duration_in_milliseconds': :'Integer', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'account_sid': :'String', 'phone_number': :'String', 'is_mms_enabled': :'BOOLEAN', 'original_connectors_url': :'String', 'bot_id': :'String', 'webhook_url': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 163 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && category == other.category && type == other.type && session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && account_sid == other.account_sid && phone_number == other.phone_number && is_mms_enabled == other.is_mms_enabled && original_connectors_url == other.original_connectors_url && bot_id == other.bot_id && webhook_url == other.webhook_url end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 209 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
189 190 191 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 189 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 198 def hash [id, name, description, category, type, session_expiry_duration_in_milliseconds, lifecycle_state, time_created, time_updated, , , account_sid, phone_number, is_mms_enabled, original_connectors_url, bot_id, webhook_url].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 242 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
236 237 238 |
# File 'lib/oci/oda/models/twilio_channel.rb', line 236 def to_s to_hash.to_s end |