Class: OCI::Oda::Models::UpdateChannelDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/oda/models/update_channel_details.rb

Overview

Properties to update a Channel. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_ANDROID = 'ANDROID'.freeze,
  TYPE_APPEVENT = 'APPEVENT'.freeze,
  TYPE_APPLICATION = 'APPLICATION'.freeze,
  TYPE_CORTANA = 'CORTANA'.freeze,
  TYPE_FACEBOOK = 'FACEBOOK'.freeze,
  TYPE_IOS = 'IOS'.freeze,
  TYPE_MSTEAMS = 'MSTEAMS'.freeze,
  TYPE_OSS = 'OSS'.freeze,
  TYPE_OSVC = 'OSVC'.freeze,
  TYPE_SERVICECLOUD = 'SERVICECLOUD'.freeze,
  TYPE_SLACK = 'SLACK'.freeze,
  TYPE_TEST = 'TEST'.freeze,
  TYPE_TWILIO = 'TWILIO'.freeze,
  TYPE_WEB = 'WEB'.freeze,
  TYPE_WEBHOOK = 'WEBHOOK'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateChannelDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :description (String)

    The value to assign to the #description property

  • :type (String)

    The value to assign to the #type property

  • :session_expiry_duration_in_milliseconds (Integer)

    The value to assign to the #session_expiry_duration_in_milliseconds property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/oci/oda/models/update_channel_details.rb', line 118

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.type = attributes[:'type'] if attributes[:'type']

  self.session_expiry_duration_in_milliseconds = attributes[:'sessionExpiryDurationInMilliseconds'] if attributes[:'sessionExpiryDurationInMilliseconds']

  raise 'You cannot provide both :sessionExpiryDurationInMilliseconds and :session_expiry_duration_in_milliseconds' if attributes.key?(:'sessionExpiryDurationInMilliseconds') && attributes.key?(:'session_expiry_duration_in_milliseconds')

  self.session_expiry_duration_in_milliseconds = attributes[:'session_expiry_duration_in_milliseconds'] if attributes[:'session_expiry_duration_in_milliseconds']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


51
52
53
# File 'lib/oci/oda/models/update_channel_details.rb', line 51

def defined_tags
  @defined_tags
end

#descriptionString

A short description of the Channel.

Returns:

  • (String)


31
32
33
# File 'lib/oci/oda/models/update_channel_details.rb', line 31

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type, or scope. Example: `"value"`

Returns:

  • (Hash<String, String>)


45
46
47
# File 'lib/oci/oda/models/update_channel_details.rb', line 45

def freeform_tags
  @freeform_tags
end

#session_expiry_duration_in_millisecondsInteger

The number of milliseconds before a session expires.

Returns:

  • (Integer)


39
40
41
# File 'lib/oci/oda/models/update_channel_details.rb', line 39

def session_expiry_duration_in_milliseconds
  @session_expiry_duration_in_milliseconds
end

#typeString

**[Required]** The Channel type.

Returns:

  • (String)


35
36
37
# File 'lib/oci/oda/models/update_channel_details.rb', line 35

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/oda/models/update_channel_details.rb', line 54

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'type': :'type',
    'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/oda/models/update_channel_details.rb', line 84

def self.get_subtype(object_hash)
  type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Oda::Models::UpdateOsvcChannelDetails' if type == 'OSVC'
  return 'OCI::Oda::Models::UpdateOSSChannelDetails' if type == 'OSS'
  return 'OCI::Oda::Models::UpdateAndroidChannelDetails' if type == 'ANDROID'
  return 'OCI::Oda::Models::UpdateMSTeamsChannelDetails' if type == 'MSTEAMS'
  return 'OCI::Oda::Models::UpdateAppEventChannelDetails' if type == 'APPEVENT'
  return 'OCI::Oda::Models::UpdateWebChannelDetails' if type == 'WEB'
  return 'OCI::Oda::Models::UpdateIosChannelDetails' if type == 'IOS'
  return 'OCI::Oda::Models::UpdateSlackChannelDetails' if type == 'SLACK'
  return 'OCI::Oda::Models::UpdateServiceCloudChannelDetails' if type == 'SERVICECLOUD'
  return 'OCI::Oda::Models::UpdateTwilioChannelDetails' if type == 'TWILIO'
  return 'OCI::Oda::Models::UpdateWebhookChannelDetails' if type == 'WEBHOOK'
  return 'OCI::Oda::Models::UpdateApplicationChannelDetails' if type == 'APPLICATION'
  return 'OCI::Oda::Models::UpdateFacebookChannelDetails' if type == 'FACEBOOK'
  return 'OCI::Oda::Models::UpdateCortanaChannelDetails' if type == 'CORTANA'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Oda::Models::UpdateChannelDetails'
end

.swagger_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
# File 'lib/oci/oda/models/update_channel_details.rb', line 67

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'type': :'String',
    'session_expiry_duration_in_milliseconds': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/oda/models/update_channel_details.rb', line 162

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    type == other.type &&
    session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/oda/models/update_channel_details.rb', line 196

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/oci/oda/models/update_channel_details.rb', line 176

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



185
186
187
# File 'lib/oci/oda/models/update_channel_details.rb', line 185

def hash
  [description, type, session_expiry_duration_in_milliseconds, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
# File 'lib/oci/oda/models/update_channel_details.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



223
224
225
# File 'lib/oci/oda/models/update_channel_details.rb', line 223

def to_s
  to_hash.to_s
end