Class: OCI::Oda::Models::UpdateCortanaChannelDetails
- Inherits:
-
UpdateChannelDetails
- Object
- UpdateChannelDetails
- OCI::Oda::Models::UpdateCortanaChannelDetails
- Defined in:
- lib/oci/oda/models/update_cortana_channel_details.rb
Overview
Properties to update a Cortana channel.
Constant Summary
Constants inherited from UpdateChannelDetails
OCI::Oda::Models::UpdateChannelDetails::TYPE_ENUM
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
-
#msa_app_id ⇒ String
The Microsoft App ID that you obtained when you created your bot registration in Azure.
-
#msa_app_password ⇒ String
The client secret that you obtained from your bot registration.
Attributes inherited from UpdateChannelDetails
#defined_tags, #description, #freeform_tags, #session_expiry_duration_in_milliseconds, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCortanaChannelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateChannelDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCortanaChannelDetails
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'CORTANA' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.msa_app_id = attributes[:'msaAppId'] if attributes[:'msaAppId'] raise 'You cannot provide both :msaAppId and :msa_app_id' if attributes.key?(:'msaAppId') && attributes.key?(:'msa_app_id') self.msa_app_id = attributes[:'msa_app_id'] if attributes[:'msa_app_id'] self.msa_app_password = attributes[:'msaAppPassword'] if attributes[:'msaAppPassword'] raise 'You cannot provide both :msaAppPassword and :msa_app_password' if attributes.key?(:'msaAppPassword') && attributes.key?(:'msa_app_password') self.msa_app_password = attributes[:'msa_app_password'] if attributes[:'msa_app_password'] self.bot_id = attributes[:'botId'] if attributes[:'botId'] raise 'You cannot provide both :botId and :bot_id' if attributes.key?(:'botId') && attributes.key?(:'bot_id') self.bot_id = attributes[:'bot_id'] if attributes[:'bot_id'] end |
Instance Attribute Details
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
21 22 23 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 21 def bot_id @bot_id end |
#msa_app_id ⇒ String
The Microsoft App ID that you obtained when you created your bot registration in Azure.
13 14 15 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 13 def msa_app_id @msa_app_id end |
#msa_app_password ⇒ String
The client secret that you obtained from your bot registration.
17 18 19 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 17 def msa_app_password @msa_app_password end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'type': :'type', 'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'msa_app_id': :'msaAppId', 'msa_app_password': :'msaAppPassword', 'bot_id': :'botId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'type': :'String', 'session_expiry_duration_in_milliseconds': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'msa_app_id': :'String', 'msa_app_password': :'String', 'bot_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 104 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && type == other.type && session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds && == other. && == other. && msa_app_id == other.msa_app_id && msa_app_password == other.msa_app_password && bot_id == other.bot_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 141 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
121 122 123 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 121 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 130 def hash [description, type, session_expiry_duration_in_milliseconds, , , msa_app_id, msa_app_password, bot_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/oci/oda/models/update_cortana_channel_details.rb', line 168 def to_s to_hash.to_s end |