Class: OCI::Oda::Models::UpdateDigitalAssistantDetails
- Inherits:
-
Object
- Object
- OCI::Oda::Models::UpdateDigitalAssistantDetails
- Defined in:
- lib/oci/oda/models/update_digital_assistant_details.rb
Overview
Properties to update a Digital Assistant.
Instance Attribute Summary collapse
-
#category ⇒ String
The resource's category.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
A short description of the resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDigitalAssistantDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDigitalAssistantDetails
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 64 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.category = attributes[:'category'] if attributes[:'category'] self.description = attributes[:'description'] if attributes[:'description'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#category ⇒ String
The resource's category. This is used to group resource's together.
12 13 14 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 12 def category @category end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
28 29 30 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 28 def @defined_tags end |
#description ⇒ String
A short description of the resource.
16 17 18 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 16 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope. Example: `"value"`
22 23 24 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 22 def @freeform_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'category': :'category', 'description': :'description', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'category': :'String', 'description': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 94 def ==(other) return true if equal?(other) self.class == other.class && category == other.category && description == other.description && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 127 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
107 108 109 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 107 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 116 def hash [category, description, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 160 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
154 155 156 |
# File 'lib/oci/oda/models/update_digital_assistant_details.rb', line 154 def to_s to_hash.to_s end |