Class: OCI::Oda::Models::UpdateOSSChannelDetails
- Inherits:
-
UpdateChannelDetails
- Object
- UpdateChannelDetails
- OCI::Oda::Models::UpdateOSSChannelDetails
- Defined in:
- lib/oci/oda/models/update_oss_channel_details.rb
Overview
Properties to update an Oracle Streaming Service (OSS) channel.
Constant Summary
Constants inherited from UpdateChannelDetails
OCI::Oda::Models::UpdateChannelDetails::TYPE_ENUM
Instance Attribute Summary collapse
-
#auth_token ⇒ String
The authentication token to use when connecting to the Oracle Streaming Service.
-
#bootstrap_servers ⇒ String
The Oracle Streaming Service bootstrap servers.
-
#event_sink_bot_ids ⇒ Array<String>
The IDs of the Skills and Digital Assistants that the Channel is routed to.
-
#inbound_message_topic ⇒ String
The topic inbound messages are received on.
-
#outbound_message_topic ⇒ String
The topic outbound messages are sent on.
-
#sasl_mechanism ⇒ String
The SASL mechanmism to use when conecting to the Oracle Streaming Service.
-
#security_protocol ⇒ String
The security protocol to use when conecting to the Oracle Streaming Service.
-
#stream_pool_id ⇒ String
The stream pool OCI to use when connecting to the Oracle Streaming Service.
-
#tenancy_name ⇒ String
The tenancy to use when connecting to the Oracle Streaming Service.
-
#user_name ⇒ String
The user name to use when connecting to the Oracle Streaming Service.
Attributes inherited from UpdateChannelDetails
#defined_tags, #description, #freeform_tags, #session_expiry_duration_in_milliseconds, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOSSChannelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateChannelDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOSSChannelDetails
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 117 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'OSS' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.event_sink_bot_ids = attributes[:'eventSinkBotIds'] if attributes[:'eventSinkBotIds'] raise 'You cannot provide both :eventSinkBotIds and :event_sink_bot_ids' if attributes.key?(:'eventSinkBotIds') && attributes.key?(:'event_sink_bot_ids') self.event_sink_bot_ids = attributes[:'event_sink_bot_ids'] if attributes[:'event_sink_bot_ids'] self. = attributes[:'inboundMessageTopic'] if attributes[:'inboundMessageTopic'] raise 'You cannot provide both :inboundMessageTopic and :inbound_message_topic' if attributes.key?(:'inboundMessageTopic') && attributes.key?(:'inbound_message_topic') self. = attributes[:'inbound_message_topic'] if attributes[:'inbound_message_topic'] self. = attributes[:'outboundMessageTopic'] if attributes[:'outboundMessageTopic'] raise 'You cannot provide both :outboundMessageTopic and :outbound_message_topic' if attributes.key?(:'outboundMessageTopic') && attributes.key?(:'outbound_message_topic') self. = attributes[:'outbound_message_topic'] if attributes[:'outbound_message_topic'] self.bootstrap_servers = attributes[:'bootstrapServers'] if attributes[:'bootstrapServers'] raise 'You cannot provide both :bootstrapServers and :bootstrap_servers' if attributes.key?(:'bootstrapServers') && attributes.key?(:'bootstrap_servers') self.bootstrap_servers = attributes[:'bootstrap_servers'] if attributes[:'bootstrap_servers'] self.security_protocol = attributes[:'securityProtocol'] if attributes[:'securityProtocol'] raise 'You cannot provide both :securityProtocol and :security_protocol' if attributes.key?(:'securityProtocol') && attributes.key?(:'security_protocol') self.security_protocol = attributes[:'security_protocol'] if attributes[:'security_protocol'] self.sasl_mechanism = attributes[:'saslMechanism'] if attributes[:'saslMechanism'] raise 'You cannot provide both :saslMechanism and :sasl_mechanism' if attributes.key?(:'saslMechanism') && attributes.key?(:'sasl_mechanism') self.sasl_mechanism = attributes[:'sasl_mechanism'] if attributes[:'sasl_mechanism'] self.tenancy_name = attributes[:'tenancyName'] if attributes[:'tenancyName'] raise 'You cannot provide both :tenancyName and :tenancy_name' if attributes.key?(:'tenancyName') && attributes.key?(:'tenancy_name') self.tenancy_name = attributes[:'tenancy_name'] if attributes[:'tenancy_name'] self.user_name = attributes[:'userName'] if attributes[:'userName'] raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] if attributes[:'user_name'] self.stream_pool_id = attributes[:'streamPoolId'] if attributes[:'streamPoolId'] raise 'You cannot provide both :streamPoolId and :stream_pool_id' if attributes.key?(:'streamPoolId') && attributes.key?(:'stream_pool_id') self.stream_pool_id = attributes[:'stream_pool_id'] if attributes[:'stream_pool_id'] self.auth_token = attributes[:'authToken'] if attributes[:'authToken'] raise 'You cannot provide both :authToken and :auth_token' if attributes.key?(:'authToken') && attributes.key?(:'auth_token') self.auth_token = attributes[:'auth_token'] if attributes[:'auth_token'] end |
Instance Attribute Details
#auth_token ⇒ String
The authentication token to use when connecting to the Oracle Streaming Service.
49 50 51 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 49 def auth_token @auth_token end |
#bootstrap_servers ⇒ String
The Oracle Streaming Service bootstrap servers.
25 26 27 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 25 def bootstrap_servers @bootstrap_servers end |
#event_sink_bot_ids ⇒ Array<String>
The IDs of the Skills and Digital Assistants that the Channel is routed to.
13 14 15 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 13 def event_sink_bot_ids @event_sink_bot_ids end |
#inbound_message_topic ⇒ String
The topic inbound messages are received on.
17 18 19 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 17 def @inbound_message_topic end |
#outbound_message_topic ⇒ String
The topic outbound messages are sent on.
21 22 23 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 21 def @outbound_message_topic end |
#sasl_mechanism ⇒ String
The SASL mechanmism to use when conecting to the Oracle Streaming Service. See Oracle Streaming Service documentation for a list of valid values.
33 34 35 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 33 def sasl_mechanism @sasl_mechanism end |
#security_protocol ⇒ String
The security protocol to use when conecting to the Oracle Streaming Service. See Oracle Streaming Service documentation for a list of valid values.
29 30 31 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 29 def security_protocol @security_protocol end |
#stream_pool_id ⇒ String
The stream pool OCI to use when connecting to the Oracle Streaming Service.
45 46 47 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 45 def stream_pool_id @stream_pool_id end |
#tenancy_name ⇒ String
The tenancy to use when connecting to the Oracle Streaming Service.
37 38 39 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 37 def tenancy_name @tenancy_name end |
#user_name ⇒ String
The user name to use when connecting to the Oracle Streaming Service.
41 42 43 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 41 def user_name @user_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'type': :'type', 'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'event_sink_bot_ids': :'eventSinkBotIds', 'inbound_message_topic': :'inboundMessageTopic', 'outbound_message_topic': :'outboundMessageTopic', 'bootstrap_servers': :'bootstrapServers', 'security_protocol': :'securityProtocol', 'sasl_mechanism': :'saslMechanism', 'tenancy_name': :'tenancyName', 'user_name': :'userName', 'stream_pool_id': :'streamPoolId', 'auth_token': :'authToken' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'type': :'String', 'session_expiry_duration_in_milliseconds': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'event_sink_bot_ids': :'Array<String>', 'inbound_message_topic': :'String', 'outbound_message_topic': :'String', 'bootstrap_servers': :'String', 'security_protocol': :'String', 'sasl_mechanism': :'String', 'tenancy_name': :'String', 'user_name': :'String', 'stream_pool_id': :'String', 'auth_token': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 195 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && type == other.type && session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds && == other. && == other. && event_sink_bot_ids == other.event_sink_bot_ids && == other. && == other. && bootstrap_servers == other.bootstrap_servers && security_protocol == other.security_protocol && sasl_mechanism == other.sasl_mechanism && tenancy_name == other.tenancy_name && user_name == other.user_name && stream_pool_id == other.stream_pool_id && auth_token == other.auth_token end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 239 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
219 220 221 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 219 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
228 229 230 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 228 def hash [description, type, session_expiry_duration_in_milliseconds, , , event_sink_bot_ids, , , bootstrap_servers, security_protocol, sasl_mechanism, tenancy_name, user_name, stream_pool_id, auth_token].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 272 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
266 267 268 |
# File 'lib/oci/oda/models/update_oss_channel_details.rb', line 266 def to_s to_hash.to_s end |