Class: OCI::Oda::Models::UpdateOsvcChannelDetails

Inherits:
UpdateChannelDetails show all
Defined in:
lib/oci/oda/models/update_osvc_channel_details.rb

Overview

Properties required to update an OSVC channel.

Constant Summary collapse

CHANNEL_SERVICE_ENUM =
[
  CHANNEL_SERVICE_OSVC = 'OSVC'.freeze,
  CHANNEL_SERVICE_FUSION = 'FUSION'.freeze
].freeze

Constants inherited from UpdateChannelDetails

OCI::Oda::Models::UpdateChannelDetails::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from UpdateChannelDetails

#defined_tags, #description, #freeform_tags, #session_expiry_duration_in_milliseconds, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from UpdateChannelDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ UpdateOsvcChannelDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :description (String)

    The value to assign to the #description proprety

  • :session_expiry_duration_in_milliseconds (Integer)

    The value to assign to the #session_expiry_duration_in_milliseconds proprety

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags proprety

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags proprety

  • :host (String)

    The value to assign to the #host property

  • :port (String)

    The value to assign to the #port property

  • :user_name (String)

    The value to assign to the #user_name property

  • :password (String)

    The value to assign to the #password property

  • :total_session_count (Integer)

    The value to assign to the #total_session_count property

  • :channel_service (String)

    The value to assign to the #channel_service property

  • :authentication_provider_name (String)

    The value to assign to the #authentication_provider_name property

  • :bot_id (String)

    The value to assign to the #bot_id property



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 116

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'OSVC'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.host = attributes[:'host'] if attributes[:'host']

  self.port = attributes[:'port'] if attributes[:'port']

  self.user_name = attributes[:'userName'] if attributes[:'userName']

  raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name')

  self.user_name = attributes[:'user_name'] if attributes[:'user_name']

  self.password = attributes[:'password'] if attributes[:'password']

  self.total_session_count = attributes[:'totalSessionCount'] if attributes[:'totalSessionCount']

  raise 'You cannot provide both :totalSessionCount and :total_session_count' if attributes.key?(:'totalSessionCount') && attributes.key?(:'total_session_count')

  self.total_session_count = attributes[:'total_session_count'] if attributes[:'total_session_count']

  self.channel_service = attributes[:'channelService'] if attributes[:'channelService']

  raise 'You cannot provide both :channelService and :channel_service' if attributes.key?(:'channelService') && attributes.key?(:'channel_service')

  self.channel_service = attributes[:'channel_service'] if attributes[:'channel_service']

  self.authentication_provider_name = attributes[:'authenticationProviderName'] if attributes[:'authenticationProviderName']

  raise 'You cannot provide both :authenticationProviderName and :authentication_provider_name' if attributes.key?(:'authenticationProviderName') && attributes.key?(:'authentication_provider_name')

  self.authentication_provider_name = attributes[:'authentication_provider_name'] if attributes[:'authentication_provider_name']

  self.bot_id = attributes[:'botId'] if attributes[:'botId']

  raise 'You cannot provide both :botId and :bot_id' if attributes.key?(:'botId') && attributes.key?(:'bot_id')

  self.bot_id = attributes[:'bot_id'] if attributes[:'bot_id']
end

Instance Attribute Details

#authentication_provider_nameString

The name of the Authentication Provider to use to authenticate the user.

Returns:

  • (String)


50
51
52
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 50

def authentication_provider_name
  @authentication_provider_name
end

#bot_idString

The ID of the Skill or Digital Assistant that the Channel is routed to.

Returns:

  • (String)


54
55
56
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 54

def bot_id
  @bot_id
end

#channel_serviceString

The type of OSVC service.

Returns:

  • (String)


46
47
48
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 46

def channel_service
  @channel_service
end

#hostString

The host.

For OSVC, you can derive these values from the URL that you use to launch the Agent Browser User Interface or the chat launch page. For example, if the URL is sitename.exampledomain.com/app/chat/chat_launch, then the host is sitename.exampledomain.com.

For FUSION, this is the host portion of your Oracle Applications Cloud (Fusion) instance's URL. For example: sitename.exampledomain.com.

Returns:

  • (String)


26
27
28
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 26

def host
  @host
end

#passwordString

The password for the digital-assistant agent.

Returns:

  • (String)


38
39
40
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 38

def password
  @password
end

#portString

The port.

Returns:

  • (String)


30
31
32
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 30

def port
  @port
end

#total_session_countInteger

The total session count.

Returns:

  • (Integer)


42
43
44
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 42

def total_session_count
  @total_session_count
end

#user_nameString

The user name for the digital-assistant agent.

Returns:

  • (String)


34
35
36
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 34

def user_name
  @user_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 57

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'type': :'type',
    'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'host': :'host',
    'port': :'port',
    'user_name': :'userName',
    'password': :'password',
    'total_session_count': :'totalSessionCount',
    'channel_service': :'channelService',
    'authentication_provider_name': :'authenticationProviderName',
    'bot_id': :'botId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 78

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'type': :'String',
    'session_expiry_duration_in_milliseconds': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'host': :'String',
    'port': :'String',
    'user_name': :'String',
    'password': :'String',
    'total_session_count': :'Integer',
    'channel_service': :'String',
    'authentication_provider_name': :'String',
    'bot_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 178

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    type == other.type &&
    session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    host == other.host &&
    port == other.port &&
    user_name == other.user_name &&
    password == other.password &&
    total_session_count == other.total_session_count &&
    channel_service == other.channel_service &&
    authentication_provider_name == other.authentication_provider_name &&
    bot_id == other.bot_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 220

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 200

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



209
210
211
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 209

def hash
  [description, type, session_expiry_duration_in_milliseconds, freeform_tags, defined_tags, host, port, user_name, password, total_session_count, channel_service, authentication_provider_name, bot_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



247
248
249
# File 'lib/oci/oda/models/update_osvc_channel_details.rb', line 247

def to_s
  to_hash.to_s
end