Class: OCI::Oda::Models::UpdateServiceCloudChannelDetails
- Inherits:
-
UpdateChannelDetails
- Object
- UpdateChannelDetails
- OCI::Oda::Models::UpdateServiceCloudChannelDetails
- Defined in:
- lib/oci/oda/models/update_service_cloud_channel_details.rb
Overview
Properties to update a Service Cloud agent channel.
Constant Summary collapse
- CLIENT_TYPE_ENUM =
[ CLIENT_TYPE_WSDL = 'WSDL'.freeze, CLIENT_TYPE_REST = 'REST'.freeze ].freeze
Constants inherited from UpdateChannelDetails
OCI::Oda::Models::UpdateChannelDetails::TYPE_ENUM
Instance Attribute Summary collapse
-
#client_type ⇒ String
The type of Service Cloud client.
-
#domain_name ⇒ String
The domain name.
-
#host_name_prefix ⇒ String
The host prefix.
-
#password ⇒ String
The password for the Oracle B2C Service staff member who has the necessary profile permissions.
-
#user_name ⇒ String
The user name for an Oracle B2C Service staff member who has the necessary profile permissions.
Attributes inherited from UpdateChannelDetails
#defined_tags, #description, #freeform_tags, #session_expiry_duration_in_milliseconds, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateServiceCloudChannelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateChannelDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateServiceCloudChannelDetails
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 103 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'SERVICECLOUD' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.domain_name = attributes[:'domainName'] if attributes[:'domainName'] raise 'You cannot provide both :domainName and :domain_name' if attributes.key?(:'domainName') && attributes.key?(:'domain_name') self.domain_name = attributes[:'domain_name'] if attributes[:'domain_name'] self.host_name_prefix = attributes[:'hostNamePrefix'] if attributes[:'hostNamePrefix'] raise 'You cannot provide both :hostNamePrefix and :host_name_prefix' if attributes.key?(:'hostNamePrefix') && attributes.key?(:'host_name_prefix') self.host_name_prefix = attributes[:'host_name_prefix'] if attributes[:'host_name_prefix'] self.user_name = attributes[:'userName'] if attributes[:'userName'] raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] if attributes[:'user_name'] self.password = attributes[:'password'] if attributes[:'password'] self.client_type = attributes[:'clientType'] if attributes[:'clientType'] raise 'You cannot provide both :clientType and :client_type' if attributes.key?(:'clientType') && attributes.key?(:'client_type') self.client_type = attributes[:'client_type'] if attributes[:'client_type'] end |
Instance Attribute Details
#client_type ⇒ String
The type of Service Cloud client.
50 51 52 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 50 def client_type @client_type end |
#domain_name ⇒ String
The domain name.
If you have access to Oracle B2C Service, you can derive this value from the URL that you use to launch the Agent Browser User Interface. For example, if the URL is sitename.exampledomain.com, then the host name prefix is sitename and the domain name is exampledomain.com.
If the channel is connecting to Oracle B2C Service version 19A or later, and you have multiple interfaces, then you must include the interface ID in the host (site) name . For example, for the interface that has an ID of 2, you would use something like sitename-2.exampledomain.com.
26 27 28 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 26 def domain_name @domain_name end |
#host_name_prefix ⇒ String
The host prefix.
If you have access to Oracle B2C Service, you can derive this value from the URL that you use to launch the Agent Browser User Interface. For example, if the URL is sitename.exampledomain.com, then the host name prefix is sitename and the domain name is exampledomain.com.
If the channel is connecting to Oracle B2C Service version 19A or later, and you have multiple interfaces, then you must include the interface ID in the host (site) name . For example, for the interface that has an ID of 2, you would use something like sitename-2.exampledomain.com.
38 39 40 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 38 def host_name_prefix @host_name_prefix end |
#password ⇒ String
The password for the Oracle B2C Service staff member who has the necessary profile permissions.
46 47 48 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 46 def password @password end |
#user_name ⇒ String
The user name for an Oracle B2C Service staff member who has the necessary profile permissions.
42 43 44 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 42 def user_name @user_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 53 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'type': :'type', 'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'domain_name': :'domainName', 'host_name_prefix': :'hostNamePrefix', 'user_name': :'userName', 'password': :'password', 'client_type': :'clientType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 71 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'type': :'String', 'session_expiry_duration_in_milliseconds': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'domain_name': :'String', 'host_name_prefix': :'String', 'user_name': :'String', 'password': :'String', 'client_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 155 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && type == other.type && session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds && == other. && == other. && domain_name == other.domain_name && host_name_prefix == other.host_name_prefix && user_name == other.user_name && password == other.password && client_type == other.client_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 194 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
174 175 176 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 174 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 183 def hash [description, type, session_expiry_duration_in_milliseconds, , , domain_name, host_name_prefix, user_name, password, client_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
221 222 223 |
# File 'lib/oci/oda/models/update_service_cloud_channel_details.rb', line 221 def to_s to_hash.to_s end |