Class: OCI::Oda::Models::UpdateSlackChannelDetails
- Inherits:
-
UpdateChannelDetails
- Object
- UpdateChannelDetails
- OCI::Oda::Models::UpdateSlackChannelDetails
- Defined in:
- lib/oci/oda/models/update_slack_channel_details.rb
Overview
Properties to update a Slack channel.
Constant Summary
Constants inherited from UpdateChannelDetails
OCI::Oda::Models::UpdateChannelDetails::TYPE_ENUM
Instance Attribute Summary collapse
-
#auth_error_url ⇒ String
The URL to redirect to when authentication is unsuccessful.
-
#auth_success_url ⇒ String
The URL to redirect to when authentication is successful.
-
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
-
#client_id ⇒ String
The Slack Client Id for the Slack app.
-
#client_secret ⇒ String
The Client Secret for the Slack App.
-
#signing_secret ⇒ String
The Signing Secret for the Slack App.
Attributes inherited from UpdateChannelDetails
#defined_tags, #description, #freeform_tags, #session_expiry_duration_in_milliseconds, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateSlackChannelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateChannelDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateSlackChannelDetails
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 89 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'SLACK' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.client_id = attributes[:'clientId'] if attributes[:'clientId'] raise 'You cannot provide both :clientId and :client_id' if attributes.key?(:'clientId') && attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] if attributes[:'client_id'] self.auth_success_url = attributes[:'authSuccessUrl'] if attributes[:'authSuccessUrl'] raise 'You cannot provide both :authSuccessUrl and :auth_success_url' if attributes.key?(:'authSuccessUrl') && attributes.key?(:'auth_success_url') self.auth_success_url = attributes[:'auth_success_url'] if attributes[:'auth_success_url'] self.auth_error_url = attributes[:'authErrorUrl'] if attributes[:'authErrorUrl'] raise 'You cannot provide both :authErrorUrl and :auth_error_url' if attributes.key?(:'authErrorUrl') && attributes.key?(:'auth_error_url') self.auth_error_url = attributes[:'auth_error_url'] if attributes[:'auth_error_url'] self.signing_secret = attributes[:'signingSecret'] if attributes[:'signingSecret'] raise 'You cannot provide both :signingSecret and :signing_secret' if attributes.key?(:'signingSecret') && attributes.key?(:'signing_secret') self.signing_secret = attributes[:'signing_secret'] if attributes[:'signing_secret'] self.client_secret = attributes[:'clientSecret'] if attributes[:'clientSecret'] raise 'You cannot provide both :clientSecret and :client_secret' if attributes.key?(:'clientSecret') && attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] if attributes[:'client_secret'] self.bot_id = attributes[:'botId'] if attributes[:'botId'] raise 'You cannot provide both :botId and :bot_id' if attributes.key?(:'botId') && attributes.key?(:'bot_id') self.bot_id = attributes[:'bot_id'] if attributes[:'bot_id'] end |
Instance Attribute Details
#auth_error_url ⇒ String
The URL to redirect to when authentication is unsuccessful.
21 22 23 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 21 def auth_error_url @auth_error_url end |
#auth_success_url ⇒ String
The URL to redirect to when authentication is successful.
17 18 19 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 17 def auth_success_url @auth_success_url end |
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
33 34 35 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 33 def bot_id @bot_id end |
#client_id ⇒ String
The Slack Client Id for the Slack app.
13 14 15 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 13 def client_id @client_id end |
#client_secret ⇒ String
The Client Secret for the Slack App.
29 30 31 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 29 def client_secret @client_secret end |
#signing_secret ⇒ String
The Signing Secret for the Slack App.
25 26 27 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 25 def signing_secret @signing_secret end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'type': :'type', 'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'client_id': :'clientId', 'auth_success_url': :'authSuccessUrl', 'auth_error_url': :'authErrorUrl', 'signing_secret': :'signingSecret', 'client_secret': :'clientSecret', 'bot_id': :'botId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'type': :'String', 'session_expiry_duration_in_milliseconds': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'client_id': :'String', 'auth_success_url': :'String', 'auth_error_url': :'String', 'signing_secret': :'String', 'client_secret': :'String', 'bot_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 143 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && type == other.type && session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds && == other. && == other. && client_id == other.client_id && auth_success_url == other.auth_success_url && auth_error_url == other.auth_error_url && signing_secret == other.signing_secret && client_secret == other.client_secret && bot_id == other.bot_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 172 def hash [description, type, session_expiry_duration_in_milliseconds, , , client_id, auth_success_url, auth_error_url, signing_secret, client_secret, bot_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/oda/models/update_slack_channel_details.rb', line 210 def to_s to_hash.to_s end |