Class: OCI::Oda::Models::UpdateWebhookChannelDetails
- Inherits:
-
UpdateChannelDetails
- Object
- UpdateChannelDetails
- OCI::Oda::Models::UpdateWebhookChannelDetails
- Defined in:
- lib/oci/oda/models/update_webhook_channel_details.rb
Overview
Properties to update a Webhook channel.
Constant Summary collapse
- PAYLOAD_VERSION_ENUM =
[ PAYLOAD_VERSION_1_0 = '1.0'.freeze, PAYLOAD_VERSION_1_1 = '1.1'.freeze ].freeze
Constants inherited from UpdateChannelDetails
OCI::Oda::Models::UpdateChannelDetails::TYPE_ENUM
Instance Attribute Summary collapse
-
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
-
#outbound_url ⇒ String
The URL to send responses to.
-
#payload_version ⇒ String
The version for payloads.
Attributes inherited from UpdateChannelDetails
#defined_tags, #description, #freeform_tags, #session_expiry_duration_in_milliseconds, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateWebhookChannelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateChannelDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateWebhookChannelDetails
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 73 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'WEBHOOK' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.outbound_url = attributes[:'outboundUrl'] if attributes[:'outboundUrl'] raise 'You cannot provide both :outboundUrl and :outbound_url' if attributes.key?(:'outboundUrl') && attributes.key?(:'outbound_url') self.outbound_url = attributes[:'outbound_url'] if attributes[:'outbound_url'] self.payload_version = attributes[:'payloadVersion'] if attributes[:'payloadVersion'] raise 'You cannot provide both :payloadVersion and :payload_version' if attributes.key?(:'payloadVersion') && attributes.key?(:'payload_version') self.payload_version = attributes[:'payload_version'] if attributes[:'payload_version'] self.bot_id = attributes[:'botId'] if attributes[:'botId'] raise 'You cannot provide both :botId and :bot_id' if attributes.key?(:'botId') && attributes.key?(:'bot_id') self.bot_id = attributes[:'bot_id'] if attributes[:'bot_id'] end |
Instance Attribute Details
#bot_id ⇒ String
The ID of the Skill or Digital Assistant that the Channel is routed to.
26 27 28 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 26 def bot_id @bot_id end |
#outbound_url ⇒ String
The URL to send responses to.
18 19 20 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 18 def outbound_url @outbound_url end |
#payload_version ⇒ String
The version for payloads.
22 23 24 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 22 def payload_version @payload_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'type': :'type', 'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'outbound_url': :'outboundUrl', 'payload_version': :'payloadVersion', 'bot_id': :'botId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'type': :'String', 'session_expiry_duration_in_milliseconds': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'outbound_url': :'String', 'payload_version': :'String', 'bot_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 117 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && type == other.type && session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds && == other. && == other. && outbound_url == other.outbound_url && payload_version == other.payload_version && bot_id == other.bot_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 143 def hash [description, type, session_expiry_duration_in_milliseconds, , , outbound_url, payload_version, bot_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/oda/models/update_webhook_channel_details.rb', line 181 def to_s to_hash.to_s end |