Class: OCI::Oda::Models::WebChannel

Inherits:
Channel
  • Object
show all
Defined in:
lib/oci/oda/models/web_channel.rb

Overview

The configuration for a Web channel.

Constant Summary

Constants inherited from Channel

Channel::CATEGORY_ENUM, Channel::LIFECYCLE_STATE_ENUM, Channel::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from Channel

#category, #defined_tags, #description, #freeform_tags, #id, #lifecycle_state, #name, #session_expiry_duration_in_milliseconds, #time_created, #time_updated, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Channel

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ WebChannel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id proprety

  • :name (String)

    The value to assign to the #name proprety

  • :description (String)

    The value to assign to the #description proprety

  • :category (String)

    The value to assign to the #category proprety

  • :session_expiry_duration_in_milliseconds (Integer)

    The value to assign to the #session_expiry_duration_in_milliseconds proprety

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state proprety

  • :time_created (DateTime)

    The value to assign to the #time_created proprety

  • :time_updated (DateTime)

    The value to assign to the #time_updated proprety

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags proprety

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags proprety

  • :max_token_expiration_time_in_minutes (Integer)

    The value to assign to the #max_token_expiration_time_in_minutes property

  • :is_client_authentication_enabled (BOOLEAN)

    The value to assign to the #is_client_authentication_enabled property

  • :allowed_domains (String)

    The value to assign to the #allowed_domains property

  • :bot_id (String)

    The value to assign to the #bot_id property



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/oci/oda/models/web_channel.rb', line 100

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'WEB'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.max_token_expiration_time_in_minutes = attributes[:'maxTokenExpirationTimeInMinutes'] if attributes[:'maxTokenExpirationTimeInMinutes']

  raise 'You cannot provide both :maxTokenExpirationTimeInMinutes and :max_token_expiration_time_in_minutes' if attributes.key?(:'maxTokenExpirationTimeInMinutes') && attributes.key?(:'max_token_expiration_time_in_minutes')

  self.max_token_expiration_time_in_minutes = attributes[:'max_token_expiration_time_in_minutes'] if attributes[:'max_token_expiration_time_in_minutes']

  self.is_client_authentication_enabled = attributes[:'isClientAuthenticationEnabled'] unless attributes[:'isClientAuthenticationEnabled'].nil?

  raise 'You cannot provide both :isClientAuthenticationEnabled and :is_client_authentication_enabled' if attributes.key?(:'isClientAuthenticationEnabled') && attributes.key?(:'is_client_authentication_enabled')

  self.is_client_authentication_enabled = attributes[:'is_client_authentication_enabled'] unless attributes[:'is_client_authentication_enabled'].nil?

  self.allowed_domains = attributes[:'allowedDomains'] if attributes[:'allowedDomains']

  raise 'You cannot provide both :allowedDomains and :allowed_domains' if attributes.key?(:'allowedDomains') && attributes.key?(:'allowed_domains')

  self.allowed_domains = attributes[:'allowed_domains'] if attributes[:'allowed_domains']

  self.bot_id = attributes[:'botId'] if attributes[:'botId']

  raise 'You cannot provide both :botId and :bot_id' if attributes.key?(:'botId') && attributes.key?(:'bot_id')

  self.bot_id = attributes[:'bot_id'] if attributes[:'bot_id']
end

Instance Attribute Details

#allowed_domainsString

A comma-delimited whitelist of allowed domains.

The channel will only communicate with the sites from the domains that you add to this list. For example, *.corp.example.com, *.hdr.example.com. Entering a single asterisk (*) allows unrestricted access to the channel from any domain.

Typically, you'd only enter a single asterisk during development. For production, you would add an allowlist of domains.

Returns:

  • (String)


28
29
30
# File 'lib/oci/oda/models/web_channel.rb', line 28

def allowed_domains
  @allowed_domains
end

#bot_idString

The ID of the Skill or Digital Assistant that the Channel is routed to.

Returns:

  • (String)


32
33
34
# File 'lib/oci/oda/models/web_channel.rb', line 32

def bot_id
  @bot_id
end

#is_client_authentication_enabledBOOLEAN

**[Required]** Whether client authentication is enabled or not.

Returns:

  • (BOOLEAN)


17
18
19
# File 'lib/oci/oda/models/web_channel.rb', line 17

def is_client_authentication_enabled
  @is_client_authentication_enabled
end

#max_token_expiration_time_in_minutesInteger

The maximum time until the token expires (in minutes).

Returns:

  • (Integer)


13
14
15
# File 'lib/oci/oda/models/web_channel.rb', line 13

def max_token_expiration_time_in_minutes
  @max_token_expiration_time_in_minutes
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/oci/oda/models/web_channel.rb', line 35

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'description': :'description',
    'category': :'category',
    'type': :'type',
    'session_expiry_duration_in_milliseconds': :'sessionExpiryDurationInMilliseconds',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'max_token_expiration_time_in_minutes': :'maxTokenExpirationTimeInMinutes',
    'is_client_authentication_enabled': :'isClientAuthenticationEnabled',
    'allowed_domains': :'allowedDomains',
    'bot_id': :'botId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/oci/oda/models/web_channel.rb', line 58

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'description': :'String',
    'category': :'String',
    'type': :'String',
    'session_expiry_duration_in_milliseconds': :'Integer',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'max_token_expiration_time_in_minutes': :'Integer',
    'is_client_authentication_enabled': :'BOOLEAN',
    'allowed_domains': :'String',
    'bot_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/oda/models/web_channel.rb', line 142

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    description == other.description &&
    category == other.category &&
    type == other.type &&
    session_expiry_duration_in_milliseconds == other.session_expiry_duration_in_milliseconds &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    max_token_expiration_time_in_minutes == other.max_token_expiration_time_in_minutes &&
    is_client_authentication_enabled == other.is_client_authentication_enabled &&
    allowed_domains == other.allowed_domains &&
    bot_id == other.bot_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/oci/oda/models/web_channel.rb', line 186

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/oci/oda/models/web_channel.rb', line 166

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



175
176
177
# File 'lib/oci/oda/models/web_channel.rb', line 175

def hash
  [id, name, description, category, type, session_expiry_duration_in_milliseconds, lifecycle_state, time_created, time_updated, freeform_tags, defined_tags, max_token_expiration_time_in_minutes, is_client_authentication_enabled, allowed_domains, bot_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
# File 'lib/oci/oda/models/web_channel.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



213
214
215
# File 'lib/oci/oda/models/web_channel.rb', line 213

def to_s
  to_hash.to_s
end