Class: OCI::Oda::Models::WorkRequestSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/oda/models/work_request_summary.rb

Overview

A description of the work request's status.

Constant Summary collapse

REQUEST_ACTION_ENUM =
[
  REQUEST_ACTION_CREATE_ODA_INSTANCE = 'CREATE_ODA_INSTANCE'.freeze,
  REQUEST_ACTION_UPGRADE_ODA_INSTANCE = 'UPGRADE_ODA_INSTANCE'.freeze,
  REQUEST_ACTION_DELETE_ODA_INSTANCE = 'DELETE_ODA_INSTANCE'.freeze,
  REQUEST_ACTION_PURGE_ODA_INSTANCE = 'PURGE_ODA_INSTANCE'.freeze,
  REQUEST_ACTION_RECOVER_ODA_INSTANCE = 'RECOVER_ODA_INSTANCE'.freeze,
  REQUEST_ACTION_STOP_ODA_INSTANCE = 'STOP_ODA_INSTANCE'.freeze,
  REQUEST_ACTION_START_ODA_INSTANCE = 'START_ODA_INSTANCE'.freeze,
  REQUEST_ACTION_CHANGE_ODA_INSTANCE_COMPARTMENT = 'CHANGE_ODA_INSTANCE_COMPARTMENT'.freeze,
  REQUEST_ACTION_CHANGE_CUST_ENC_KEY = 'CHANGE_CUST_ENC_KEY'.freeze,
  REQUEST_ACTION_DEACT_CUST_ENC_KEY = 'DEACT_CUST_ENC_KEY'.freeze,
  REQUEST_ACTION_CREATE_ASSOCIATION = 'CREATE_ASSOCIATION'.freeze,
  REQUEST_ACTION_DELETE_ASSOCIATION = 'DELETE_ASSOCIATION'.freeze,
  REQUEST_ACTION_UPDATE_ENTITLEMENTS_FOR_CACCT = 'UPDATE_ENTITLEMENTS_FOR_CACCT'.freeze,
  REQUEST_ACTION_LOOKUP_ODA_INSTANCES_FOR_CACCT = 'LOOKUP_ODA_INSTANCES_FOR_CACCT'.freeze,
  REQUEST_ACTION_CREATE_ODA_INSTANCE_ATTACHMENT = 'CREATE_ODA_INSTANCE_ATTACHMENT'.freeze,
  REQUEST_ACTION_UPDATE_ODA_INSTANCE_ATTACHMENT = 'UPDATE_ODA_INSTANCE_ATTACHMENT'.freeze,
  REQUEST_ACTION_DELETE_ODA_INSTANCE_ATTACHMENT = 'DELETE_ODA_INSTANCE_ATTACHMENT'.freeze,
  REQUEST_ACTION_CREATE_IMPORTED_PACKAGE = 'CREATE_IMPORTED_PACKAGE'.freeze,
  REQUEST_ACTION_UPDATE_IMPORTED_PACKAGE = 'UPDATE_IMPORTED_PACKAGE'.freeze,
  REQUEST_ACTION_DELETE_IMPORTED_PACKAGE = 'DELETE_IMPORTED_PACKAGE'.freeze,
  REQUEST_ACTION_IMPORT_BOT = 'IMPORT_BOT'.freeze,
  REQUEST_ACTION_CREATE_SKILL = 'CREATE_SKILL'.freeze,
  REQUEST_ACTION_CLONE_SKILL = 'CLONE_SKILL'.freeze,
  REQUEST_ACTION_EXTEND_SKILL = 'EXTEND_SKILL'.freeze,
  REQUEST_ACTION_VERSION_SKILL = 'VERSION_SKILL'.freeze,
  REQUEST_ACTION_EXPORT_SKILL = 'EXPORT_SKILL'.freeze,
  REQUEST_ACTION_CREATE_DIGITAL_ASSISTANT = 'CREATE_DIGITAL_ASSISTANT'.freeze,
  REQUEST_ACTION_CLONE_DIGITAL_ASSISTANT = 'CLONE_DIGITAL_ASSISTANT'.freeze,
  REQUEST_ACTION_EXTEND_DIGITAL_ASSISTANT = 'EXTEND_DIGITAL_ASSISTANT'.freeze,
  REQUEST_ACTION_VERSION_DIGITAL_ASSISTANT = 'VERSION_DIGITAL_ASSISTANT'.freeze,
  REQUEST_ACTION_EXPORT_DIGITAL_ASSISTANT = 'EXPORT_DIGITAL_ASSISTANT'.freeze,
  REQUEST_ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_ACCEPTED = 'ACCEPTED'.freeze,
  STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  STATUS_SUCCEEDED = 'SUCCEEDED'.freeze,
  STATUS_FAILED = 'FAILED'.freeze,
  STATUS_CANCELING = 'CANCELING'.freeze,
  STATUS_CANCELED = 'CANCELED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkRequestSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/oda/models/work_request_summary.rb', line 120

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.oda_instance_id = attributes[:'odaInstanceId'] if attributes[:'odaInstanceId']

  raise 'You cannot provide both :odaInstanceId and :oda_instance_id' if attributes.key?(:'odaInstanceId') && attributes.key?(:'oda_instance_id')

  self.oda_instance_id = attributes[:'oda_instance_id'] if attributes[:'oda_instance_id']

  self.request_action = attributes[:'requestAction'] if attributes[:'requestAction']

  raise 'You cannot provide both :requestAction and :request_action' if attributes.key?(:'requestAction') && attributes.key?(:'request_action')

  self.request_action = attributes[:'request_action'] if attributes[:'request_action']

  self.status = attributes[:'status'] if attributes[:'status']

  self.resources = attributes[:'resources'] if attributes[:'resources']
end

Instance Attribute Details

#compartment_idString

**[Required]** The identifier of the compartment that contains the work request.

Returns:

  • (String)


62
63
64
# File 'lib/oci/oda/models/work_request_summary.rb', line 62

def compartment_id
  @compartment_id
end

#idString

**[Required]** The identifier of the work request.

Returns:

  • (String)


58
59
60
# File 'lib/oci/oda/models/work_request_summary.rb', line 58

def id
  @id
end

#oda_instance_idString

**[Required]** The identifier of the Digital Assistant instance to which this work request pertains.

Returns:

  • (String)


66
67
68
# File 'lib/oci/oda/models/work_request_summary.rb', line 66

def oda_instance_id
  @oda_instance_id
end

#request_actionString

**[Required]** The type of the operation that's associated with the work request.

Returns:

  • (String)


70
71
72
# File 'lib/oci/oda/models/work_request_summary.rb', line 70

def request_action
  @request_action
end

#resourcesArray<OCI::Oda::Models::WorkRequestResource>

**[Required]** The resources that this work request affects.



78
79
80
# File 'lib/oci/oda/models/work_request_summary.rb', line 78

def resources
  @resources
end

#statusString

**[Required]** The status of current work request.

Returns:

  • (String)


74
75
76
# File 'lib/oci/oda/models/work_request_summary.rb', line 74

def status
  @status
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/oci/oda/models/work_request_summary.rb', line 81

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'oda_instance_id': :'odaInstanceId',
    'request_action': :'requestAction',
    'status': :'status',
    'resources': :'resources'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/oda/models/work_request_summary.rb', line 95

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'oda_instance_id': :'String',
    'request_action': :'String',
    'status': :'String',
    'resources': :'Array<OCI::Oda::Models::WorkRequestResource>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



184
185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/oda/models/work_request_summary.rb', line 184

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    oda_instance_id == other.oda_instance_id &&
    request_action == other.request_action &&
    status == other.status &&
    resources == other.resources
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/oci/oda/models/work_request_summary.rb', line 219

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


199
200
201
# File 'lib/oci/oda/models/work_request_summary.rb', line 199

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



208
209
210
# File 'lib/oci/oda/models/work_request_summary.rb', line 208

def hash
  [id, compartment_id, oda_instance_id, request_action, status, resources].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



252
253
254
255
256
257
258
259
260
261
# File 'lib/oci/oda/models/work_request_summary.rb', line 252

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



246
247
248
# File 'lib/oci/oda/models/work_request_summary.rb', line 246

def to_s
  to_hash.to_s
end