Class: OCI::Onesubscription::Models::CommitmentSummary
- Inherits:
-
Object
- Object
- OCI::Onesubscription::Models::CommitmentSummary
- Defined in:
- lib/oci/onesubscription/models/commitment_summary.rb
Overview
Subscribed Service commitment summary
Instance Attribute Summary collapse
-
#available_amount ⇒ String
Commitment available amount.
-
#funded_allocation_value ⇒ String
Funded Allocation line value example: 12000.00.
-
#id ⇒ String
**[Required]** SPM internal Commitment ID.
-
#quantity ⇒ String
Commitment quantity.
-
#subscribed_service_id ⇒ String
SPM internal Subscribed Service ID.
-
#time_end ⇒ DateTime
Commitment end date.
-
#time_start ⇒ DateTime
Commitment start date.
-
#used_amount ⇒ String
Commitment used amount.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CommitmentSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CommitmentSummary
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 98 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.subscribed_service_id = attributes[:'subscribedServiceId'] if attributes[:'subscribedServiceId'] raise 'You cannot provide both :subscribedServiceId and :subscribed_service_id' if attributes.key?(:'subscribedServiceId') && attributes.key?(:'subscribed_service_id') self.subscribed_service_id = attributes[:'subscribed_service_id'] if attributes[:'subscribed_service_id'] self.time_start = attributes[:'timeStart'] if attributes[:'timeStart'] raise 'You cannot provide both :timeStart and :time_start' if attributes.key?(:'timeStart') && attributes.key?(:'time_start') self.time_start = attributes[:'time_start'] if attributes[:'time_start'] self.time_end = attributes[:'timeEnd'] if attributes[:'timeEnd'] raise 'You cannot provide both :timeEnd and :time_end' if attributes.key?(:'timeEnd') && attributes.key?(:'time_end') self.time_end = attributes[:'time_end'] if attributes[:'time_end'] self.quantity = attributes[:'quantity'] if attributes[:'quantity'] self.used_amount = attributes[:'usedAmount'] if attributes[:'usedAmount'] raise 'You cannot provide both :usedAmount and :used_amount' if attributes.key?(:'usedAmount') && attributes.key?(:'used_amount') self.used_amount = attributes[:'used_amount'] if attributes[:'used_amount'] self.available_amount = attributes[:'availableAmount'] if attributes[:'availableAmount'] raise 'You cannot provide both :availableAmount and :available_amount' if attributes.key?(:'availableAmount') && attributes.key?(:'available_amount') self.available_amount = attributes[:'available_amount'] if attributes[:'available_amount'] self.funded_allocation_value = attributes[:'fundedAllocationValue'] if attributes[:'fundedAllocationValue'] raise 'You cannot provide both :fundedAllocationValue and :funded_allocation_value' if attributes.key?(:'fundedAllocationValue') && attributes.key?(:'funded_allocation_value') self.funded_allocation_value = attributes[:'funded_allocation_value'] if attributes[:'funded_allocation_value'] end |
Instance Attribute Details
#available_amount ⇒ String
Commitment available amount
44 45 46 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 44 def available_amount @available_amount end |
#funded_allocation_value ⇒ String
Funded Allocation line value example: 12000.00
50 51 52 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 50 def funded_allocation_value @funded_allocation_value end |
#id ⇒ String
**[Required]** SPM internal Commitment ID
14 15 16 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 14 def id @id end |
#quantity ⇒ String
Commitment quantity
34 35 36 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 34 def quantity @quantity end |
#subscribed_service_id ⇒ String
SPM internal Subscribed Service ID
19 20 21 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 19 def subscribed_service_id @subscribed_service_id end |
#time_end ⇒ DateTime
Commitment end date
29 30 31 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 29 def time_end @time_end end |
#time_start ⇒ DateTime
Commitment start date
24 25 26 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 24 def time_start @time_start end |
#used_amount ⇒ String
Commitment used amount
39 40 41 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 39 def used_amount @used_amount end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 53 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'subscribed_service_id': :'subscribedServiceId', 'time_start': :'timeStart', 'time_end': :'timeEnd', 'quantity': :'quantity', 'used_amount': :'usedAmount', 'available_amount': :'availableAmount', 'funded_allocation_value': :'fundedAllocationValue' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'subscribed_service_id': :'String', 'time_start': :'DateTime', 'time_end': :'DateTime', 'quantity': :'String', 'used_amount': :'String', 'available_amount': :'String', 'funded_allocation_value': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 152 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && subscribed_service_id == other.subscribed_service_id && time_start == other.time_start && time_end == other.time_end && quantity == other.quantity && used_amount == other.used_amount && available_amount == other.available_amount && funded_allocation_value == other.funded_allocation_value end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 189 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
169 170 171 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 169 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 178 def hash [id, subscribed_service_id, time_start, time_end, quantity, used_amount, available_amount, funded_allocation_value].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/oci/onesubscription/models/commitment_summary.rb', line 216 def to_s to_hash.to_s end |