Class: OCI::Onesubscription::Models::InvoicingPaymentTerm
- Inherits:
-
Object
- Object
- OCI::Onesubscription::Models::InvoicingPaymentTerm
- Defined in:
- lib/oci/onesubscription/models/invoicing_payment_term.rb
Overview
Payment Term details
Instance Attribute Summary collapse
-
#created_by ⇒ String
User that created the Payment term.
-
#description ⇒ String
Payment term Description.
-
#is_active ⇒ BOOLEAN
Payment term active flag.
-
#name ⇒ String
**[Required]** Payment Term name.
-
#time_created ⇒ DateTime
Payment term last update date.
-
#time_updated ⇒ DateTime
Payment term last update date.
-
#updated_by ⇒ String
User that updated the Payment term.
-
#value ⇒ String
Payment Term value.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InvoicingPaymentTerm
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ InvoicingPaymentTerm
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.value = attributes[:'value'] if attributes[:'value'] self.description = attributes[:'description'] if attributes[:'description'] self.is_active = attributes[:'isActive'] unless attributes[:'isActive'].nil? raise 'You cannot provide both :isActive and :is_active' if attributes.key?(:'isActive') && attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] unless attributes[:'is_active'].nil? self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.created_by = attributes[:'createdBy'] if attributes[:'createdBy'] raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] if attributes[:'created_by'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.updated_by = attributes[:'updatedBy'] if attributes[:'updatedBy'] raise 'You cannot provide both :updatedBy and :updated_by' if attributes.key?(:'updatedBy') && attributes.key?(:'updated_by') self.updated_by = attributes[:'updated_by'] if attributes[:'updated_by'] end |
Instance Attribute Details
#created_by ⇒ String
User that created the Payment term
39 40 41 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 39 def created_by @created_by end |
#description ⇒ String
Payment term Description
24 25 26 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 24 def description @description end |
#is_active ⇒ BOOLEAN
Payment term active flag
29 30 31 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 29 def is_active @is_active end |
#name ⇒ String
**[Required]** Payment Term name
14 15 16 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 14 def name @name end |
#time_created ⇒ DateTime
Payment term last update date
34 35 36 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 34 def time_created @time_created end |
#time_updated ⇒ DateTime
Payment term last update date
44 45 46 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 44 def time_updated @time_updated end |
#updated_by ⇒ String
User that updated the Payment term
49 50 51 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 49 def updated_by @updated_by end |
#value ⇒ String
Payment Term value
19 20 21 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 19 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'value': :'value', 'description': :'description', 'is_active': :'isActive', 'time_created': :'timeCreated', 'created_by': :'createdBy', 'time_updated': :'timeUpdated', 'updated_by': :'updatedBy' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'value': :'String', 'description': :'String', 'is_active': :'BOOLEAN', 'time_created': :'DateTime', 'created_by': :'String', 'time_updated': :'DateTime', 'updated_by': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 147 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && value == other.value && description == other.description && is_active == other.is_active && time_created == other.time_created && created_by == other.created_by && time_updated == other.time_updated && updated_by == other.updated_by end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 184 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
164 165 166 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 164 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 173 def hash [name, value, description, is_active, time_created, created_by, time_updated, updated_by].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
211 212 213 |
# File 'lib/oci/onesubscription/models/invoicing_payment_term.rb', line 211 def to_s to_hash.to_s end |