Class: OCI::Onesubscription::Models::InvoicingUser
- Inherits:
-
Object
- Object
- OCI::Onesubscription::Models::InvoicingUser
- Defined in:
- lib/oci/onesubscription/models/invoicing_user.rb
Overview
User.
Instance Attribute Summary collapse
-
#email ⇒ String
Email.
-
#first_name ⇒ String
First name.
-
#last_name ⇒ String
Last name.
-
#name ⇒ String
Name.
-
#tca_contact_id ⇒ Integer
TCA contact ID.
-
#tca_cust_accnt_site_id ⇒ Integer
TCA customer account site ID.
-
#tca_party_id ⇒ Integer
TCA party ID.
-
#user_name ⇒ String
userName.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InvoicingUser
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ InvoicingUser
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.user_name = attributes[:'userName'] if attributes[:'userName'] raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] if attributes[:'user_name'] self.first_name = attributes[:'firstName'] if attributes[:'firstName'] raise 'You cannot provide both :firstName and :first_name' if attributes.key?(:'firstName') && attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] if attributes[:'first_name'] self.last_name = attributes[:'lastName'] if attributes[:'lastName'] raise 'You cannot provide both :lastName and :last_name' if attributes.key?(:'lastName') && attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] if attributes[:'last_name'] self.email = attributes[:'email'] if attributes[:'email'] self.tca_contact_id = attributes[:'tcaContactId'] if attributes[:'tcaContactId'] raise 'You cannot provide both :tcaContactId and :tca_contact_id' if attributes.key?(:'tcaContactId') && attributes.key?(:'tca_contact_id') self.tca_contact_id = attributes[:'tca_contact_id'] if attributes[:'tca_contact_id'] self.tca_cust_accnt_site_id = attributes[:'tcaCustAccntSiteId'] if attributes[:'tcaCustAccntSiteId'] raise 'You cannot provide both :tcaCustAccntSiteId and :tca_cust_accnt_site_id' if attributes.key?(:'tcaCustAccntSiteId') && attributes.key?(:'tca_cust_accnt_site_id') self.tca_cust_accnt_site_id = attributes[:'tca_cust_accnt_site_id'] if attributes[:'tca_cust_accnt_site_id'] self.tca_party_id = attributes[:'tcaPartyId'] if attributes[:'tcaPartyId'] raise 'You cannot provide both :tcaPartyId and :tca_party_id' if attributes.key?(:'tcaPartyId') && attributes.key?(:'tca_party_id') self.tca_party_id = attributes[:'tca_party_id'] if attributes[:'tca_party_id'] end |
Instance Attribute Details
#email ⇒ String
Email.
34 35 36 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 34 def email @email end |
#first_name ⇒ String
First name.
24 25 26 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 24 def first_name @first_name end |
#last_name ⇒ String
Last name.
29 30 31 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 29 def last_name @last_name end |
#name ⇒ String
Name.
14 15 16 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 14 def name @name end |
#tca_contact_id ⇒ Integer
TCA contact ID.
39 40 41 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 39 def tca_contact_id @tca_contact_id end |
#tca_cust_accnt_site_id ⇒ Integer
TCA customer account site ID.
44 45 46 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 44 def tca_cust_accnt_site_id @tca_cust_accnt_site_id end |
#tca_party_id ⇒ Integer
TCA party ID.
49 50 51 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 49 def tca_party_id @tca_party_id end |
#user_name ⇒ String
userName.
19 20 21 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 19 def user_name @user_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'user_name': :'userName', 'first_name': :'firstName', 'last_name': :'lastName', 'email': :'email', 'tca_contact_id': :'tcaContactId', 'tca_cust_accnt_site_id': :'tcaCustAccntSiteId', 'tca_party_id': :'tcaPartyId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'user_name': :'String', 'first_name': :'String', 'last_name': :'String', 'email': :'String', 'tca_contact_id': :'Integer', 'tca_cust_accnt_site_id': :'Integer', 'tca_party_id': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 151 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && user_name == other.user_name && first_name == other.first_name && last_name == other.last_name && email == other.email && tca_contact_id == other.tca_contact_id && tca_cust_accnt_site_id == other.tca_cust_accnt_site_id && tca_party_id == other.tca_party_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 188 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
168 169 170 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 168 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 177 def hash [name, user_name, first_name, last_name, email, tca_contact_id, tca_cust_accnt_site_id, tca_party_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
215 216 217 |
# File 'lib/oci/onesubscription/models/invoicing_user.rb', line 215 def to_s to_hash.to_s end |