Class: OCI::Ons::Models::CreateSubscriptionDetails
- Inherits:
-
Object
- Object
- OCI::Ons::Models::CreateSubscriptionDetails
- Defined in:
- lib/oci/ons/models/create_subscription_details.rb
Overview
The configuration details for creating the subscription.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment for the subscription.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#endpoint ⇒ String
[Required] A locator that corresponds to the subscription protocol.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#metadata ⇒ String
Metadata for the subscription.
-
#protocol ⇒ String
[Required] The protocol used for the subscription.
-
#topic_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the topic for the subscription.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSubscriptionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSubscriptionDetails
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 111 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.topic_id = attributes[:'topicId'] if attributes[:'topicId'] raise 'You cannot provide both :topicId and :topic_id' if attributes.key?(:'topicId') && attributes.key?(:'topic_id') self.topic_id = attributes[:'topic_id'] if attributes[:'topic_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.endpoint = attributes[:'endpoint'] if attributes[:'endpoint'] self. = attributes[:'metadata'] if attributes[:'metadata'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment for the subscription.
19 20 21 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 19 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
66 67 68 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 66 def @defined_tags end |
#endpoint ⇒ String
[Required] A locator that corresponds to the subscription protocol. For example, an email address for a subscription that uses the EMAIL protocol, or a URL for a subscription that uses an HTTP-based protocol. HTTP-based protocols use URL endpoints that begin with "http:" or "https:". A URL cannot exceed 512 characters. Avoid entering confidential information.
For protocol-specific endpoint formats and steps to get or create endpoints, see [To create a subscription](docs.cloud.oracle.com/iaas/Content/Notification/Tasks/managingtopicsandsubscriptions.htm#createSub).
48 49 50 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 48 def endpoint @endpoint end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
59 60 61 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 59 def @freeform_tags end |
#metadata ⇒ String
Metadata for the subscription.
52 53 54 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 52 def @metadata end |
#protocol ⇒ String
[Required] The protocol used for the subscription.
Allowed values:
* `CUSTOM_HTTPS`
* `EMAIL`
* `HTTPS` (deprecated; for PagerDuty endpoints, use `PAGERDUTY`)
* `ORACLE_FUNCTIONS`
* `PAGERDUTY`
* `SLACK`
* `SMS`
For information about subscription protocols, see [To create a subscription](docs.cloud.oracle.com/iaas/Content/Notification/Tasks/managingtopicsandsubscriptions.htm#createSub).
36 37 38 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 36 def protocol @protocol end |
#topic_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the topic for the subscription.
14 15 16 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 14 def topic_id @topic_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'topic_id': :'topicId', 'compartment_id': :'compartmentId', 'protocol': :'protocol', 'endpoint': :'endpoint', 'metadata': :'metadata', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 84 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'topic_id': :'String', 'compartment_id': :'String', 'protocol': :'String', 'endpoint': :'String', 'metadata': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 155 def ==(other) return true if equal?(other) self.class == other.class && topic_id == other.topic_id && compartment_id == other.compartment_id && protocol == other.protocol && endpoint == other.endpoint && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 191 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
171 172 173 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 171 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 180 def hash [topic_id, compartment_id, protocol, endpoint, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/oci/ons/models/create_subscription_details.rb', line 218 def to_s to_hash.to_s end |