Class: OCI::Ons::Models::Subscription
- Inherits:
-
Object
- Object
- OCI::Ons::Models::Subscription
- Defined in:
- lib/oci/ons/models/subscription.rb
Overview
The subscription’s configuration. For general information about subscriptions, see [Notifications Overview](docs.cloud.oracle.com/iaas/Content/Notification/Concepts/notificationoverview.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PENDING = 'PENDING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment for the subscription.
-
#created_time ⇒ Integer
The time when this suscription was created.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#deliver_policy ⇒ String
The delivery policy of the subscription.
-
#endpoint ⇒ String
[Required] A locator that corresponds to the subscription protocol.
-
#etag ⇒ String
For optimistic concurrency control.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subscription.
-
#lifecycle_state ⇒ String
[Required] The lifecycle state of the subscription.
-
#protocol ⇒ String
[Required] The protocol used for the subscription.
-
#topic_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the associated topic.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Subscription
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Subscription
Initializes the object
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/ons/models/subscription.rb', line 146 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.topic_id = attributes[:'topicId'] if attributes[:'topicId'] raise 'You cannot provide both :topicId and :topic_id' if attributes.key?(:'topicId') && attributes.key?(:'topic_id') self.topic_id = attributes[:'topic_id'] if attributes[:'topic_id'] self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.endpoint = attributes[:'endpoint'] if attributes[:'endpoint'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] self.lifecycle_state = "PENDING" if lifecycle_state.nil? && !attributes.key?(:'lifecycleState') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_state = "PENDING" if lifecycle_state.nil? && !attributes.key?(:'lifecycleState') && !attributes.key?(:'lifecycle_state') # rubocop:disable Style/StringLiterals self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.created_time = attributes[:'createdTime'] if attributes[:'createdTime'] raise 'You cannot provide both :createdTime and :created_time' if attributes.key?(:'createdTime') && attributes.key?(:'created_time') self.created_time = attributes[:'created_time'] if attributes[:'created_time'] self.deliver_policy = attributes[:'deliverPolicy'] if attributes[:'deliverPolicy'] raise 'You cannot provide both :deliverPolicy and :deliver_policy' if attributes.key?(:'deliverPolicy') && attributes.key?(:'deliver_policy') self.deliver_policy = attributes[:'deliver_policy'] if attributes[:'deliver_policy'] self.etag = attributes[:'etag'] if attributes[:'etag'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment for the subscription.
61 62 63 |
# File 'lib/oci/ons/models/subscription.rb', line 61 def compartment_id @compartment_id end |
#created_time ⇒ Integer
The time when this suscription was created.
66 67 68 |
# File 'lib/oci/ons/models/subscription.rb', line 66 def created_time @created_time end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
89 90 91 |
# File 'lib/oci/ons/models/subscription.rb', line 89 def @defined_tags end |
#deliver_policy ⇒ String
The delivery policy of the subscription. Stored as a JSON string.
70 71 72 |
# File 'lib/oci/ons/models/subscription.rb', line 70 def deliver_policy @deliver_policy end |
#endpoint ⇒ String
[Required] A locator that corresponds to the subscription protocol. For example, an email address for a subscription that uses the EMAIL protocol, or a URL for a subscription that uses an HTTP-based protocol.
51 52 53 |
# File 'lib/oci/ons/models/subscription.rb', line 51 def endpoint @endpoint end |
#etag ⇒ String
For optimistic concurrency control. See if-match.
75 76 77 |
# File 'lib/oci/ons/models/subscription.rb', line 75 def etag @etag end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
82 83 84 |
# File 'lib/oci/ons/models/subscription.rb', line 82 def @freeform_tags end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subscription.
23 24 25 |
# File 'lib/oci/ons/models/subscription.rb', line 23 def id @id end |
#lifecycle_state ⇒ String
[Required] The lifecycle state of the subscription. The status of a new subscription is PENDING; when confirmed, the subscription status changes to ACTIVE.
56 57 58 |
# File 'lib/oci/ons/models/subscription.rb', line 56 def lifecycle_state @lifecycle_state end |
#protocol ⇒ String
[Required] The protocol used for the subscription.
Allowed values:
* `CUSTOM_HTTPS`
* `EMAIL`
* `HTTPS` (deprecated; for PagerDuty endpoints, use `PAGERDUTY`)
* `ORACLE_FUNCTIONS`
* `PAGERDUTY`
* `SLACK`
* `SMS`
For information about subscription protocols, see [To create a subscription](docs.cloud.oracle.com/iaas/Content/Notification/Tasks/managingtopicsandsubscriptions.htm#createSub).
45 46 47 |
# File 'lib/oci/ons/models/subscription.rb', line 45 def protocol @protocol end |
#topic_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the associated topic.
28 29 30 |
# File 'lib/oci/ons/models/subscription.rb', line 28 def topic_id @topic_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/ons/models/subscription.rb', line 92 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'topic_id': :'topicId', 'protocol': :'protocol', 'endpoint': :'endpoint', 'lifecycle_state': :'lifecycleState', 'compartment_id': :'compartmentId', 'created_time': :'createdTime', 'deliver_policy': :'deliverPolicy', 'etag': :'etag', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/ons/models/subscription.rb', line 111 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'topic_id': :'String', 'protocol': :'String', 'endpoint': :'String', 'lifecycle_state': :'String', 'compartment_id': :'String', 'created_time': :'Integer', 'deliver_policy': :'String', 'etag': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/oci/ons/models/subscription.rb', line 225 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && topic_id == other.topic_id && protocol == other.protocol && endpoint == other.endpoint && lifecycle_state == other.lifecycle_state && compartment_id == other.compartment_id && created_time == other.created_time && deliver_policy == other.deliver_policy && etag == other.etag && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/oci/ons/models/subscription.rb', line 265 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
245 246 247 |
# File 'lib/oci/ons/models/subscription.rb', line 245 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/oci/ons/models/subscription.rb', line 254 def hash [id, topic_id, protocol, endpoint, lifecycle_state, compartment_id, created_time, deliver_policy, etag, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
298 299 300 301 302 303 304 305 306 307 |
# File 'lib/oci/ons/models/subscription.rb', line 298 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
292 293 294 |
# File 'lib/oci/ons/models/subscription.rb', line 292 def to_s to_hash.to_s end |