Class: OCI::OperatorAccessControl::Models::ApproveAccessRequestDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/operator_access_control/models/approve_access_request_details.rb

Overview

Details of the access request approval.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApproveAccessRequestDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :approver_comment (String)

    The value to assign to the #approver_comment property

  • :audit_type (Array<String>)

    The value to assign to the #audit_type property

  • :additional_message (String)

    The value to assign to the #additional_message property



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 56

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.approver_comment = attributes[:'approverComment'] if attributes[:'approverComment']

  raise 'You cannot provide both :approverComment and :approver_comment' if attributes.key?(:'approverComment') && attributes.key?(:'approver_comment')

  self.approver_comment = attributes[:'approver_comment'] if attributes[:'approver_comment']

  self.audit_type = attributes[:'auditType'] if attributes[:'auditType']

  raise 'You cannot provide both :auditType and :audit_type' if attributes.key?(:'auditType') && attributes.key?(:'audit_type')

  self.audit_type = attributes[:'audit_type'] if attributes[:'audit_type']

  self.additional_message = attributes[:'additionalMessage'] if attributes[:'additionalMessage']

  raise 'You cannot provide both :additionalMessage and :additional_message' if attributes.key?(:'additionalMessage') && attributes.key?(:'additional_message')

  self.additional_message = attributes[:'additional_message'] if attributes[:'additional_message']
end

Instance Attribute Details

#additional_messageString

Message that needs to be displayed to the Ops User.

Returns:

  • (String)


23
24
25
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 23

def additional_message
  @additional_message
end

#approver_commentString

Comment by the approver during approval.

Returns:

  • (String)


12
13
14
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 12

def approver_comment
  @approver_comment
end

#audit_typeArray<String>

Specifies the type of auditing to be enabled. There are two levels of auditing: command-level and keystroke-level. By default, auditing is enabled at the command level i.e., each command issued by the operator is audited. When keystroke-level is chosen, in addition to command level logging, key strokes are also logged.

Returns:

  • (Array<String>)


19
20
21
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 19

def audit_type
  @audit_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
34
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 26

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'approver_comment': :'approverComment',
    'audit_type': :'auditType',
    'additional_message': :'additionalMessage'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



37
38
39
40
41
42
43
44
45
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 37

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'approver_comment': :'String',
    'audit_type': :'Array<String>',
    'additional_message': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



88
89
90
91
92
93
94
95
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 88

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    approver_comment == other.approver_comment &&
    audit_type == other.audit_type &&
    additional_message == other.additional_message
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 120

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


100
101
102
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 100

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



109
110
111
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 109

def hash
  [approver_comment, audit_type, additional_message].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 153

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



147
148
149
# File 'lib/oci/operator_access_control/models/approve_access_request_details.rb', line 147

def to_s
  to_hash.to_s
end