Class: OCI::OperatorAccessControl::Models::CreateOperatorControlDetails
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::CreateOperatorControlDetails
- Defined in:
- lib/oci/operator_access_control/models/create_operator_control_details.rb
Overview
While creating the operator control, specify how operator actions are approved and the users who have the privilege of approving the operator actions associated with the Operator Control.
You must specify which operator actions must be pre-approved. The rest of the operator actions associated with the Operator Control will require an explicit approval from the users selected either through the approver groups or individually.
You must name your Operator Control appropriately so it reflects the resources that will be governed by the Operator Control. Neither the Operator Controls nor their assignments to resources are visible to the Oracle operators.
Instance Attribute Summary collapse
-
#approver_groups_list ⇒ Array<String>
List of user groups who can approve an access request associated with a resource governed by this operator control.
-
#approvers_list ⇒ Array<String>
List of users who can approve an access request associated with a resource governed by this operator control.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains this operator control.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the operator control.
-
#email_id_list ⇒ Array<String>
List of emailId.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_fully_pre_approved ⇒ BOOLEAN
Whether all the operator actions have been pre-approved.
-
#operator_control_name ⇒ String
[Required] Name of the operator control.
-
#pre_approved_op_action_list ⇒ Array<String>
List of pre-approved operator actions.
-
#system_message ⇒ String
This is the message that will be displayed to the operator users while accessing the system.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOperatorControlDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateOperatorControlDetails
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 121 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operator_control_name = attributes[:'operatorControlName'] if attributes[:'operatorControlName'] raise 'You cannot provide both :operatorControlName and :operator_control_name' if attributes.key?(:'operatorControlName') && attributes.key?(:'operator_control_name') self.operator_control_name = attributes[:'operator_control_name'] if attributes[:'operator_control_name'] self.description = attributes[:'description'] if attributes[:'description'] self.approvers_list = attributes[:'approversList'] if attributes[:'approversList'] raise 'You cannot provide both :approversList and :approvers_list' if attributes.key?(:'approversList') && attributes.key?(:'approvers_list') self.approvers_list = attributes[:'approvers_list'] if attributes[:'approvers_list'] self.approver_groups_list = attributes[:'approverGroupsList'] if attributes[:'approverGroupsList'] raise 'You cannot provide both :approverGroupsList and :approver_groups_list' if attributes.key?(:'approverGroupsList') && attributes.key?(:'approver_groups_list') self.approver_groups_list = attributes[:'approver_groups_list'] if attributes[:'approver_groups_list'] self.pre_approved_op_action_list = attributes[:'preApprovedOpActionList'] if attributes[:'preApprovedOpActionList'] raise 'You cannot provide both :preApprovedOpActionList and :pre_approved_op_action_list' if attributes.key?(:'preApprovedOpActionList') && attributes.key?(:'pre_approved_op_action_list') self.pre_approved_op_action_list = attributes[:'pre_approved_op_action_list'] if attributes[:'pre_approved_op_action_list'] self.is_fully_pre_approved = attributes[:'isFullyPreApproved'] unless attributes[:'isFullyPreApproved'].nil? raise 'You cannot provide both :isFullyPreApproved and :is_fully_pre_approved' if attributes.key?(:'isFullyPreApproved') && attributes.key?(:'is_fully_pre_approved') self.is_fully_pre_approved = attributes[:'is_fully_pre_approved'] unless attributes[:'is_fully_pre_approved'].nil? self.email_id_list = attributes[:'emailIdList'] if attributes[:'emailIdList'] raise 'You cannot provide both :emailIdList and :email_id_list' if attributes.key?(:'emailIdList') && attributes.key?(:'email_id_list') self.email_id_list = attributes[:'email_id_list'] if attributes[:'email_id_list'] self. = attributes[:'systemMessage'] if attributes[:'systemMessage'] raise 'You cannot provide both :systemMessage and :system_message' if attributes.key?(:'systemMessage') && attributes.key?(:'system_message') self. = attributes[:'system_message'] if attributes[:'system_message'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#approver_groups_list ⇒ Array<String>
List of user groups who can approve an access request associated with a resource governed by this operator control.
29 30 31 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 29 def approver_groups_list @approver_groups_list end |
#approvers_list ⇒ Array<String>
List of users who can approve an access request associated with a resource governed by this operator control.
25 26 27 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 25 def approvers_list @approvers_list end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains this operator control.
54 55 56 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 54 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
64 65 66 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 64 def end |
#description ⇒ String
Description of the operator control.
21 22 23 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 21 def description @description end |
#email_id_list ⇒ Array<String>
List of emailId.
46 47 48 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 46 def email_id_list @email_id_list end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
59 60 61 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 59 def end |
#is_fully_pre_approved ⇒ BOOLEAN
Whether all the operator actions have been pre-approved. If yes, all access requests associated with a resource governed by this operator control will be auto-approved.
41 42 43 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 41 def is_fully_pre_approved @is_fully_pre_approved end |
#operator_control_name ⇒ String
[Required] Name of the operator control.
17 18 19 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 17 def operator_control_name @operator_control_name end |
#pre_approved_op_action_list ⇒ Array<String>
List of pre-approved operator actions. Access requests associated with a resource governed by this operator control will be auto-approved if the access request only contain operator actions in the pre-approved list.
35 36 37 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 35 def pre_approved_op_action_list @pre_approved_op_action_list end |
#system_message ⇒ String
This is the message that will be displayed to the operator users while accessing the system.
50 51 52 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 50 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operator_control_name': :'operatorControlName', 'description': :'description', 'approvers_list': :'approversList', 'approver_groups_list': :'approverGroupsList', 'pre_approved_op_action_list': :'preApprovedOpActionList', 'is_fully_pre_approved': :'isFullyPreApproved', 'email_id_list': :'emailIdList', 'system_message': :'systemMessage', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 86 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operator_control_name': :'String', 'description': :'String', 'approvers_list': :'Array<String>', 'approver_groups_list': :'Array<String>', 'pre_approved_op_action_list': :'Array<String>', 'is_fully_pre_approved': :'BOOLEAN', 'email_id_list': :'Array<String>', 'system_message': :'String', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 197 def ==(other) return true if equal?(other) self.class == other.class && operator_control_name == other.operator_control_name && description == other.description && approvers_list == other.approvers_list && approver_groups_list == other.approver_groups_list && pre_approved_op_action_list == other.pre_approved_op_action_list && is_fully_pre_approved == other.is_fully_pre_approved && email_id_list == other.email_id_list && == other. && compartment_id == other.compartment_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 237 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
217 218 219 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 217 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 226 def hash [operator_control_name, description, approvers_list, approver_groups_list, pre_approved_op_action_list, is_fully_pre_approved, email_id_list, , compartment_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
270 271 272 273 274 275 276 277 278 279 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 270 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
264 265 266 |
# File 'lib/oci/operator_access_control/models/create_operator_control_details.rb', line 264 def to_s to_hash.to_s end |