Class: OCI::OperatorAccessControl::Models::OperatorActionSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/operator_access_control/models/operator_action_summary.rb

Overview

Details of the operator action. Operator actions are pre-defined set of commands available to the operator on different layers of the infrastructure.

Constant Summary collapse

RESOURCE_TYPE_ENUM =
[
  RESOURCE_TYPE_EXACC = 'EXACC'.freeze,
  RESOURCE_TYPE_EXADATAINFRASTRUCTURE = 'EXADATAINFRASTRUCTURE'.freeze,
  RESOURCE_TYPE_AUTONOMOUSVMCLUSTER = 'AUTONOMOUSVMCLUSTER'.freeze,
  RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OperatorActionSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :component (String)

    The value to assign to the #component property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :resource_type (String)

    The value to assign to the #resource_type property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :description (String)

    The value to assign to the #description property



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 97

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.component = attributes[:'component'] if attributes[:'component']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType']

  raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type')

  self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.description = attributes[:'description'] if attributes[:'description']
end

Instance Attribute Details

#compartment_idString

compartmentId for which the OperatorAction is applicable

Returns:

  • (String)


38
39
40
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 38

def compartment_id
  @compartment_id
end

#componentString

Name of the component for which the operator action is applicable.

Returns:

  • (String)


34
35
36
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 34

def component
  @component
end

#descriptionString

Description of the operator action in terms of associated risk profile, and characteristics of the operating system commands made available to the operator under this operator action.

Returns:

  • (String)


52
53
54
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 52

def description
  @description
end

#idString

[Required] Unique identifier assigned by Oracle to an operator action.

Returns:

  • (String)


26
27
28
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 26

def id
  @id
end

#lifecycle_stateString

The current lifecycle state of the operator action.

Returns:

  • (String)


46
47
48
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 46

def lifecycle_state
  @lifecycle_state
end

#nameString

[Required] Name of the operator action.

Returns:

  • (String)


30
31
32
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 30

def name
  @name
end

#resource_typeString

resourceType for which the OperatorAction is applicable

Returns:

  • (String)


42
43
44
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 42

def resource_type
  @resource_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 55

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'component': :'component',
    'compartment_id': :'compartmentId',
    'resource_type': :'resourceType',
    'lifecycle_state': :'lifecycleState',
    'description': :'description'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 70

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'component': :'String',
    'compartment_id': :'String',
    'resource_type': :'String',
    'lifecycle_state': :'String',
    'description': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 163

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    component == other.component &&
    compartment_id == other.compartment_id &&
    resource_type == other.resource_type &&
    lifecycle_state == other.lifecycle_state &&
    description == other.description
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 199

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 179

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



188
189
190
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 188

def hash
  [id, name, component, compartment_id, resource_type, lifecycle_state, description].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



226
227
228
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 226

def to_s
  to_hash.to_s
end