Class: OperatorAccessControl::Models::OperatorControl
- Inherits:
-
Object
- Object
- OperatorAccessControl::Models::OperatorControl
- Defined in:
- lib/oci/operator_access_control/models/operator_control.rb
Overview
Operator Access Control enables you to grant, audit, or revoke the access Oracle has to your Exadata Cloud@Customer infrastructure, and obtain audit reports of all actions taken by a human operator, in a near real-time manner.
Constant Summary collapse
- RESOURCE_TYPE_ENUM =
[ RESOURCE_TYPE_EXACC = 'EXACC'.freeze, RESOURCE_TYPE_EXADATAINFRASTRUCTURE = 'EXADATAINFRASTRUCTURE'.freeze, RESOURCE_TYPE_AUTONOMOUSVMCLUSTER = 'AUTONOMOUSVMCLUSTER'.freeze, RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATED = 'CREATED'.freeze, LIFECYCLE_STATE_ASSIGNED = 'ASSIGNED'.freeze, LIFECYCLE_STATE_UNASSIGNED = 'UNASSIGNED'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#approval_required_op_action_list ⇒ Array<String>
List of operator actions that need explicit approval.
-
#approver_groups_list ⇒ Array<String>
List of user groups who can approve an access request associated with a target resource under the governance of this operator control.
-
#approvers_list ⇒ Array<String>
List of users who can approve an access request associated with a target resource under the governance of this operator control.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the operator control.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of operator control.
-
#email_id_list ⇒ Array<String>
List of emailId.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The OCID of the operator control.
-
#is_fully_pre_approved ⇒ BOOLEAN
Whether all the operator actions have been pre-approved.
-
#last_modified_info ⇒ String
Description associated with the latest modification of the operator control.
-
#lifecycle_state ⇒ String
The current lifecycle state of the operator control.
-
#operator_control_name ⇒ String
**[Required]** Name of the operator control.
-
#pre_approved_op_action_list ⇒ Array<String>
List of pre-approved operator actions.
-
#resource_type ⇒ String
resourceType for which the OperatorControl is applicable.
-
#system_message ⇒ String
System message that would be displayed to the operator users on accessing the target resource under the governance of this operator control.
-
#time_of_creation ⇒ DateTime
Time when the operator control was created expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_of_deletion ⇒ DateTime
Time when deleted expressed in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.
-
#time_of_modification ⇒ DateTime
Time when the operator control was last modified expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperatorControl
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OperatorControl
Initializes the object
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 197 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.operator_control_name = attributes[:'operatorControlName'] if attributes[:'operatorControlName'] raise 'You cannot provide both :operatorControlName and :operator_control_name' if attributes.key?(:'operatorControlName') && attributes.key?(:'operator_control_name') self.operator_control_name = attributes[:'operator_control_name'] if attributes[:'operator_control_name'] self.description = attributes[:'description'] if attributes[:'description'] self.approvers_list = attributes[:'approversList'] if attributes[:'approversList'] raise 'You cannot provide both :approversList and :approvers_list' if attributes.key?(:'approversList') && attributes.key?(:'approvers_list') self.approvers_list = attributes[:'approvers_list'] if attributes[:'approvers_list'] self.approver_groups_list = attributes[:'approverGroupsList'] if attributes[:'approverGroupsList'] raise 'You cannot provide both :approverGroupsList and :approver_groups_list' if attributes.key?(:'approverGroupsList') && attributes.key?(:'approver_groups_list') self.approver_groups_list = attributes[:'approver_groups_list'] if attributes[:'approver_groups_list'] self.pre_approved_op_action_list = attributes[:'preApprovedOpActionList'] if attributes[:'preApprovedOpActionList'] raise 'You cannot provide both :preApprovedOpActionList and :pre_approved_op_action_list' if attributes.key?(:'preApprovedOpActionList') && attributes.key?(:'pre_approved_op_action_list') self.pre_approved_op_action_list = attributes[:'pre_approved_op_action_list'] if attributes[:'pre_approved_op_action_list'] self.approval_required_op_action_list = attributes[:'approvalRequiredOpActionList'] if attributes[:'approvalRequiredOpActionList'] raise 'You cannot provide both :approvalRequiredOpActionList and :approval_required_op_action_list' if attributes.key?(:'approvalRequiredOpActionList') && attributes.key?(:'approval_required_op_action_list') self.approval_required_op_action_list = attributes[:'approval_required_op_action_list'] if attributes[:'approval_required_op_action_list'] self.is_fully_pre_approved = attributes[:'isFullyPreApproved'] unless attributes[:'isFullyPreApproved'].nil? raise 'You cannot provide both :isFullyPreApproved and :is_fully_pre_approved' if attributes.key?(:'isFullyPreApproved') && attributes.key?(:'is_fully_pre_approved') self.is_fully_pre_approved = attributes[:'is_fully_pre_approved'] unless attributes[:'is_fully_pre_approved'].nil? self.email_id_list = attributes[:'emailIdList'] if attributes[:'emailIdList'] raise 'You cannot provide both :emailIdList and :email_id_list' if attributes.key?(:'emailIdList') && attributes.key?(:'email_id_list') self.email_id_list = attributes[:'email_id_list'] if attributes[:'email_id_list'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self. = attributes[:'systemMessage'] if attributes[:'systemMessage'] raise 'You cannot provide both :systemMessage and :system_message' if attributes.key?(:'systemMessage') && attributes.key?(:'system_message') self. = attributes[:'system_message'] if attributes[:'system_message'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_of_creation = attributes[:'timeOfCreation'] if attributes[:'timeOfCreation'] raise 'You cannot provide both :timeOfCreation and :time_of_creation' if attributes.key?(:'timeOfCreation') && attributes.key?(:'time_of_creation') self.time_of_creation = attributes[:'time_of_creation'] if attributes[:'time_of_creation'] self.time_of_modification = attributes[:'timeOfModification'] if attributes[:'timeOfModification'] raise 'You cannot provide both :timeOfModification and :time_of_modification' if attributes.key?(:'timeOfModification') && attributes.key?(:'time_of_modification') self.time_of_modification = attributes[:'time_of_modification'] if attributes[:'time_of_modification'] self.time_of_deletion = attributes[:'timeOfDeletion'] if attributes[:'timeOfDeletion'] raise 'You cannot provide both :timeOfDeletion and :time_of_deletion' if attributes.key?(:'timeOfDeletion') && attributes.key?(:'time_of_deletion') self.time_of_deletion = attributes[:'time_of_deletion'] if attributes[:'time_of_deletion'] self.last_modified_info = attributes[:'lastModifiedInfo'] if attributes[:'lastModifiedInfo'] raise 'You cannot provide both :lastModifiedInfo and :last_modified_info' if attributes.key?(:'lastModifiedInfo') && attributes.key?(:'last_modified_info') self.last_modified_info = attributes[:'last_modified_info'] if attributes[:'last_modified_info'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#approval_required_op_action_list ⇒ Array<String>
List of operator actions that need explicit approval. Any operator action not in the pre-approved list will require explicit approval. Access requests associated with a resource governed by this operator control will be require explicit approval if the access request contains any operator action in this list.
58 59 60 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 58 def approval_required_op_action_list @approval_required_op_action_list end |
#approver_groups_list ⇒ Array<String>
List of user groups who can approve an access request associated with a target resource under the governance of this operator control.
45 46 47 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 45 def approver_groups_list @approver_groups_list end |
#approvers_list ⇒ Array<String>
List of users who can approve an access request associated with a target resource under the governance of this operator control.
41 42 43 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 41 def approvers_list @approvers_list end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the operator control.
81 82 83 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 81 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
116 117 118 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 116 def @defined_tags end |
#description ⇒ String
Description of operator control.
37 38 39 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 37 def description @description end |
#email_id_list ⇒ Array<String>
List of emailId.
69 70 71 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 69 def email_id_list @email_id_list end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
111 112 113 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 111 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the operator control.
29 30 31 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 29 def id @id end |
#is_fully_pre_approved ⇒ BOOLEAN
Whether all the operator actions have been pre-approved. If yes, all access requests associated with a resource governed by this operator control will be auto-approved.
64 65 66 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 64 def is_fully_pre_approved @is_fully_pre_approved end |
#last_modified_info ⇒ String
Description associated with the latest modification of the operator control.
106 107 108 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 106 def last_modified_info @last_modified_info end |
#lifecycle_state ⇒ String
The current lifecycle state of the operator control.
85 86 87 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 85 def lifecycle_state @lifecycle_state end |
#operator_control_name ⇒ String
**[Required]** Name of the operator control. The name must be unique.
33 34 35 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 33 def operator_control_name @operator_control_name end |
#pre_approved_op_action_list ⇒ Array<String>
List of pre-approved operator actions. Access requests associated with a resource governed by this operator control will be automatically approved if the access request only contain operator actions in the pre-approved list.
51 52 53 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 51 def pre_approved_op_action_list @pre_approved_op_action_list end |
#resource_type ⇒ String
resourceType for which the OperatorControl is applicable
73 74 75 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 73 def resource_type @resource_type end |
#system_message ⇒ String
System message that would be displayed to the operator users on accessing the target resource under the governance of this operator control.
77 78 79 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 77 def @system_message end |
#time_of_creation ⇒ DateTime
Time when the operator control was created expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: '2020-05-22T21:10:29.600Z'
90 91 92 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 90 def time_of_creation @time_of_creation end |
#time_of_deletion ⇒ DateTime
Time when deleted expressed in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format. Example: '2020-05-22T21:10:29.600Z'. Note a deleted operator control still stays in the system, so that you can still audit operator actions associated with access requests raised on target resources governed by the deleted operator control.
102 103 104 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 102 def time_of_deletion @time_of_deletion end |
#time_of_modification ⇒ DateTime
Time when the operator control was last modified expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: '2020-05-22T21:10:29.600Z'
95 96 97 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 95 def time_of_modification @time_of_modification end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 119 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'operator_control_name': :'operatorControlName', 'description': :'description', 'approvers_list': :'approversList', 'approver_groups_list': :'approverGroupsList', 'pre_approved_op_action_list': :'preApprovedOpActionList', 'approval_required_op_action_list': :'approvalRequiredOpActionList', 'is_fully_pre_approved': :'isFullyPreApproved', 'email_id_list': :'emailIdList', 'resource_type': :'resourceType', 'system_message': :'systemMessage', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'time_of_creation': :'timeOfCreation', 'time_of_modification': :'timeOfModification', 'time_of_deletion': :'timeOfDeletion', 'last_modified_info': :'lastModifiedInfo', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 146 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'operator_control_name': :'String', 'description': :'String', 'approvers_list': :'Array<String>', 'approver_groups_list': :'Array<String>', 'pre_approved_op_action_list': :'Array<String>', 'approval_required_op_action_list': :'Array<String>', 'is_fully_pre_approved': :'BOOLEAN', 'email_id_list': :'Array<String>', 'resource_type': :'String', 'system_message': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'time_of_creation': :'DateTime', 'time_of_modification': :'DateTime', 'time_of_deletion': :'DateTime', 'last_modified_info': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 343 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && operator_control_name == other.operator_control_name && description == other.description && approvers_list == other.approvers_list && approver_groups_list == other.approver_groups_list && pre_approved_op_action_list == other.pre_approved_op_action_list && approval_required_op_action_list == other.approval_required_op_action_list && is_fully_pre_approved == other.is_fully_pre_approved && email_id_list == other.email_id_list && resource_type == other.resource_type && == other. && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && time_of_creation == other.time_of_creation && time_of_modification == other.time_of_modification && time_of_deletion == other.time_of_deletion && last_modified_info == other.last_modified_info && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 391 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
371 372 373 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 371 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
380 381 382 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 380 def hash [id, operator_control_name, description, approvers_list, approver_groups_list, pre_approved_op_action_list, approval_required_op_action_list, is_fully_pre_approved, email_id_list, resource_type, , compartment_id, lifecycle_state, time_of_creation, time_of_modification, time_of_deletion, last_modified_info, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
424 425 426 427 428 429 430 431 432 433 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 424 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
418 419 420 |
# File 'lib/oci/operator_access_control/models/operator_control.rb', line 418 def to_s to_hash.to_s end |