Class: OCI::OperatorAccessControl::Models::OperatorControlAssignment

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/operator_access_control/models/operator_control_assignment.rb

Overview

An Operator Control Assignment identifies the target resource that is placed under the governance of an Operator Control. Creating an Operator Control Assignment Assignment with a time duration ensures that human accesses to the target resource will be governed by Operator Control for the duration specified.

Constant Summary collapse

RESOURCE_TYPE_ENUM =
[
  RESOURCE_TYPE_EXACC = 'EXACC'.freeze,
  RESOURCE_TYPE_EXADATAINFRASTRUCTURE = 'EXADATAINFRASTRUCTURE'.freeze,
  RESOURCE_TYPE_AUTONOMOUSVMCLUSTER = 'AUTONOMOUSVMCLUSTER'.freeze,
  RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATED = 'CREATED'.freeze,
  LIFECYCLE_STATE_APPLIED = 'APPLIED'.freeze,
  LIFECYCLE_STATE_APPLYFAILED = 'APPLYFAILED'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_DELETIONFAILED = 'DELETIONFAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OperatorControlAssignment

Initializes the object

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :operator_control_id (String)

    The value to assign to the #operator_control_id property

  • :resource_id (String)

    The value to assign to the #resource_id property

  • :resource_name (String)

    The value to assign to the #resource_name property

  • :resource_compartment_id (String)

    The value to assign to the #resource_compartment_id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :resource_type (String)

    The value to assign to the #resource_type property

  • :time_assignment_from (DateTime)

    The value to assign to the #time_assignment_from property

  • :time_assignment_to (DateTime)

    The value to assign to the #time_assignment_to property

  • :is_enforced_always (BOOLEAN)

    The value to assign to the #is_enforced_always property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :assigner_id (String)

    The value to assign to the #assigner_id property

  • :time_of_assignment (DateTime)

    The value to assign to the #time_of_assignment property

  • :comment (String)

    The value to assign to the #comment property

  • :unassigner_id (String)

    The value to assign to the #unassigner_id property

  • :time_of_deletion (DateTime)

    The value to assign to the #time_of_deletion property

  • :detachment_description (String)

    The value to assign to the #detachment_description property

  • :is_log_forwarded (BOOLEAN)

    The value to assign to the #is_log_forwarded property

  • :remote_syslog_server_address (String)

    The value to assign to the #remote_syslog_server_address property

  • :remote_syslog_server_port (Integer)

    The value to assign to the #remote_syslog_server_port property

  • :remote_syslog_server_ca_cert (String)

    The value to assign to the #remote_syslog_server_ca_cert property

  • :is_auto_approve_during_maintenance (BOOLEAN)

    The value to assign to the #is_auto_approve_during_maintenance property

  • :error_code (Integer)

    The value to assign to the #error_code property

  • :error_message (String)

    The value to assign to the #error_message property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 243

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.operator_control_id = attributes[:'operatorControlId'] if attributes[:'operatorControlId']

  raise 'You cannot provide both :operatorControlId and :operator_control_id' if attributes.key?(:'operatorControlId') && attributes.key?(:'operator_control_id')

  self.operator_control_id = attributes[:'operator_control_id'] if attributes[:'operator_control_id']

  self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId']

  raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id')

  self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id']

  self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName']

  raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name')

  self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name']

  self.resource_compartment_id = attributes[:'resourceCompartmentId'] if attributes[:'resourceCompartmentId']

  raise 'You cannot provide both :resourceCompartmentId and :resource_compartment_id' if attributes.key?(:'resourceCompartmentId') && attributes.key?(:'resource_compartment_id')

  self.resource_compartment_id = attributes[:'resource_compartment_id'] if attributes[:'resource_compartment_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType']

  raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type')

  self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type']

  self.time_assignment_from = attributes[:'timeAssignmentFrom'] if attributes[:'timeAssignmentFrom']

  raise 'You cannot provide both :timeAssignmentFrom and :time_assignment_from' if attributes.key?(:'timeAssignmentFrom') && attributes.key?(:'time_assignment_from')

  self.time_assignment_from = attributes[:'time_assignment_from'] if attributes[:'time_assignment_from']

  self.time_assignment_to = attributes[:'timeAssignmentTo'] if attributes[:'timeAssignmentTo']

  raise 'You cannot provide both :timeAssignmentTo and :time_assignment_to' if attributes.key?(:'timeAssignmentTo') && attributes.key?(:'time_assignment_to')

  self.time_assignment_to = attributes[:'time_assignment_to'] if attributes[:'time_assignment_to']

  self.is_enforced_always = attributes[:'isEnforcedAlways'] unless attributes[:'isEnforcedAlways'].nil?

  raise 'You cannot provide both :isEnforcedAlways and :is_enforced_always' if attributes.key?(:'isEnforcedAlways') && attributes.key?(:'is_enforced_always')

  self.is_enforced_always = attributes[:'is_enforced_always'] unless attributes[:'is_enforced_always'].nil?

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.assigner_id = attributes[:'assignerId'] if attributes[:'assignerId']

  raise 'You cannot provide both :assignerId and :assigner_id' if attributes.key?(:'assignerId') && attributes.key?(:'assigner_id')

  self.assigner_id = attributes[:'assigner_id'] if attributes[:'assigner_id']

  self.time_of_assignment = attributes[:'timeOfAssignment'] if attributes[:'timeOfAssignment']

  raise 'You cannot provide both :timeOfAssignment and :time_of_assignment' if attributes.key?(:'timeOfAssignment') && attributes.key?(:'time_of_assignment')

  self.time_of_assignment = attributes[:'time_of_assignment'] if attributes[:'time_of_assignment']

  self.comment = attributes[:'comment'] if attributes[:'comment']

  self.unassigner_id = attributes[:'unassignerId'] if attributes[:'unassignerId']

  raise 'You cannot provide both :unassignerId and :unassigner_id' if attributes.key?(:'unassignerId') && attributes.key?(:'unassigner_id')

  self.unassigner_id = attributes[:'unassigner_id'] if attributes[:'unassigner_id']

  self.time_of_deletion = attributes[:'timeOfDeletion'] if attributes[:'timeOfDeletion']

  raise 'You cannot provide both :timeOfDeletion and :time_of_deletion' if attributes.key?(:'timeOfDeletion') && attributes.key?(:'time_of_deletion')

  self.time_of_deletion = attributes[:'time_of_deletion'] if attributes[:'time_of_deletion']

  self.detachment_description = attributes[:'detachmentDescription'] if attributes[:'detachmentDescription']

  raise 'You cannot provide both :detachmentDescription and :detachment_description' if attributes.key?(:'detachmentDescription') && attributes.key?(:'detachment_description')

  self.detachment_description = attributes[:'detachment_description'] if attributes[:'detachment_description']

  self.is_log_forwarded = attributes[:'isLogForwarded'] unless attributes[:'isLogForwarded'].nil?

  raise 'You cannot provide both :isLogForwarded and :is_log_forwarded' if attributes.key?(:'isLogForwarded') && attributes.key?(:'is_log_forwarded')

  self.is_log_forwarded = attributes[:'is_log_forwarded'] unless attributes[:'is_log_forwarded'].nil?

  self.remote_syslog_server_address = attributes[:'remoteSyslogServerAddress'] if attributes[:'remoteSyslogServerAddress']

  raise 'You cannot provide both :remoteSyslogServerAddress and :remote_syslog_server_address' if attributes.key?(:'remoteSyslogServerAddress') && attributes.key?(:'remote_syslog_server_address')

  self.remote_syslog_server_address = attributes[:'remote_syslog_server_address'] if attributes[:'remote_syslog_server_address']

  self.remote_syslog_server_port = attributes[:'remoteSyslogServerPort'] if attributes[:'remoteSyslogServerPort']

  raise 'You cannot provide both :remoteSyslogServerPort and :remote_syslog_server_port' if attributes.key?(:'remoteSyslogServerPort') && attributes.key?(:'remote_syslog_server_port')

  self.remote_syslog_server_port = attributes[:'remote_syslog_server_port'] if attributes[:'remote_syslog_server_port']

  self.remote_syslog_server_ca_cert = attributes[:'remoteSyslogServerCACert'] if attributes[:'remoteSyslogServerCACert']

  raise 'You cannot provide both :remoteSyslogServerCACert and :remote_syslog_server_ca_cert' if attributes.key?(:'remoteSyslogServerCACert') && attributes.key?(:'remote_syslog_server_ca_cert')

  self.remote_syslog_server_ca_cert = attributes[:'remote_syslog_server_ca_cert'] if attributes[:'remote_syslog_server_ca_cert']

  self.is_auto_approve_during_maintenance = attributes[:'isAutoApproveDuringMaintenance'] unless attributes[:'isAutoApproveDuringMaintenance'].nil?

  raise 'You cannot provide both :isAutoApproveDuringMaintenance and :is_auto_approve_during_maintenance' if attributes.key?(:'isAutoApproveDuringMaintenance') && attributes.key?(:'is_auto_approve_during_maintenance')

  self.is_auto_approve_during_maintenance = attributes[:'is_auto_approve_during_maintenance'] unless attributes[:'is_auto_approve_during_maintenance'].nil?

  self.error_code = attributes[:'errorCode'] if attributes[:'errorCode']

  raise 'You cannot provide both :errorCode and :error_code' if attributes.key?(:'errorCode') && attributes.key?(:'error_code')

  self.error_code = attributes[:'error_code'] if attributes[:'error_code']

  self.error_message = attributes[:'errorMessage'] if attributes[:'errorMessage']

  raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message')

  self.error_message = attributes[:'error_message'] if attributes[:'error_message']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#assigner_idString

The OCID of the user who created this operator control assignment.

Returns:



81
82
83
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 81

def assigner_id
  @assigner_id
end

#commentString

Comment about the assignment of the operator control to this target resource.

Returns:



90
91
92
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 90

def comment
  @comment
end

#compartment_idString

The OCID of the comparment that contains the operator control assignment.

Returns:



53
54
55
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 53

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace.

Returns:



141
142
143
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 141

def defined_tags
  @defined_tags
end

#detachment_descriptionString

description containing reason for releasing of OperatorControl.

Returns:



103
104
105
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 103

def detachment_description
  @detachment_description
end

#error_codeInteger

The code identifying the error occurred during Assignment operation.

Returns:



127
128
129
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 127

def error_code
  @error_code
end

#error_messageString

The message describing the error occurred during Assignment operation.

Returns:



131
132
133
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 131

def error_message
  @error_message
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.

Returns:



136
137
138
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 136

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the operator control assignment.

Returns:



33
34
35
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 33

def id
  @id
end

#is_auto_approve_during_maintenanceBOOLEAN

The boolean if true would autoApprove during maintenance.

Returns:



123
124
125
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 123

def is_auto_approve_during_maintenance
  @is_auto_approve_during_maintenance
end

#is_enforced_alwaysBOOLEAN

If set, then the target resource is always governed by the operator control.

Returns:



73
74
75
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 73

def is_enforced_always
  @is_enforced_always
end

#is_log_forwardedBOOLEAN

If set indicates that the audit logs are being forwarded to the relevant remote logging server

Returns:



107
108
109
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 107

def is_log_forwarded
  @is_log_forwarded
end

#lifecycle_stateString

The current lifcycle state of the OperatorControl.

Returns:



77
78
79
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 77

def lifecycle_state
  @lifecycle_state
end

#operator_control_idString

[Required] The OCID of the operator control.

Returns:



37
38
39
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 37

def operator_control_id
  @operator_control_id
end

#remote_syslog_server_addressString

The address of the remote syslog server where the audit logs are being forwarded to. Address in host or IP format.

Returns:



111
112
113
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 111

def remote_syslog_server_address
  @remote_syslog_server_address
end

#remote_syslog_server_ca_certString

The CA certificate of the remote syslog server.

Returns:



119
120
121
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 119

def remote_syslog_server_ca_cert
  @remote_syslog_server_ca_cert
end

#remote_syslog_server_portInteger

The listening port of the remote syslog server. The port range is 0 - 65535. Only TCP supported.

Returns:



115
116
117
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 115

def remote_syslog_server_port
  @remote_syslog_server_port
end

#resource_compartment_idString

The OCID of the compartment that contains the target resource.

Returns:



49
50
51
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 49

def resource_compartment_id
  @resource_compartment_id
end

#resource_idString

[Required] The OCID of the target resource.

Returns:



41
42
43
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 41

def resource_id
  @resource_id
end

#resource_nameString

[Required] Name of the target resource.

Returns:



45
46
47
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 45

def resource_name
  @resource_name
end

#resource_typeString

resourceType for which the OperatorControlAssignment is applicable

Returns:



57
58
59
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 57

def resource_type
  @resource_type
end

#time_assignment_fromDateTime

The time at which the target resource will be brought under the governance of the operator control expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’

Returns:



63
64
65
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 63

def time_assignment_from
  @time_assignment_from
end

#time_assignment_toDateTime

The time at which the target resource will leave the governance of the operator control expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’

Returns:



69
70
71
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 69

def time_assignment_to
  @time_assignment_to
end

#time_of_assignmentDateTime

Time when the operator control assignment is created in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’

Returns:



86
87
88
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 86

def time_of_assignment
  @time_of_assignment
end

#time_of_deletionDateTime

Time on which the operator control assignment was deleted in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’

Returns:



99
100
101
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 99

def time_of_deletion
  @time_of_deletion
end

#unassigner_idString

User id who released the operatorControl.

Returns:



94
95
96
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 94

def unassigner_id
  @unassigner_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 144

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'operator_control_id': :'operatorControlId',
    'resource_id': :'resourceId',
    'resource_name': :'resourceName',
    'resource_compartment_id': :'resourceCompartmentId',
    'compartment_id': :'compartmentId',
    'resource_type': :'resourceType',
    'time_assignment_from': :'timeAssignmentFrom',
    'time_assignment_to': :'timeAssignmentTo',
    'is_enforced_always': :'isEnforcedAlways',
    'lifecycle_state': :'lifecycleState',
    'assigner_id': :'assignerId',
    'time_of_assignment': :'timeOfAssignment',
    'comment': :'comment',
    'unassigner_id': :'unassignerId',
    'time_of_deletion': :'timeOfDeletion',
    'detachment_description': :'detachmentDescription',
    'is_log_forwarded': :'isLogForwarded',
    'remote_syslog_server_address': :'remoteSyslogServerAddress',
    'remote_syslog_server_port': :'remoteSyslogServerPort',
    'remote_syslog_server_ca_cert': :'remoteSyslogServerCACert',
    'is_auto_approve_during_maintenance': :'isAutoApproveDuringMaintenance',
    'error_code': :'errorCode',
    'error_message': :'errorMessage',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 178

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'operator_control_id': :'String',
    'resource_id': :'String',
    'resource_name': :'String',
    'resource_compartment_id': :'String',
    'compartment_id': :'String',
    'resource_type': :'String',
    'time_assignment_from': :'DateTime',
    'time_assignment_to': :'DateTime',
    'is_enforced_always': :'BOOLEAN',
    'lifecycle_state': :'String',
    'assigner_id': :'String',
    'time_of_assignment': :'DateTime',
    'comment': :'String',
    'unassigner_id': :'String',
    'time_of_deletion': :'DateTime',
    'detachment_description': :'String',
    'is_log_forwarded': :'BOOLEAN',
    'remote_syslog_server_address': :'String',
    'remote_syslog_server_port': :'Integer',
    'remote_syslog_server_ca_cert': :'String',
    'is_auto_approve_during_maintenance': :'BOOLEAN',
    'error_code': :'Integer',
    'error_message': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 431

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    operator_control_id == other.operator_control_id &&
    resource_id == other.resource_id &&
    resource_name == other.resource_name &&
    resource_compartment_id == other.resource_compartment_id &&
    compartment_id == other.compartment_id &&
    resource_type == other.resource_type &&
    time_assignment_from == other.time_assignment_from &&
    time_assignment_to == other.time_assignment_to &&
    is_enforced_always == other.is_enforced_always &&
    lifecycle_state == other.lifecycle_state &&
    assigner_id == other.assigner_id &&
    time_of_assignment == other.time_of_assignment &&
    comment == other.comment &&
    unassigner_id == other.unassigner_id &&
    time_of_deletion == other.time_of_deletion &&
    detachment_description == other.detachment_description &&
    is_log_forwarded == other.is_log_forwarded &&
    remote_syslog_server_address == other.remote_syslog_server_address &&
    remote_syslog_server_port == other.remote_syslog_server_port &&
    remote_syslog_server_ca_cert == other.remote_syslog_server_ca_cert &&
    is_auto_approve_during_maintenance == other.is_auto_approve_during_maintenance &&
    error_code == other.error_code &&
    error_message == other.error_message &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 486

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



466
467
468
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 466

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



475
476
477
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 475

def hash
  [id, operator_control_id, resource_id, resource_name, resource_compartment_id, compartment_id, resource_type, time_assignment_from, time_assignment_to, is_enforced_always, lifecycle_state, assigner_id, time_of_assignment, comment, unassigner_id, time_of_deletion, detachment_description, is_log_forwarded, remote_syslog_server_address, remote_syslog_server_port, remote_syslog_server_ca_cert, is_auto_approve_during_maintenance, error_code, error_message, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



519
520
521
522
523
524
525
526
527
528
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 519

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



513
514
515
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 513

def to_s
  to_hash.to_s
end