Class: OCI::OperatorAccessControl::Models::OperatorControlAssignmentSummary
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::OperatorControlAssignmentSummary
- Defined in:
- lib/oci/operator_access_control/models/operator_control_assignment_summary.rb
Overview
Details of the operator control assignment.
Constant Summary collapse
- RESOURCE_TYPE_ENUM =
[ RESOURCE_TYPE_EXACC = 'EXACC'.freeze, RESOURCE_TYPE_EXADATAINFRASTRUCTURE = 'EXADATAINFRASTRUCTURE'.freeze, RESOURCE_TYPE_AUTONOMOUSVMCLUSTER = 'AUTONOMOUSVMCLUSTER'.freeze, RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATED = 'CREATED'.freeze, LIFECYCLE_STATE_APPLIED = 'APPLIED'.freeze, LIFECYCLE_STATE_APPLYFAILED = 'APPLYFAILED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DELETIONFAILED = 'DELETIONFAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the operator control assignment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#error_code ⇒ Integer
The code identifying the error occurred during Assignment operation.
-
#error_message ⇒ String
The message describing the error occurred during Assignment operation.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The OCID of the operator control assignment.
-
#is_enforced_always ⇒ BOOLEAN
If true, then the target resource is always governed by the operator control.
-
#is_log_forwarded ⇒ BOOLEAN
If set, then the audit logs are being forwarded to the relevant remote logging server.
-
#lifecycle_state ⇒ String
The current lifcycle state of the OperatorControl.
-
#operator_control_id ⇒ String
[Required] The OCID of the operator control.
-
#remote_syslog_server_address ⇒ String
The address of the remote syslog server where the audit logs are being forwarded to.
-
#remote_syslog_server_port ⇒ Integer
The listening port of the remote syslog server.
-
#resource_id ⇒ String
[Required] The OCID of the target resource being governed by the operator control.
-
#resource_type ⇒ String
resourceType for which the OperatorControlAssignment is applicable.
-
#time_assignment_from ⇒ DateTime
The time at which the target resource will be brought under the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_assignment_to ⇒ DateTime
The time at which the target resource will leave the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’.
-
#time_of_assignment ⇒ DateTime
Time when the operator control assignment is created in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperatorControlAssignmentSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OperatorControlAssignmentSummary
Initializes the object
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 175 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.operator_control_id = attributes[:'operatorControlId'] if attributes[:'operatorControlId'] raise 'You cannot provide both :operatorControlId and :operator_control_id' if attributes.key?(:'operatorControlId') && attributes.key?(:'operator_control_id') self.operator_control_id = attributes[:'operator_control_id'] if attributes[:'operator_control_id'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.time_assignment_from = attributes[:'timeAssignmentFrom'] if attributes[:'timeAssignmentFrom'] raise 'You cannot provide both :timeAssignmentFrom and :time_assignment_from' if attributes.key?(:'timeAssignmentFrom') && attributes.key?(:'time_assignment_from') self.time_assignment_from = attributes[:'time_assignment_from'] if attributes[:'time_assignment_from'] self.time_assignment_to = attributes[:'timeAssignmentTo'] if attributes[:'timeAssignmentTo'] raise 'You cannot provide both :timeAssignmentTo and :time_assignment_to' if attributes.key?(:'timeAssignmentTo') && attributes.key?(:'time_assignment_to') self.time_assignment_to = attributes[:'time_assignment_to'] if attributes[:'time_assignment_to'] self.is_enforced_always = attributes[:'isEnforcedAlways'] unless attributes[:'isEnforcedAlways'].nil? raise 'You cannot provide both :isEnforcedAlways and :is_enforced_always' if attributes.key?(:'isEnforcedAlways') && attributes.key?(:'is_enforced_always') self.is_enforced_always = attributes[:'is_enforced_always'] unless attributes[:'is_enforced_always'].nil? self.time_of_assignment = attributes[:'timeOfAssignment'] if attributes[:'timeOfAssignment'] raise 'You cannot provide both :timeOfAssignment and :time_of_assignment' if attributes.key?(:'timeOfAssignment') && attributes.key?(:'time_of_assignment') self.time_of_assignment = attributes[:'time_of_assignment'] if attributes[:'time_of_assignment'] self.error_code = attributes[:'errorCode'] if attributes[:'errorCode'] raise 'You cannot provide both :errorCode and :error_code' if attributes.key?(:'errorCode') && attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] if attributes[:'error_code'] self. = attributes[:'errorMessage'] if attributes[:'errorMessage'] raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message') self. = attributes[:'error_message'] if attributes[:'error_message'] self.is_log_forwarded = attributes[:'isLogForwarded'] unless attributes[:'isLogForwarded'].nil? raise 'You cannot provide both :isLogForwarded and :is_log_forwarded' if attributes.key?(:'isLogForwarded') && attributes.key?(:'is_log_forwarded') self.is_log_forwarded = attributes[:'is_log_forwarded'] unless attributes[:'is_log_forwarded'].nil? self.remote_syslog_server_address = attributes[:'remoteSyslogServerAddress'] if attributes[:'remoteSyslogServerAddress'] raise 'You cannot provide both :remoteSyslogServerAddress and :remote_syslog_server_address' if attributes.key?(:'remoteSyslogServerAddress') && attributes.key?(:'remote_syslog_server_address') self.remote_syslog_server_address = attributes[:'remote_syslog_server_address'] if attributes[:'remote_syslog_server_address'] self.remote_syslog_server_port = attributes[:'remoteSyslogServerPort'] if attributes[:'remoteSyslogServerPort'] raise 'You cannot provide both :remoteSyslogServerPort and :remote_syslog_server_port' if attributes.key?(:'remoteSyslogServerPort') && attributes.key?(:'remote_syslog_server_port') self.remote_syslog_server_port = attributes[:'remote_syslog_server_port'] if attributes[:'remote_syslog_server_port'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the operator control assignment.
43 44 45 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 43 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
100 101 102 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 100 def end |
#error_code ⇒ Integer
The code identifying the error occurred during Assignment operation.
70 71 72 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 70 def error_code @error_code end |
#error_message ⇒ String
The message describing the error occurred during Assignment operation.
74 75 76 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 74 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
95 96 97 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 95 def end |
#id ⇒ String
[Required] The OCID of the operator control assignment.
31 32 33 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 31 def id @id end |
#is_enforced_always ⇒ BOOLEAN
If true, then the target resource is always governed by the operator control. Otherwise governance is time-based as specified by timeAssignmentTo and timeAssignmentFrom.
61 62 63 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 61 def is_enforced_always @is_enforced_always end |
#is_log_forwarded ⇒ BOOLEAN
If set, then the audit logs are being forwarded to the relevant remote logging server
78 79 80 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 78 def is_log_forwarded @is_log_forwarded end |
#lifecycle_state ⇒ String
The current lifcycle state of the OperatorControl.
90 91 92 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 90 def lifecycle_state @lifecycle_state end |
#operator_control_id ⇒ String
[Required] The OCID of the operator control.
35 36 37 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 35 def operator_control_id @operator_control_id end |
#remote_syslog_server_address ⇒ String
The address of the remote syslog server where the audit logs are being forwarded to. Address in host or IP format.
82 83 84 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 82 def remote_syslog_server_address @remote_syslog_server_address end |
#remote_syslog_server_port ⇒ Integer
The listening port of the remote syslog server. The port range is 0 - 65535.
86 87 88 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 86 def remote_syslog_server_port @remote_syslog_server_port end |
#resource_id ⇒ String
[Required] The OCID of the target resource being governed by the operator control.
39 40 41 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 39 def resource_id @resource_id end |
#resource_type ⇒ String
resourceType for which the OperatorControlAssignment is applicable
47 48 49 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 47 def resource_type @resource_type end |
#time_assignment_from ⇒ DateTime
The time at which the target resource will be brought under the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
52 53 54 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 52 def time_assignment_from @time_assignment_from end |
#time_assignment_to ⇒ DateTime
The time at which the target resource will leave the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’
57 58 59 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 57 def time_assignment_to @time_assignment_to end |
#time_of_assignment ⇒ DateTime
Time when the operator control assignment is created in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
66 67 68 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 66 def time_of_assignment @time_of_assignment end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 103 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'operator_control_id': :'operatorControlId', 'resource_id': :'resourceId', 'compartment_id': :'compartmentId', 'resource_type': :'resourceType', 'time_assignment_from': :'timeAssignmentFrom', 'time_assignment_to': :'timeAssignmentTo', 'is_enforced_always': :'isEnforcedAlways', 'time_of_assignment': :'timeOfAssignment', 'error_code': :'errorCode', 'error_message': :'errorMessage', 'is_log_forwarded': :'isLogForwarded', 'remote_syslog_server_address': :'remoteSyslogServerAddress', 'remote_syslog_server_port': :'remoteSyslogServerPort', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 128 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'operator_control_id': :'String', 'resource_id': :'String', 'compartment_id': :'String', 'resource_type': :'String', 'time_assignment_from': :'DateTime', 'time_assignment_to': :'DateTime', 'is_enforced_always': :'BOOLEAN', 'time_of_assignment': :'DateTime', 'error_code': :'Integer', 'error_message': :'String', 'is_log_forwarded': :'BOOLEAN', 'remote_syslog_server_address': :'String', 'remote_syslog_server_port': :'Integer', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 313 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && operator_control_id == other.operator_control_id && resource_id == other.resource_id && compartment_id == other.compartment_id && resource_type == other.resource_type && time_assignment_from == other.time_assignment_from && time_assignment_to == other.time_assignment_to && is_enforced_always == other.is_enforced_always && time_of_assignment == other.time_of_assignment && error_code == other.error_code && == other. && is_log_forwarded == other.is_log_forwarded && remote_syslog_server_address == other.remote_syslog_server_address && remote_syslog_server_port == other.remote_syslog_server_port && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 359 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
339 340 341 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 339 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
348 349 350 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 348 def hash [id, operator_control_id, resource_id, compartment_id, resource_type, time_assignment_from, time_assignment_to, is_enforced_always, time_of_assignment, error_code, , is_log_forwarded, remote_syslog_server_address, remote_syslog_server_port, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
392 393 394 395 396 397 398 399 400 401 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 392 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
386 387 388 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 386 def to_s to_hash.to_s end |