Class: OCI::OperatorAccessControl::Models::OperatorControlSummary
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::OperatorControlSummary
- Defined in:
- lib/oci/operator_access_control/models/operator_control_summary.rb
Overview
Summary of the OperatorControl.
Constant Summary collapse
- RESOURCE_TYPE_ENUM =
[ RESOURCE_TYPE_EXACC = 'EXACC'.freeze, RESOURCE_TYPE_EXADATAINFRASTRUCTURE = 'EXADATAINFRASTRUCTURE'.freeze, RESOURCE_TYPE_AUTONOMOUSVMCLUSTER = 'AUTONOMOUSVMCLUSTER'.freeze, RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATED = 'CREATED'.freeze, LIFECYCLE_STATE_ASSIGNED = 'ASSIGNED'.freeze, LIFECYCLE_STATE_UNASSIGNED = 'UNASSIGNED'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the compartment that contains the operator control.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The OCID of the operator control.
-
#is_fully_pre_approved ⇒ BOOLEAN
Whether all operator actions are pre-approved.
-
#lifecycle_state ⇒ String
The current lifecycle state of the operator control.
-
#operator_control_name ⇒ String
[Required] Name of the operator control.
-
#resource_type ⇒ String
resourceType for which the OperatorControl is applicable.
-
#time_of_creation ⇒ DateTime
Time when the operator control was created, expressed in [RFC 3339] (tools.ietf.org/html/rfc3339) timestamp format.
-
#time_of_deletion ⇒ DateTime
Time when the operator control was deleted, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_of_modification ⇒ DateTime
Time when the operator control was last modified, expressed in [RFC 3339] (tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperatorControlSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OperatorControlSummary
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 130 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.operator_control_name = attributes[:'operatorControlName'] if attributes[:'operatorControlName'] raise 'You cannot provide both :operatorControlName and :operator_control_name' if attributes.key?(:'operatorControlName') && attributes.key?(:'operator_control_name') self.operator_control_name = attributes[:'operator_control_name'] if attributes[:'operator_control_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_fully_pre_approved = attributes[:'isFullyPreApproved'] unless attributes[:'isFullyPreApproved'].nil? raise 'You cannot provide both :isFullyPreApproved and :is_fully_pre_approved' if attributes.key?(:'isFullyPreApproved') && attributes.key?(:'is_fully_pre_approved') self.is_fully_pre_approved = attributes[:'is_fully_pre_approved'] unless attributes[:'is_fully_pre_approved'].nil? self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.time_of_creation = attributes[:'timeOfCreation'] if attributes[:'timeOfCreation'] raise 'You cannot provide both :timeOfCreation and :time_of_creation' if attributes.key?(:'timeOfCreation') && attributes.key?(:'time_of_creation') self.time_of_creation = attributes[:'time_of_creation'] if attributes[:'time_of_creation'] self.time_of_modification = attributes[:'timeOfModification'] if attributes[:'timeOfModification'] raise 'You cannot provide both :timeOfModification and :time_of_modification' if attributes.key?(:'timeOfModification') && attributes.key?(:'time_of_modification') self.time_of_modification = attributes[:'time_of_modification'] if attributes[:'time_of_modification'] self.time_of_deletion = attributes[:'timeOfDeletion'] if attributes[:'timeOfDeletion'] raise 'You cannot provide both :timeOfDeletion and :time_of_deletion' if attributes.key?(:'timeOfDeletion') && attributes.key?(:'time_of_deletion') self.time_of_deletion = attributes[:'time_of_deletion'] if attributes[:'time_of_deletion'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the compartment that contains the operator control.
36 37 38 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 36 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
73 74 75 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 73 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
68 69 70 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 68 def end |
#id ⇒ String
[Required] The OCID of the operator control.
28 29 30 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 28 def id @id end |
#is_fully_pre_approved ⇒ BOOLEAN
Whether all operator actions are pre-approved. If yes, an access request associated with a resource governed by the operator control will be automatically approved by the system.
40 41 42 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 40 def is_fully_pre_approved @is_fully_pre_approved end |
#lifecycle_state ⇒ String
The current lifecycle state of the operator control.
63 64 65 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 63 def lifecycle_state @lifecycle_state end |
#operator_control_name ⇒ String
[Required] Name of the operator control.
32 33 34 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 32 def operator_control_name @operator_control_name end |
#resource_type ⇒ String
resourceType for which the OperatorControl is applicable
44 45 46 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 44 def resource_type @resource_type end |
#time_of_creation ⇒ DateTime
Time when the operator control was created, expressed in [RFC 3339] (tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
49 50 51 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 49 def time_of_creation @time_of_creation end |
#time_of_deletion ⇒ DateTime
Time when the operator control was deleted, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
59 60 61 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 59 def time_of_deletion @time_of_deletion end |
#time_of_modification ⇒ DateTime
Time when the operator control was last modified, expressed in [RFC 3339] (tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
54 55 56 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 54 def time_of_modification @time_of_modification end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'operator_control_name': :'operatorControlName', 'compartment_id': :'compartmentId', 'is_fully_pre_approved': :'isFullyPreApproved', 'resource_type': :'resourceType', 'time_of_creation': :'timeOfCreation', 'time_of_modification': :'timeOfModification', 'time_of_deletion': :'timeOfDeletion', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 95 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'operator_control_name': :'String', 'compartment_id': :'String', 'is_fully_pre_approved': :'BOOLEAN', 'resource_type': :'String', 'time_of_creation': :'DateTime', 'time_of_modification': :'DateTime', 'time_of_deletion': :'DateTime', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 232 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && operator_control_name == other.operator_control_name && compartment_id == other.compartment_id && is_fully_pre_approved == other.is_fully_pre_approved && resource_type == other.resource_type && time_of_creation == other.time_of_creation && time_of_modification == other.time_of_modification && time_of_deletion == other.time_of_deletion && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 272 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
252 253 254 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 252 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 261 def hash [id, operator_control_name, compartment_id, is_fully_pre_approved, resource_type, time_of_creation, time_of_modification, time_of_deletion, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
299 300 301 |
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 299 def to_s to_hash.to_s end |