Class: OCI::OperatorAccessControl::Models::UpdateOperatorControlAssignmentDetails
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::UpdateOperatorControlAssignmentDetails
- Defined in:
- lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb
Overview
Details for modifying the Operator Control assignment.
Instance Attribute Summary collapse
-
#comment ⇒ String
Comment about the modification of the operator control assignment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_auto_approve_during_maintenance ⇒ BOOLEAN
The boolean if true would autoApprove during maintenance.
-
#is_enforced_always ⇒ BOOLEAN
[Required] If true, then the target resource is always governed by the operator control.
-
#is_log_forwarded ⇒ BOOLEAN
If set, then the audit logs will be forwarded to the relevant remote logging server.
-
#remote_syslog_server_address ⇒ String
The address of the remote syslog server where the audit logs will be forwarded to.
-
#remote_syslog_server_ca_cert ⇒ String
The CA certificate of the remote syslog server.
-
#remote_syslog_server_port ⇒ Integer
The listening port of the remote syslog server.
-
#time_assignment_from ⇒ DateTime
The time at which the target resource will be brought under the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_assignment_to ⇒ DateTime
The time at which the target resource will leave the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOperatorControlAssignmentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOperatorControlAssignmentDetails
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 113 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_assignment_from = attributes[:'timeAssignmentFrom'] if attributes[:'timeAssignmentFrom'] raise 'You cannot provide both :timeAssignmentFrom and :time_assignment_from' if attributes.key?(:'timeAssignmentFrom') && attributes.key?(:'time_assignment_from') self.time_assignment_from = attributes[:'time_assignment_from'] if attributes[:'time_assignment_from'] self.time_assignment_to = attributes[:'timeAssignmentTo'] if attributes[:'timeAssignmentTo'] raise 'You cannot provide both :timeAssignmentTo and :time_assignment_to' if attributes.key?(:'timeAssignmentTo') && attributes.key?(:'time_assignment_to') self.time_assignment_to = attributes[:'time_assignment_to'] if attributes[:'time_assignment_to'] self.is_enforced_always = attributes[:'isEnforcedAlways'] unless attributes[:'isEnforcedAlways'].nil? raise 'You cannot provide both :isEnforcedAlways and :is_enforced_always' if attributes.key?(:'isEnforcedAlways') && attributes.key?(:'is_enforced_always') self.is_enforced_always = attributes[:'is_enforced_always'] unless attributes[:'is_enforced_always'].nil? self.comment = attributes[:'comment'] if attributes[:'comment'] self.is_log_forwarded = attributes[:'isLogForwarded'] unless attributes[:'isLogForwarded'].nil? raise 'You cannot provide both :isLogForwarded and :is_log_forwarded' if attributes.key?(:'isLogForwarded') && attributes.key?(:'is_log_forwarded') self.is_log_forwarded = attributes[:'is_log_forwarded'] unless attributes[:'is_log_forwarded'].nil? self.remote_syslog_server_address = attributes[:'remoteSyslogServerAddress'] if attributes[:'remoteSyslogServerAddress'] raise 'You cannot provide both :remoteSyslogServerAddress and :remote_syslog_server_address' if attributes.key?(:'remoteSyslogServerAddress') && attributes.key?(:'remote_syslog_server_address') self.remote_syslog_server_address = attributes[:'remote_syslog_server_address'] if attributes[:'remote_syslog_server_address'] self.remote_syslog_server_port = attributes[:'remoteSyslogServerPort'] if attributes[:'remoteSyslogServerPort'] raise 'You cannot provide both :remoteSyslogServerPort and :remote_syslog_server_port' if attributes.key?(:'remoteSyslogServerPort') && attributes.key?(:'remote_syslog_server_port') self.remote_syslog_server_port = attributes[:'remote_syslog_server_port'] if attributes[:'remote_syslog_server_port'] self.remote_syslog_server_ca_cert = attributes[:'remoteSyslogServerCACert'] if attributes[:'remoteSyslogServerCACert'] raise 'You cannot provide both :remoteSyslogServerCACert and :remote_syslog_server_ca_cert' if attributes.key?(:'remoteSyslogServerCACert') && attributes.key?(:'remote_syslog_server_ca_cert') self.remote_syslog_server_ca_cert = attributes[:'remote_syslog_server_ca_cert'] if attributes[:'remote_syslog_server_ca_cert'] self.is_auto_approve_during_maintenance = attributes[:'isAutoApproveDuringMaintenance'] unless attributes[:'isAutoApproveDuringMaintenance'].nil? raise 'You cannot provide both :isAutoApproveDuringMaintenance and :is_auto_approve_during_maintenance' if attributes.key?(:'isAutoApproveDuringMaintenance') && attributes.key?(:'is_auto_approve_during_maintenance') self.is_auto_approve_during_maintenance = attributes[:'is_auto_approve_during_maintenance'] unless attributes[:'is_auto_approve_during_maintenance'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#comment ⇒ String
Comment about the modification of the operator control assignment.
26 27 28 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 26 def comment @comment end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
56 57 58 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 56 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
51 52 53 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 51 def @freeform_tags end |
#is_auto_approve_during_maintenance ⇒ BOOLEAN
The boolean if true would autoApprove during maintenance.
46 47 48 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 46 def is_auto_approve_during_maintenance @is_auto_approve_during_maintenance end |
#is_enforced_always ⇒ BOOLEAN
[Required] If true, then the target resource is always governed by the operator control. Otherwise governance is time-based as specified by timeAssignmentTo and timeAssignmentFrom.
22 23 24 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 22 def is_enforced_always @is_enforced_always end |
#is_log_forwarded ⇒ BOOLEAN
If set, then the audit logs will be forwarded to the relevant remote logging server
30 31 32 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 30 def is_log_forwarded @is_log_forwarded end |
#remote_syslog_server_address ⇒ String
The address of the remote syslog server where the audit logs will be forwarded to. Address in host or IP format.
34 35 36 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 34 def remote_syslog_server_address @remote_syslog_server_address end |
#remote_syslog_server_ca_cert ⇒ String
The CA certificate of the remote syslog server. Identity of the remote syslog server will be asserted based on this certificate.
42 43 44 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 42 def remote_syslog_server_ca_cert @remote_syslog_server_ca_cert end |
#remote_syslog_server_port ⇒ Integer
The listening port of the remote syslog server. The port range is 0 - 65535. Only TCP supported.
38 39 40 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 38 def remote_syslog_server_port @remote_syslog_server_port end |
#time_assignment_from ⇒ DateTime
The time at which the target resource will be brought under the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
13 14 15 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 13 def time_assignment_from @time_assignment_from end |
#time_assignment_to ⇒ DateTime
The time at which the target resource will leave the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’
18 19 20 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 18 def time_assignment_to @time_assignment_to end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 59 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_assignment_from': :'timeAssignmentFrom', 'time_assignment_to': :'timeAssignmentTo', 'is_enforced_always': :'isEnforcedAlways', 'comment': :'comment', 'is_log_forwarded': :'isLogForwarded', 'remote_syslog_server_address': :'remoteSyslogServerAddress', 'remote_syslog_server_port': :'remoteSyslogServerPort', 'remote_syslog_server_ca_cert': :'remoteSyslogServerCACert', 'is_auto_approve_during_maintenance': :'isAutoApproveDuringMaintenance', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 78 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_assignment_from': :'DateTime', 'time_assignment_to': :'DateTime', 'is_enforced_always': :'BOOLEAN', 'comment': :'String', 'is_log_forwarded': :'BOOLEAN', 'remote_syslog_server_address': :'String', 'remote_syslog_server_port': :'Integer', 'remote_syslog_server_ca_cert': :'String', 'is_auto_approve_during_maintenance': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 189 def ==(other) return true if equal?(other) self.class == other.class && time_assignment_from == other.time_assignment_from && time_assignment_to == other.time_assignment_to && is_enforced_always == other.is_enforced_always && comment == other.comment && is_log_forwarded == other.is_log_forwarded && remote_syslog_server_address == other.remote_syslog_server_address && remote_syslog_server_port == other.remote_syslog_server_port && remote_syslog_server_ca_cert == other.remote_syslog_server_ca_cert && is_auto_approve_during_maintenance == other.is_auto_approve_during_maintenance && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 229 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
209 210 211 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 209 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 218 def hash [time_assignment_from, time_assignment_to, is_enforced_always, comment, is_log_forwarded, remote_syslog_server_address, remote_syslog_server_port, remote_syslog_server_ca_cert, is_auto_approve_during_maintenance, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 262 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
256 257 258 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 256 def to_s to_hash.to_s end |