Class: OCI::OperatorAccessControl::Models::UpdateOperatorControlDetails
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::UpdateOperatorControlDetails
- Defined in:
- lib/oci/operator_access_control/models/update_operator_control_details.rb
Overview
Information about the new operator control.
Instance Attribute Summary collapse
-
#approver_groups_list ⇒ Array<String>
[Required] List of user groups who can approve an access request associated with a target resource under the governance of this operator control.
-
#approvers_list ⇒ Array<String>
List of users who can approve an access request associated with a target resource under the governance of this operator control.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the operator control.
-
#email_id_list ⇒ Array<String>
List of emailId.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_fully_pre_approved ⇒ BOOLEAN
[Required] Whether all the operator actions have been pre-approved.
-
#operator_control_name ⇒ String
[Required] Name of the operator control.
-
#pre_approved_op_action_list ⇒ Array<String>
List of pre-approved operator actions.
-
#system_message ⇒ String
System message that would be displayed to the operator users on accessing the target resource under the governance of this operator control.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOperatorControlDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOperatorControlDetails
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 109 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operator_control_name = attributes[:'operatorControlName'] if attributes[:'operatorControlName'] raise 'You cannot provide both :operatorControlName and :operator_control_name' if attributes.key?(:'operatorControlName') && attributes.key?(:'operator_control_name') self.operator_control_name = attributes[:'operator_control_name'] if attributes[:'operator_control_name'] self.description = attributes[:'description'] if attributes[:'description'] self.approvers_list = attributes[:'approversList'] if attributes[:'approversList'] raise 'You cannot provide both :approversList and :approvers_list' if attributes.key?(:'approversList') && attributes.key?(:'approvers_list') self.approvers_list = attributes[:'approvers_list'] if attributes[:'approvers_list'] self.approver_groups_list = attributes[:'approverGroupsList'] if attributes[:'approverGroupsList'] raise 'You cannot provide both :approverGroupsList and :approver_groups_list' if attributes.key?(:'approverGroupsList') && attributes.key?(:'approver_groups_list') self.approver_groups_list = attributes[:'approver_groups_list'] if attributes[:'approver_groups_list'] self.pre_approved_op_action_list = attributes[:'preApprovedOpActionList'] if attributes[:'preApprovedOpActionList'] raise 'You cannot provide both :preApprovedOpActionList and :pre_approved_op_action_list' if attributes.key?(:'preApprovedOpActionList') && attributes.key?(:'pre_approved_op_action_list') self.pre_approved_op_action_list = attributes[:'pre_approved_op_action_list'] if attributes[:'pre_approved_op_action_list'] self.is_fully_pre_approved = attributes[:'isFullyPreApproved'] unless attributes[:'isFullyPreApproved'].nil? raise 'You cannot provide both :isFullyPreApproved and :is_fully_pre_approved' if attributes.key?(:'isFullyPreApproved') && attributes.key?(:'is_fully_pre_approved') self.is_fully_pre_approved = attributes[:'is_fully_pre_approved'] unless attributes[:'is_fully_pre_approved'].nil? self.email_id_list = attributes[:'emailIdList'] if attributes[:'emailIdList'] raise 'You cannot provide both :emailIdList and :email_id_list' if attributes.key?(:'emailIdList') && attributes.key?(:'email_id_list') self.email_id_list = attributes[:'email_id_list'] if attributes[:'email_id_list'] self. = attributes[:'systemMessage'] if attributes[:'systemMessage'] raise 'You cannot provide both :systemMessage and :system_message' if attributes.key?(:'systemMessage') && attributes.key?(:'system_message') self. = attributes[:'system_message'] if attributes[:'system_message'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#approver_groups_list ⇒ Array<String>
[Required] List of user groups who can approve an access request associated with a target resource under the governance of this operator control.
24 25 26 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 24 def approver_groups_list @approver_groups_list end |
#approvers_list ⇒ Array<String>
List of users who can approve an access request associated with a target resource under the governance of this operator control.
20 21 22 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 20 def approvers_list @approvers_list end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
55 56 57 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 55 def end |
#description ⇒ String
Description of the operator control.
16 17 18 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 16 def description @description end |
#email_id_list ⇒ Array<String>
List of emailId.
41 42 43 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 41 def email_id_list @email_id_list end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
50 51 52 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 50 def end |
#is_fully_pre_approved ⇒ BOOLEAN
[Required] Whether all the operator actions have been pre-approved. If yes, all access requests associated with a resource governed by this operator control will be auto-approved.
36 37 38 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 36 def is_fully_pre_approved @is_fully_pre_approved end |
#operator_control_name ⇒ String
[Required] Name of the operator control.
12 13 14 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 12 def operator_control_name @operator_control_name end |
#pre_approved_op_action_list ⇒ Array<String>
List of pre-approved operator actions. Access requests associated with a resource governed by this operator control will be automatically approved if the access request only contain operator actions in the pre-approved list.
30 31 32 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 30 def pre_approved_op_action_list @pre_approved_op_action_list end |
#system_message ⇒ String
System message that would be displayed to the operator users on accessing the target resource under the governance of this operator control.
45 46 47 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 45 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operator_control_name': :'operatorControlName', 'description': :'description', 'approvers_list': :'approversList', 'approver_groups_list': :'approverGroupsList', 'pre_approved_op_action_list': :'preApprovedOpActionList', 'is_fully_pre_approved': :'isFullyPreApproved', 'email_id_list': :'emailIdList', 'system_message': :'systemMessage', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 76 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operator_control_name': :'String', 'description': :'String', 'approvers_list': :'Array<String>', 'approver_groups_list': :'Array<String>', 'pre_approved_op_action_list': :'Array<String>', 'is_fully_pre_approved': :'BOOLEAN', 'email_id_list': :'Array<String>', 'system_message': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 179 def ==(other) return true if equal?(other) self.class == other.class && operator_control_name == other.operator_control_name && description == other.description && approvers_list == other.approvers_list && approver_groups_list == other.approver_groups_list && pre_approved_op_action_list == other.pre_approved_op_action_list && is_fully_pre_approved == other.is_fully_pre_approved && email_id_list == other.email_id_list && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 218 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
198 199 200 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 198 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 207 def hash [operator_control_name, description, approvers_list, approver_groups_list, pre_approved_op_action_list, is_fully_pre_approved, email_id_list, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 251 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
245 246 247 |
# File 'lib/oci/operator_access_control/models/update_operator_control_details.rb', line 245 def to_s to_hash.to_s end |