Class: OCI::Opsi::Models::AddEmManagedExternalExadataInsightMembersDetails
- Inherits:
-
AddExadataInsightMembersDetails
- Object
- AddExadataInsightMembersDetails
- OCI::Opsi::Models::AddEmManagedExternalExadataInsightMembersDetails
- Defined in:
- lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb
Overview
The information about the members of Exadata system to be added. If memberEntityDetails is not specified, the the Enterprise Manager entity (e.g. databases and hosts) associated with an Exadata system will be placed in the same compartment as the Exadata system.
Constant Summary
Constants inherited from AddExadataInsightMembersDetails
OCI::Opsi::Models::AddExadataInsightMembersDetails::ENTITY_SOURCE_ENUM
Instance Attribute Summary collapse
- #member_entity_details ⇒ Array<OCI::Opsi::Models::CreateEmManagedExternalExadataMemberEntityDetails>
Attributes inherited from AddExadataInsightMembersDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddEmManagedExternalExadataInsightMembersDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AddExadataInsightMembersDetails
Constructor Details
#initialize(attributes = {}) ⇒ AddEmManagedExternalExadataInsightMembersDetails
Initializes the object
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb', line 41 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['entitySource'] = 'EM_MANAGED_EXTERNAL_EXADATA' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.member_entity_details = attributes[:'memberEntityDetails'] if attributes[:'memberEntityDetails'] raise 'You cannot provide both :memberEntityDetails and :member_entity_details' if attributes.key?(:'memberEntityDetails') && attributes.key?(:'member_entity_details') self.member_entity_details = attributes[:'member_entity_details'] if attributes[:'member_entity_details'] end |
Instance Attribute Details
#member_entity_details ⇒ Array<OCI::Opsi::Models::CreateEmManagedExternalExadataMemberEntityDetails>
12 13 14 |
# File 'lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb', line 12 def member_entity_details @member_entity_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
15 16 17 18 19 20 21 22 |
# File 'lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb', line 15 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_source': :'entitySource', 'member_entity_details': :'memberEntityDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
25 26 27 28 29 30 31 32 |
# File 'lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb', line 25 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_source': :'String', 'member_entity_details': :'Array<OCI::Opsi::Models::CreateEmManagedExternalExadataMemberEntityDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
65 66 67 68 69 70 71 |
# File 'lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb', line 65 def ==(other) return true if equal?(other) self.class == other.class && entity_source == other.entity_source && member_entity_details == other.member_entity_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb', line 96 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
76 77 78 |
# File 'lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb', line 76 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
85 86 87 |
# File 'lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb', line 85 def hash [entity_source, member_entity_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb', line 129 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
123 124 125 |
# File 'lib/oci/opsi/models/add_em_managed_external_exadata_insight_members_details.rb', line 123 def to_s to_hash.to_s end |