Class: OCI::Opsi::Models::AutonomousDatabaseConfigurationSummary

Inherits:
DatabaseConfigurationSummary show all
Defined in:
lib/oci/opsi/models/autonomous_database_configuration_summary.rb

Overview

Configuration Summary of autonomous database.

Constant Summary

Constants inherited from DatabaseConfigurationSummary

DatabaseConfigurationSummary::ENTITY_SOURCE_ENUM

Instance Attribute Summary collapse

Attributes inherited from DatabaseConfigurationSummary

#compartment_id, #database_display_name, #database_insight_id, #database_name, #database_type, #database_version, #defined_tags, #entity_source, #freeform_tags, #processor_count

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DatabaseConfigurationSummary

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ AutonomousDatabaseConfigurationSummary

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :database_insight_id (String)

    The value to assign to the #database_insight_id proprety

  • :compartment_id (String)

    The value to assign to the #compartment_id proprety

  • :database_name (String)

    The value to assign to the #database_name proprety

  • :database_display_name (String)

    The value to assign to the #database_display_name proprety

  • :database_type (String)

    The value to assign to the #database_type proprety

  • :database_version (String)

    The value to assign to the #database_version proprety

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags proprety

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags proprety

  • :processor_count (Integer)

    The value to assign to the #processor_count proprety

  • :database_id (String)

    The value to assign to the #database_id property



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/opsi/models/autonomous_database_configuration_summary.rb', line 69

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['entitySource'] = 'AUTONOMOUS_DATABASE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']
end

Instance Attribute Details

#database_idString

Returns:



13
14
15
# File 'lib/oci/opsi/models/autonomous_database_configuration_summary.rb', line 13

def database_id
  @database_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
# File 'lib/oci/opsi/models/autonomous_database_configuration_summary.rb', line 16

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'database_insight_id': :'databaseInsightId',
    'entity_source': :'entitySource',
    'compartment_id': :'compartmentId',
    'database_name': :'databaseName',
    'database_display_name': :'databaseDisplayName',
    'database_type': :'databaseType',
    'database_version': :'databaseVersion',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags',
    'processor_count': :'processorCount',
    'database_id': :'databaseId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/oci/opsi/models/autonomous_database_configuration_summary.rb', line 35

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'database_insight_id': :'String',
    'entity_source': :'String',
    'compartment_id': :'String',
    'database_name': :'String',
    'database_display_name': :'String',
    'database_type': :'String',
    'database_version': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>',
    'processor_count': :'Integer',
    'database_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/opsi/models/autonomous_database_configuration_summary.rb', line 93

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    database_insight_id == other.database_insight_id &&
    entity_source == other.entity_source &&
    compartment_id == other.compartment_id &&
    database_name == other.database_name &&
    database_display_name == other.database_display_name &&
    database_type == other.database_type &&
    database_version == other.database_version &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags &&
    processor_count == other.processor_count &&
    database_id == other.database_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/opsi/models/autonomous_database_configuration_summary.rb', line 133

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


113
114
115
# File 'lib/oci/opsi/models/autonomous_database_configuration_summary.rb', line 113

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



122
123
124
# File 'lib/oci/opsi/models/autonomous_database_configuration_summary.rb', line 122

def hash
  [database_insight_id, entity_source, compartment_id, database_name, database_display_name, database_type, database_version, defined_tags, freeform_tags, processor_count, database_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/opsi/models/autonomous_database_configuration_summary.rb', line 166

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



160
161
162
# File 'lib/oci/opsi/models/autonomous_database_configuration_summary.rb', line 160

def to_s
  to_hash.to_s
end