Class: OCI::Opsi::Models::AutonomousDatabaseInsight
- Inherits:
-
DatabaseInsight
- Object
- DatabaseInsight
- OCI::Opsi::Models::AutonomousDatabaseInsight
- Defined in:
- lib/oci/opsi/models/autonomous_database_insight.rb
Overview
Database insight resource.
Constant Summary
Constants inherited from DatabaseInsight
DatabaseInsight::ENTITY_SOURCE_ENUM, DatabaseInsight::LIFECYCLE_STATE_ENUM, DatabaseInsight::STATUS_ENUM
Instance Attribute Summary collapse
-
#database_display_name ⇒ String
Display name of database.
-
#database_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
-
#database_name ⇒ String
**[Required]** Name of database.
-
#database_resource_type ⇒ String
**[Required]** OCI database resource type.
-
#db_additional_details ⇒ Object
Additional details of a database in JSON format.
Attributes inherited from DatabaseInsight
#compartment_id, #database_connection_status_details, #database_type, #database_version, #defined_tags, #entity_source, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #processor_count, #status, #system_tags, #time_created, #time_updated
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutonomousDatabaseInsight
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DatabaseInsight
Constructor Details
#initialize(attributes = {}) ⇒ AutonomousDatabaseInsight
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 113 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['entitySource'] = 'AUTONOMOUS_DATABASE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.database_name = attributes[:'databaseName'] if attributes[:'databaseName'] raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name') self.database_name = attributes[:'database_name'] if attributes[:'database_name'] self.database_display_name = attributes[:'databaseDisplayName'] if attributes[:'databaseDisplayName'] raise 'You cannot provide both :databaseDisplayName and :database_display_name' if attributes.key?(:'databaseDisplayName') && attributes.key?(:'database_display_name') self.database_display_name = attributes[:'database_display_name'] if attributes[:'database_display_name'] self.database_resource_type = attributes[:'databaseResourceType'] if attributes[:'databaseResourceType'] raise 'You cannot provide both :databaseResourceType and :database_resource_type' if attributes.key?(:'databaseResourceType') && attributes.key?(:'database_resource_type') self.database_resource_type = attributes[:'database_resource_type'] if attributes[:'database_resource_type'] self.db_additional_details = attributes[:'dbAdditionalDetails'] if attributes[:'dbAdditionalDetails'] raise 'You cannot provide both :dbAdditionalDetails and :db_additional_details' if attributes.key?(:'dbAdditionalDetails') && attributes.key?(:'db_additional_details') self.db_additional_details = attributes[:'db_additional_details'] if attributes[:'db_additional_details'] end |
Instance Attribute Details
#database_display_name ⇒ String
Display name of database
21 22 23 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 21 def database_display_name @database_display_name end |
#database_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
13 14 15 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 13 def database_id @database_id end |
#database_name ⇒ String
**[Required]** Name of database
17 18 19 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 17 def database_name @database_name end |
#database_resource_type ⇒ String
**[Required]** OCI database resource type
25 26 27 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 25 def database_resource_type @database_resource_type end |
#db_additional_details ⇒ Object
Additional details of a database in JSON format. For autonomous databases, this is the AutonomousDatabase object serialized as a JSON string as defined in docs.cloud.oracle.com/en-us/iaas/api/#/en/database/20160918/AutonomousDatabase/. For EM, pass in null or an empty string. Note that this string needs to be escaped when specified in the curl command.
30 31 32 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 30 def db_additional_details @db_additional_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_source': :'entitySource', 'id': :'id', 'compartment_id': :'compartmentId', 'status': :'status', 'database_type': :'databaseType', 'database_version': :'databaseVersion', 'processor_count': :'processorCount', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'database_connection_status_details': :'databaseConnectionStatusDetails', 'database_id': :'databaseId', 'database_name': :'databaseName', 'database_display_name': :'databaseDisplayName', 'database_resource_type': :'databaseResourceType', 'db_additional_details': :'dbAdditionalDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_source': :'String', 'id': :'String', 'compartment_id': :'String', 'status': :'String', 'database_type': :'String', 'database_version': :'String', 'processor_count': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'database_connection_status_details': :'String', 'database_id': :'String', 'database_name': :'String', 'database_display_name': :'String', 'database_resource_type': :'String', 'db_additional_details': :'Object' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 161 def ==(other) return true if equal?(other) self.class == other.class && entity_source == other.entity_source && id == other.id && compartment_id == other.compartment_id && status == other.status && database_type == other.database_type && database_version == other.database_version && processor_count == other.processor_count && == other. && == other. && == other. && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && database_connection_status_details == other.database_connection_status_details && database_id == other.database_id && database_name == other.database_name && database_display_name == other.database_display_name && database_resource_type == other.database_resource_type && db_additional_details == other.db_additional_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 210 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
190 191 192 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 190 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
199 200 201 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 199 def hash [entity_source, id, compartment_id, status, database_type, database_version, processor_count, , , , time_created, time_updated, lifecycle_state, lifecycle_details, database_connection_status_details, database_id, database_name, database_display_name, database_resource_type, db_additional_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 243 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
237 238 239 |
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 237 def to_s to_hash.to_s end |