Class: OCI::Opsi::Models::ChangePeComanagedDatabaseInsightDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb

Overview

Details of a Private Endpoint co-managed database insight.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ChangePeComanagedDatabaseInsightDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 53

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.service_name = attributes[:'serviceName'] if attributes[:'serviceName']

  raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name')

  self.service_name = attributes[:'service_name'] if attributes[:'service_name']

  self.credential_details = attributes[:'credentialDetails'] if attributes[:'credentialDetails']

  raise 'You cannot provide both :credentialDetails and :credential_details' if attributes.key?(:'credentialDetails') && attributes.key?(:'credential_details')

  self.credential_details = attributes[:'credential_details'] if attributes[:'credential_details']

  self.opsi_private_endpoint_id = attributes[:'opsiPrivateEndpointId'] if attributes[:'opsiPrivateEndpointId']

  raise 'You cannot provide both :opsiPrivateEndpointId and :opsi_private_endpoint_id' if attributes.key?(:'opsiPrivateEndpointId') && attributes.key?(:'opsi_private_endpoint_id')

  self.opsi_private_endpoint_id = attributes[:'opsi_private_endpoint_id'] if attributes[:'opsi_private_endpoint_id']
end

Instance Attribute Details

#credential_detailsOCI::Opsi::Models::CredentialDetails

This attribute is required.



16
17
18
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 16

def credential_details
  @credential_details
end

#opsi_private_endpoint_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the OPSI private endpoint

Returns:

  • (String)


20
21
22
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 20

def opsi_private_endpoint_id
  @opsi_private_endpoint_id
end

#service_nameString

**[Required]** Database service name used for connection requests.

Returns:

  • (String)


12
13
14
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 12

def service_name
  @service_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'service_name': :'serviceName',
    'credential_details': :'credentialDetails',
    'opsi_private_endpoint_id': :'opsiPrivateEndpointId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



34
35
36
37
38
39
40
41
42
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 34

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'service_name': :'String',
    'credential_details': :'OCI::Opsi::Models::CredentialDetails',
    'opsi_private_endpoint_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



85
86
87
88
89
90
91
92
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 85

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    service_name == other.service_name &&
    credential_details == other.credential_details &&
    opsi_private_endpoint_id == other.opsi_private_endpoint_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 117

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


97
98
99
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 97

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



106
107
108
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 106

def hash
  [service_name, credential_details, opsi_private_endpoint_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 150

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



144
145
146
# File 'lib/oci/opsi/models/change_pe_comanaged_database_insight_details.rb', line 144

def to_s
  to_hash.to_s
end