Class: OCI::Opsi::Models::ConnectionDetails
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::ConnectionDetails
- Defined in:
- lib/oci/opsi/models/connection_details.rb
Overview
Connection details to connect to the database. HostName, protocol, and port should be specified.
Constant Summary collapse
- PROTOCOL_ENUM =
[ PROTOCOL_TCP = 'TCP'.freeze, PROTOCOL_TCPS = 'TCPS'.freeze, PROTOCOL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#host_name ⇒ String
[Required] Name of the listener host that will be used to create the connect string to the database.
-
#port ⇒ Integer
[Required] Listener port number used for connection requests.
-
#protocol ⇒ String
[Required] Protocol used for connection requests.
-
#service_name ⇒ String
[Required] Service name used for connection requests.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConnectionDetails
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/opsi/models/connection_details.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.host_name = attributes[:'hostName'] if attributes[:'hostName'] raise 'You cannot provide both :hostName and :host_name' if attributes.key?(:'hostName') && attributes.key?(:'host_name') self.host_name = attributes[:'host_name'] if attributes[:'host_name'] self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.port = attributes[:'port'] if attributes[:'port'] self.service_name = attributes[:'serviceName'] if attributes[:'serviceName'] raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] if attributes[:'service_name'] end |
Instance Attribute Details
#host_name ⇒ String
[Required] Name of the listener host that will be used to create the connect string to the database.
19 20 21 |
# File 'lib/oci/opsi/models/connection_details.rb', line 19 def host_name @host_name end |
#port ⇒ Integer
[Required] Listener port number used for connection requests.
27 28 29 |
# File 'lib/oci/opsi/models/connection_details.rb', line 27 def port @port end |
#protocol ⇒ String
[Required] Protocol used for connection requests.
23 24 25 |
# File 'lib/oci/opsi/models/connection_details.rb', line 23 def protocol @protocol end |
#service_name ⇒ String
[Required] Service name used for connection requests.
31 32 33 |
# File 'lib/oci/opsi/models/connection_details.rb', line 31 def service_name @service_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/opsi/models/connection_details.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'host_name': :'hostName', 'protocol': :'protocol', 'port': :'port', 'service_name': :'serviceName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/opsi/models/connection_details.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'host_name': :'String', 'protocol': :'String', 'port': :'Integer', 'service_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/opsi/models/connection_details.rb', line 110 def ==(other) return true if equal?(other) self.class == other.class && host_name == other.host_name && protocol == other.protocol && port == other.port && service_name == other.service_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/opsi/models/connection_details.rb', line 143 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
123 124 125 |
# File 'lib/oci/opsi/models/connection_details.rb', line 123 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
132 133 134 |
# File 'lib/oci/opsi/models/connection_details.rb', line 132 def hash [host_name, protocol, port, service_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/opsi/models/connection_details.rb', line 176 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
170 171 172 |
# File 'lib/oci/opsi/models/connection_details.rb', line 170 def to_s to_hash.to_s end |