Class: OCI::Opsi::Models::CreateEmManagedExternalExadataInsightDetails
- Inherits:
-
CreateExadataInsightDetails
- Object
- CreateExadataInsightDetails
- OCI::Opsi::Models::CreateEmManagedExternalExadataInsightDetails
- Defined in:
- lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb
Overview
The information about the Exadata system to be analyzed. If memberEntityDetails is not specified, the the Enterprise Manager entity (e.g. databases and hosts) associated with an Exadata system will be placed in the same compartment as the Exadata system.
Constant Summary
Constants inherited from CreateExadataInsightDetails
OCI::Opsi::Models::CreateExadataInsightDetails::ENTITY_SOURCE_ENUM
Instance Attribute Summary collapse
-
#enterprise_manager_bridge_id ⇒ String
[Required] OPSI Enterprise Manager Bridge OCID.
-
#enterprise_manager_entity_identifier ⇒ String
[Required] Enterprise Manager Entity Unique Identifier.
-
#enterprise_manager_identifier ⇒ String
[Required] Enterprise Manager Unique Identifier.
-
#is_auto_sync_enabled ⇒ BOOLEAN
Set to true to enable automatic enablement and disablement of related targets from Enterprise Manager.
- #member_entity_details ⇒ Array<OCI::Opsi::Models::CreateEmManagedExternalExadataMemberEntityDetails>
Attributes inherited from CreateExadataInsightDetails
#compartment_id, #defined_tags, #entity_source, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateEmManagedExternalExadataInsightDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateExadataInsightDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateEmManagedExternalExadataInsightDetails
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['entitySource'] = 'EM_MANAGED_EXTERNAL_EXADATA' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.enterprise_manager_identifier = attributes[:'enterpriseManagerIdentifier'] if attributes[:'enterpriseManagerIdentifier'] raise 'You cannot provide both :enterpriseManagerIdentifier and :enterprise_manager_identifier' if attributes.key?(:'enterpriseManagerIdentifier') && attributes.key?(:'enterprise_manager_identifier') self.enterprise_manager_identifier = attributes[:'enterprise_manager_identifier'] if attributes[:'enterprise_manager_identifier'] self.enterprise_manager_bridge_id = attributes[:'enterpriseManagerBridgeId'] if attributes[:'enterpriseManagerBridgeId'] raise 'You cannot provide both :enterpriseManagerBridgeId and :enterprise_manager_bridge_id' if attributes.key?(:'enterpriseManagerBridgeId') && attributes.key?(:'enterprise_manager_bridge_id') self.enterprise_manager_bridge_id = attributes[:'enterprise_manager_bridge_id'] if attributes[:'enterprise_manager_bridge_id'] self.enterprise_manager_entity_identifier = attributes[:'enterpriseManagerEntityIdentifier'] if attributes[:'enterpriseManagerEntityIdentifier'] raise 'You cannot provide both :enterpriseManagerEntityIdentifier and :enterprise_manager_entity_identifier' if attributes.key?(:'enterpriseManagerEntityIdentifier') && attributes.key?(:'enterprise_manager_entity_identifier') self.enterprise_manager_entity_identifier = attributes[:'enterprise_manager_entity_identifier'] if attributes[:'enterprise_manager_entity_identifier'] self.member_entity_details = attributes[:'memberEntityDetails'] if attributes[:'memberEntityDetails'] raise 'You cannot provide both :memberEntityDetails and :member_entity_details' if attributes.key?(:'memberEntityDetails') && attributes.key?(:'member_entity_details') self.member_entity_details = attributes[:'member_entity_details'] if attributes[:'member_entity_details'] self.is_auto_sync_enabled = attributes[:'isAutoSyncEnabled'] unless attributes[:'isAutoSyncEnabled'].nil? raise 'You cannot provide both :isAutoSyncEnabled and :is_auto_sync_enabled' if attributes.key?(:'isAutoSyncEnabled') && attributes.key?(:'is_auto_sync_enabled') self.is_auto_sync_enabled = attributes[:'is_auto_sync_enabled'] unless attributes[:'is_auto_sync_enabled'].nil? end |
Instance Attribute Details
#enterprise_manager_bridge_id ⇒ String
[Required] OPSI Enterprise Manager Bridge OCID
17 18 19 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 17 def enterprise_manager_bridge_id @enterprise_manager_bridge_id end |
#enterprise_manager_entity_identifier ⇒ String
[Required] Enterprise Manager Entity Unique Identifier
21 22 23 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 21 def enterprise_manager_entity_identifier @enterprise_manager_entity_identifier end |
#enterprise_manager_identifier ⇒ String
[Required] Enterprise Manager Unique Identifier
13 14 15 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 13 def enterprise_manager_identifier @enterprise_manager_identifier end |
#is_auto_sync_enabled ⇒ BOOLEAN
Set to true to enable automatic enablement and disablement of related targets from Enterprise Manager. New resources (e.g. Database Insights) will be placed in the same compartment as the related Exadata Insight.
28 29 30 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 28 def is_auto_sync_enabled @is_auto_sync_enabled end |
#member_entity_details ⇒ Array<OCI::Opsi::Models::CreateEmManagedExternalExadataMemberEntityDetails>
24 25 26 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 24 def member_entity_details @member_entity_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_source': :'entitySource', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'enterprise_manager_identifier': :'enterpriseManagerIdentifier', 'enterprise_manager_bridge_id': :'enterpriseManagerBridgeId', 'enterprise_manager_entity_identifier': :'enterpriseManagerEntityIdentifier', 'member_entity_details': :'memberEntityDetails', 'is_auto_sync_enabled': :'isAutoSyncEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_source': :'String', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'enterprise_manager_identifier': :'String', 'enterprise_manager_bridge_id': :'String', 'enterprise_manager_entity_identifier': :'String', 'member_entity_details': :'Array<OCI::Opsi::Models::CreateEmManagedExternalExadataMemberEntityDetails>', 'is_auto_sync_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 126 def ==(other) return true if equal?(other) self.class == other.class && entity_source == other.entity_source && compartment_id == other.compartment_id && == other. && == other. && enterprise_manager_identifier == other.enterprise_manager_identifier && enterprise_manager_bridge_id == other.enterprise_manager_bridge_id && enterprise_manager_entity_identifier == other.enterprise_manager_entity_identifier && member_entity_details == other.member_entity_details && is_auto_sync_enabled == other.is_auto_sync_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 164 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
144 145 146 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 144 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 153 def hash [entity_source, compartment_id, , , enterprise_manager_identifier, enterprise_manager_bridge_id, enterprise_manager_entity_identifier, member_entity_details, is_auto_sync_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 197 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
191 192 193 |
# File 'lib/oci/opsi/models/create_em_managed_external_exadata_insight_details.rb', line 191 def to_s to_hash.to_s end |