Class: OCI::Opsi::Models::CreateOperationsInsightsPrivateEndpointDetails
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::CreateOperationsInsightsPrivateEndpointDetails
- Defined in:
- lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb
Overview
The details used to create a new Operation Insights private endpoint.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The compartment [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Private service accessed database.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the private endpoint.
-
#display_name ⇒ String
**[Required]** The display name for the private endpoint.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_used_for_rac_dbs ⇒ BOOLEAN
**[Required]** The flag to identify if private endpoint is used for rac database or not.
-
#nsg_ids ⇒ Array<String>
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the network security groups that the private endpoint belongs to.
-
#subnet_id ⇒ String
**[Required]** The Subnet [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Private service accessed database.
-
#vcn_id ⇒ String
**[Required]** The VCN [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Private service accessed database.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOperationsInsightsPrivateEndpointDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateOperationsInsightsPrivateEndpointDetails
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 100 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.is_used_for_rac_dbs = attributes[:'isUsedForRacDbs'] unless attributes[:'isUsedForRacDbs'].nil? self.is_used_for_rac_dbs = false if is_used_for_rac_dbs.nil? && !attributes.key?(:'isUsedForRacDbs') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isUsedForRacDbs and :is_used_for_rac_dbs' if attributes.key?(:'isUsedForRacDbs') && attributes.key?(:'is_used_for_rac_dbs') self.is_used_for_rac_dbs = attributes[:'is_used_for_rac_dbs'] unless attributes[:'is_used_for_rac_dbs'].nil? self.is_used_for_rac_dbs = false if is_used_for_rac_dbs.nil? && !attributes.key?(:'isUsedForRacDbs') && !attributes.key?(:'is_used_for_rac_dbs') # rubocop:disable Style/StringLiterals self.description = attributes[:'description'] if attributes[:'description'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The compartment [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Private service accessed database.
16 17 18 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 16 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
49 50 51 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 49 def @defined_tags end |
#description ⇒ String
The description of the private endpoint.
32 33 34 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 32 def description @description end |
#display_name ⇒ String
**[Required]** The display name for the private endpoint. It is changeable.
12 13 14 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
43 44 45 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 43 def @freeform_tags end |
#is_used_for_rac_dbs ⇒ BOOLEAN
**[Required]** The flag to identify if private endpoint is used for rac database or not
28 29 30 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 28 def is_used_for_rac_dbs @is_used_for_rac_dbs end |
#nsg_ids ⇒ Array<String>
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the network security groups that the private endpoint belongs to.
37 38 39 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 37 def nsg_ids @nsg_ids end |
#subnet_id ⇒ String
**[Required]** The Subnet [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Private service accessed database.
24 25 26 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 24 def subnet_id @subnet_id end |
#vcn_id ⇒ String
**[Required]** The VCN [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Private service accessed database.
20 21 22 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 20 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'vcn_id': :'vcnId', 'subnet_id': :'subnetId', 'is_used_for_rac_dbs': :'isUsedForRacDbs', 'description': :'description', 'nsg_ids': :'nsgIds', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'vcn_id': :'String', 'subnet_id': :'String', 'is_used_for_rac_dbs': :'BOOLEAN', 'description': :'String', 'nsg_ids': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 166 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && vcn_id == other.vcn_id && subnet_id == other.subnet_id && is_used_for_rac_dbs == other.is_used_for_rac_dbs && description == other.description && nsg_ids == other.nsg_ids && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 204 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
184 185 186 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 184 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 193 def hash [display_name, compartment_id, vcn_id, subnet_id, is_used_for_rac_dbs, description, nsg_ids, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
237 238 239 240 241 242 243 244 245 246 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 237 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
231 232 233 |
# File 'lib/oci/opsi/models/create_operations_insights_private_endpoint_details.rb', line 231 def to_s to_hash.to_s end |