Class: OCI::Opsi::Models::CreateOperationsInsightsWarehouseUserDetails
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::CreateOperationsInsightsWarehouseUserDetails
- Defined in:
- lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb
Overview
The information about a Operations Insights Warehouse User to be created. Input compartmentId MUST be the root compartment.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
-
#connection_password ⇒ String
[Required] User provided connection password for the AWR Data, Enterprise Manager Data and Operations Insights OPSI Hub.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_awr_data_access ⇒ BOOLEAN
[Required] Indicate whether user has access to AWR data.
-
#is_em_data_access ⇒ BOOLEAN
Indicate whether user has access to EM data.
-
#is_opsi_data_access ⇒ BOOLEAN
Indicate whether user has access to OPSI data.
-
#name ⇒ String
[Required] Username for schema which would have access to AWR Data, Enterprise Manager Data and Operations Insights OPSI Hub.
-
#operations_insights_warehouse_id ⇒ String
[Required] OPSI Warehouse OCID.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOperationsInsightsWarehouseUserDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateOperationsInsightsWarehouseUserDetails
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 99 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operations_insights_warehouse_id = attributes[:'operationsInsightsWarehouseId'] if attributes[:'operationsInsightsWarehouseId'] raise 'You cannot provide both :operationsInsightsWarehouseId and :operations_insights_warehouse_id' if attributes.key?(:'operationsInsightsWarehouseId') && attributes.key?(:'operations_insights_warehouse_id') self.operations_insights_warehouse_id = attributes[:'operations_insights_warehouse_id'] if attributes[:'operations_insights_warehouse_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.connection_password = attributes[:'connectionPassword'] if attributes[:'connectionPassword'] raise 'You cannot provide both :connectionPassword and :connection_password' if attributes.key?(:'connectionPassword') && attributes.key?(:'connection_password') self.connection_password = attributes[:'connection_password'] if attributes[:'connection_password'] self.is_awr_data_access = attributes[:'isAwrDataAccess'] unless attributes[:'isAwrDataAccess'].nil? raise 'You cannot provide both :isAwrDataAccess and :is_awr_data_access' if attributes.key?(:'isAwrDataAccess') && attributes.key?(:'is_awr_data_access') self.is_awr_data_access = attributes[:'is_awr_data_access'] unless attributes[:'is_awr_data_access'].nil? self.is_em_data_access = attributes[:'isEmDataAccess'] unless attributes[:'isEmDataAccess'].nil? raise 'You cannot provide both :isEmDataAccess and :is_em_data_access' if attributes.key?(:'isEmDataAccess') && attributes.key?(:'is_em_data_access') self.is_em_data_access = attributes[:'is_em_data_access'] unless attributes[:'is_em_data_access'].nil? self.is_opsi_data_access = attributes[:'isOpsiDataAccess'] unless attributes[:'isOpsiDataAccess'].nil? raise 'You cannot provide both :isOpsiDataAccess and :is_opsi_data_access' if attributes.key?(:'isOpsiDataAccess') && attributes.key?(:'is_opsi_data_access') self.is_opsi_data_access = attributes[:'is_opsi_data_access'] unless attributes[:'is_opsi_data_access'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
16 17 18 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 16 def compartment_id @compartment_id end |
#connection_password ⇒ String
[Required] User provided connection password for the AWR Data, Enterprise Manager Data and Operations Insights OPSI Hub.
24 25 26 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 24 def connection_password @connection_password end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
48 49 50 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 48 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
42 43 44 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 42 def end |
#is_awr_data_access ⇒ BOOLEAN
[Required] Indicate whether user has access to AWR data.
28 29 30 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 28 def is_awr_data_access @is_awr_data_access end |
#is_em_data_access ⇒ BOOLEAN
Indicate whether user has access to EM data.
32 33 34 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 32 def is_em_data_access @is_em_data_access end |
#is_opsi_data_access ⇒ BOOLEAN
Indicate whether user has access to OPSI data.
36 37 38 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 36 def is_opsi_data_access @is_opsi_data_access end |
#name ⇒ String
[Required] Username for schema which would have access to AWR Data, Enterprise Manager Data and Operations Insights OPSI Hub.
20 21 22 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 20 def name @name end |
#operations_insights_warehouse_id ⇒ String
[Required] OPSI Warehouse OCID
12 13 14 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 12 def operations_insights_warehouse_id @operations_insights_warehouse_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operations_insights_warehouse_id': :'operationsInsightsWarehouseId', 'compartment_id': :'compartmentId', 'name': :'name', 'connection_password': :'connectionPassword', 'is_awr_data_access': :'isAwrDataAccess', 'is_em_data_access': :'isEmDataAccess', 'is_opsi_data_access': :'isOpsiDataAccess', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operations_insights_warehouse_id': :'String', 'compartment_id': :'String', 'name': :'String', 'connection_password': :'String', 'is_awr_data_access': :'BOOLEAN', 'is_em_data_access': :'BOOLEAN', 'is_opsi_data_access': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 163 def ==(other) return true if equal?(other) self.class == other.class && operations_insights_warehouse_id == other.operations_insights_warehouse_id && compartment_id == other.compartment_id && name == other.name && connection_password == other.connection_password && is_awr_data_access == other.is_awr_data_access && is_em_data_access == other.is_em_data_access && is_opsi_data_access == other.is_opsi_data_access && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 201 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
181 182 183 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 181 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
190 191 192 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 190 def hash [operations_insights_warehouse_id, compartment_id, name, connection_password, is_awr_data_access, is_em_data_access, is_opsi_data_access, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
228 229 230 |
# File 'lib/oci/opsi/models/create_operations_insights_warehouse_user_details.rb', line 228 def to_s to_hash.to_s end |