Class: OCI::Opsi::Models::CreatePeComanagedDatabaseInsightDetails
- Inherits:
-
CreateDatabaseInsightDetails
- Object
- CreateDatabaseInsightDetails
- OCI::Opsi::Models::CreatePeComanagedDatabaseInsightDetails
- Defined in:
- lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb
Overview
The information about database to be analyzed. Either an opsiPrivateEndpointId or dbmPrivateEndpointId must be specified. If the dbmPrivateEndpointId is specified, a new Operations Insights private endpoint will be created.
Constant Summary collapse
- DEPLOYMENT_TYPE_ENUM =
[ DEPLOYMENT_TYPE_VIRTUAL_MACHINE = 'VIRTUAL_MACHINE'.freeze, DEPLOYMENT_TYPE_BARE_METAL = 'BARE_METAL'.freeze, DEPLOYMENT_TYPE_EXACS = 'EXACS'.freeze ].freeze
Constants inherited from CreateDatabaseInsightDetails
OCI::Opsi::Models::CreateDatabaseInsightDetails::ENTITY_SOURCE_ENUM
Instance Attribute Summary collapse
-
#credential_details ⇒ OCI::Opsi::Models::CredentialDetails
This attribute is required.
-
#database_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
-
#database_resource_type ⇒ String
**[Required]** OCI database resource type.
-
#dbm_private_endpoint_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Database Management private endpoint.
-
#deployment_type ⇒ String
**[Required]** Database Deployment Type.
-
#opsi_private_endpoint_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the OPSI private endpoint.
-
#service_name ⇒ String
**[Required]** Database service name used for connection requests.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
Attributes inherited from CreateDatabaseInsightDetails
#compartment_id, #defined_tags, #entity_source, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePeComanagedDatabaseInsightDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateDatabaseInsightDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreatePeComanagedDatabaseInsightDetails
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['entitySource'] = 'PE_COMANAGED_DATABASE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.database_resource_type = attributes[:'databaseResourceType'] if attributes[:'databaseResourceType'] raise 'You cannot provide both :databaseResourceType and :database_resource_type' if attributes.key?(:'databaseResourceType') && attributes.key?(:'database_resource_type') self.database_resource_type = attributes[:'database_resource_type'] if attributes[:'database_resource_type'] self.opsi_private_endpoint_id = attributes[:'opsiPrivateEndpointId'] if attributes[:'opsiPrivateEndpointId'] raise 'You cannot provide both :opsiPrivateEndpointId and :opsi_private_endpoint_id' if attributes.key?(:'opsiPrivateEndpointId') && attributes.key?(:'opsi_private_endpoint_id') self.opsi_private_endpoint_id = attributes[:'opsi_private_endpoint_id'] if attributes[:'opsi_private_endpoint_id'] self.dbm_private_endpoint_id = attributes[:'dbmPrivateEndpointId'] if attributes[:'dbmPrivateEndpointId'] raise 'You cannot provide both :dbmPrivateEndpointId and :dbm_private_endpoint_id' if attributes.key?(:'dbmPrivateEndpointId') && attributes.key?(:'dbm_private_endpoint_id') self.dbm_private_endpoint_id = attributes[:'dbm_private_endpoint_id'] if attributes[:'dbm_private_endpoint_id'] self.service_name = attributes[:'serviceName'] if attributes[:'serviceName'] raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] if attributes[:'service_name'] self.credential_details = attributes[:'credentialDetails'] if attributes[:'credentialDetails'] raise 'You cannot provide both :credentialDetails and :credential_details' if attributes.key?(:'credentialDetails') && attributes.key?(:'credential_details') self.credential_details = attributes[:'credential_details'] if attributes[:'credential_details'] self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType'] raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type') self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#credential_details ⇒ OCI::Opsi::Models::CredentialDetails
This attribute is required.
39 40 41 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 39 def credential_details @credential_details end |
#database_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
19 20 21 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 19 def database_id @database_id end |
#database_resource_type ⇒ String
**[Required]** OCI database resource type
23 24 25 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 23 def database_resource_type @database_resource_type end |
#dbm_private_endpoint_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Database Management private endpoint
31 32 33 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 31 def dbm_private_endpoint_id @dbm_private_endpoint_id end |
#deployment_type ⇒ String
**[Required]** Database Deployment Type
43 44 45 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 43 def deployment_type @deployment_type end |
#opsi_private_endpoint_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the OPSI private endpoint
27 28 29 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 27 def opsi_private_endpoint_id @opsi_private_endpoint_id end |
#service_name ⇒ String
**[Required]** Database service name used for connection requests.
35 36 37 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 35 def service_name @service_name end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"free-tier-retained": "true"}`
49 50 51 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 49 def @system_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_source': :'entitySource', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'database_id': :'databaseId', 'database_resource_type': :'databaseResourceType', 'opsi_private_endpoint_id': :'opsiPrivateEndpointId', 'dbm_private_endpoint_id': :'dbmPrivateEndpointId', 'service_name': :'serviceName', 'credential_details': :'credentialDetails', 'deployment_type': :'deploymentType', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 72 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_source': :'String', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'database_id': :'String', 'database_resource_type': :'String', 'opsi_private_endpoint_id': :'String', 'dbm_private_endpoint_id': :'String', 'service_name': :'String', 'credential_details': :'OCI::Opsi::Models::CredentialDetails', 'deployment_type': :'String', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 182 def ==(other) return true if equal?(other) self.class == other.class && entity_source == other.entity_source && compartment_id == other.compartment_id && == other. && == other. && database_id == other.database_id && database_resource_type == other.database_resource_type && opsi_private_endpoint_id == other.opsi_private_endpoint_id && dbm_private_endpoint_id == other.dbm_private_endpoint_id && service_name == other.service_name && credential_details == other.credential_details && deployment_type == other.deployment_type && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 223 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
203 204 205 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 203 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 212 def hash [entity_source, compartment_id, , , database_id, database_resource_type, opsi_private_endpoint_id, dbm_private_endpoint_id, service_name, credential_details, deployment_type, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 256 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
250 251 252 |
# File 'lib/oci/opsi/models/create_pe_comanaged_database_insight_details.rb', line 250 def to_s to_hash.to_s end |