Class: OCI::Opsi::Models::CredentialByVault
- Inherits:
-
CredentialDetails
- Object
- CredentialDetails
- OCI::Opsi::Models::CredentialByVault
- Defined in:
- lib/oci/opsi/models/credential_by_vault.rb
Overview
Vault Credential Details to connect to the database.
Constant Summary collapse
- ROLE_ENUM =
[ ROLE_NORMAL = 'NORMAL'.freeze, ROLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from CredentialDetails
OCI::Opsi::Models::CredentialDetails::CREDENTIAL_TYPE_ENUM
Instance Attribute Summary collapse
-
#password_secret_id ⇒ String
The secret [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) mapping to the database credentials.
-
#role ⇒ String
database user role.
-
#user_name ⇒ String
database user name.
Attributes inherited from CredentialDetails
#credential_source_name, #credential_type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CredentialByVault
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CredentialDetails
Constructor Details
#initialize(attributes = {}) ⇒ CredentialByVault
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 65 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['credentialType'] = 'CREDENTIALS_BY_VAULT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.user_name = attributes[:'userName'] if attributes[:'userName'] raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] if attributes[:'user_name'] self.password_secret_id = attributes[:'passwordSecretId'] if attributes[:'passwordSecretId'] raise 'You cannot provide both :passwordSecretId and :password_secret_id' if attributes.key?(:'passwordSecretId') && attributes.key?(:'password_secret_id') self.password_secret_id = attributes[:'password_secret_id'] if attributes[:'password_secret_id'] self.role = attributes[:'role'] if attributes[:'role'] end |
Instance Attribute Details
#password_secret_id ⇒ String
The secret [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) mapping to the database credentials.
23 24 25 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 23 def password_secret_id @password_secret_id end |
#role ⇒ String
database user role.
27 28 29 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 27 def role @role end |
#user_name ⇒ String
database user name.
19 20 21 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 19 def user_name @user_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'credential_source_name': :'credentialSourceName', 'credential_type': :'credentialType', 'user_name': :'userName', 'password_secret_id': :'passwordSecretId', 'role': :'role' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'credential_source_name': :'String', 'credential_type': :'String', 'user_name': :'String', 'password_secret_id': :'String', 'role': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 110 def ==(other) return true if equal?(other) self.class == other.class && credential_source_name == other.credential_source_name && credential_type == other.credential_type && user_name == other.user_name && password_secret_id == other.password_secret_id && role == other.role end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 144 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
124 125 126 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 124 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
133 134 135 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 133 def hash [credential_source_name, credential_type, user_name, password_secret_id, role].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
171 172 173 |
# File 'lib/oci/opsi/models/credential_by_vault.rb', line 171 def to_s to_hash.to_s end |