Class: OCI::Opsi::Models::CredentialDetails
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::CredentialDetails
- Defined in:
- lib/oci/opsi/models/credential_details.rb
Overview
User credential details to connect to the database. This is supplied via the External Database Service.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- CREDENTIAL_TYPE_ENUM =
[ CREDENTIAL_TYPE_CREDENTIALS_BY_SOURCE = 'CREDENTIALS_BY_SOURCE'.freeze, CREDENTIAL_TYPE_CREDENTIALS_BY_VAULT = 'CREDENTIALS_BY_VAULT'.freeze, CREDENTIAL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#credential_source_name ⇒ String
**[Required]** Credential source name that had been added in Management Agent wallet.
-
#credential_type ⇒ String
**[Required]** Credential type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CredentialDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CredentialDetails
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/opsi/models/credential_details.rb', line 71 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.credential_source_name = attributes[:'credentialSourceName'] if attributes[:'credentialSourceName'] raise 'You cannot provide both :credentialSourceName and :credential_source_name' if attributes.key?(:'credentialSourceName') && attributes.key?(:'credential_source_name') self.credential_source_name = attributes[:'credential_source_name'] if attributes[:'credential_source_name'] self.credential_type = attributes[:'credentialType'] if attributes[:'credentialType'] raise 'You cannot provide both :credentialType and :credential_type' if attributes.key?(:'credentialType') && attributes.key?(:'credential_type') self.credential_type = attributes[:'credential_type'] if attributes[:'credential_type'] end |
Instance Attribute Details
#credential_source_name ⇒ String
**[Required]** Credential source name that had been added in Management Agent wallet. This is supplied in the External Database Service.
21 22 23 |
# File 'lib/oci/opsi/models/credential_details.rb', line 21 def credential_source_name @credential_source_name end |
#credential_type ⇒ String
**[Required]** Credential type.
25 26 27 |
# File 'lib/oci/opsi/models/credential_details.rb', line 25 def credential_type @credential_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 |
# File 'lib/oci/opsi/models/credential_details.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'credential_source_name': :'credentialSourceName', 'credential_type': :'credentialType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/opsi/models/credential_details.rb', line 52 def self.get_subtype(object_hash) type = object_hash[:'credentialType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Opsi::Models::CredentialsBySource' if type == 'CREDENTIALS_BY_SOURCE' return 'OCI::Opsi::Models::CredentialByVault' if type == 'CREDENTIALS_BY_VAULT' # TODO: Log a warning when the subtype is not found. 'OCI::Opsi::Models::CredentialDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 |
# File 'lib/oci/opsi/models/credential_details.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'credential_source_name': :'String', 'credential_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
110 111 112 113 114 115 116 |
# File 'lib/oci/opsi/models/credential_details.rb', line 110 def ==(other) return true if equal?(other) self.class == other.class && credential_source_name == other.credential_source_name && credential_type == other.credential_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/opsi/models/credential_details.rb', line 141 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
121 122 123 |
# File 'lib/oci/opsi/models/credential_details.rb', line 121 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/oci/opsi/models/credential_details.rb', line 130 def hash [credential_source_name, credential_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/opsi/models/credential_details.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/oci/opsi/models/credential_details.rb', line 168 def to_s to_hash.to_s end |