Class: OCI::Opsi::Models::DataObjectQueryTimeFilters
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::DataObjectQueryTimeFilters
- Defined in:
- lib/oci/opsi/models/data_object_query_time_filters.rb
Overview
Time filters to be applied in the data object query.
Instance Attribute Summary collapse
-
#time_end ⇒ DateTime
End time in UTC in RFC3339 formatted datetime string.
-
#time_period ⇒ String
Specify time period in ISO 8601 format with respect to current time.
-
#time_start ⇒ DateTime
Start time in UTC in RFC3339 formatted datetime string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataObjectQueryTimeFilters
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataObjectQueryTimeFilters
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_period = attributes[:'timePeriod'] if attributes[:'timePeriod'] raise 'You cannot provide both :timePeriod and :time_period' if attributes.key?(:'timePeriod') && attributes.key?(:'time_period') self.time_period = attributes[:'time_period'] if attributes[:'time_period'] self.time_start = attributes[:'timeStart'] if attributes[:'timeStart'] raise 'You cannot provide both :timeStart and :time_start' if attributes.key?(:'timeStart') && attributes.key?(:'time_start') self.time_start = attributes[:'time_start'] if attributes[:'time_start'] self.time_end = attributes[:'timeEnd'] if attributes[:'timeEnd'] raise 'You cannot provide both :timeEnd and :time_end' if attributes.key?(:'timeEnd') && attributes.key?(:'time_end') self.time_end = attributes[:'time_end'] if attributes[:'time_end'] end |
Instance Attribute Details
#time_end ⇒ DateTime
End time in UTC in RFC3339 formatted datetime string. Example: 2021-10-30T00:00:00.000Z. timeStart and timeEnd are used together. If timePeriod is specified, this parameter is ignored. If timeEnd is not specified, current time is used as timeEnd.
29 30 31 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 29 def time_end @time_end end |
#time_period ⇒ String
Specify time period in ISO 8601 format with respect to current time. Default is last 30 days represented by P30D. If timePeriod is specified, then timeStart and timeEnd will be ignored. Examples: P90D (last 90 days), P4W (last 4 weeks), P2M (last 2 months), P1Y (last 12 months).
16 17 18 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 16 def time_period @time_period end |
#time_start ⇒ DateTime
Start time in UTC in RFC3339 formatted datetime string. Example: 2021-10-30T00:00:00.000Z. timeStart and timeEnd are used together. If timePeriod is specified, this parameter is ignored.
22 23 24 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 22 def time_start @time_start end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_period': :'timePeriod', 'time_start': :'timeStart', 'time_end': :'timeEnd' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_period': :'String', 'time_start': :'DateTime', 'time_end': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
94 95 96 97 98 99 100 101 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 94 def ==(other) return true if equal?(other) self.class == other.class && time_period == other.time_period && time_start == other.time_start && time_end == other.time_end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 126 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
106 107 108 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 106 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
115 116 117 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 115 def hash [time_period, time_start, time_end].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 159 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
153 154 155 |
# File 'lib/oci/opsi/models/data_object_query_time_filters.rb', line 153 def to_s to_hash.to_s end |