Class: OCI::Opsi::Models::DatabaseDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/database_details.rb

Overview

Partial information about the database which includes id, name, type.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DatabaseDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/opsi/models/database_details.rb', line 96

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.database_name = attributes[:'databaseName'] if attributes[:'databaseName']

  raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name')

  self.database_name = attributes[:'database_name'] if attributes[:'database_name']

  self.database_display_name = attributes[:'databaseDisplayName'] if attributes[:'databaseDisplayName']

  raise 'You cannot provide both :databaseDisplayName and :database_display_name' if attributes.key?(:'databaseDisplayName') && attributes.key?(:'database_display_name')

  self.database_display_name = attributes[:'database_display_name'] if attributes[:'database_display_name']

  self.database_type = attributes[:'databaseType'] if attributes[:'databaseType']

  raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type')

  self.database_type = attributes[:'database_type'] if attributes[:'database_type']

  self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion']

  raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version')

  self.database_version = attributes[:'database_version'] if attributes[:'database_version']

  self.instances = attributes[:'instances'] if attributes[:'instances']

  self.cdb_name = attributes[:'cdbName'] if attributes[:'cdbName']

  raise 'You cannot provide both :cdbName and :cdb_name' if attributes.key?(:'cdbName') && attributes.key?(:'cdb_name')

  self.cdb_name = attributes[:'cdb_name'] if attributes[:'cdb_name']
end

Instance Attribute Details

#cdb_nameString

Name of the CDB.Only applies to PDB.

Returns:

  • (String)


45
46
47
# File 'lib/oci/opsi/models/database_details.rb', line 45

def cdb_name
  @cdb_name
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


21
22
23
# File 'lib/oci/opsi/models/database_details.rb', line 21

def compartment_id
  @compartment_id
end

#database_display_nameString

The user-friendly name for the database. The name does not have to be unique.

Returns:

  • (String)


29
30
31
# File 'lib/oci/opsi/models/database_details.rb', line 29

def database_display_name
  @database_display_name
end

#database_idString

Returns:

  • (String)


17
18
19
# File 'lib/oci/opsi/models/database_details.rb', line 17

def database_id
  @database_id
end

#database_nameString

[Required] The database name. The database name is unique within the tenancy.

Returns:

  • (String)


25
26
27
# File 'lib/oci/opsi/models/database_details.rb', line 25

def database_name
  @database_name
end

#database_typeString

[Required] Operations Insights internal representation of the database type.

Returns:

  • (String)


33
34
35
# File 'lib/oci/opsi/models/database_details.rb', line 33

def database_type
  @database_type
end

#database_versionString

The version of the database.

Returns:

  • (String)


37
38
39
# File 'lib/oci/opsi/models/database_details.rb', line 37

def database_version
  @database_version
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.

Returns:

  • (String)


13
14
15
# File 'lib/oci/opsi/models/database_details.rb', line 13

def id
  @id
end

#instancesArray<OCI::Opsi::Models::HostInstanceMap>

Array of hostname and instance name.



41
42
43
# File 'lib/oci/opsi/models/database_details.rb', line 41

def instances
  @instances
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/opsi/models/database_details.rb', line 48

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'database_id': :'databaseId',
    'compartment_id': :'compartmentId',
    'database_name': :'databaseName',
    'database_display_name': :'databaseDisplayName',
    'database_type': :'databaseType',
    'database_version': :'databaseVersion',
    'instances': :'instances',
    'cdb_name': :'cdbName'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/opsi/models/database_details.rb', line 65

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'database_id': :'String',
    'compartment_id': :'String',
    'database_name': :'String',
    'database_display_name': :'String',
    'database_type': :'String',
    'database_version': :'String',
    'instances': :'Array<OCI::Opsi::Models::HostInstanceMap>',
    'cdb_name': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/oci/opsi/models/database_details.rb', line 156

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    database_id == other.database_id &&
    compartment_id == other.compartment_id &&
    database_name == other.database_name &&
    database_display_name == other.database_display_name &&
    database_type == other.database_type &&
    database_version == other.database_version &&
    instances == other.instances &&
    cdb_name == other.cdb_name
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/opsi/models/database_details.rb', line 194

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/oci/opsi/models/database_details.rb', line 174

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



183
184
185
# File 'lib/oci/opsi/models/database_details.rb', line 183

def hash
  [id, database_id, compartment_id, database_name, database_display_name, database_type, database_version, instances, cdb_name].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



227
228
229
230
231
232
233
234
235
236
# File 'lib/oci/opsi/models/database_details.rb', line 227

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



221
222
223
# File 'lib/oci/opsi/models/database_details.rb', line 221

def to_s
  to_hash.to_s
end