Class: OCI::Opsi::Models::DatabaseInsightSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/database_insight_summary.rb

Overview

Summary of a database insight resource. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

ENTITY_SOURCE_ENUM =
[
  ENTITY_SOURCE_AUTONOMOUS_DATABASE = 'AUTONOMOUS_DATABASE'.freeze,
  ENTITY_SOURCE_EM_MANAGED_EXTERNAL_DATABASE = 'EM_MANAGED_EXTERNAL_DATABASE'.freeze,
  ENTITY_SOURCE_MACS_MANAGED_EXTERNAL_DATABASE = 'MACS_MANAGED_EXTERNAL_DATABASE'.freeze,
  ENTITY_SOURCE_PE_COMANAGED_DATABASE = 'PE_COMANAGED_DATABASE'.freeze,
  ENTITY_SOURCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_DISABLED = 'DISABLED'.freeze,
  STATUS_ENABLED = 'ENABLED'.freeze,
  STATUS_TERMINATED = 'TERMINATED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DatabaseInsightSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :database_id (String)

    The value to assign to the #database_id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :database_name (String)

    The value to assign to the #database_name property

  • :database_display_name (String)

    The value to assign to the #database_display_name property

  • :database_type (String)

    The value to assign to the #database_type property

  • :database_version (String)

    The value to assign to the #database_version property

  • :database_host_names (Array<String>)

    The value to assign to the #database_host_names property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property

  • :entity_source (String)

    The value to assign to the #entity_source property

  • :processor_count (Integer)

    The value to assign to the #processor_count property

  • :status (String)

    The value to assign to the #status property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :database_connection_status_details (String)

    The value to assign to the #database_connection_status_details property



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 217

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.database_name = attributes[:'databaseName'] if attributes[:'databaseName']

  raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name')

  self.database_name = attributes[:'database_name'] if attributes[:'database_name']

  self.database_display_name = attributes[:'databaseDisplayName'] if attributes[:'databaseDisplayName']

  raise 'You cannot provide both :databaseDisplayName and :database_display_name' if attributes.key?(:'databaseDisplayName') && attributes.key?(:'database_display_name')

  self.database_display_name = attributes[:'database_display_name'] if attributes[:'database_display_name']

  self.database_type = attributes[:'databaseType'] if attributes[:'databaseType']

  raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type')

  self.database_type = attributes[:'database_type'] if attributes[:'database_type']

  self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion']

  raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version')

  self.database_version = attributes[:'database_version'] if attributes[:'database_version']

  self.database_host_names = attributes[:'databaseHostNames'] if attributes[:'databaseHostNames']

  raise 'You cannot provide both :databaseHostNames and :database_host_names' if attributes.key?(:'databaseHostNames') && attributes.key?(:'database_host_names')

  self.database_host_names = attributes[:'database_host_names'] if attributes[:'database_host_names']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

  self.entity_source = attributes[:'entitySource'] if attributes[:'entitySource']

  raise 'You cannot provide both :entitySource and :entity_source' if attributes.key?(:'entitySource') && attributes.key?(:'entity_source')

  self.entity_source = attributes[:'entity_source'] if attributes[:'entity_source']

  self.processor_count = attributes[:'processorCount'] if attributes[:'processorCount']

  raise 'You cannot provide both :processorCount and :processor_count' if attributes.key?(:'processorCount') && attributes.key?(:'processor_count')

  self.processor_count = attributes[:'processor_count'] if attributes[:'processor_count']

  self.status = attributes[:'status'] if attributes[:'status']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.database_connection_status_details = attributes[:'databaseConnectionStatusDetails'] if attributes[:'databaseConnectionStatusDetails']

  raise 'You cannot provide both :databaseConnectionStatusDetails and :database_connection_status_details' if attributes.key?(:'databaseConnectionStatusDetails') && attributes.key?(:'database_connection_status_details')

  self.database_connection_status_details = attributes[:'database_connection_status_details'] if attributes[:'database_connection_status_details']
end

Instance Attribute Details

#compartment_idString

Returns:

  • (String)


48
49
50
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 48

def compartment_id
  @compartment_id
end

#database_connection_status_detailsString

A message describing the status of the database connection of this resource. For example, it can be used to provide actionable information about the permission and content validity of the database connection.

Returns:

  • (String)


118
119
120
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 118

def database_connection_status_details
  @database_connection_status_details
end

#database_display_nameString

The user-friendly name for the database. The name does not have to be unique.

Returns:

  • (String)


56
57
58
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 56

def database_display_name
  @database_display_name
end

#database_host_namesArray<String>

The hostnames for the database.

Returns:

  • (Array<String>)


68
69
70
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 68

def database_host_names
  @database_host_names
end

#database_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.

Returns:

  • (String)


44
45
46
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 44

def database_id
  @database_id
end

#database_nameString

The database name. The database name is unique within the tenancy.

Returns:

  • (String)


52
53
54
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 52

def database_name
  @database_name
end

#database_typeString

Operations Insights internal representation of the database type.

Returns:

  • (String)


60
61
62
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 60

def database_type
  @database_type
end

#database_versionString

The version of the database.

Returns:

  • (String)


64
65
66
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 64

def database_version
  @database_version
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


80
81
82
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 80

def defined_tags
  @defined_tags
end

#entity_sourceString

**[Required]** Source of the database entity.

Returns:

  • (String)


90
91
92
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 90

def entity_source
  @entity_source
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


74
75
76
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 74

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.

Returns:

  • (String)


40
41
42
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 40

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


114
115
116
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 114

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

The current state of the database.

Returns:

  • (String)


110
111
112
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 110

def lifecycle_state
  @lifecycle_state
end

#processor_countInteger

Processor count. This is the OCPU count for Autonomous Database and CPU core count for other database types.

Returns:

  • (Integer)


94
95
96
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 94

def processor_count
  @processor_count
end

#statusString

Indicates the status of a database insight in Operations Insights

Returns:

  • (String)


98
99
100
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 98

def status
  @status
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


86
87
88
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 86

def system_tags
  @system_tags
end

#time_createdDateTime

The time the the database insight was first enabled. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


102
103
104
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 102

def time_created
  @time_created
end

#time_updatedDateTime

The time the database insight was updated. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


106
107
108
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 106

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 121

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'database_id': :'databaseId',
    'compartment_id': :'compartmentId',
    'database_name': :'databaseName',
    'database_display_name': :'databaseDisplayName',
    'database_type': :'databaseType',
    'database_version': :'databaseVersion',
    'database_host_names': :'databaseHostNames',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'entity_source': :'entitySource',
    'processor_count': :'processorCount',
    'status': :'status',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'database_connection_status_details': :'databaseConnectionStatusDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



179
180
181
182
183
184
185
186
187
188
189
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 179

def self.get_subtype(object_hash)
  type = object_hash[:'entitySource'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Opsi::Models::MacsManagedExternalDatabaseInsightSummary' if type == 'MACS_MANAGED_EXTERNAL_DATABASE'
  return 'OCI::Opsi::Models::AutonomousDatabaseInsightSummary' if type == 'AUTONOMOUS_DATABASE'
  return 'OCI::Opsi::Models::PeComanagedDatabaseInsightSummary' if type == 'PE_COMANAGED_DATABASE'
  return 'OCI::Opsi::Models::EmManagedExternalDatabaseInsightSummary' if type == 'EM_MANAGED_EXTERNAL_DATABASE'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Opsi::Models::DatabaseInsightSummary'
end

.swagger_typesObject

Attribute type mapping.



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 148

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'database_id': :'String',
    'compartment_id': :'String',
    'database_name': :'String',
    'database_display_name': :'String',
    'database_type': :'String',
    'database_version': :'String',
    'database_host_names': :'Array<String>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'entity_source': :'String',
    'processor_count': :'Integer',
    'status': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'database_connection_status_details': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 376

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    database_id == other.database_id &&
    compartment_id == other.compartment_id &&
    database_name == other.database_name &&
    database_display_name == other.database_display_name &&
    database_type == other.database_type &&
    database_version == other.database_version &&
    database_host_names == other.database_host_names &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    entity_source == other.entity_source &&
    processor_count == other.processor_count &&
    status == other.status &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    database_connection_status_details == other.database_connection_status_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 424

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


404
405
406
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 404

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



413
414
415
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 413

def hash
  [id, database_id, compartment_id, database_name, database_display_name, database_type, database_version, database_host_names, freeform_tags, defined_tags, system_tags, entity_source, processor_count, status, time_created, time_updated, lifecycle_state, lifecycle_details, database_connection_status_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



457
458
459
460
461
462
463
464
465
466
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 457

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



451
452
453
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 451

def to_s
  to_hash.to_s
end