Class: OCI::Opsi::Models::EmManagedExternalDatabaseConfigurationSummary
- Inherits:
-
DatabaseConfigurationSummary
- Object
- DatabaseConfigurationSummary
- OCI::Opsi::Models::EmManagedExternalDatabaseConfigurationSummary
- Defined in:
- lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb
Overview
Configuration summary of a EM Managed External database.
Constant Summary
Constants inherited from DatabaseConfigurationSummary
DatabaseConfigurationSummary::ENTITY_SOURCE_ENUM
Instance Attribute Summary collapse
-
#enterprise_manager_bridge_id ⇒ String
[Required] OPSI Enterprise Manager Bridge OCID.
-
#enterprise_manager_identifier ⇒ String
[Required] Enterprise Manager Unique Identifier.
-
#instances ⇒ Array<OCI::Opsi::Models::HostInstanceMap>
[Required] Array of hostname and instance name.
Attributes inherited from DatabaseConfigurationSummary
#compartment_id, #database_display_name, #database_insight_id, #database_name, #database_type, #database_version, #defined_tags, #entity_source, #freeform_tags, #processor_count
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmManagedExternalDatabaseConfigurationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DatabaseConfigurationSummary
Constructor Details
#initialize(attributes = {}) ⇒ EmManagedExternalDatabaseConfigurationSummary
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['entitySource'] = 'EM_MANAGED_EXTERNAL_DATABASE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.enterprise_manager_identifier = attributes[:'enterpriseManagerIdentifier'] if attributes[:'enterpriseManagerIdentifier'] raise 'You cannot provide both :enterpriseManagerIdentifier and :enterprise_manager_identifier' if attributes.key?(:'enterpriseManagerIdentifier') && attributes.key?(:'enterprise_manager_identifier') self.enterprise_manager_identifier = attributes[:'enterprise_manager_identifier'] if attributes[:'enterprise_manager_identifier'] self.enterprise_manager_bridge_id = attributes[:'enterpriseManagerBridgeId'] if attributes[:'enterpriseManagerBridgeId'] raise 'You cannot provide both :enterpriseManagerBridgeId and :enterprise_manager_bridge_id' if attributes.key?(:'enterpriseManagerBridgeId') && attributes.key?(:'enterprise_manager_bridge_id') self.enterprise_manager_bridge_id = attributes[:'enterprise_manager_bridge_id'] if attributes[:'enterprise_manager_bridge_id'] self.instances = attributes[:'instances'] if attributes[:'instances'] end |
Instance Attribute Details
#enterprise_manager_bridge_id ⇒ String
[Required] OPSI Enterprise Manager Bridge OCID
17 18 19 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 17 def enterprise_manager_bridge_id @enterprise_manager_bridge_id end |
#enterprise_manager_identifier ⇒ String
[Required] Enterprise Manager Unique Identifier
13 14 15 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 13 def enterprise_manager_identifier @enterprise_manager_identifier end |
#instances ⇒ Array<OCI::Opsi::Models::HostInstanceMap>
[Required] Array of hostname and instance name.
21 22 23 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 21 def instances @instances end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'database_insight_id': :'databaseInsightId', 'entity_source': :'entitySource', 'compartment_id': :'compartmentId', 'database_name': :'databaseName', 'database_display_name': :'databaseDisplayName', 'database_type': :'databaseType', 'database_version': :'databaseVersion', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'processor_count': :'processorCount', 'enterprise_manager_identifier': :'enterpriseManagerIdentifier', 'enterprise_manager_bridge_id': :'enterpriseManagerBridgeId', 'instances': :'instances' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'database_insight_id': :'String', 'entity_source': :'String', 'compartment_id': :'String', 'database_name': :'String', 'database_display_name': :'String', 'database_type': :'String', 'database_version': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'processor_count': :'Integer', 'enterprise_manager_identifier': :'String', 'enterprise_manager_bridge_id': :'String', 'instances': :'Array<OCI::Opsi::Models::HostInstanceMap>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 115 def ==(other) return true if equal?(other) self.class == other.class && database_insight_id == other.database_insight_id && entity_source == other.entity_source && compartment_id == other.compartment_id && database_name == other.database_name && database_display_name == other.database_display_name && database_type == other.database_type && database_version == other.database_version && == other. && == other. && processor_count == other.processor_count && enterprise_manager_identifier == other.enterprise_manager_identifier && enterprise_manager_bridge_id == other.enterprise_manager_bridge_id && instances == other.instances end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 146 def hash [database_insight_id, entity_source, compartment_id, database_name, database_display_name, database_type, database_version, , , processor_count, enterprise_manager_identifier, enterprise_manager_bridge_id, instances].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/opsi/models/em_managed_external_database_configuration_summary.rb', line 184 def to_s to_hash.to_s end |