Class: OCI::Opsi::Models::EmManagedExternalExadataInsight

Inherits:
ExadataInsight
  • Object
show all
Defined in:
lib/oci/opsi/models/em_managed_external_exadata_insight.rb

Overview

EM-managed Exadata insight resource.

Constant Summary

Constants inherited from ExadataInsight

OCI::Opsi::Models::ExadataInsight::ENTITY_SOURCE_ENUM, OCI::Opsi::Models::ExadataInsight::EXADATA_RACK_TYPE_ENUM, OCI::Opsi::Models::ExadataInsight::EXADATA_TYPE_ENUM, OCI::Opsi::Models::ExadataInsight::LIFECYCLE_STATE_ENUM, OCI::Opsi::Models::ExadataInsight::STATUS_ENUM

Instance Attribute Summary collapse

Attributes inherited from ExadataInsight

#compartment_id, #defined_tags, #entity_source, #exadata_display_name, #exadata_name, #exadata_rack_type, #exadata_type, #freeform_tags, #id, #is_virtualized_exadata, #lifecycle_details, #lifecycle_state, #status, #system_tags, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ExadataInsight

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ EmManagedExternalExadataInsight

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 129

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['entitySource'] = 'EM_MANAGED_EXTERNAL_EXADATA'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.enterprise_manager_identifier = attributes[:'enterpriseManagerIdentifier'] if attributes[:'enterpriseManagerIdentifier']

  raise 'You cannot provide both :enterpriseManagerIdentifier and :enterprise_manager_identifier' if attributes.key?(:'enterpriseManagerIdentifier') && attributes.key?(:'enterprise_manager_identifier')

  self.enterprise_manager_identifier = attributes[:'enterprise_manager_identifier'] if attributes[:'enterprise_manager_identifier']

  self.enterprise_manager_entity_name = attributes[:'enterpriseManagerEntityName'] if attributes[:'enterpriseManagerEntityName']

  raise 'You cannot provide both :enterpriseManagerEntityName and :enterprise_manager_entity_name' if attributes.key?(:'enterpriseManagerEntityName') && attributes.key?(:'enterprise_manager_entity_name')

  self.enterprise_manager_entity_name = attributes[:'enterprise_manager_entity_name'] if attributes[:'enterprise_manager_entity_name']

  self.enterprise_manager_entity_type = attributes[:'enterpriseManagerEntityType'] if attributes[:'enterpriseManagerEntityType']

  raise 'You cannot provide both :enterpriseManagerEntityType and :enterprise_manager_entity_type' if attributes.key?(:'enterpriseManagerEntityType') && attributes.key?(:'enterprise_manager_entity_type')

  self.enterprise_manager_entity_type = attributes[:'enterprise_manager_entity_type'] if attributes[:'enterprise_manager_entity_type']

  self.enterprise_manager_entity_identifier = attributes[:'enterpriseManagerEntityIdentifier'] if attributes[:'enterpriseManagerEntityIdentifier']

  raise 'You cannot provide both :enterpriseManagerEntityIdentifier and :enterprise_manager_entity_identifier' if attributes.key?(:'enterpriseManagerEntityIdentifier') && attributes.key?(:'enterprise_manager_entity_identifier')

  self.enterprise_manager_entity_identifier = attributes[:'enterprise_manager_entity_identifier'] if attributes[:'enterprise_manager_entity_identifier']

  self.enterprise_manager_entity_display_name = attributes[:'enterpriseManagerEntityDisplayName'] if attributes[:'enterpriseManagerEntityDisplayName']

  raise 'You cannot provide both :enterpriseManagerEntityDisplayName and :enterprise_manager_entity_display_name' if attributes.key?(:'enterpriseManagerEntityDisplayName') && attributes.key?(:'enterprise_manager_entity_display_name')

  self.enterprise_manager_entity_display_name = attributes[:'enterprise_manager_entity_display_name'] if attributes[:'enterprise_manager_entity_display_name']

  self.enterprise_manager_bridge_id = attributes[:'enterpriseManagerBridgeId'] if attributes[:'enterpriseManagerBridgeId']

  raise 'You cannot provide both :enterpriseManagerBridgeId and :enterprise_manager_bridge_id' if attributes.key?(:'enterpriseManagerBridgeId') && attributes.key?(:'enterprise_manager_bridge_id')

  self.enterprise_manager_bridge_id = attributes[:'enterprise_manager_bridge_id'] if attributes[:'enterprise_manager_bridge_id']

  self.is_auto_sync_enabled = attributes[:'isAutoSyncEnabled'] unless attributes[:'isAutoSyncEnabled'].nil?

  raise 'You cannot provide both :isAutoSyncEnabled and :is_auto_sync_enabled' if attributes.key?(:'isAutoSyncEnabled') && attributes.key?(:'is_auto_sync_enabled')

  self.is_auto_sync_enabled = attributes[:'is_auto_sync_enabled'] unless attributes[:'is_auto_sync_enabled'].nil?
end

Instance Attribute Details

#enterprise_manager_bridge_idString

[Required] OPSI Enterprise Manager Bridge OCID

Returns:



33
34
35
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 33

def enterprise_manager_bridge_id
  @enterprise_manager_bridge_id
end

#enterprise_manager_entity_display_nameString

Enterprise Manager Entity Display Name

Returns:



29
30
31
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 29

def enterprise_manager_entity_display_name
  @enterprise_manager_entity_display_name
end

#enterprise_manager_entity_identifierString

[Required] Enterprise Manager Entity Unique Identifier

Returns:



25
26
27
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 25

def enterprise_manager_entity_identifier
  @enterprise_manager_entity_identifier
end

#enterprise_manager_entity_nameString

[Required] Enterprise Manager Entity Name

Returns:



17
18
19
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 17

def enterprise_manager_entity_name
  @enterprise_manager_entity_name
end

#enterprise_manager_entity_typeString

[Required] Enterprise Manager Entity Type

Returns:



21
22
23
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 21

def enterprise_manager_entity_type
  @enterprise_manager_entity_type
end

#enterprise_manager_identifierString

[Required] Enterprise Manager Unique Identifier

Returns:



13
14
15
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 13

def enterprise_manager_identifier
  @enterprise_manager_identifier
end

#is_auto_sync_enabledBOOLEAN

Set to true to enable automatic enablement and disablement of related targets from Enterprise Manager. New resources (e.g. Database Insights) will be placed in the same compartment as the related Exadata Insight.

Returns:



37
38
39
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 37

def is_auto_sync_enabled
  @is_auto_sync_enabled
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 40

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'entitySource',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'exadata_name': :'exadataName',
    'exadata_display_name': :'exadataDisplayName',
    'exadata_type': :'exadataType',
    'exadata_rack_type': :'exadataRackType',
    'is_virtualized_exadata': :'isVirtualizedExadata',
    'status': :'status',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'enterprise_manager_identifier': :'enterpriseManagerIdentifier',
    'enterprise_manager_entity_name': :'enterpriseManagerEntityName',
    'enterprise_manager_entity_type': :'enterpriseManagerEntityType',
    'enterprise_manager_entity_identifier': :'enterpriseManagerEntityIdentifier',
    'enterprise_manager_entity_display_name': :'enterpriseManagerEntityDisplayName',
    'enterprise_manager_bridge_id': :'enterpriseManagerBridgeId',
    'is_auto_sync_enabled': :'isAutoSyncEnabled'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 71

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'String',
    'id': :'String',
    'compartment_id': :'String',
    'exadata_name': :'String',
    'exadata_display_name': :'String',
    'exadata_type': :'String',
    'exadata_rack_type': :'String',
    'is_virtualized_exadata': :'BOOLEAN',
    'status': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'enterprise_manager_identifier': :'String',
    'enterprise_manager_entity_name': :'String',
    'enterprise_manager_entity_type': :'String',
    'enterprise_manager_entity_identifier': :'String',
    'enterprise_manager_entity_display_name': :'String',
    'enterprise_manager_bridge_id': :'String',
    'is_auto_sync_enabled': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 189

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    entity_source == other.entity_source &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    exadata_name == other.exadata_name &&
    exadata_display_name == other.exadata_display_name &&
    exadata_type == other.exadata_type &&
    exadata_rack_type == other.exadata_rack_type &&
    is_virtualized_exadata == other.is_virtualized_exadata &&
    status == other.status &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    enterprise_manager_identifier == other.enterprise_manager_identifier &&
    enterprise_manager_entity_name == other.enterprise_manager_entity_name &&
    enterprise_manager_entity_type == other.enterprise_manager_entity_type &&
    enterprise_manager_entity_identifier == other.enterprise_manager_entity_identifier &&
    enterprise_manager_entity_display_name == other.enterprise_manager_entity_display_name &&
    enterprise_manager_bridge_id == other.enterprise_manager_bridge_id &&
    is_auto_sync_enabled == other.is_auto_sync_enabled
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


221
222
223
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 221

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



230
231
232
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 230

def hash
  [entity_source, id, compartment_id, exadata_name, exadata_display_name, exadata_type, exadata_rack_type, is_virtualized_exadata, status, freeform_tags, defined_tags, system_tags, time_created, time_updated, lifecycle_state, lifecycle_details, enterprise_manager_identifier, enterprise_manager_entity_name, enterprise_manager_entity_type, enterprise_manager_entity_identifier, enterprise_manager_entity_display_name, enterprise_manager_bridge_id, is_auto_sync_enabled].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



268
269
270
# File 'lib/oci/opsi/models/em_managed_external_exadata_insight.rb', line 268

def to_s
  to_hash.to_s
end