Class: OCI::Opsi::Models::ExadataConfigurationSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/exadata_configuration_summary.rb

Overview

Summary of a exadata configuration for a resource. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

ENTITY_SOURCE_ENUM =
[
  ENTITY_SOURCE_EM_MANAGED_EXTERNAL_EXADATA = 'EM_MANAGED_EXTERNAL_EXADATA'.freeze,
  ENTITY_SOURCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
EXADATA_TYPE_ENUM =
[
  EXADATA_TYPE_DBMACHINE = 'DBMACHINE'.freeze,
  EXADATA_TYPE_EXACS = 'EXACS'.freeze,
  EXADATA_TYPE_EXACC = 'EXACC'.freeze,
  EXADATA_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
EXADATA_RACK_TYPE_ENUM =
[
  EXADATA_RACK_TYPE_FULL = 'FULL'.freeze,
  EXADATA_RACK_TYPE_HALF = 'HALF'.freeze,
  EXADATA_RACK_TYPE_QUARTER = 'QUARTER'.freeze,
  EXADATA_RACK_TYPE_EIGHTH = 'EIGHTH'.freeze,
  EXADATA_RACK_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExadataConfigurationSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :exadata_insight_id (String)

    The value to assign to the #exadata_insight_id property

  • :entity_source (String)

    The value to assign to the #entity_source property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :exadata_name (String)

    The value to assign to the #exadata_name property

  • :exadata_display_name (String)

    The value to assign to the #exadata_display_name property

  • :exadata_type (String)

    The value to assign to the #exadata_type property

  • :exadata_rack_type (String)

    The value to assign to the #exadata_rack_type property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 136

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.exadata_insight_id = attributes[:'exadataInsightId'] if attributes[:'exadataInsightId']

  raise 'You cannot provide both :exadataInsightId and :exadata_insight_id' if attributes.key?(:'exadataInsightId') && attributes.key?(:'exadata_insight_id')

  self.exadata_insight_id = attributes[:'exadata_insight_id'] if attributes[:'exadata_insight_id']

  self.entity_source = attributes[:'entitySource'] if attributes[:'entitySource']

  raise 'You cannot provide both :entitySource and :entity_source' if attributes.key?(:'entitySource') && attributes.key?(:'entity_source')

  self.entity_source = attributes[:'entity_source'] if attributes[:'entity_source']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.exadata_name = attributes[:'exadataName'] if attributes[:'exadataName']

  raise 'You cannot provide both :exadataName and :exadata_name' if attributes.key?(:'exadataName') && attributes.key?(:'exadata_name')

  self.exadata_name = attributes[:'exadata_name'] if attributes[:'exadata_name']

  self.exadata_display_name = attributes[:'exadataDisplayName'] if attributes[:'exadataDisplayName']

  raise 'You cannot provide both :exadataDisplayName and :exadata_display_name' if attributes.key?(:'exadataDisplayName') && attributes.key?(:'exadata_display_name')

  self.exadata_display_name = attributes[:'exadata_display_name'] if attributes[:'exadata_display_name']

  self.exadata_type = attributes[:'exadataType'] if attributes[:'exadataType']

  raise 'You cannot provide both :exadataType and :exadata_type' if attributes.key?(:'exadataType') && attributes.key?(:'exadata_type')

  self.exadata_type = attributes[:'exadata_type'] if attributes[:'exadata_type']

  self.exadata_rack_type = attributes[:'exadataRackType'] if attributes[:'exadataRackType']

  raise 'You cannot provide both :exadataRackType and :exadata_rack_type' if attributes.key?(:'exadataRackType') && attributes.key?(:'exadata_rack_type')

  self.exadata_rack_type = attributes[:'exadata_rack_type'] if attributes[:'exadata_rack_type']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


42
43
44
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 42

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

[Required] Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


64
65
66
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 64

def defined_tags
  @defined_tags
end

#entity_sourceString

[Required] Source of the exadata entity.

Returns:

  • (String)


38
39
40
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 38

def entity_source
  @entity_source
end

#exadata_display_nameString

[Required] The user-friendly name for the Exadata system. The name does not have to be unique.

Returns:

  • (String)


50
51
52
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 50

def exadata_display_name
  @exadata_display_name
end

#exadata_insight_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.

Returns:

  • (String)


34
35
36
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 34

def exadata_insight_id
  @exadata_insight_id
end

#exadata_nameString

[Required] The Exadata system name. If the Exadata systems managed by Enterprise Manager, the name is unique amongst the Exadata systems managed by the same Enterprise Manager.

Returns:

  • (String)


46
47
48
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 46

def exadata_name
  @exadata_name
end

#exadata_rack_typeString

[Required] Exadata rack type.

Returns:

  • (String)


58
59
60
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 58

def exadata_rack_type
  @exadata_rack_type
end

#exadata_typeString

[Required] Operations Insights internal representation of the the Exadata system type.

Returns:

  • (String)


54
55
56
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 54

def exadata_type
  @exadata_type
end

#freeform_tagsHash<String, String>

[Required] Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


70
71
72
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 70

def freeform_tags
  @freeform_tags
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 73

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'exadata_insight_id': :'exadataInsightId',
    'entity_source': :'entitySource',
    'compartment_id': :'compartmentId',
    'exadata_name': :'exadataName',
    'exadata_display_name': :'exadataDisplayName',
    'exadata_type': :'exadataType',
    'exadata_rack_type': :'exadataRackType',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



111
112
113
114
115
116
117
118
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 111

def self.get_subtype(object_hash)
  type = object_hash[:'entitySource'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Opsi::Models::ExadataDatabaseMachineConfigurationSummary' if type == 'EM_MANAGED_EXTERNAL_EXADATA'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Opsi::Models::ExadataConfigurationSummary'
end

.swagger_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 90

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'exadata_insight_id': :'String',
    'entity_source': :'String',
    'compartment_id': :'String',
    'exadata_name': :'String',
    'exadata_display_name': :'String',
    'exadata_type': :'String',
    'exadata_rack_type': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 243

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    exadata_insight_id == other.exadata_insight_id &&
    entity_source == other.entity_source &&
    compartment_id == other.compartment_id &&
    exadata_name == other.exadata_name &&
    exadata_display_name == other.exadata_display_name &&
    exadata_type == other.exadata_type &&
    exadata_rack_type == other.exadata_rack_type &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 281

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 261

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



270
271
272
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 270

def hash
  [exadata_insight_id, entity_source, compartment_id, exadata_name, exadata_display_name, exadata_type, exadata_rack_type, defined_tags, freeform_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
317
318
319
320
321
322
323
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 314

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



308
309
310
# File 'lib/oci/opsi/models/exadata_configuration_summary.rb', line 308

def to_s
  to_hash.to_s
end