Class: OCI::Opsi::Models::ExadataInsightResourceInsightUtilizationItem
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::ExadataInsightResourceInsightUtilizationItem
- Defined in:
- lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb
Overview
Object containing current utilization, projected utilization, id and daysToReach high and low utilization value.
Instance Attribute Summary collapse
-
#current_utilization ⇒ Float
**[Required]** Current utilization.
-
#days_to_reach_high_utilization ⇒ Integer
**[Required]** Days to reach projected high utilization.
-
#days_to_reach_low_utilization ⇒ Integer
**[Required]** Days to reach projected low utilization.
-
#exadata_display_name ⇒ String
The user-friendly name for the Exadata system.
-
#exadata_insight_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
-
#projected_utilization ⇒ Float
**[Required]** Projected utilization.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExadataInsightResourceInsightUtilizationItem
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ExadataInsightResourceInsightUtilizationItem
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.exadata_insight_id = attributes[:'exadataInsightId'] if attributes[:'exadataInsightId'] raise 'You cannot provide both :exadataInsightId and :exadata_insight_id' if attributes.key?(:'exadataInsightId') && attributes.key?(:'exadata_insight_id') self.exadata_insight_id = attributes[:'exadata_insight_id'] if attributes[:'exadata_insight_id'] self.exadata_display_name = attributes[:'exadataDisplayName'] if attributes[:'exadataDisplayName'] raise 'You cannot provide both :exadataDisplayName and :exadata_display_name' if attributes.key?(:'exadataDisplayName') && attributes.key?(:'exadata_display_name') self.exadata_display_name = attributes[:'exadata_display_name'] if attributes[:'exadata_display_name'] self.current_utilization = attributes[:'currentUtilization'] if attributes[:'currentUtilization'] raise 'You cannot provide both :currentUtilization and :current_utilization' if attributes.key?(:'currentUtilization') && attributes.key?(:'current_utilization') self.current_utilization = attributes[:'current_utilization'] if attributes[:'current_utilization'] self.projected_utilization = attributes[:'projectedUtilization'] if attributes[:'projectedUtilization'] raise 'You cannot provide both :projectedUtilization and :projected_utilization' if attributes.key?(:'projectedUtilization') && attributes.key?(:'projected_utilization') self.projected_utilization = attributes[:'projected_utilization'] if attributes[:'projected_utilization'] self.days_to_reach_high_utilization = attributes[:'daysToReachHighUtilization'] if attributes[:'daysToReachHighUtilization'] raise 'You cannot provide both :daysToReachHighUtilization and :days_to_reach_high_utilization' if attributes.key?(:'daysToReachHighUtilization') && attributes.key?(:'days_to_reach_high_utilization') self.days_to_reach_high_utilization = attributes[:'days_to_reach_high_utilization'] if attributes[:'days_to_reach_high_utilization'] self.days_to_reach_low_utilization = attributes[:'daysToReachLowUtilization'] if attributes[:'daysToReachLowUtilization'] raise 'You cannot provide both :daysToReachLowUtilization and :days_to_reach_low_utilization' if attributes.key?(:'daysToReachLowUtilization') && attributes.key?(:'days_to_reach_low_utilization') self.days_to_reach_low_utilization = attributes[:'days_to_reach_low_utilization'] if attributes[:'days_to_reach_low_utilization'] end |
Instance Attribute Details
#current_utilization ⇒ Float
**[Required]** Current utilization
20 21 22 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 20 def current_utilization @current_utilization end |
#days_to_reach_high_utilization ⇒ Integer
**[Required]** Days to reach projected high utilization
28 29 30 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 28 def days_to_reach_high_utilization @days_to_reach_high_utilization end |
#days_to_reach_low_utilization ⇒ Integer
**[Required]** Days to reach projected low utilization
32 33 34 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 32 def days_to_reach_low_utilization @days_to_reach_low_utilization end |
#exadata_display_name ⇒ String
The user-friendly name for the Exadata system. The name does not have to be unique.
16 17 18 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 16 def exadata_display_name @exadata_display_name end |
#exadata_insight_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
12 13 14 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 12 def exadata_insight_id @exadata_insight_id end |
#projected_utilization ⇒ Float
**[Required]** Projected utilization
24 25 26 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 24 def projected_utilization @projected_utilization end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'exadata_insight_id': :'exadataInsightId', 'exadata_display_name': :'exadataDisplayName', 'current_utilization': :'currentUtilization', 'projected_utilization': :'projectedUtilization', 'days_to_reach_high_utilization': :'daysToReachHighUtilization', 'days_to_reach_low_utilization': :'daysToReachLowUtilization' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'exadata_insight_id': :'String', 'exadata_display_name': :'String', 'current_utilization': :'Float', 'projected_utilization': :'Float', 'days_to_reach_high_utilization': :'Integer', 'days_to_reach_low_utilization': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 124 def ==(other) return true if equal?(other) self.class == other.class && exadata_insight_id == other.exadata_insight_id && exadata_display_name == other.exadata_display_name && current_utilization == other.current_utilization && projected_utilization == other.projected_utilization && days_to_reach_high_utilization == other.days_to_reach_high_utilization && days_to_reach_low_utilization == other.days_to_reach_low_utilization end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 159 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
139 140 141 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 139 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 148 def hash [exadata_insight_id, exadata_display_name, current_utilization, projected_utilization, days_to_reach_high_utilization, days_to_reach_low_utilization].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
186 187 188 |
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 186 def to_s to_hash.to_s end |