Class: OCI::Opsi::Models::ExadataInsightSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/exadata_insight_summary.rb

Overview

Summary of an Exadata insight resource. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Direct Known Subclasses

EmManagedExternalExadataInsightSummary

Constant Summary collapse

ENTITY_SOURCE_ENUM =
[
  ENTITY_SOURCE_EM_MANAGED_EXTERNAL_EXADATA = 'EM_MANAGED_EXTERNAL_EXADATA'.freeze,
  ENTITY_SOURCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
EXADATA_TYPE_ENUM =
[
  EXADATA_TYPE_DBMACHINE = 'DBMACHINE'.freeze,
  EXADATA_TYPE_EXACS = 'EXACS'.freeze,
  EXADATA_TYPE_EXACC = 'EXACC'.freeze,
  EXADATA_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
EXADATA_RACK_TYPE_ENUM =
[
  EXADATA_RACK_TYPE_FULL = 'FULL'.freeze,
  EXADATA_RACK_TYPE_HALF = 'HALF'.freeze,
  EXADATA_RACK_TYPE_QUARTER = 'QUARTER'.freeze,
  EXADATA_RACK_TYPE_EIGHTH = 'EIGHTH'.freeze,
  EXADATA_RACK_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_DISABLED = 'DISABLED'.freeze,
  STATUS_ENABLED = 'ENABLED'.freeze,
  STATUS_TERMINATED = 'TERMINATED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExadataInsightSummary

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :entity_source (String)

    The value to assign to the #entity_source property

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :exadata_name (String)

    The value to assign to the #exadata_name property

  • :exadata_display_name (String)

    The value to assign to the #exadata_display_name property

  • :exadata_type (String)

    The value to assign to the #exadata_type property

  • :exadata_rack_type (String)

    The value to assign to the #exadata_rack_type property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property

  • :status (String)

    The value to assign to the #status property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 197

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.entity_source = attributes[:'entitySource'] if attributes[:'entitySource']

  raise 'You cannot provide both :entitySource and :entity_source' if attributes.key?(:'entitySource') && attributes.key?(:'entity_source')

  self.entity_source = attributes[:'entity_source'] if attributes[:'entity_source']

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.exadata_name = attributes[:'exadataName'] if attributes[:'exadataName']

  raise 'You cannot provide both :exadataName and :exadata_name' if attributes.key?(:'exadataName') && attributes.key?(:'exadata_name')

  self.exadata_name = attributes[:'exadata_name'] if attributes[:'exadata_name']

  self.exadata_display_name = attributes[:'exadataDisplayName'] if attributes[:'exadataDisplayName']

  raise 'You cannot provide both :exadataDisplayName and :exadata_display_name' if attributes.key?(:'exadataDisplayName') && attributes.key?(:'exadata_display_name')

  self.exadata_display_name = attributes[:'exadata_display_name'] if attributes[:'exadata_display_name']

  self.exadata_type = attributes[:'exadataType'] if attributes[:'exadataType']

  raise 'You cannot provide both :exadataType and :exadata_type' if attributes.key?(:'exadataType') && attributes.key?(:'exadata_type')

  self.exadata_type = attributes[:'exadata_type'] if attributes[:'exadata_type']

  self.exadata_rack_type = attributes[:'exadataRackType'] if attributes[:'exadataRackType']

  raise 'You cannot provide both :exadataRackType and :exadata_rack_type' if attributes.key?(:'exadataRackType') && attributes.key?(:'exadata_rack_type')

  self.exadata_rack_type = attributes[:'exadata_rack_type'] if attributes[:'exadata_rack_type']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

  self.status = attributes[:'status'] if attributes[:'status']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:



59
60
61
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 59

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

[Required] Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:



87
88
89
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 87

def defined_tags
  @defined_tags
end

#entity_sourceString

[Required] Source of the Exadata system.

Returns:



51
52
53
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 51

def entity_source
  @entity_source
end

#exadata_display_nameString

The user-friendly name for the Exadata system. The name does not have to be unique.

Returns:



67
68
69
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 67

def exadata_display_name
  @exadata_display_name
end

#exadata_nameString

[Required] The Exadata system name. If the Exadata systems managed by Enterprise Manager, the name is unique amongst the Exadata systems managed by the same Enterprise Manager.

Returns:



63
64
65
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 63

def exadata_name
  @exadata_name
end

#exadata_rack_typeString

Operations Insights internal representation of the the Exadata system rack type.

Returns:



75
76
77
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 75

def exadata_rack_type
  @exadata_rack_type
end

#exadata_typeString

Operations Insights internal representation of the the Exadata system type.

Returns:



71
72
73
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 71

def exadata_type
  @exadata_type
end

#freeform_tagsHash<String, String>

[Required] Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:



81
82
83
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 81

def freeform_tags
  @freeform_tags
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight resource.

Returns:



55
56
57
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 55

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:



113
114
115
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 113

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the Exadata insight.

Returns:



109
110
111
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 109

def lifecycle_state
  @lifecycle_state
end

#statusString

[Required] Indicates the status of an Exadata insight in Operations Insights

Returns:



97
98
99
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 97

def status
  @status
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"free-tier-retained": "true"}`

Returns:



93
94
95
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 93

def system_tags
  @system_tags
end

#time_createdDateTime

[Required] The time the the Exadata insight was first enabled. An RFC3339 formatted datetime string

Returns:



101
102
103
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 101

def time_created
  @time_created
end

#time_updatedDateTime

The time the Exadata insight was updated. An RFC3339 formatted datetime string

Returns:



105
106
107
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 105

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 116

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'entitySource',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'exadata_name': :'exadataName',
    'exadata_display_name': :'exadataDisplayName',
    'exadata_type': :'exadataType',
    'exadata_rack_type': :'exadataRackType',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'status': :'status',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



166
167
168
169
170
171
172
173
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 166

def self.get_subtype(object_hash)
  type = object_hash[:'entitySource'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Opsi::Models::EmManagedExternalExadataInsightSummary' if type == 'EM_MANAGED_EXTERNAL_EXADATA'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Opsi::Models::ExadataInsightSummary'
end

.swagger_typesObject

Attribute type mapping.



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 139

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'String',
    'id': :'String',
    'compartment_id': :'String',
    'exadata_name': :'String',
    'exadata_display_name': :'String',
    'exadata_type': :'String',
    'exadata_rack_type': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'status': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 358

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    entity_source == other.entity_source &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    exadata_name == other.exadata_name &&
    exadata_display_name == other.exadata_display_name &&
    exadata_type == other.exadata_type &&
    exadata_rack_type == other.exadata_rack_type &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    status == other.status &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 402

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


382
383
384
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 382

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



391
392
393
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 391

def hash
  [entity_source, id, compartment_id, exadata_name, exadata_display_name, exadata_type, exadata_rack_type, freeform_tags, defined_tags, system_tags, status, time_created, time_updated, lifecycle_state, lifecycle_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



435
436
437
438
439
440
441
442
443
444
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 435

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



429
430
431
# File 'lib/oci/opsi/models/exadata_insight_summary.rb', line 429

def to_s
  to_hash.to_s
end