Class: OCI::Opsi::Models::ExadataMemberCollection
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::ExadataMemberCollection
- Defined in:
- lib/oci/opsi/models/exadata_member_collection.rb
Overview
Partial definition of the exadata insight resource.
Constant Summary collapse
- EXADATA_TYPE_ENUM =
[ EXADATA_TYPE_DBMACHINE = 'DBMACHINE'.freeze, EXADATA_TYPE_EXACS = 'EXACS'.freeze, EXADATA_TYPE_EXACC = 'EXACC'.freeze, EXADATA_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- EXADATA_RACK_TYPE_ENUM =
[ EXADATA_RACK_TYPE_FULL = 'FULL'.freeze, EXADATA_RACK_TYPE_HALF = 'HALF'.freeze, EXADATA_RACK_TYPE_QUARTER = 'QUARTER'.freeze, EXADATA_RACK_TYPE_EIGHTH = 'EIGHTH'.freeze, EXADATA_RACK_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#exadata_display_name ⇒ String
[Required] The user-friendly name for the Exadata system.
-
#exadata_insight_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
-
#exadata_name ⇒ String
[Required] The Exadata system name.
-
#exadata_rack_type ⇒ String
[Required] Exadata rack type.
-
#exadata_type ⇒ String
[Required] Operations Insights internal representation of the the Exadata system type.
-
#items ⇒ Array<OCI::Opsi::Models::ExadataMemberSummary>
[Required] Collection of Exadata members.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExadataMemberCollection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ExadataMemberCollection
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.exadata_insight_id = attributes[:'exadataInsightId'] if attributes[:'exadataInsightId'] raise 'You cannot provide both :exadataInsightId and :exadata_insight_id' if attributes.key?(:'exadataInsightId') && attributes.key?(:'exadata_insight_id') self.exadata_insight_id = attributes[:'exadata_insight_id'] if attributes[:'exadata_insight_id'] self.exadata_name = attributes[:'exadataName'] if attributes[:'exadataName'] raise 'You cannot provide both :exadataName and :exadata_name' if attributes.key?(:'exadataName') && attributes.key?(:'exadata_name') self.exadata_name = attributes[:'exadata_name'] if attributes[:'exadata_name'] self.exadata_display_name = attributes[:'exadataDisplayName'] if attributes[:'exadataDisplayName'] raise 'You cannot provide both :exadataDisplayName and :exadata_display_name' if attributes.key?(:'exadataDisplayName') && attributes.key?(:'exadata_display_name') self.exadata_display_name = attributes[:'exadata_display_name'] if attributes[:'exadata_display_name'] self.exadata_type = attributes[:'exadataType'] if attributes[:'exadataType'] raise 'You cannot provide both :exadataType and :exadata_type' if attributes.key?(:'exadataType') && attributes.key?(:'exadata_type') self.exadata_type = attributes[:'exadata_type'] if attributes[:'exadata_type'] self.exadata_rack_type = attributes[:'exadataRackType'] if attributes[:'exadataRackType'] raise 'You cannot provide both :exadataRackType and :exadata_rack_type' if attributes.key?(:'exadataRackType') && attributes.key?(:'exadata_rack_type') self.exadata_rack_type = attributes[:'exadata_rack_type'] if attributes[:'exadata_rack_type'] self.items = attributes[:'items'] if attributes[:'items'] end |
Instance Attribute Details
#exadata_display_name ⇒ String
[Required] The user-friendly name for the Exadata system. The name does not have to be unique.
36 37 38 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 36 def exadata_display_name @exadata_display_name end |
#exadata_insight_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
28 29 30 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 28 def exadata_insight_id @exadata_insight_id end |
#exadata_name ⇒ String
[Required] The Exadata system name. If the Exadata systems managed by Enterprise Manager, the name is unique amongst the Exadata systems managed by the same Enterprise Manager.
32 33 34 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 32 def exadata_name @exadata_name end |
#exadata_rack_type ⇒ String
[Required] Exadata rack type.
44 45 46 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 44 def exadata_rack_type @exadata_rack_type end |
#exadata_type ⇒ String
[Required] Operations Insights internal representation of the the Exadata system type.
40 41 42 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 40 def exadata_type @exadata_type end |
#items ⇒ Array<OCI::Opsi::Models::ExadataMemberSummary>
[Required] Collection of Exadata members
48 49 50 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 48 def items @items end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'exadata_insight_id': :'exadataInsightId', 'exadata_name': :'exadataName', 'exadata_display_name': :'exadataDisplayName', 'exadata_type': :'exadataType', 'exadata_rack_type': :'exadataRackType', 'items': :'items' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'exadata_insight_id': :'String', 'exadata_name': :'String', 'exadata_display_name': :'String', 'exadata_type': :'String', 'exadata_rack_type': :'String', 'items': :'Array<OCI::Opsi::Models::ExadataMemberSummary>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 162 def ==(other) return true if equal?(other) self.class == other.class && exadata_insight_id == other.exadata_insight_id && exadata_name == other.exadata_name && exadata_display_name == other.exadata_display_name && exadata_type == other.exadata_type && exadata_rack_type == other.exadata_rack_type && items == other.items end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 197 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
177 178 179 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 177 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 186 def hash [exadata_insight_id, exadata_name, exadata_display_name, exadata_type, exadata_rack_type, items].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 230 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
224 225 226 |
# File 'lib/oci/opsi/models/exadata_member_collection.rb', line 224 def to_s to_hash.to_s end |