Class: OCI::Opsi::Models::HostConfigurationMetricGroup
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::HostConfigurationMetricGroup
- Defined in:
- lib/oci/opsi/models/host_configuration_metric_group.rb
Overview
Base Metric Group for Host configuration metrics
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
HostCpuHardwareConfiguration, HostEntities, HostHardwareConfiguration, HostMemoryConfiguration, HostNetworkConfiguration, HostProduct, HostResourceAllocation
Constant Summary collapse
- METRIC_NAME_ENUM =
[ METRIC_NAME_HOST_PRODUCT = 'HOST_PRODUCT'.freeze, METRIC_NAME_HOST_RESOURCE_ALLOCATION = 'HOST_RESOURCE_ALLOCATION'.freeze, METRIC_NAME_HOST_MEMORY_CONFIGURATION = 'HOST_MEMORY_CONFIGURATION'.freeze, METRIC_NAME_HOST_HARDWARE_CONFIGURATION = 'HOST_HARDWARE_CONFIGURATION'.freeze, METRIC_NAME_HOST_CPU_HARDWARE_CONFIGURATION = 'HOST_CPU_HARDWARE_CONFIGURATION'.freeze, METRIC_NAME_HOST_NETWORK_CONFIGURATION = 'HOST_NETWORK_CONFIGURATION'.freeze, METRIC_NAME_HOST_ENTITES = 'HOST_ENTITES'.freeze ].freeze
Instance Attribute Summary collapse
-
#metric_name ⇒ String
[Required] Name of the metric group.
-
#time_collected ⇒ DateTime
[Required] Collection timestamp Example: ‘"2020-05-06T00:00:00.000Z"`.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostConfigurationMetricGroup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HostConfigurationMetricGroup
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.metric_name = attributes[:'metricName'] if attributes[:'metricName'] raise 'You cannot provide both :metricName and :metric_name' if attributes.key?(:'metricName') && attributes.key?(:'metric_name') self.metric_name = attributes[:'metric_name'] if attributes[:'metric_name'] self.time_collected = attributes[:'timeCollected'] if attributes[:'timeCollected'] raise 'You cannot provide both :timeCollected and :time_collected' if attributes.key?(:'timeCollected') && attributes.key?(:'time_collected') self.time_collected = attributes[:'time_collected'] if attributes[:'time_collected'] end |
Instance Attribute Details
#metric_name ⇒ String
[Required] Name of the metric group
25 26 27 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 25 def metric_name @metric_name end |
#time_collected ⇒ DateTime
[Required] Collection timestamp Example: ‘"2020-05-06T00:00:00.000Z"`
31 32 33 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 31 def time_collected @time_collected end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'metric_name': :'metricName', 'time_collected': :'timeCollected' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 58 def self.get_subtype(object_hash) type = object_hash[:'metricName'] # rubocop:disable Style/SymbolLiteral return 'OCI::Opsi::Models::HostResourceAllocation' if type == 'HOST_RESOURCE_ALLOCATION' return 'OCI::Opsi::Models::HostProduct' if type == 'HOST_PRODUCT' return 'OCI::Opsi::Models::HostNetworkConfiguration' if type == 'HOST_NETWORK_CONFIGURATION' return 'OCI::Opsi::Models::HostEntities' if type == 'HOST_ENTITIES' return 'OCI::Opsi::Models::HostMemoryConfiguration' if type == 'HOST_MEMORY_CONFIGURATION' return 'OCI::Opsi::Models::HostCpuHardwareConfiguration' if type == 'HOST_CPU_HARDWARE_CONFIGURATION' return 'OCI::Opsi::Models::HostHardwareConfiguration' if type == 'HOST_HARDWARE_CONFIGURATION' # TODO: Log a warning when the subtype is not found. 'OCI::Opsi::Models::HostConfigurationMetricGroup' end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'metric_name': :'String', 'time_collected': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
116 117 118 119 120 121 122 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 116 def ==(other) return true if equal?(other) self.class == other.class && metric_name == other.metric_name && time_collected == other.time_collected end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 147 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
127 128 129 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 127 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 136 def hash [metric_name, time_collected].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
174 175 176 |
# File 'lib/oci/opsi/models/host_configuration_metric_group.rb', line 174 def to_s to_hash.to_s end |