Class: OCI::Opsi::Models::HostDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/host_details.rb

Overview

Partial information about a host which includes id, name, type.

Constant Summary collapse

PLATFORM_TYPE_ENUM =
[
  PLATFORM_TYPE_LINUX = 'LINUX'.freeze,
  PLATFORM_TYPE_SOLARIS = 'SOLARIS'.freeze,
  PLATFORM_TYPE_SUNOS = 'SUNOS'.freeze,
  PLATFORM_TYPE_ZLINUX = 'ZLINUX'.freeze,
  PLATFORM_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HostDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :host_name (String)

    The value to assign to the #host_name property

  • :host_display_name (String)

    The value to assign to the #host_display_name property

  • :platform_type (String)

    The value to assign to the #platform_type property

  • :agent_identifier (String)

    The value to assign to the #agent_identifier property



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/oci/opsi/models/host_details.rb', line 86

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.host_name = attributes[:'hostName'] if attributes[:'hostName']

  raise 'You cannot provide both :hostName and :host_name' if attributes.key?(:'hostName') && attributes.key?(:'host_name')

  self.host_name = attributes[:'host_name'] if attributes[:'host_name']

  self.host_display_name = attributes[:'hostDisplayName'] if attributes[:'hostDisplayName']

  raise 'You cannot provide both :hostDisplayName and :host_display_name' if attributes.key?(:'hostDisplayName') && attributes.key?(:'host_display_name')

  self.host_display_name = attributes[:'host_display_name'] if attributes[:'host_display_name']

  self.platform_type = attributes[:'platformType'] if attributes[:'platformType']

  raise 'You cannot provide both :platformType and :platform_type' if attributes.key?(:'platformType') && attributes.key?(:'platform_type')

  self.platform_type = attributes[:'platform_type'] if attributes[:'platform_type']

  self.agent_identifier = attributes[:'agentIdentifier'] if attributes[:'agentIdentifier']

  raise 'You cannot provide both :agentIdentifier and :agent_identifier' if attributes.key?(:'agentIdentifier') && attributes.key?(:'agent_identifier')

  self.agent_identifier = attributes[:'agent_identifier'] if attributes[:'agent_identifier']
end

Instance Attribute Details

#agent_identifierString

**[Required]** The identifier of the agent.

Returns:

  • (String)


44
45
46
# File 'lib/oci/opsi/models/host_details.rb', line 44

def agent_identifier
  @agent_identifier
end

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


25
26
27
# File 'lib/oci/opsi/models/host_details.rb', line 25

def compartment_id
  @compartment_id
end

#host_display_nameString

The user-friendly name for the host. The name does not have to be unique.

Returns:

  • (String)


33
34
35
# File 'lib/oci/opsi/models/host_details.rb', line 33

def host_display_name
  @host_display_name
end

#host_nameString

**[Required]** The host name. The host name is unique amongst the hosts managed by the same management agent.

Returns:

  • (String)


29
30
31
# File 'lib/oci/opsi/models/host_details.rb', line 29

def host_name
  @host_name
end

#idString

Returns:

  • (String)


21
22
23
# File 'lib/oci/opsi/models/host_details.rb', line 21

def id
  @id
end

#platform_typeString

**[Required]** Platform type. Supported platformType(s) for MACS-managed external host insight: [LINUX]. Supported platformType(s) for EM-managed external host insight: [LINUX, SOLARIS, SUNOS, ZLINUX].

Returns:

  • (String)


40
41
42
# File 'lib/oci/opsi/models/host_details.rb', line 40

def platform_type
  @platform_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/oci/opsi/models/host_details.rb', line 47

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'host_name': :'hostName',
    'host_display_name': :'hostDisplayName',
    'platform_type': :'platformType',
    'agent_identifier': :'agentIdentifier'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/opsi/models/host_details.rb', line 61

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'host_name': :'String',
    'host_display_name': :'String',
    'platform_type': :'String',
    'agent_identifier': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



145
146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/opsi/models/host_details.rb', line 145

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    host_name == other.host_name &&
    host_display_name == other.host_display_name &&
    platform_type == other.platform_type &&
    agent_identifier == other.agent_identifier
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/oci/opsi/models/host_details.rb', line 180

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/oci/opsi/models/host_details.rb', line 160

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



169
170
171
# File 'lib/oci/opsi/models/host_details.rb', line 169

def hash
  [id, compartment_id, host_name, host_display_name, platform_type, agent_identifier].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
# File 'lib/oci/opsi/models/host_details.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



207
208
209
# File 'lib/oci/opsi/models/host_details.rb', line 207

def to_s
  to_hash.to_s
end