Class: OCI::Opsi::Models::HostMemoryConfiguration
- Inherits:
-
HostConfigurationMetricGroup
- Object
- HostConfigurationMetricGroup
- OCI::Opsi::Models::HostMemoryConfiguration
- Defined in:
- lib/oci/opsi/models/host_memory_configuration.rb
Overview
Memory Configuration metric for the host
Constant Summary
Constants inherited from HostConfigurationMetricGroup
OCI::Opsi::Models::HostConfigurationMetricGroup::METRIC_NAME_ENUM
Instance Attribute Summary collapse
-
#huge_page_size_in_kb ⇒ Float
Size of huge pages in kilobytes.
-
#huge_pages_total ⇒ Integer
Total number of huge pages.
-
#page_size_in_kb ⇒ Float
Page size in kilobytes.
-
#page_tables_in_kb ⇒ Float
Amount of memory used for page tables in kilobytes.
-
#swap_total_in_kb ⇒ Float
Amount of total swap space in kilobytes.
Attributes inherited from HostConfigurationMetricGroup
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostMemoryConfiguration
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from HostConfigurationMetricGroup
Constructor Details
#initialize(attributes = {}) ⇒ HostMemoryConfiguration
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['metricName'] = 'HOST_MEMORY_CONFIGURATION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.page_size_in_kb = attributes[:'pageSizeInKB'] if attributes[:'pageSizeInKB'] raise 'You cannot provide both :pageSizeInKB and :page_size_in_kb' if attributes.key?(:'pageSizeInKB') && attributes.key?(:'page_size_in_kb') self.page_size_in_kb = attributes[:'page_size_in_kb'] if attributes[:'page_size_in_kb'] self.page_tables_in_kb = attributes[:'pageTablesInKB'] if attributes[:'pageTablesInKB'] raise 'You cannot provide both :pageTablesInKB and :page_tables_in_kb' if attributes.key?(:'pageTablesInKB') && attributes.key?(:'page_tables_in_kb') self.page_tables_in_kb = attributes[:'page_tables_in_kb'] if attributes[:'page_tables_in_kb'] self.swap_total_in_kb = attributes[:'swapTotalInKB'] if attributes[:'swapTotalInKB'] raise 'You cannot provide both :swapTotalInKB and :swap_total_in_kb' if attributes.key?(:'swapTotalInKB') && attributes.key?(:'swap_total_in_kb') self.swap_total_in_kb = attributes[:'swap_total_in_kb'] if attributes[:'swap_total_in_kb'] self.huge_page_size_in_kb = attributes[:'hugePageSizeInKB'] if attributes[:'hugePageSizeInKB'] raise 'You cannot provide both :hugePageSizeInKB and :huge_page_size_in_kb' if attributes.key?(:'hugePageSizeInKB') && attributes.key?(:'huge_page_size_in_kb') self.huge_page_size_in_kb = attributes[:'huge_page_size_in_kb'] if attributes[:'huge_page_size_in_kb'] self.huge_pages_total = attributes[:'hugePagesTotal'] if attributes[:'hugePagesTotal'] raise 'You cannot provide both :hugePagesTotal and :huge_pages_total' if attributes.key?(:'hugePagesTotal') && attributes.key?(:'huge_pages_total') self.huge_pages_total = attributes[:'huge_pages_total'] if attributes[:'huge_pages_total'] end |
Instance Attribute Details
#huge_page_size_in_kb ⇒ Float
Size of huge pages in kilobytes
26 27 28 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 26 def huge_page_size_in_kb @huge_page_size_in_kb end |
#huge_pages_total ⇒ Integer
Total number of huge pages
30 31 32 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 30 def huge_pages_total @huge_pages_total end |
#page_size_in_kb ⇒ Float
Page size in kilobytes
14 15 16 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 14 def page_size_in_kb @page_size_in_kb end |
#page_tables_in_kb ⇒ Float
Amount of memory used for page tables in kilobytes
18 19 20 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 18 def page_tables_in_kb @page_tables_in_kb end |
#swap_total_in_kb ⇒ Float
Amount of total swap space in kilobytes
22 23 24 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 22 def swap_total_in_kb @swap_total_in_kb end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'metric_name': :'metricName', 'time_collected': :'timeCollected', 'page_size_in_kb': :'pageSizeInKB', 'page_tables_in_kb': :'pageTablesInKB', 'swap_total_in_kb': :'swapTotalInKB', 'huge_page_size_in_kb': :'hugePageSizeInKB', 'huge_pages_total': :'hugePagesTotal' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'metric_name': :'String', 'time_collected': :'DateTime', 'page_size_in_kb': :'Float', 'page_tables_in_kb': :'Float', 'swap_total_in_kb': :'Float', 'huge_page_size_in_kb': :'Float', 'huge_pages_total': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && metric_name == other.metric_name && time_collected == other.time_collected && page_size_in_kb == other.page_size_in_kb && page_tables_in_kb == other.page_tables_in_kb && swap_total_in_kb == other.swap_total_in_kb && huge_page_size_in_kb == other.huge_page_size_in_kb && huge_pages_total == other.huge_pages_total end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 158 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
138 139 140 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 138 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
147 148 149 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 147 def hash [metric_name, time_collected, page_size_in_kb, page_tables_in_kb, swap_total_in_kb, huge_page_size_in_kb, huge_pages_total].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
185 186 187 |
# File 'lib/oci/opsi/models/host_memory_configuration.rb', line 185 def to_s to_hash.to_s end |