Class: OCI::Opsi::Models::HostResourceAllocation
- Inherits:
-
HostConfigurationMetricGroup
- Object
- HostConfigurationMetricGroup
- OCI::Opsi::Models::HostResourceAllocation
- Defined in:
- lib/oci/opsi/models/host_resource_allocation.rb
Overview
Resource Allocation metric for the host
Constant Summary
Constants inherited from HostConfigurationMetricGroup
OCI::Opsi::Models::HostConfigurationMetricGroup::METRIC_NAME_ENUM
Instance Attribute Summary collapse
-
#total_cpus ⇒ Integer
Total number of CPUs available.
-
#total_memory_in_gb ⇒ Float
Total amount of usable physical memory in gibabytes.
Attributes inherited from HostConfigurationMetricGroup
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostResourceAllocation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from HostConfigurationMetricGroup
Constructor Details
#initialize(attributes = {}) ⇒ HostResourceAllocation
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['metricName'] = 'HOST_RESOURCE_ALLOCATION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.total_cpus = attributes[:'totalCpus'] if attributes[:'totalCpus'] raise 'You cannot provide both :totalCpus and :total_cpus' if attributes.key?(:'totalCpus') && attributes.key?(:'total_cpus') self.total_cpus = attributes[:'total_cpus'] if attributes[:'total_cpus'] self.total_memory_in_gb = attributes[:'totalMemoryInGB'] if attributes[:'totalMemoryInGB'] raise 'You cannot provide both :totalMemoryInGB and :total_memory_in_gb' if attributes.key?(:'totalMemoryInGB') && attributes.key?(:'total_memory_in_gb') self.total_memory_in_gb = attributes[:'total_memory_in_gb'] if attributes[:'total_memory_in_gb'] end |
Instance Attribute Details
#total_cpus ⇒ Integer
Total number of CPUs available
14 15 16 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 14 def total_cpus @total_cpus end |
#total_memory_in_gb ⇒ Float
Total amount of usable physical memory in gibabytes
18 19 20 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 18 def total_memory_in_gb @total_memory_in_gb end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
21 22 23 24 25 26 27 28 29 30 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 21 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'metric_name': :'metricName', 'time_collected': :'timeCollected', 'total_cpus': :'totalCpus', 'total_memory_in_gb': :'totalMemoryInGB' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 33 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'metric_name': :'String', 'time_collected': :'DateTime', 'total_cpus': :'Integer', 'total_memory_in_gb': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 83 def ==(other) return true if equal?(other) self.class == other.class && metric_name == other.metric_name && time_collected == other.time_collected && total_cpus == other.total_cpus && total_memory_in_gb == other.total_memory_in_gb end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 116 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
96 97 98 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 96 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
105 106 107 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 105 def hash [metric_name, time_collected, total_cpus, total_memory_in_gb].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 149 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
143 144 145 |
# File 'lib/oci/opsi/models/host_resource_allocation.rb', line 143 def to_s to_hash.to_s end |