Class: OCI::Opsi::Models::HostResourceStatistics
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::HostResourceStatistics
- Defined in:
- lib/oci/opsi/models/host_resource_statistics.rb
Overview
Contains host resource base statistics.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- RESOURCE_NAME_ENUM =
[ RESOURCE_NAME_HOST_CPU_STATISTICS = 'HOST_CPU_STATISTICS'.freeze, RESOURCE_NAME_HOST_MEMORY_STATISTICS = 'HOST_MEMORY_STATISTICS'.freeze, RESOURCE_NAME_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#capacity ⇒ Float
[Required] The maximum allocated amount of the resource metric type (CPU, STORAGE).
-
#resource_name ⇒ String
[Required] Name of resource for host.
-
#usage ⇒ Float
[Required] Total amount used of the resource metric type (CPU, STORAGE).
-
#usage_change_percent ⇒ Float
[Required] Change in resource utilization in percentage.
-
#utilization_percent ⇒ Float
[Required] Resource utilization in percentage.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostResourceStatistics
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HostResourceStatistics
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.usage = attributes[:'usage'] if attributes[:'usage'] self.capacity = attributes[:'capacity'] if attributes[:'capacity'] self.utilization_percent = attributes[:'utilizationPercent'] if attributes[:'utilizationPercent'] raise 'You cannot provide both :utilizationPercent and :utilization_percent' if attributes.key?(:'utilizationPercent') && attributes.key?(:'utilization_percent') self.utilization_percent = attributes[:'utilization_percent'] if attributes[:'utilization_percent'] self.usage_change_percent = attributes[:'usageChangePercent'] if attributes[:'usageChangePercent'] raise 'You cannot provide both :usageChangePercent and :usage_change_percent' if attributes.key?(:'usageChangePercent') && attributes.key?(:'usage_change_percent') self.usage_change_percent = attributes[:'usage_change_percent'] if attributes[:'usage_change_percent'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] end |
Instance Attribute Details
#capacity ⇒ Float
[Required] The maximum allocated amount of the resource metric type (CPU, STORAGE).
27 28 29 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 27 def capacity @capacity end |
#resource_name ⇒ String
[Required] Name of resource for host
40 41 42 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 40 def resource_name @resource_name end |
#usage ⇒ Float
[Required] Total amount used of the resource metric type (CPU, STORAGE).
22 23 24 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 22 def usage @usage end |
#usage_change_percent ⇒ Float
[Required] Change in resource utilization in percentage
36 37 38 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 36 def usage_change_percent @usage_change_percent end |
#utilization_percent ⇒ Float
[Required] Resource utilization in percentage.
32 33 34 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 32 def utilization_percent @utilization_percent end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'usage': :'usage', 'capacity': :'capacity', 'utilization_percent': :'utilizationPercent', 'usage_change_percent': :'usageChangePercent', 'resource_name': :'resourceName' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 73 def self.get_subtype(object_hash) type = object_hash[:'resourceName'] # rubocop:disable Style/SymbolLiteral return 'OCI::Opsi::Models::HostMemoryStatistics' if type == 'HOST_MEMORY_STATISTICS' return 'OCI::Opsi::Models::HostCpuStatistics' if type == 'HOST_CPU_STATISTICS' # TODO: Log a warning when the subtype is not found. 'OCI::Opsi::Models::HostResourceStatistics' end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'usage': :'Float', 'capacity': :'Float', 'utilization_percent': :'Float', 'usage_change_percent': :'Float', 'resource_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 144 def ==(other) return true if equal?(other) self.class == other.class && usage == other.usage && capacity == other.capacity && utilization_percent == other.utilization_percent && usage_change_percent == other.usage_change_percent && resource_name == other.resource_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 178 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
158 159 160 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 158 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 167 def hash [usage, capacity, utilization_percent, usage_change_percent, resource_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 211 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
205 206 207 |
# File 'lib/oci/opsi/models/host_resource_statistics.rb', line 205 def to_s to_hash.to_s end |