Class: OCI::Opsi::Models::ImportableEnterpriseManagerEntity
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::ImportableEnterpriseManagerEntity
- Defined in:
- lib/oci/opsi/models/importable_enterprise_manager_entity.rb
Overview
An Enterprise Manager entity that can be imported into Operations Insights.
Instance Attribute Summary collapse
-
#enterprise_manager_entity_identifier ⇒ String
[Required] Enterprise Manager Entity Unique Identifier.
-
#enterprise_manager_entity_name ⇒ String
[Required] Enterprise Manager Entity Name.
-
#enterprise_manager_entity_type ⇒ String
[Required] Enterprise Manager Entity Type.
-
#enterprise_manager_identifier ⇒ String
[Required] Enterprise Manager Unique Identifier.
-
#opsi_entity_type ⇒ String
Operations Insights internal representation of the resource type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImportableEnterpriseManagerEntity
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ImportableEnterpriseManagerEntity
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.enterprise_manager_identifier = attributes[:'enterpriseManagerIdentifier'] if attributes[:'enterpriseManagerIdentifier'] raise 'You cannot provide both :enterpriseManagerIdentifier and :enterprise_manager_identifier' if attributes.key?(:'enterpriseManagerIdentifier') && attributes.key?(:'enterprise_manager_identifier') self.enterprise_manager_identifier = attributes[:'enterprise_manager_identifier'] if attributes[:'enterprise_manager_identifier'] self.enterprise_manager_entity_name = attributes[:'enterpriseManagerEntityName'] if attributes[:'enterpriseManagerEntityName'] raise 'You cannot provide both :enterpriseManagerEntityName and :enterprise_manager_entity_name' if attributes.key?(:'enterpriseManagerEntityName') && attributes.key?(:'enterprise_manager_entity_name') self.enterprise_manager_entity_name = attributes[:'enterprise_manager_entity_name'] if attributes[:'enterprise_manager_entity_name'] self.enterprise_manager_entity_type = attributes[:'enterpriseManagerEntityType'] if attributes[:'enterpriseManagerEntityType'] raise 'You cannot provide both :enterpriseManagerEntityType and :enterprise_manager_entity_type' if attributes.key?(:'enterpriseManagerEntityType') && attributes.key?(:'enterprise_manager_entity_type') self.enterprise_manager_entity_type = attributes[:'enterprise_manager_entity_type'] if attributes[:'enterprise_manager_entity_type'] self.enterprise_manager_entity_identifier = attributes[:'enterpriseManagerEntityIdentifier'] if attributes[:'enterpriseManagerEntityIdentifier'] raise 'You cannot provide both :enterpriseManagerEntityIdentifier and :enterprise_manager_entity_identifier' if attributes.key?(:'enterpriseManagerEntityIdentifier') && attributes.key?(:'enterprise_manager_entity_identifier') self.enterprise_manager_entity_identifier = attributes[:'enterprise_manager_entity_identifier'] if attributes[:'enterprise_manager_entity_identifier'] self.opsi_entity_type = attributes[:'opsiEntityType'] if attributes[:'opsiEntityType'] raise 'You cannot provide both :opsiEntityType and :opsi_entity_type' if attributes.key?(:'opsiEntityType') && attributes.key?(:'opsi_entity_type') self.opsi_entity_type = attributes[:'opsi_entity_type'] if attributes[:'opsi_entity_type'] end |
Instance Attribute Details
#enterprise_manager_entity_identifier ⇒ String
[Required] Enterprise Manager Entity Unique Identifier
24 25 26 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 24 def enterprise_manager_entity_identifier @enterprise_manager_entity_identifier end |
#enterprise_manager_entity_name ⇒ String
[Required] Enterprise Manager Entity Name
16 17 18 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 16 def enterprise_manager_entity_name @enterprise_manager_entity_name end |
#enterprise_manager_entity_type ⇒ String
[Required] Enterprise Manager Entity Type
20 21 22 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 20 def enterprise_manager_entity_type @enterprise_manager_entity_type end |
#enterprise_manager_identifier ⇒ String
[Required] Enterprise Manager Unique Identifier
12 13 14 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 12 def enterprise_manager_identifier @enterprise_manager_identifier end |
#opsi_entity_type ⇒ String
Operations Insights internal representation of the resource type.
28 29 30 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 28 def opsi_entity_type @opsi_entity_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'enterprise_manager_identifier': :'enterpriseManagerIdentifier', 'enterprise_manager_entity_name': :'enterpriseManagerEntityName', 'enterprise_manager_entity_type': :'enterpriseManagerEntityType', 'enterprise_manager_entity_identifier': :'enterpriseManagerEntityIdentifier', 'opsi_entity_type': :'opsiEntityType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'enterprise_manager_identifier': :'String', 'enterprise_manager_entity_name': :'String', 'enterprise_manager_entity_type': :'String', 'enterprise_manager_entity_identifier': :'String', 'opsi_entity_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && enterprise_manager_identifier == other.enterprise_manager_identifier && enterprise_manager_entity_name == other.enterprise_manager_entity_name && enterprise_manager_entity_type == other.enterprise_manager_entity_type && enterprise_manager_entity_identifier == other.enterprise_manager_entity_identifier && opsi_entity_type == other.opsi_entity_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 134 def hash [enterprise_manager_identifier, enterprise_manager_entity_name, enterprise_manager_entity_type, enterprise_manager_entity_identifier, opsi_entity_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/opsi/models/importable_enterprise_manager_entity.rb', line 172 def to_s to_hash.to_s end |