Class: OCI::Opsi::Models::InstanceMetrics
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::InstanceMetrics
- Defined in:
- lib/oci/opsi/models/instance_metrics.rb
Overview
Object containing instance metrics.
Instance Attribute Summary collapse
-
#capacity ⇒ Float
The maximum allocated amount of the resource metric type (CPU, STORAGE).
-
#host_name ⇒ String
The hostname of the database insight resource.
-
#instance_name ⇒ String
The instance name of the database insight resource.
-
#usage ⇒ Float
Total amount used of the resource metric type (CPU, STORAGE).
-
#usage_change_percent ⇒ Float
Change in resource utilization in percentage.
-
#utilization_percent ⇒ Float
Resource utilization in percentage.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InstanceMetrics
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ InstanceMetrics
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.host_name = attributes[:'hostName'] if attributes[:'hostName'] raise 'You cannot provide both :hostName and :host_name' if attributes.key?(:'hostName') && attributes.key?(:'host_name') self.host_name = attributes[:'host_name'] if attributes[:'host_name'] self.instance_name = attributes[:'instanceName'] if attributes[:'instanceName'] raise 'You cannot provide both :instanceName and :instance_name' if attributes.key?(:'instanceName') && attributes.key?(:'instance_name') self.instance_name = attributes[:'instance_name'] if attributes[:'instance_name'] self.usage = attributes[:'usage'] if attributes[:'usage'] self.capacity = attributes[:'capacity'] if attributes[:'capacity'] self.utilization_percent = attributes[:'utilizationPercent'] if attributes[:'utilizationPercent'] raise 'You cannot provide both :utilizationPercent and :utilization_percent' if attributes.key?(:'utilizationPercent') && attributes.key?(:'utilization_percent') self.utilization_percent = attributes[:'utilization_percent'] if attributes[:'utilization_percent'] self.usage_change_percent = attributes[:'usageChangePercent'] if attributes[:'usageChangePercent'] raise 'You cannot provide both :usageChangePercent and :usage_change_percent' if attributes.key?(:'usageChangePercent') && attributes.key?(:'usage_change_percent') self.usage_change_percent = attributes[:'usage_change_percent'] if attributes[:'usage_change_percent'] end |
Instance Attribute Details
#capacity ⇒ Float
The maximum allocated amount of the resource metric type (CPU, STORAGE).
26 27 28 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 26 def capacity @capacity end |
#host_name ⇒ String
The hostname of the database insight resource.
12 13 14 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 12 def host_name @host_name end |
#instance_name ⇒ String
The instance name of the database insight resource.
16 17 18 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 16 def instance_name @instance_name end |
#usage ⇒ Float
Total amount used of the resource metric type (CPU, STORAGE).
21 22 23 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 21 def usage @usage end |
#usage_change_percent ⇒ Float
Change in resource utilization in percentage
34 35 36 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 34 def usage_change_percent @usage_change_percent end |
#utilization_percent ⇒ Float
Resource utilization in percentage
30 31 32 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 30 def utilization_percent @utilization_percent end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'host_name': :'hostName', 'instance_name': :'instanceName', 'usage': :'usage', 'capacity': :'capacity', 'utilization_percent': :'utilizationPercent', 'usage_change_percent': :'usageChangePercent' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'host_name': :'String', 'instance_name': :'String', 'usage': :'Float', 'capacity': :'Float', 'utilization_percent': :'Float', 'usage_change_percent': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 118 def ==(other) return true if equal?(other) self.class == other.class && host_name == other.host_name && instance_name == other.instance_name && usage == other.usage && capacity == other.capacity && utilization_percent == other.utilization_percent && usage_change_percent == other.usage_change_percent end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 153 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
133 134 135 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 133 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 142 def hash [host_name, instance_name, usage, capacity, utilization_percent, usage_change_percent].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
180 181 182 |
# File 'lib/oci/opsi/models/instance_metrics.rb', line 180 def to_s to_hash.to_s end |