Class: OCI::Opsi::Models::MacsManagedExternalDatabaseConfigurationSummary
- Inherits:
-
DatabaseConfigurationSummary
- Object
- DatabaseConfigurationSummary
- OCI::Opsi::Models::MacsManagedExternalDatabaseConfigurationSummary
- Defined in:
- lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb
Overview
Configuration Summary of a Macs Managed External database.
Constant Summary
Constants inherited from DatabaseConfigurationSummary
DatabaseConfigurationSummary::ENTITY_SOURCE_ENUM
Instance Attribute Summary collapse
-
#connector_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of External Database Connector.
-
#database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
-
#instances ⇒ Array<OCI::Opsi::Models::HostInstanceMap>
[Required] Array of hostname and instance name.
-
#management_agent_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Management Agent.
Attributes inherited from DatabaseConfigurationSummary
#compartment_id, #database_display_name, #database_insight_id, #database_name, #database_type, #database_version, #defined_tags, #entity_source, #freeform_tags, #processor_count
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MacsManagedExternalDatabaseConfigurationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DatabaseConfigurationSummary
Constructor Details
#initialize(attributes = {}) ⇒ MacsManagedExternalDatabaseConfigurationSummary
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['entitySource'] = 'MACS_MANAGED_EXTERNAL_DATABASE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.management_agent_id = attributes[:'managementAgentId'] if attributes[:'managementAgentId'] raise 'You cannot provide both :managementAgentId and :management_agent_id' if attributes.key?(:'managementAgentId') && attributes.key?(:'management_agent_id') self.management_agent_id = attributes[:'management_agent_id'] if attributes[:'management_agent_id'] self.connector_id = attributes[:'connectorId'] if attributes[:'connectorId'] raise 'You cannot provide both :connectorId and :connector_id' if attributes.key?(:'connectorId') && attributes.key?(:'connector_id') self.connector_id = attributes[:'connector_id'] if attributes[:'connector_id'] self.instances = attributes[:'instances'] if attributes[:'instances'] end |
Instance Attribute Details
#connector_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of External Database Connector
21 22 23 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 21 def connector_id @connector_id end |
#database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
13 14 15 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 13 def database_id @database_id end |
#instances ⇒ Array<OCI::Opsi::Models::HostInstanceMap>
[Required] Array of hostname and instance name.
25 26 27 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 25 def instances @instances end |
#management_agent_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Management Agent
17 18 19 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 17 def management_agent_id @management_agent_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'database_insight_id': :'databaseInsightId', 'entity_source': :'entitySource', 'compartment_id': :'compartmentId', 'database_name': :'databaseName', 'database_display_name': :'databaseDisplayName', 'database_type': :'databaseType', 'database_version': :'databaseVersion', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'processor_count': :'processorCount', 'database_id': :'databaseId', 'management_agent_id': :'managementAgentId', 'connector_id': :'connectorId', 'instances': :'instances' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'database_insight_id': :'String', 'entity_source': :'String', 'compartment_id': :'String', 'database_name': :'String', 'database_display_name': :'String', 'database_type': :'String', 'database_version': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'processor_count': :'Integer', 'database_id': :'String', 'management_agent_id': :'String', 'connector_id': :'String', 'instances': :'Array<OCI::Opsi::Models::HostInstanceMap>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 128 def ==(other) return true if equal?(other) self.class == other.class && database_insight_id == other.database_insight_id && entity_source == other.entity_source && compartment_id == other.compartment_id && database_name == other.database_name && database_display_name == other.database_display_name && database_type == other.database_type && database_version == other.database_version && == other. && == other. && processor_count == other.processor_count && database_id == other.database_id && management_agent_id == other.management_agent_id && connector_id == other.connector_id && instances == other.instances end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 171 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
151 152 153 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 151 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 160 def hash [database_insight_id, entity_source, compartment_id, database_name, database_display_name, database_type, database_version, , , processor_count, database_id, management_agent_id, connector_id, instances].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
198 199 200 |
# File 'lib/oci/opsi/models/macs_managed_external_database_configuration_summary.rb', line 198 def to_s to_hash.to_s end |