Class: OCI::Opsi::Models::OperationsInsightsPrivateEndpoint

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/operations_insights_private_endpoint.rb

Overview

A private endpoint that allows Operation Insights services to connect to databases in a customer's virtual cloud network (VCN).

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OperationsInsightsPrivateEndpoint

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :vcn_id (String)

    The value to assign to the #vcn_id property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :private_ip (String)

    The value to assign to the #private_ip property

  • :description (String)

    The value to assign to the #description property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :private_endpoint_status_details (String)

    The value to assign to the #private_endpoint_status_details property

  • :is_used_for_rac_dbs (BOOLEAN)

    The value to assign to the #is_used_for_rac_dbs property

  • :nsg_ids (Array<String>)

    The value to assign to the #nsg_ids property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 164

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId']

  raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id')

  self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.private_ip = attributes[:'privateIp'] if attributes[:'privateIp']

  raise 'You cannot provide both :privateIp and :private_ip' if attributes.key?(:'privateIp') && attributes.key?(:'private_ip')

  self.private_ip = attributes[:'private_ip'] if attributes[:'private_ip']

  self.description = attributes[:'description'] if attributes[:'description']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.private_endpoint_status_details = attributes[:'privateEndpointStatusDetails'] if attributes[:'privateEndpointStatusDetails']

  raise 'You cannot provide both :privateEndpointStatusDetails and :private_endpoint_status_details' if attributes.key?(:'privateEndpointStatusDetails') && attributes.key?(:'private_endpoint_status_details')

  self.private_endpoint_status_details = attributes[:'private_endpoint_status_details'] if attributes[:'private_endpoint_status_details']

  self.is_used_for_rac_dbs = attributes[:'isUsedForRacDbs'] unless attributes[:'isUsedForRacDbs'].nil?
  self.is_used_for_rac_dbs = false if is_used_for_rac_dbs.nil? && !attributes.key?(:'isUsedForRacDbs') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isUsedForRacDbs and :is_used_for_rac_dbs' if attributes.key?(:'isUsedForRacDbs') && attributes.key?(:'is_used_for_rac_dbs')

  self.is_used_for_rac_dbs = attributes[:'is_used_for_rac_dbs'] unless attributes[:'is_used_for_rac_dbs'].nil?
  self.is_used_for_rac_dbs = false if is_used_for_rac_dbs.nil? && !attributes.key?(:'isUsedForRacDbs') && !attributes.key?(:'is_used_for_rac_dbs') # rubocop:disable Style/StringLiterals

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The compartment OCID of the Private service accessed database.

Returns:

  • (String)


32
33
34
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 32

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


86
87
88
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 86

def defined_tags
  @defined_tags
end

#descriptionString

The description of the private endpoint.

Returns:

  • (String)


49
50
51
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 49

def description
  @description
end

#display_nameString

**[Required]** The display name of the private endpoint.

Returns:

  • (String)


28
29
30
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 28

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


80
81
82
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 80

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The OCID of the Private service accessed database.

Returns:

  • (String)


24
25
26
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 24

def id
  @id
end

#is_used_for_rac_dbsBOOLEAN

The flag is to identify if private endpoint is used for rac database or not

Returns:

  • (BOOLEAN)


69
70
71
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 69

def is_used_for_rac_dbs
  @is_used_for_rac_dbs
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


61
62
63
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 61

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the private endpoint.

Returns:

  • (String)


57
58
59
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 57

def lifecycle_state
  @lifecycle_state
end

#nsg_idsArray<String>

The OCIDs of the network security groups that the private endpoint belongs to.

Returns:

  • (Array<String>)


74
75
76
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 74

def nsg_ids
  @nsg_ids
end

#private_endpoint_status_detailsString

A message describing the status of the private endpoint connection of this resource. For example, it can be used to provide actionable information about the validity of the private endpoint connection.

Returns:

  • (String)


65
66
67
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 65

def private_endpoint_status_details
  @private_endpoint_status_details
end

#private_ipString

The private IP addresses assigned to the private endpoint. All IP addresses will be concatenated if it is RAC DBs.

Returns:

  • (String)


45
46
47
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 45

def private_ip
  @private_ip
end

#subnet_idString

**[Required]** The OCID of the subnet.

Returns:

  • (String)


40
41
42
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 40

def subnet_id
  @subnet_id
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


92
93
94
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 92

def system_tags
  @system_tags
end

#time_createdDateTime

The date and time the private endpoint was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


53
54
55
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 53

def time_created
  @time_created
end

#vcn_idString

**[Required]** The OCID of the VCN.

Returns:

  • (String)


36
37
38
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 36

def vcn_id
  @vcn_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 95

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'vcn_id': :'vcnId',
    'subnet_id': :'subnetId',
    'private_ip': :'privateIp',
    'description': :'description',
    'time_created': :'timeCreated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'private_endpoint_status_details': :'privateEndpointStatusDetails',
    'is_used_for_rac_dbs': :'isUsedForRacDbs',
    'nsg_ids': :'nsgIds',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 119

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'vcn_id': :'String',
    'subnet_id': :'String',
    'private_ip': :'String',
    'description': :'String',
    'time_created': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'private_endpoint_status_details': :'String',
    'is_used_for_rac_dbs': :'BOOLEAN',
    'nsg_ids': :'Array<String>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 281

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    vcn_id == other.vcn_id &&
    subnet_id == other.subnet_id &&
    private_ip == other.private_ip &&
    description == other.description &&
    time_created == other.time_created &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    private_endpoint_status_details == other.private_endpoint_status_details &&
    is_used_for_rac_dbs == other.is_used_for_rac_dbs &&
    nsg_ids == other.nsg_ids &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 326

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


306
307
308
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 306

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



315
316
317
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 315

def hash
  [id, display_name, compartment_id, vcn_id, subnet_id, private_ip, description, time_created, lifecycle_state, lifecycle_details, private_endpoint_status_details, is_used_for_rac_dbs, nsg_ids, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



359
360
361
362
363
364
365
366
367
368
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 359

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



353
354
355
# File 'lib/oci/opsi/models/operations_insights_private_endpoint.rb', line 353

def to_s
  to_hash.to_s
end