Class: OCI::Opsi::Models::OperationsInsightsPrivateEndpointSummary
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::OperationsInsightsPrivateEndpointSummary
- Defined in:
- lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb
Overview
Summary of a Operation Insights private endpoint.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The compartment OCID of the Private service accessed database.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the private endpoint.
-
#display_name ⇒ String
**[Required]** The display name of the private endpoint.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The OCID of the Private service accessed database.
-
#is_used_for_rac_dbs ⇒ BOOLEAN
The flag to identify if private endpoint is used for rac database or not.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
**[Required]** Private endpoint lifecycle states.
-
#private_endpoint_status_details ⇒ String
A message describing the status of the private endpoint connection of this resource.
-
#subnet_id ⇒ String
**[Required]** The OCID of the subnet.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
**[Required]** The date and time the private endpoint was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcn_id ⇒ String
**[Required]** The OCID of the VCN.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperationsInsightsPrivateEndpointSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OperationsInsightsPrivateEndpointSummary
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 148 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.is_used_for_rac_dbs = attributes[:'isUsedForRacDbs'] unless attributes[:'isUsedForRacDbs'].nil? self.is_used_for_rac_dbs = false if is_used_for_rac_dbs.nil? && !attributes.key?(:'isUsedForRacDbs') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isUsedForRacDbs and :is_used_for_rac_dbs' if attributes.key?(:'isUsedForRacDbs') && attributes.key?(:'is_used_for_rac_dbs') self.is_used_for_rac_dbs = attributes[:'is_used_for_rac_dbs'] unless attributes[:'is_used_for_rac_dbs'].nil? self.is_used_for_rac_dbs = false if is_used_for_rac_dbs.nil? && !attributes.key?(:'isUsedForRacDbs') && !attributes.key?(:'is_used_for_rac_dbs') # rubocop:disable Style/StringLiterals self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.private_endpoint_status_details = attributes[:'privateEndpointStatusDetails'] if attributes[:'privateEndpointStatusDetails'] raise 'You cannot provide both :privateEndpointStatusDetails and :private_endpoint_status_details' if attributes.key?(:'privateEndpointStatusDetails') && attributes.key?(:'private_endpoint_status_details') self.private_endpoint_status_details = attributes[:'private_endpoint_status_details'] if attributes[:'private_endpoint_status_details'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The compartment OCID of the Private service accessed database.
32 33 34 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 32 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
64 65 66 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 64 def @defined_tags end |
#description ⇒ String
The description of the private endpoint.
48 49 50 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 48 def description @description end |
#display_name ⇒ String
**[Required]** The display name of the private endpoint.
28 29 30 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 28 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
58 59 60 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 58 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the Private service accessed database.
24 25 26 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 24 def id @id end |
#is_used_for_rac_dbs ⇒ BOOLEAN
The flag to identify if private endpoint is used for rac database or not
44 45 46 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 44 def is_used_for_rac_dbs @is_used_for_rac_dbs end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
78 79 80 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 78 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** Private endpoint lifecycle states
74 75 76 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 74 def lifecycle_state @lifecycle_state end |
#private_endpoint_status_details ⇒ String
A message describing the status of the private endpoint connection of this resource. For example, it can be used to provide actionable information about the validity of the private endpoint connection.
82 83 84 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 82 def private_endpoint_status_details @private_endpoint_status_details end |
#subnet_id ⇒ String
**[Required]** The OCID of the subnet.
40 41 42 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 40 def subnet_id @subnet_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"free-tier-retained": "true"}`
70 71 72 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 70 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The date and time the private endpoint was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
52 53 54 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 52 def time_created @time_created end |
#vcn_id ⇒ String
**[Required]** The OCID of the VCN.
36 37 38 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 36 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 85 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'vcn_id': :'vcnId', 'subnet_id': :'subnetId', 'is_used_for_rac_dbs': :'isUsedForRacDbs', 'description': :'description', 'time_created': :'timeCreated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'private_endpoint_status_details': :'privateEndpointStatusDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 107 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'vcn_id': :'String', 'subnet_id': :'String', 'is_used_for_rac_dbs': :'BOOLEAN', 'description': :'String', 'time_created': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'private_endpoint_status_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 253 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && vcn_id == other.vcn_id && subnet_id == other.subnet_id && is_used_for_rac_dbs == other.is_used_for_rac_dbs && description == other.description && time_created == other.time_created && == other. && == other. && == other. && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && private_endpoint_status_details == other.private_endpoint_status_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 296 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
276 277 278 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 276 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 285 def hash [id, display_name, compartment_id, vcn_id, subnet_id, is_used_for_rac_dbs, description, time_created, , , , lifecycle_state, lifecycle_details, private_endpoint_status_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 338 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
323 324 325 |
# File 'lib/oci/opsi/models/operations_insights_private_endpoint_summary.rb', line 323 def to_s to_hash.to_s end |