Class: OCI::Opsi::Models::OperationsInsightsWarehouseUser
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::OperationsInsightsWarehouseUser
- Defined in:
- lib/oci/opsi/models/operations_insights_warehouse_user.rb
Overview
OPSI warehouse User.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
-
#connection_password ⇒ String
User provided connection password for the AWR Data, Enterprise Manager Data and Operations Insights OPSI Hub.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Hub User OCID.
-
#is_awr_data_access ⇒ BOOLEAN
[Required] Indicate whether user has access to AWR data.
-
#is_em_data_access ⇒ BOOLEAN
Indicate whether user has access to EM data.
-
#is_opsi_data_access ⇒ BOOLEAN
Indicate whether user has access to OPSI data.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
[Required] Possible lifecycle states.
-
#name ⇒ String
[Required] Username for schema which would have access to AWR Data, Enterprise Manager Data and Operations Insights OPSI Hub.
-
#operations_insights_warehouse_id ⇒ String
[Required] OPSI Warehouse OCID.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
[Required] The time at which the resource was first created.
-
#time_updated ⇒ DateTime
The time at which the resource was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperationsInsightsWarehouseUser
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OperationsInsightsWarehouseUser
Initializes the object
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 154 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operations_insights_warehouse_id = attributes[:'operationsInsightsWarehouseId'] if attributes[:'operationsInsightsWarehouseId'] raise 'You cannot provide both :operationsInsightsWarehouseId and :operations_insights_warehouse_id' if attributes.key?(:'operationsInsightsWarehouseId') && attributes.key?(:'operations_insights_warehouse_id') self.operations_insights_warehouse_id = attributes[:'operations_insights_warehouse_id'] if attributes[:'operations_insights_warehouse_id'] self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.connection_password = attributes[:'connectionPassword'] if attributes[:'connectionPassword'] raise 'You cannot provide both :connectionPassword and :connection_password' if attributes.key?(:'connectionPassword') && attributes.key?(:'connection_password') self.connection_password = attributes[:'connection_password'] if attributes[:'connection_password'] self.is_awr_data_access = attributes[:'isAwrDataAccess'] unless attributes[:'isAwrDataAccess'].nil? raise 'You cannot provide both :isAwrDataAccess and :is_awr_data_access' if attributes.key?(:'isAwrDataAccess') && attributes.key?(:'is_awr_data_access') self.is_awr_data_access = attributes[:'is_awr_data_access'] unless attributes[:'is_awr_data_access'].nil? self.is_em_data_access = attributes[:'isEmDataAccess'] unless attributes[:'isEmDataAccess'].nil? raise 'You cannot provide both :isEmDataAccess and :is_em_data_access' if attributes.key?(:'isEmDataAccess') && attributes.key?(:'is_em_data_access') self.is_em_data_access = attributes[:'is_em_data_access'] unless attributes[:'is_em_data_access'].nil? self.is_opsi_data_access = attributes[:'isOpsiDataAccess'] unless attributes[:'isOpsiDataAccess'].nil? raise 'You cannot provide both :isOpsiDataAccess and :is_opsi_data_access' if attributes.key?(:'isOpsiDataAccess') && attributes.key?(:'is_opsi_data_access') self.is_opsi_data_access = attributes[:'is_opsi_data_access'] unless attributes[:'is_opsi_data_access'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
31 32 33 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 31 def compartment_id @compartment_id end |
#connection_password ⇒ String
User provided connection password for the AWR Data, Enterprise Manager Data and Operations Insights OPSI Hub.
39 40 41 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 39 def connection_password @connection_password end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
63 64 65 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 63 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
57 58 59 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 57 def end |
#id ⇒ String
[Required] Hub User OCID
27 28 29 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 27 def id @id end |
#is_awr_data_access ⇒ BOOLEAN
[Required] Indicate whether user has access to AWR data.
43 44 45 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 43 def is_awr_data_access @is_awr_data_access end |
#is_em_data_access ⇒ BOOLEAN
Indicate whether user has access to EM data.
47 48 49 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 47 def is_em_data_access @is_em_data_access end |
#is_opsi_data_access ⇒ BOOLEAN
Indicate whether user has access to OPSI data.
51 52 53 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 51 def is_opsi_data_access @is_opsi_data_access end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
85 86 87 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 85 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] Possible lifecycle states
81 82 83 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 81 def lifecycle_state @lifecycle_state end |
#name ⇒ String
[Required] Username for schema which would have access to AWR Data, Enterprise Manager Data and Operations Insights OPSI Hub.
35 36 37 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 35 def name @name end |
#operations_insights_warehouse_id ⇒ String
[Required] OPSI Warehouse OCID
23 24 25 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 23 def operations_insights_warehouse_id @operations_insights_warehouse_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"free-tier-retained": "true"}`
69 70 71 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 69 def end |
#time_created ⇒ DateTime
[Required] The time at which the resource was first created. An RFC3339 formatted datetime string
73 74 75 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 73 def time_created @time_created end |
#time_updated ⇒ DateTime
The time at which the resource was last updated. An RFC3339 formatted datetime string
77 78 79 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 77 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 88 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operations_insights_warehouse_id': :'operationsInsightsWarehouseId', 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'connection_password': :'connectionPassword', 'is_awr_data_access': :'isAwrDataAccess', 'is_em_data_access': :'isEmDataAccess', 'is_opsi_data_access': :'isOpsiDataAccess', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 111 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operations_insights_warehouse_id': :'String', 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'connection_password': :'String', 'is_awr_data_access': :'BOOLEAN', 'is_em_data_access': :'BOOLEAN', 'is_opsi_data_access': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 263 def ==(other) return true if equal?(other) self.class == other.class && operations_insights_warehouse_id == other.operations_insights_warehouse_id && id == other.id && compartment_id == other.compartment_id && name == other.name && connection_password == other.connection_password && is_awr_data_access == other.is_awr_data_access && is_em_data_access == other.is_em_data_access && is_opsi_data_access == other.is_opsi_data_access && == other. && == other. && == other. && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 307 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
287 288 289 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 287 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
296 297 298 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 296 def hash [operations_insights_warehouse_id, id, compartment_id, name, connection_password, is_awr_data_access, is_em_data_access, is_opsi_data_access, , , , time_created, time_updated, lifecycle_state, lifecycle_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
340 341 342 343 344 345 346 347 348 349 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 340 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
334 335 336 |
# File 'lib/oci/opsi/models/operations_insights_warehouse_user.rb', line 334 def to_s to_hash.to_s end |