Class: OCI::Opsi::Models::OpsiDataObject

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/opsi_data_object.rb

Overview

OPSI data object. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

DATA_OBJECT_TYPE_ENUM =
[
  DATA_OBJECT_TYPE_DATABASE_INSIGHTS_DATA_OBJECT = 'DATABASE_INSIGHTS_DATA_OBJECT'.freeze,
  DATA_OBJECT_TYPE_HOST_INSIGHTS_DATA_OBJECT = 'HOST_INSIGHTS_DATA_OBJECT'.freeze,
  DATA_OBJECT_TYPE_EXADATA_INSIGHTS_DATA_OBJECT = 'EXADATA_INSIGHTS_DATA_OBJECT'.freeze,
  DATA_OBJECT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OpsiDataObject

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 93

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.data_object_type = attributes[:'dataObjectType'] if attributes[:'dataObjectType']

  raise 'You cannot provide both :dataObjectType and :data_object_type' if attributes.key?(:'dataObjectType') && attributes.key?(:'data_object_type')

  self.data_object_type = attributes[:'data_object_type'] if attributes[:'data_object_type']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self. = attributes[:'columnsMetadata'] if attributes[:'columnsMetadata']

  raise 'You cannot provide both :columnsMetadata and :columns_metadata' if attributes.key?(:'columnsMetadata') && attributes.key?(:'columns_metadata')

  self. = attributes[:'columns_metadata'] if attributes[:'columns_metadata']
end

Instance Attribute Details

#columns_metadataArray<OCI::Opsi::Models::DataObjectColumnMetadata>

**[Required]** Metadata of columns in a data object.



37
38
39
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 37

def 
  @columns_metadata
end

#data_object_typeString

**[Required]** Type of OPSI data object.

Returns:

  • (String)


25
26
27
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 25

def data_object_type
  @data_object_type
end

#descriptionString

Description of OPSI data object.

Returns:

  • (String)


33
34
35
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 33

def description
  @description
end

#display_nameString

**[Required]** User-friendly name of OPSI data object.

Returns:

  • (String)


29
30
31
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 29

def display_name
  @display_name
end

#identifierString

**[Required]** Unique identifier of OPSI data object.

Returns:

  • (String)


21
22
23
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 21

def identifier
  @identifier
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 40

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'identifier': :'identifier',
    'data_object_type': :'dataObjectType',
    'display_name': :'displayName',
    'description': :'description',
    'columns_metadata': :'columnsMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 70

def self.get_subtype(object_hash)
  type = object_hash[:'dataObjectType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Opsi::Models::HostInsightsDataObject' if type == 'HOST_INSIGHTS_DATA_OBJECT'
  return 'OCI::Opsi::Models::ExadataInsightsDataObject' if type == 'EXADATA_INSIGHTS_DATA_OBJECT'
  return 'OCI::Opsi::Models::DatabaseInsightsDataObject' if type == 'DATABASE_INSIGHTS_DATA_OBJECT'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Opsi::Models::OpsiDataObject'
end

.swagger_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 53

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'identifier': :'String',
    'data_object_type': :'String',
    'display_name': :'String',
    'description': :'String',
    'columns_metadata': :'Array<OCI::Opsi::Models::DataObjectColumnMetadata>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 142

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    identifier == other.identifier &&
    data_object_type == other.data_object_type &&
    display_name == other.display_name &&
    description == other.description &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 176

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 156

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



165
166
167
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 165

def hash
  [identifier, data_object_type, display_name, description, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



203
204
205
# File 'lib/oci/opsi/models/opsi_data_object.rb', line 203

def to_s
  to_hash.to_s
end