Class: OCI::Opsi::Models::OpsiDataObjectSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/opsi_data_object_summary.rb

Overview

Summary of an OPSI data object. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

DATA_OBJECT_TYPE_ENUM =
[
  DATA_OBJECT_TYPE_DATABASE_INSIGHTS_DATA_OBJECT = 'DATABASE_INSIGHTS_DATA_OBJECT'.freeze,
  DATA_OBJECT_TYPE_HOST_INSIGHTS_DATA_OBJECT = 'HOST_INSIGHTS_DATA_OBJECT'.freeze,
  DATA_OBJECT_TYPE_EXADATA_INSIGHTS_DATA_OBJECT = 'EXADATA_INSIGHTS_DATA_OBJECT'.freeze,
  DATA_OBJECT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OpsiDataObjectSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :identifier (String)

    The value to assign to the #identifier property

  • :data_object_type (String)

    The value to assign to the #data_object_type property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 86

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.data_object_type = attributes[:'dataObjectType'] if attributes[:'dataObjectType']

  raise 'You cannot provide both :dataObjectType and :data_object_type' if attributes.key?(:'dataObjectType') && attributes.key?(:'data_object_type')

  self.data_object_type = attributes[:'data_object_type'] if attributes[:'data_object_type']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']
end

Instance Attribute Details

#data_object_typeString

**[Required]** Type of OPSI data object.

Returns:

  • (String)


25
26
27
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 25

def data_object_type
  @data_object_type
end

#descriptionString

Description of OPSI data object.

Returns:

  • (String)


33
34
35
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 33

def description
  @description
end

#display_nameString

**[Required]** User-friendly name of OPSI data object.

Returns:

  • (String)


29
30
31
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 29

def display_name
  @display_name
end

#identifierString

**[Required]** Unique identifier of OPSI data object.

Returns:

  • (String)


21
22
23
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 21

def identifier
  @identifier
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 36

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'identifier': :'identifier',
    'data_object_type': :'dataObjectType',
    'display_name': :'displayName',
    'description': :'description'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 64

def self.get_subtype(object_hash)
  type = object_hash[:'dataObjectType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Opsi::Models::HostInsightsDataObjectSummary' if type == 'HOST_INSIGHTS_DATA_OBJECT'
  return 'OCI::Opsi::Models::DatabaseInsightsDataObjectSummary' if type == 'DATABASE_INSIGHTS_DATA_OBJECT'
  return 'OCI::Opsi::Models::ExadataInsightsDataObjectSummary' if type == 'EXADATA_INSIGHTS_DATA_OBJECT'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Opsi::Models::OpsiDataObjectSummary'
end

.swagger_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
57
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 48

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'identifier': :'String',
    'data_object_type': :'String',
    'display_name': :'String',
    'description': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



129
130
131
132
133
134
135
136
137
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 129

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    identifier == other.identifier &&
    data_object_type == other.data_object_type &&
    display_name == other.display_name &&
    description == other.description
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 162

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


142
143
144
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 142

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



151
152
153
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 151

def hash
  [identifier, data_object_type, display_name, description].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



189
190
191
# File 'lib/oci/opsi/models/opsi_data_object_summary.rb', line 189

def to_s
  to_hash.to_s
end