Class: OCI::Opsi::Models::PeComanagedDatabaseInsight

Inherits:
DatabaseInsight show all
Defined in:
lib/oci/opsi/models/pe_comanaged_database_insight.rb

Overview

Database insight resource.

Constant Summary

Constants inherited from DatabaseInsight

DatabaseInsight::ENTITY_SOURCE_ENUM, DatabaseInsight::LIFECYCLE_STATE_ENUM, DatabaseInsight::STATUS_ENUM

Instance Attribute Summary collapse

Attributes inherited from DatabaseInsight

#compartment_id, #database_connection_status_details, #database_type, #database_version, #defined_tags, #entity_source, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #processor_count, #status, #system_tags, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DatabaseInsight

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ PeComanagedDatabaseInsight

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 124

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['entitySource'] = 'PE_COMANAGED_DATABASE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.opsi_private_endpoint_id = attributes[:'opsiPrivateEndpointId'] if attributes[:'opsiPrivateEndpointId']

  raise 'You cannot provide both :opsiPrivateEndpointId and :opsi_private_endpoint_id' if attributes.key?(:'opsiPrivateEndpointId') && attributes.key?(:'opsi_private_endpoint_id')

  self.opsi_private_endpoint_id = attributes[:'opsi_private_endpoint_id'] if attributes[:'opsi_private_endpoint_id']

  self.connection_details = attributes[:'connectionDetails'] if attributes[:'connectionDetails']

  raise 'You cannot provide both :connectionDetails and :connection_details' if attributes.key?(:'connectionDetails') && attributes.key?(:'connection_details')

  self.connection_details = attributes[:'connection_details'] if attributes[:'connection_details']

  self.credential_details = attributes[:'credentialDetails'] if attributes[:'credentialDetails']

  raise 'You cannot provide both :credentialDetails and :credential_details' if attributes.key?(:'credentialDetails') && attributes.key?(:'credential_details')

  self.credential_details = attributes[:'credential_details'] if attributes[:'credential_details']

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.database_name = attributes[:'databaseName'] if attributes[:'databaseName']

  raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name')

  self.database_name = attributes[:'database_name'] if attributes[:'database_name']

  self.database_display_name = attributes[:'databaseDisplayName'] if attributes[:'databaseDisplayName']

  raise 'You cannot provide both :databaseDisplayName and :database_display_name' if attributes.key?(:'databaseDisplayName') && attributes.key?(:'database_display_name')

  self.database_display_name = attributes[:'database_display_name'] if attributes[:'database_display_name']

  self.database_resource_type = attributes[:'databaseResourceType'] if attributes[:'databaseResourceType']

  raise 'You cannot provide both :databaseResourceType and :database_resource_type' if attributes.key?(:'databaseResourceType') && attributes.key?(:'database_resource_type')

  self.database_resource_type = attributes[:'database_resource_type'] if attributes[:'database_resource_type']
end

Instance Attribute Details

#connection_detailsOCI::Opsi::Models::PeComanagedDatabaseConnectionDetails



16
17
18
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 16

def connection_details
  @connection_details
end

#credential_detailsOCI::Opsi::Models::CredentialDetails



19
20
21
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 19

def credential_details
  @credential_details
end

#database_display_nameString

Display name of database

Returns:

  • (String)


31
32
33
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 31

def database_display_name
  @database_display_name
end

#database_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.

Returns:

  • (String)


23
24
25
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 23

def database_id
  @database_id
end

#database_nameString

**[Required]** Name of database

Returns:

  • (String)


27
28
29
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 27

def database_name
  @database_name
end

#database_resource_typeString

**[Required]** OCI database resource type

Returns:

  • (String)


35
36
37
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 35

def database_resource_type
  @database_resource_type
end

#opsi_private_endpoint_idString

Returns:

  • (String)


13
14
15
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 13

def opsi_private_endpoint_id
  @opsi_private_endpoint_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 38

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'entitySource',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'status': :'status',
    'database_type': :'databaseType',
    'database_version': :'databaseVersion',
    'processor_count': :'processorCount',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'database_connection_status_details': :'databaseConnectionStatusDetails',
    'opsi_private_endpoint_id': :'opsiPrivateEndpointId',
    'connection_details': :'connectionDetails',
    'credential_details': :'credentialDetails',
    'database_id': :'databaseId',
    'database_name': :'databaseName',
    'database_display_name': :'databaseDisplayName',
    'database_resource_type': :'databaseResourceType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 68

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'String',
    'id': :'String',
    'compartment_id': :'String',
    'status': :'String',
    'database_type': :'String',
    'database_version': :'String',
    'processor_count': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'database_connection_status_details': :'String',
    'opsi_private_endpoint_id': :'String',
    'connection_details': :'OCI::Opsi::Models::PeComanagedDatabaseConnectionDetails',
    'credential_details': :'OCI::Opsi::Models::CredentialDetails',
    'database_id': :'String',
    'database_name': :'String',
    'database_display_name': :'String',
    'database_resource_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 184

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    entity_source == other.entity_source &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    status == other.status &&
    database_type == other.database_type &&
    database_version == other.database_version &&
    processor_count == other.processor_count &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    database_connection_status_details == other.database_connection_status_details &&
    opsi_private_endpoint_id == other.opsi_private_endpoint_id &&
    connection_details == other.connection_details &&
    credential_details == other.credential_details &&
    database_id == other.database_id &&
    database_name == other.database_name &&
    database_display_name == other.database_display_name &&
    database_resource_type == other.database_resource_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 235

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


215
216
217
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 215

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



224
225
226
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 224

def hash
  [entity_source, id, compartment_id, status, database_type, database_version, processor_count, freeform_tags, defined_tags, system_tags, time_created, time_updated, lifecycle_state, lifecycle_details, database_connection_status_details, opsi_private_endpoint_id, connection_details, credential_details, database_id, database_name, database_display_name, database_resource_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



268
269
270
271
272
273
274
275
276
277
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 268

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



262
263
264
# File 'lib/oci/opsi/models/pe_comanaged_database_insight.rb', line 262

def to_s
  to_hash.to_s
end