Class: OCI::Opsi::Models::PeComanagedDatabaseInsightSummary

Inherits:
DatabaseInsightSummary show all
Defined in:
lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb

Overview

Summary of a database insight resource.

Constant Summary

Constants inherited from DatabaseInsightSummary

DatabaseInsightSummary::ENTITY_SOURCE_ENUM, DatabaseInsightSummary::LIFECYCLE_STATE_ENUM, DatabaseInsightSummary::STATUS_ENUM

Instance Attribute Summary collapse

Attributes inherited from DatabaseInsightSummary

#compartment_id, #database_connection_status_details, #database_display_name, #database_host_names, #database_id, #database_name, #database_type, #database_version, #defined_tags, #entity_source, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #processor_count, #status, #system_tags, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DatabaseInsightSummary

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ PeComanagedDatabaseInsightSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id proprety

  • :database_id (String)

    The value to assign to the #database_id proprety

  • :compartment_id (String)

    The value to assign to the #compartment_id proprety

  • :database_name (String)

    The value to assign to the #database_name proprety

  • :database_display_name (String)

    The value to assign to the #database_display_name proprety

  • :database_type (String)

    The value to assign to the #database_type proprety

  • :database_version (String)

    The value to assign to the #database_version proprety

  • :database_host_names (Array<String>)

    The value to assign to the #database_host_names proprety

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags proprety

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags proprety

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags proprety

  • :processor_count (Integer)

    The value to assign to the #processor_count proprety

  • :status (String)

    The value to assign to the #status proprety

  • :time_created (DateTime)

    The value to assign to the #time_created proprety

  • :time_updated (DateTime)

    The value to assign to the #time_updated proprety

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state proprety

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details proprety

  • :database_connection_status_details (String)

    The value to assign to the #database_connection_status_details proprety

  • :database_resource_type (String)

    The value to assign to the #database_resource_type property

  • :opsi_private_endpoint_id (String)

    The value to assign to the #opsi_private_endpoint_id property



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 103

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['entitySource'] = 'PE_COMANAGED_DATABASE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.database_resource_type = attributes[:'databaseResourceType'] if attributes[:'databaseResourceType']

  raise 'You cannot provide both :databaseResourceType and :database_resource_type' if attributes.key?(:'databaseResourceType') && attributes.key?(:'database_resource_type')

  self.database_resource_type = attributes[:'database_resource_type'] if attributes[:'database_resource_type']

  self.opsi_private_endpoint_id = attributes[:'opsiPrivateEndpointId'] if attributes[:'opsiPrivateEndpointId']

  raise 'You cannot provide both :opsiPrivateEndpointId and :opsi_private_endpoint_id' if attributes.key?(:'opsiPrivateEndpointId') && attributes.key?(:'opsi_private_endpoint_id')

  self.opsi_private_endpoint_id = attributes[:'opsi_private_endpoint_id'] if attributes[:'opsi_private_endpoint_id']
end

Instance Attribute Details

#database_resource_typeString

OCI database resource type

Returns:

  • (String)


13
14
15
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 13

def database_resource_type
  @database_resource_type
end

#opsi_private_endpoint_idString

Returns:

  • (String)


17
18
19
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 17

def opsi_private_endpoint_id
  @opsi_private_endpoint_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 20

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'database_id': :'databaseId',
    'compartment_id': :'compartmentId',
    'database_name': :'databaseName',
    'database_display_name': :'databaseDisplayName',
    'database_type': :'databaseType',
    'database_version': :'databaseVersion',
    'database_host_names': :'databaseHostNames',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'entity_source': :'entitySource',
    'processor_count': :'processorCount',
    'status': :'status',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'database_connection_status_details': :'databaseConnectionStatusDetails',
    'database_resource_type': :'databaseResourceType',
    'opsi_private_endpoint_id': :'opsiPrivateEndpointId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 49

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'database_id': :'String',
    'compartment_id': :'String',
    'database_name': :'String',
    'database_display_name': :'String',
    'database_type': :'String',
    'database_version': :'String',
    'database_host_names': :'Array<String>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'entity_source': :'String',
    'processor_count': :'Integer',
    'status': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'database_connection_status_details': :'String',
    'database_resource_type': :'String',
    'opsi_private_endpoint_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 133

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    database_id == other.database_id &&
    compartment_id == other.compartment_id &&
    database_name == other.database_name &&
    database_display_name == other.database_display_name &&
    database_type == other.database_type &&
    database_version == other.database_version &&
    database_host_names == other.database_host_names &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    entity_source == other.entity_source &&
    processor_count == other.processor_count &&
    status == other.status &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    database_connection_status_details == other.database_connection_status_details &&
    database_resource_type == other.database_resource_type &&
    opsi_private_endpoint_id == other.opsi_private_endpoint_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 183

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


163
164
165
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 163

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



172
173
174
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 172

def hash
  [id, database_id, compartment_id, database_name, database_display_name, database_type, database_version, database_host_names, freeform_tags, defined_tags, system_tags, entity_source, processor_count, status, time_created, time_updated, lifecycle_state, lifecycle_details, database_connection_status_details, database_resource_type, opsi_private_endpoint_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



216
217
218
219
220
221
222
223
224
225
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 216

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



210
211
212
# File 'lib/oci/opsi/models/pe_comanaged_database_insight_summary.rb', line 210

def to_s
  to_hash.to_s
end