Class: OCI::Opsi::Models::ProjectedDataItem

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/projected_data_item.rb

Overview

The timestamp of the projected event and their corresponding resource value. `highValue` and `lowValue` are the uncertainty bounds of the corresponding value.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProjectedDataItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :end_timestamp (DateTime)

    The value to assign to the #end_timestamp property

  • :usage (Float)

    The value to assign to the #usage property

  • :high_value (Float)

    The value to assign to the #high_value property

  • :low_value (Float)

    The value to assign to the #low_value property



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/oci/opsi/models/projected_data_item.rb', line 63

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.end_timestamp = attributes[:'endTimestamp'] if attributes[:'endTimestamp']

  raise 'You cannot provide both :endTimestamp and :end_timestamp' if attributes.key?(:'endTimestamp') && attributes.key?(:'end_timestamp')

  self.end_timestamp = attributes[:'end_timestamp'] if attributes[:'end_timestamp']

  self.usage = attributes[:'usage'] if attributes[:'usage']

  self.high_value = attributes[:'highValue'] if attributes[:'highValue']

  raise 'You cannot provide both :highValue and :high_value' if attributes.key?(:'highValue') && attributes.key?(:'high_value')

  self.high_value = attributes[:'high_value'] if attributes[:'high_value']

  self.low_value = attributes[:'lowValue'] if attributes[:'lowValue']

  raise 'You cannot provide both :lowValue and :low_value' if attributes.key?(:'lowValue') && attributes.key?(:'low_value')

  self.low_value = attributes[:'low_value'] if attributes[:'low_value']
end

Instance Attribute Details

#end_timestampDateTime

**[Required]** The timestamp in which the current sampling period ends in RFC 3339 format.

Returns:

  • (DateTime)


14
15
16
# File 'lib/oci/opsi/models/projected_data_item.rb', line 14

def end_timestamp
  @end_timestamp
end

#high_valueFloat

**[Required]** Upper uncertainty bound of the current usage value.

Returns:

  • (Float)


23
24
25
# File 'lib/oci/opsi/models/projected_data_item.rb', line 23

def high_value
  @high_value
end

#low_valueFloat

**[Required]** Lower uncertainty bound of the current usage value.

Returns:

  • (Float)


27
28
29
# File 'lib/oci/opsi/models/projected_data_item.rb', line 27

def low_value
  @low_value
end

#usageFloat

**[Required]** Total amount used of the resource metric type (CPU, STORAGE).

Returns:

  • (Float)


19
20
21
# File 'lib/oci/opsi/models/projected_data_item.rb', line 19

def usage
  @usage
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
39
# File 'lib/oci/opsi/models/projected_data_item.rb', line 30

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'end_timestamp': :'endTimestamp',
    'usage': :'usage',
    'high_value': :'highValue',
    'low_value': :'lowValue'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



42
43
44
45
46
47
48
49
50
51
# File 'lib/oci/opsi/models/projected_data_item.rb', line 42

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'end_timestamp': :'DateTime',
    'usage': :'Float',
    'high_value': :'Float',
    'low_value': :'Float'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



97
98
99
100
101
102
103
104
105
# File 'lib/oci/opsi/models/projected_data_item.rb', line 97

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    end_timestamp == other.end_timestamp &&
    usage == other.usage &&
    high_value == other.high_value &&
    low_value == other.low_value
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/opsi/models/projected_data_item.rb', line 130

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


110
111
112
# File 'lib/oci/opsi/models/projected_data_item.rb', line 110

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



119
120
121
# File 'lib/oci/opsi/models/projected_data_item.rb', line 119

def hash
  [end_timestamp, usage, high_value, low_value].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/opsi/models/projected_data_item.rb', line 163

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



157
158
159
# File 'lib/oci/opsi/models/projected_data_item.rb', line 157

def to_s
  to_hash.to_s
end