Class: OCI::Opsi::Models::QueryDataObjectJsonResultSetRowsCollection
- Inherits:
-
QueryDataObjectResultSetRowsCollection
- Object
- QueryDataObjectResultSetRowsCollection
- OCI::Opsi::Models::QueryDataObjectJsonResultSetRowsCollection
- Defined in:
- lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb
Overview
Collection of result set rows from the data object query.
Constant Summary
Constants inherited from QueryDataObjectResultSetRowsCollection
OCI::Opsi::Models::QueryDataObjectResultSetRowsCollection::FORMAT_ENUM
Instance Attribute Summary collapse
-
#items ⇒ Array<Object>
**[Required]** Array of result set rows.
-
#items_metadata ⇒ Array<OCI::Opsi::Models::QueryDataObjectResultSetColumnMetadata>
**[Required]** Array of QueryDataObjectResultSetColumnMetadata objects that describe the result set columns.
Attributes inherited from QueryDataObjectResultSetRowsCollection
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QueryDataObjectJsonResultSetRowsCollection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from QueryDataObjectResultSetRowsCollection
Constructor Details
#initialize(attributes = {}) ⇒ QueryDataObjectJsonResultSetRowsCollection
Initializes the object
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 49 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['format'] = 'JSON' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.items = attributes[:'items'] if attributes[:'items'] self. = attributes[:'itemsMetadata'] if attributes[:'itemsMetadata'] raise 'You cannot provide both :itemsMetadata and :items_metadata' if attributes.key?(:'itemsMetadata') && attributes.key?(:'items_metadata') self. = attributes[:'items_metadata'] if attributes[:'items_metadata'] end |
Instance Attribute Details
#items ⇒ Array<Object>
**[Required]** Array of result set rows.
13 14 15 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 13 def items @items end |
#items_metadata ⇒ Array<OCI::Opsi::Models::QueryDataObjectResultSetColumnMetadata>
**[Required]** Array of QueryDataObjectResultSetColumnMetadata objects that describe the result set columns.
17 18 19 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 17 def @items_metadata end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 27 28 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'format': :'format', 'items': :'items', 'items_metadata': :'itemsMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 31 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'format': :'String', 'items': :'Array<Object>', 'items_metadata': :'Array<OCI::Opsi::Models::QueryDataObjectResultSetColumnMetadata>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
75 76 77 78 79 80 81 82 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 75 def ==(other) return true if equal?(other) self.class == other.class && format == other.format && items == other.items && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 107 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
87 88 89 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 87 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
96 97 98 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 96 def hash [format, items, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 140 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
134 135 136 |
# File 'lib/oci/opsi/models/query_data_object_json_result_set_rows_collection.rb', line 134 def to_s to_hash.to_s end |