Class: OCI::Opsi::Models::QueryDataObjectResultSetColumnMetadata
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::QueryDataObjectResultSetColumnMetadata
- Defined in:
- lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb
Overview
Metadata of a column in a data object query result set.
Constant Summary collapse
- DATA_TYPE_NAME_ENUM =
[ DATA_TYPE_NAME_NUMBER = 'NUMBER'.freeze, DATA_TYPE_NAME_TIMESTAMP = 'TIMESTAMP'.freeze, DATA_TYPE_NAME_VARCHAR2 = 'VARCHAR2'.freeze, DATA_TYPE_NAME_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#data_type_name ⇒ String
Type of the column in a data object query result set.
-
#name ⇒ String
**[Required]** Name of the column in a data object query result set.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QueryDataObjectResultSetColumnMetadata
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ QueryDataObjectResultSetColumnMetadata
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 54 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.data_type_name = attributes[:'dataTypeName'] if attributes[:'dataTypeName'] raise 'You cannot provide both :dataTypeName and :data_type_name' if attributes.key?(:'dataTypeName') && attributes.key?(:'data_type_name') self.data_type_name = attributes[:'data_type_name'] if attributes[:'data_type_name'] end |
Instance Attribute Details
#data_type_name ⇒ String
Type of the column in a data object query result set.
24 25 26 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 24 def data_type_name @data_type_name end |
#name ⇒ String
**[Required]** Name of the column in a data object query result set.
20 21 22 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 20 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'data_type_name': :'dataTypeName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 37 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'data_type_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
89 90 91 92 93 94 95 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 89 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && data_type_name == other.data_type_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 120 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
100 101 102 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 100 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
109 110 111 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 109 def hash [name, data_type_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 153 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
147 148 149 |
# File 'lib/oci/opsi/models/query_data_object_result_set_column_metadata.rb', line 147 def to_s to_hash.to_s end |