Class: OCI::Opsi::Models::ResourceFilters

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/resource_filters.rb

Overview

Information to filter the actual target resources in an operation. e.g: While quering a DATABASE_INSIGHTS_DATA_OBJECT using /opsiDataObjects/opsiDataObjectidentifier/actions/queryData API, if resourceFilters is set with valid value for definedTagEquals field, only data of the database insights resources for which the specified freeform tags exist will be considered for the actual query scope.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResourceFilters

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/oci/opsi/models/resource_filters.rb', line 88

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.defined_tag_equals = attributes[:'definedTagEquals'] if attributes[:'definedTagEquals']

  raise 'You cannot provide both :definedTagEquals and :defined_tag_equals' if attributes.key?(:'definedTagEquals') && attributes.key?(:'defined_tag_equals')

  self.defined_tag_equals = attributes[:'defined_tag_equals'] if attributes[:'defined_tag_equals']

  self.freeform_tag_equals = attributes[:'freeformTagEquals'] if attributes[:'freeformTagEquals']

  raise 'You cannot provide both :freeformTagEquals and :freeform_tag_equals' if attributes.key?(:'freeformTagEquals') && attributes.key?(:'freeform_tag_equals')

  self.freeform_tag_equals = attributes[:'freeform_tag_equals'] if attributes[:'freeform_tag_equals']

  self.defined_tag_exists = attributes[:'definedTagExists'] if attributes[:'definedTagExists']

  raise 'You cannot provide both :definedTagExists and :defined_tag_exists' if attributes.key?(:'definedTagExists') && attributes.key?(:'defined_tag_exists')

  self.defined_tag_exists = attributes[:'defined_tag_exists'] if attributes[:'defined_tag_exists']

  self.freeform_tag_exists = attributes[:'freeformTagExists'] if attributes[:'freeformTagExists']

  raise 'You cannot provide both :freeformTagExists and :freeform_tag_exists' if attributes.key?(:'freeformTagExists') && attributes.key?(:'freeform_tag_exists')

  self.freeform_tag_exists = attributes[:'freeform_tag_exists'] if attributes[:'freeform_tag_exists']

  self.compartment_id_in_subtree = attributes[:'compartmentIdInSubtree'] unless attributes[:'compartmentIdInSubtree'].nil?
  self.compartment_id_in_subtree = false if compartment_id_in_subtree.nil? && !attributes.key?(:'compartmentIdInSubtree') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :compartmentIdInSubtree and :compartment_id_in_subtree' if attributes.key?(:'compartmentIdInSubtree') && attributes.key?(:'compartment_id_in_subtree')

  self.compartment_id_in_subtree = attributes[:'compartment_id_in_subtree'] unless attributes[:'compartment_id_in_subtree'].nil?
  self.compartment_id_in_subtree = false if compartment_id_in_subtree.nil? && !attributes.key?(:'compartmentIdInSubtree') && !attributes.key?(:'compartment_id_in_subtree') # rubocop:disable Style/StringLiterals
end

Instance Attribute Details

#compartment_id_in_subtreeBOOLEAN

A flag to consider all resources within a given compartment and all sub-compartments.

Returns:

  • (BOOLEAN)


49
50
51
# File 'lib/oci/opsi/models/resource_filters.rb', line 49

def compartment_id_in_subtree
  @compartment_id_in_subtree
end

#defined_tag_equalsArray<String>

A list of tag filters to apply. Only resources with a defined tag matching the value will be considered. Each item in the list has the format "namespace.tagName.value". All inputs are case-insensitive. Multiple values for the same key (i.e. same namespace and tag name) are interpreted as "OR". Values for different keys (i.e. different namespaces, different tag names, or both) are interpreted as "AND".

Returns:

  • (Array<String>)


20
21
22
# File 'lib/oci/opsi/models/resource_filters.rb', line 20

def defined_tag_equals
  @defined_tag_equals
end

#defined_tag_existsArray<String>

A list of tag existence filters to apply. Only resources for which the specified defined tags exist will be considered. Each item in the list has the format "namespace.tagName.true" (for checking existence of a defined tag) or "namespace.true". All inputs are case-insensitive. Currently, only existence ("true" at the end) is supported. Absence ("false" at the end) is not supported. Multiple values for the same key (i.e. same namespace and tag name) are interpreted as "OR". Values for different keys (i.e. different namespaces, different tag names, or both) are interpreted as "AND".

Returns:

  • (Array<String>)


37
38
39
# File 'lib/oci/opsi/models/resource_filters.rb', line 37

def defined_tag_exists
  @defined_tag_exists
end

#freeform_tag_equalsArray<String>

A list of tag filters to apply. Only resources with a freeform tag matching the value will be considered. The key for each tag is "tagName.value". All inputs are case-insensitive. Multiple values for the same tag name are interpreted as "OR". Values for different tag names are interpreted as "AND".

Returns:

  • (Array<String>)


27
28
29
# File 'lib/oci/opsi/models/resource_filters.rb', line 27

def freeform_tag_equals
  @freeform_tag_equals
end

#freeform_tag_existsArray<String>

A list of tag existence filters to apply. Only resources for which the specified freeform tags exist will be considered. The key for each tag is "tagName.true". All inputs are case-insensitive. Currently, only existence ("true" at the end) is supported. Absence ("false" at the end) is not supported. Multiple values for different tag names are interpreted as "AND".

Returns:

  • (Array<String>)


45
46
47
# File 'lib/oci/opsi/models/resource_filters.rb', line 45

def freeform_tag_exists
  @freeform_tag_exists
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/opsi/models/resource_filters.rb', line 52

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'defined_tag_equals': :'definedTagEquals',
    'freeform_tag_equals': :'freeformTagEquals',
    'defined_tag_exists': :'definedTagExists',
    'freeform_tag_exists': :'freeformTagExists',
    'compartment_id_in_subtree': :'compartmentIdInSubtree'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/opsi/models/resource_filters.rb', line 65

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'defined_tag_equals': :'Array<String>',
    'freeform_tag_equals': :'Array<String>',
    'defined_tag_exists': :'Array<String>',
    'freeform_tag_exists': :'Array<String>',
    'compartment_id_in_subtree': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/opsi/models/resource_filters.rb', line 134

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    defined_tag_equals == other.defined_tag_equals &&
    freeform_tag_equals == other.freeform_tag_equals &&
    defined_tag_exists == other.defined_tag_exists &&
    freeform_tag_exists == other.freeform_tag_exists &&
    compartment_id_in_subtree == other.compartment_id_in_subtree
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/oci/opsi/models/resource_filters.rb', line 168

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/oci/opsi/models/resource_filters.rb', line 148

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



157
158
159
# File 'lib/oci/opsi/models/resource_filters.rb', line 157

def hash
  [defined_tag_equals, freeform_tag_equals, defined_tag_exists, freeform_tag_exists, compartment_id_in_subtree].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



201
202
203
204
205
206
207
208
209
210
# File 'lib/oci/opsi/models/resource_filters.rb', line 201

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



195
196
197
# File 'lib/oci/opsi/models/resource_filters.rb', line 195

def to_s
  to_hash.to_s
end