Class: OCI::Opsi::Models::ResourceUsageSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/resource_usage_summary.rb

Overview

Contains resource usage summary

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResourceUsageSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :exadata_insight_id (String)

    The value to assign to the #exadata_insight_id property

  • :exadata_display_name (String)

    The value to assign to the #exadata_display_name property

  • :usage (Float)

    The value to assign to the #usage property

  • :capacity (Float)

    The value to assign to the #capacity property

  • :utilization_percent (Float)

    The value to assign to the #utilization_percent property

  • :usage_change_percent (Float)

    The value to assign to the #usage_change_percent property



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 76

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.exadata_insight_id = attributes[:'exadataInsightId'] if attributes[:'exadataInsightId']

  raise 'You cannot provide both :exadataInsightId and :exadata_insight_id' if attributes.key?(:'exadataInsightId') && attributes.key?(:'exadata_insight_id')

  self.exadata_insight_id = attributes[:'exadata_insight_id'] if attributes[:'exadata_insight_id']

  self.exadata_display_name = attributes[:'exadataDisplayName'] if attributes[:'exadataDisplayName']

  raise 'You cannot provide both :exadataDisplayName and :exadata_display_name' if attributes.key?(:'exadataDisplayName') && attributes.key?(:'exadata_display_name')

  self.exadata_display_name = attributes[:'exadata_display_name'] if attributes[:'exadata_display_name']

  self.usage = attributes[:'usage'] if attributes[:'usage']

  self.capacity = attributes[:'capacity'] if attributes[:'capacity']

  self.utilization_percent = attributes[:'utilizationPercent'] if attributes[:'utilizationPercent']

  raise 'You cannot provide both :utilizationPercent and :utilization_percent' if attributes.key?(:'utilizationPercent') && attributes.key?(:'utilization_percent')

  self.utilization_percent = attributes[:'utilization_percent'] if attributes[:'utilization_percent']

  self.usage_change_percent = attributes[:'usageChangePercent'] if attributes[:'usageChangePercent']

  raise 'You cannot provide both :usageChangePercent and :usage_change_percent' if attributes.key?(:'usageChangePercent') && attributes.key?(:'usage_change_percent')

  self.usage_change_percent = attributes[:'usage_change_percent'] if attributes[:'usage_change_percent']
end

Instance Attribute Details

#capacityFloat

**[Required]** The maximum allocated amount of the resource metric type (CPU, STORAGE).

Returns:

  • (Float)


26
27
28
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 26

def capacity
  @capacity
end

#exadata_display_nameString

The user-friendly name for the Exadata system. The name does not have to be unique.

Returns:

  • (String)


16
17
18
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 16

def exadata_display_name
  @exadata_display_name
end

#exadata_insight_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.

Returns:

  • (String)


12
13
14
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 12

def exadata_insight_id
  @exadata_insight_id
end

#usageFloat

**[Required]** Total amount used of the resource metric type (CPU, STORAGE).

Returns:

  • (Float)


21
22
23
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 21

def usage
  @usage
end

#usage_change_percentFloat

**[Required]** Change in resource utilization in percentage

Returns:

  • (Float)


34
35
36
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 34

def usage_change_percent
  @usage_change_percent
end

#utilization_percentFloat

**[Required]** Resource utilization in percentage

Returns:

  • (Float)


30
31
32
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 30

def utilization_percent
  @utilization_percent
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'exadata_insight_id': :'exadataInsightId',
    'exadata_display_name': :'exadataDisplayName',
    'usage': :'usage',
    'capacity': :'capacity',
    'utilization_percent': :'utilizationPercent',
    'usage_change_percent': :'usageChangePercent'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 51

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'exadata_insight_id': :'String',
    'exadata_display_name': :'String',
    'usage': :'Float',
    'capacity': :'Float',
    'utilization_percent': :'Float',
    'usage_change_percent': :'Float'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 118

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    exadata_insight_id == other.exadata_insight_id &&
    exadata_display_name == other.exadata_display_name &&
    usage == other.usage &&
    capacity == other.capacity &&
    utilization_percent == other.utilization_percent &&
    usage_change_percent == other.usage_change_percent
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 153

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


133
134
135
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 133

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



142
143
144
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 142

def hash
  [exadata_insight_id, exadata_display_name, usage, capacity, utilization_percent, usage_change_percent].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



180
181
182
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 180

def to_s
  to_hash.to_s
end