Class: OCI::Opsi::Models::SqlPlanInsightAggregation
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SqlPlanInsightAggregation
- Defined in:
- lib/oci/opsi/models/sql_plan_insight_aggregation.rb
Overview
SQL execution plan Performance statistics.
Instance Attribute Summary collapse
-
#cpu_time_in_sec ⇒ Float
[Required] CPU Time in seconds.
-
#executions_count ⇒ Integer
[Required] Total number of executions.
-
#inefficient_wait_time_in_sec ⇒ Float
[Required] Inefficient Wait Time in seconds.
-
#io_time_in_sec ⇒ Float
[Required] IO Time in seconds.
-
#plan_hash ⇒ Integer
[Required] Plan hash value for the SQL Execution Plan.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlPlanInsightAggregation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlPlanInsightAggregation
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.plan_hash = attributes[:'planHash'] if attributes[:'planHash'] raise 'You cannot provide both :planHash and :plan_hash' if attributes.key?(:'planHash') && attributes.key?(:'plan_hash') self.plan_hash = attributes[:'plan_hash'] if attributes[:'plan_hash'] self.io_time_in_sec = attributes[:'ioTimeInSec'] if attributes[:'ioTimeInSec'] raise 'You cannot provide both :ioTimeInSec and :io_time_in_sec' if attributes.key?(:'ioTimeInSec') && attributes.key?(:'io_time_in_sec') self.io_time_in_sec = attributes[:'io_time_in_sec'] if attributes[:'io_time_in_sec'] self.cpu_time_in_sec = attributes[:'cpuTimeInSec'] if attributes[:'cpuTimeInSec'] raise 'You cannot provide both :cpuTimeInSec and :cpu_time_in_sec' if attributes.key?(:'cpuTimeInSec') && attributes.key?(:'cpu_time_in_sec') self.cpu_time_in_sec = attributes[:'cpu_time_in_sec'] if attributes[:'cpu_time_in_sec'] self.inefficient_wait_time_in_sec = attributes[:'inefficientWaitTimeInSec'] if attributes[:'inefficientWaitTimeInSec'] raise 'You cannot provide both :inefficientWaitTimeInSec and :inefficient_wait_time_in_sec' if attributes.key?(:'inefficientWaitTimeInSec') && attributes.key?(:'inefficient_wait_time_in_sec') self.inefficient_wait_time_in_sec = attributes[:'inefficient_wait_time_in_sec'] if attributes[:'inefficient_wait_time_in_sec'] self.executions_count = attributes[:'executionsCount'] if attributes[:'executionsCount'] raise 'You cannot provide both :executionsCount and :executions_count' if attributes.key?(:'executionsCount') && attributes.key?(:'executions_count') self.executions_count = attributes[:'executions_count'] if attributes[:'executions_count'] end |
Instance Attribute Details
#cpu_time_in_sec ⇒ Float
[Required] CPU Time in seconds
20 21 22 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 20 def cpu_time_in_sec @cpu_time_in_sec end |
#executions_count ⇒ Integer
[Required] Total number of executions
28 29 30 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 28 def executions_count @executions_count end |
#inefficient_wait_time_in_sec ⇒ Float
[Required] Inefficient Wait Time in seconds
24 25 26 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 24 def inefficient_wait_time_in_sec @inefficient_wait_time_in_sec end |
#io_time_in_sec ⇒ Float
[Required] IO Time in seconds
16 17 18 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 16 def io_time_in_sec @io_time_in_sec end |
#plan_hash ⇒ Integer
[Required] Plan hash value for the SQL Execution Plan
12 13 14 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 12 def plan_hash @plan_hash end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'plan_hash': :'planHash', 'io_time_in_sec': :'ioTimeInSec', 'cpu_time_in_sec': :'cpuTimeInSec', 'inefficient_wait_time_in_sec': :'inefficientWaitTimeInSec', 'executions_count': :'executionsCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'plan_hash': :'Integer', 'io_time_in_sec': :'Float', 'cpu_time_in_sec': :'Float', 'inefficient_wait_time_in_sec': :'Float', 'executions_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && plan_hash == other.plan_hash && io_time_in_sec == other.io_time_in_sec && cpu_time_in_sec == other.cpu_time_in_sec && inefficient_wait_time_in_sec == other.inefficient_wait_time_in_sec && executions_count == other.executions_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 134 def hash [plan_hash, io_time_in_sec, cpu_time_in_sec, inefficient_wait_time_in_sec, executions_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/opsi/models/sql_plan_insight_aggregation.rb', line 172 def to_s to_hash.to_s end |