Class: OCI::Opsi::Models::SqlPlanLine

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/sql_plan_line.rb

Overview

SQL Plan Line type object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SqlPlanLine

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :version (Float)

    The value to assign to the #version property

  • :sql_identifier (String)

    The value to assign to the #sql_identifier property

  • :plan_hash (Integer)

    The value to assign to the #plan_hash property

  • :time_collected (DateTime)

    The value to assign to the #time_collected property

  • :operation (String)

    The value to assign to the #operation property

  • :remark (String)

    The value to assign to the #remark property

  • :options (String)

    The value to assign to the #options property

  • :object_node (String)

    The value to assign to the #object_node property

  • :object_owner (String)

    The value to assign to the #object_owner property

  • :object_name (String)

    The value to assign to the #object_name property

  • :object_alias (String)

    The value to assign to the #object_alias property

  • :object_instance (Integer)

    The value to assign to the #object_instance property

  • :object_type (String)

    The value to assign to the #object_type property

  • :optimizer (String)

    The value to assign to the #optimizer property

  • :search_columns (Integer)

    The value to assign to the #search_columns property

  • :identifier (Integer)

    The value to assign to the #identifier property

  • :parent_identifier (Integer)

    The value to assign to the #parent_identifier property

  • :depth (Integer)

    The value to assign to the #depth property

  • :position (Integer)

    The value to assign to the #position property

  • :cost (Integer)

    The value to assign to the #cost property

  • :cardinality (Integer)

    The value to assign to the #cardinality property

  • :bytes (Integer)

    The value to assign to the #bytes property

  • :other (String)

    The value to assign to the #other property

  • :other_tag (String)

    The value to assign to the #other_tag property

  • :partition_start (String)

    The value to assign to the #partition_start property

  • :partition_stop (String)

    The value to assign to the #partition_stop property

  • :partition_identifier (Integer)

    The value to assign to the #partition_identifier property

  • :distribution (String)

    The value to assign to the #distribution property

  • :cpu_cost (Integer)

    The value to assign to the #cpu_cost property

  • :io_cost (Integer)

    The value to assign to the #io_cost property

  • :temp_space (Integer)

    The value to assign to the #temp_space property

  • :access_predicates (String)

    The value to assign to the #access_predicates property

  • :filter_predicates (String)

    The value to assign to the #filter_predicates property

  • :projection (String)

    The value to assign to the #projection property

  • :qblock_name (String)

    The value to assign to the #qblock_name property

  • :elapsed_time_in_sec (Float)

    The value to assign to the #elapsed_time_in_sec property

  • :other_xml (String)

    The value to assign to the #other_xml property



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 362

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.version = attributes[:'version'] if attributes[:'version']

  self.sql_identifier = attributes[:'sqlIdentifier'] if attributes[:'sqlIdentifier']

  raise 'You cannot provide both :sqlIdentifier and :sql_identifier' if attributes.key?(:'sqlIdentifier') && attributes.key?(:'sql_identifier')

  self.sql_identifier = attributes[:'sql_identifier'] if attributes[:'sql_identifier']

  self.plan_hash = attributes[:'planHash'] if attributes[:'planHash']

  raise 'You cannot provide both :planHash and :plan_hash' if attributes.key?(:'planHash') && attributes.key?(:'plan_hash')

  self.plan_hash = attributes[:'plan_hash'] if attributes[:'plan_hash']

  self.time_collected = attributes[:'timeCollected'] if attributes[:'timeCollected']

  raise 'You cannot provide both :timeCollected and :time_collected' if attributes.key?(:'timeCollected') && attributes.key?(:'time_collected')

  self.time_collected = attributes[:'time_collected'] if attributes[:'time_collected']

  self.operation = attributes[:'operation'] if attributes[:'operation']

  self.remark = attributes[:'remark'] if attributes[:'remark']

  self.options = attributes[:'options'] if attributes[:'options']

  self.object_node = attributes[:'objectNode'] if attributes[:'objectNode']

  raise 'You cannot provide both :objectNode and :object_node' if attributes.key?(:'objectNode') && attributes.key?(:'object_node')

  self.object_node = attributes[:'object_node'] if attributes[:'object_node']

  self.object_owner = attributes[:'objectOwner'] if attributes[:'objectOwner']

  raise 'You cannot provide both :objectOwner and :object_owner' if attributes.key?(:'objectOwner') && attributes.key?(:'object_owner')

  self.object_owner = attributes[:'object_owner'] if attributes[:'object_owner']

  self.object_name = attributes[:'objectName'] if attributes[:'objectName']

  raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name')

  self.object_name = attributes[:'object_name'] if attributes[:'object_name']

  self.object_alias = attributes[:'objectAlias'] if attributes[:'objectAlias']

  raise 'You cannot provide both :objectAlias and :object_alias' if attributes.key?(:'objectAlias') && attributes.key?(:'object_alias')

  self.object_alias = attributes[:'object_alias'] if attributes[:'object_alias']

  self.object_instance = attributes[:'objectInstance'] if attributes[:'objectInstance']

  raise 'You cannot provide both :objectInstance and :object_instance' if attributes.key?(:'objectInstance') && attributes.key?(:'object_instance')

  self.object_instance = attributes[:'object_instance'] if attributes[:'object_instance']

  self.object_type = attributes[:'objectType'] if attributes[:'objectType']

  raise 'You cannot provide both :objectType and :object_type' if attributes.key?(:'objectType') && attributes.key?(:'object_type')

  self.object_type = attributes[:'object_type'] if attributes[:'object_type']

  self.optimizer = attributes[:'optimizer'] if attributes[:'optimizer']

  self.search_columns = attributes[:'searchColumns'] if attributes[:'searchColumns']

  raise 'You cannot provide both :searchColumns and :search_columns' if attributes.key?(:'searchColumns') && attributes.key?(:'search_columns')

  self.search_columns = attributes[:'search_columns'] if attributes[:'search_columns']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.parent_identifier = attributes[:'parentIdentifier'] if attributes[:'parentIdentifier']

  raise 'You cannot provide both :parentIdentifier and :parent_identifier' if attributes.key?(:'parentIdentifier') && attributes.key?(:'parent_identifier')

  self.parent_identifier = attributes[:'parent_identifier'] if attributes[:'parent_identifier']

  self.depth = attributes[:'depth'] if attributes[:'depth']

  self.position = attributes[:'position'] if attributes[:'position']

  self.cost = attributes[:'cost'] if attributes[:'cost']

  self.cardinality = attributes[:'cardinality'] if attributes[:'cardinality']

  self.bytes = attributes[:'bytes'] if attributes[:'bytes']

  self.other = attributes[:'other'] if attributes[:'other']

  self.other_tag = attributes[:'otherTag'] if attributes[:'otherTag']

  raise 'You cannot provide both :otherTag and :other_tag' if attributes.key?(:'otherTag') && attributes.key?(:'other_tag')

  self.other_tag = attributes[:'other_tag'] if attributes[:'other_tag']

  self.partition_start = attributes[:'partitionStart'] if attributes[:'partitionStart']

  raise 'You cannot provide both :partitionStart and :partition_start' if attributes.key?(:'partitionStart') && attributes.key?(:'partition_start')

  self.partition_start = attributes[:'partition_start'] if attributes[:'partition_start']

  self.partition_stop = attributes[:'partitionStop'] if attributes[:'partitionStop']

  raise 'You cannot provide both :partitionStop and :partition_stop' if attributes.key?(:'partitionStop') && attributes.key?(:'partition_stop')

  self.partition_stop = attributes[:'partition_stop'] if attributes[:'partition_stop']

  self.partition_identifier = attributes[:'partitionIdentifier'] if attributes[:'partitionIdentifier']

  raise 'You cannot provide both :partitionIdentifier and :partition_identifier' if attributes.key?(:'partitionIdentifier') && attributes.key?(:'partition_identifier')

  self.partition_identifier = attributes[:'partition_identifier'] if attributes[:'partition_identifier']

  self.distribution = attributes[:'distribution'] if attributes[:'distribution']

  self.cpu_cost = attributes[:'cpuCost'] if attributes[:'cpuCost']

  raise 'You cannot provide both :cpuCost and :cpu_cost' if attributes.key?(:'cpuCost') && attributes.key?(:'cpu_cost')

  self.cpu_cost = attributes[:'cpu_cost'] if attributes[:'cpu_cost']

  self.io_cost = attributes[:'ioCost'] if attributes[:'ioCost']

  raise 'You cannot provide both :ioCost and :io_cost' if attributes.key?(:'ioCost') && attributes.key?(:'io_cost')

  self.io_cost = attributes[:'io_cost'] if attributes[:'io_cost']

  self.temp_space = attributes[:'tempSpace'] if attributes[:'tempSpace']

  raise 'You cannot provide both :tempSpace and :temp_space' if attributes.key?(:'tempSpace') && attributes.key?(:'temp_space')

  self.temp_space = attributes[:'temp_space'] if attributes[:'temp_space']

  self.access_predicates = attributes[:'accessPredicates'] if attributes[:'accessPredicates']

  raise 'You cannot provide both :accessPredicates and :access_predicates' if attributes.key?(:'accessPredicates') && attributes.key?(:'access_predicates')

  self.access_predicates = attributes[:'access_predicates'] if attributes[:'access_predicates']

  self.filter_predicates = attributes[:'filterPredicates'] if attributes[:'filterPredicates']

  raise 'You cannot provide both :filterPredicates and :filter_predicates' if attributes.key?(:'filterPredicates') && attributes.key?(:'filter_predicates')

  self.filter_predicates = attributes[:'filter_predicates'] if attributes[:'filter_predicates']

  self.projection = attributes[:'projection'] if attributes[:'projection']

  self.qblock_name = attributes[:'qblockName'] if attributes[:'qblockName']

  raise 'You cannot provide both :qblockName and :qblock_name' if attributes.key?(:'qblockName') && attributes.key?(:'qblock_name')

  self.qblock_name = attributes[:'qblock_name'] if attributes[:'qblock_name']

  self.elapsed_time_in_sec = attributes[:'elapsedTimeInSec'] if attributes[:'elapsedTimeInSec']

  raise 'You cannot provide both :elapsedTimeInSec and :elapsed_time_in_sec' if attributes.key?(:'elapsedTimeInSec') && attributes.key?(:'elapsed_time_in_sec')

  self.elapsed_time_in_sec = attributes[:'elapsed_time_in_sec'] if attributes[:'elapsed_time_in_sec']

  self.other_xml = attributes[:'otherXML'] if attributes[:'otherXML']

  raise 'You cannot provide both :otherXML and :other_xml' if attributes.key?(:'otherXML') && attributes.key?(:'other_xml')

  self.other_xml = attributes[:'other_xml'] if attributes[:'other_xml']
end

Instance Attribute Details

#access_predicatesString

Access predicates Example: ‘"\"RESOURCE_ID\"=:1 AND \"QUERY_ID\"=:2"`

Returns:

  • (String)


197
198
199
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 197

def access_predicates
  @access_predicates
end

#bytesInteger

Bytes Example: 150

Returns:

  • (Integer)


137
138
139
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 137

def bytes
  @bytes
end

#cardinalityInteger

Cardinality Example: 1

Returns:

  • (Integer)


131
132
133
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 131

def cardinality
  @cardinality
end

#costInteger

Cost Example: 1

Returns:

  • (Integer)


125
126
127
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 125

def cost
  @cost
end

#cpu_costInteger

CPU cost Example: 7321

Returns:

  • (Integer)


179
180
181
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 179

def cpu_cost
  @cpu_cost
end

#depthInteger

Depth Example: 3

Returns:

  • (Integer)


113
114
115
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 113

def depth
  @depth
end

#distributionString

Distribution Example: ‘"QC (RANDOM)"`

Returns:

  • (String)


173
174
175
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 173

def distribution
  @distribution
end

#elapsed_time_in_secFloat

Total elapsed time Example: 1.2

Returns:

  • (Float)


221
222
223
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 221

def elapsed_time_in_sec
  @elapsed_time_in_sec
end

#filter_predicatesString

Filter predicates Example: ‘"(INTERNAL_FUNCTION(\"J\".\"DATABASE_ROLE\") OR (\"J\".\"DATABASE_ROLE\" IS NULL AND SYS_CONTEXT(’userenv’,‘database_role’)=‘PRIMARY’))"‘

Returns:

  • (String)


203
204
205
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 203

def filter_predicates
  @filter_predicates
end

#identifierInteger

[Required] Identifier Example: 3

Returns:

  • (Integer)


101
102
103
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 101

def identifier
  @identifier
end

#io_costInteger

IO cost Example: 1

Returns:

  • (Integer)


185
186
187
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 185

def io_cost
  @io_cost
end

#object_aliasString

Object Alias Example: ‘"PLAN_LINES@SEL$1"`

Returns:

  • (String)


71
72
73
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 71

def object_alias
  @object_alias
end

#object_instanceInteger

Object Instance Example: 37472

Returns:

  • (Integer)


77
78
79
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 77

def object_instance
  @object_instance
end

#object_nameString

Object Name Example: ‘"PLAN_LINES_PK"`

Returns:

  • (String)


65
66
67
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 65

def object_name
  @object_name
end

#object_nodeString

Object Node Example: ‘"Q4000"`

Returns:

  • (String)


53
54
55
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 53

def object_node
  @object_node
end

#object_ownerString

Object Owner Example: ‘"TENANT_A#SCHEMA"`

Returns:

  • (String)


59
60
61
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 59

def object_owner
  @object_owner
end

#object_typeString

Object Type Example: ‘"INDEX (UNIQUE)"`

Returns:

  • (String)


83
84
85
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 83

def object_type
  @object_type
end

#operationString

[Required] Operation Example: ‘"SELECT STATEMENT"`

Returns:

  • (String)


35
36
37
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 35

def operation
  @operation
end

#optimizerString

Optimizer Example: ‘"CLUSTER"`

Returns:

  • (String)


89
90
91
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 89

def optimizer
  @optimizer
end

#optionsString

Options Example: ‘"RANGE SCAN"`

Returns:

  • (String)


47
48
49
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 47

def options
  @options
end

#otherString

Other Example: “

Returns:

  • (String)


143
144
145
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 143

def other
  @other
end

#other_tagString

Other Tag Example: ‘"PARALLEL_COMBINED_WITH_PARENT"`

Returns:

  • (String)


149
150
151
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 149

def other_tag
  @other_tag
end

#other_xmlString

Other SQL Example: ‘"<other_xml><info type=\"db_version\">18.0.0.0</info><info type="parse_schema"><![CDATA]></info><info type=\"plan_hash_full\">483892784</info><info type=\"plan_hash\">2709293936</info><info type="plan_hash_2">483892784</info><outline_data><hint><![CDATA]></hint><hint><![CDATA]></hint><hint><![CDATA]></hint><hint><![CDATA[OPT_PARAM(’_b_tree_bitmap_plans’ ‘false’)]]></hint><hint><![CDATA[OPT_PARAM(‘_optim_peek_user_binds’ ‘false’)]]></hint><hint><![CDATA[OPT_PARAM(‘result_cache_mode’ ‘FORCE’)]]></hint><hint><![CDATA[OPT_PARAM(‘_fix_control’ ‘20648883:0 27745220:1 30001331:1 30142527:1 30539126:1’)]]></hint><hint><![CDATA]></hint><hint><![CDATA[INDEX(@\"SEL$1\" \"USER$\"@\"SEL$1\" \"I_USER#\")]]></hint></outline_data></other_xml>"`

Returns:

  • (String)


227
228
229
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 227

def other_xml
  @other_xml
end

#parent_identifierInteger

Parent Identifier Example: 2

Returns:

  • (Integer)


107
108
109
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 107

def parent_identifier
  @parent_identifier
end

#partition_identifierInteger

Partition identifier Example: 8

Returns:

  • (Integer)


167
168
169
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 167

def partition_identifier
  @partition_identifier
end

#partition_startString

Partition start Example: 1

Returns:

  • (String)


155
156
157
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 155

def partition_start
  @partition_start
end

#partition_stopString

Partition stop Example: 2

Returns:

  • (String)


161
162
163
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 161

def partition_stop
  @partition_stop
end

#plan_hashInteger

[Required] Plan hash value for the SQL Execution Plan

Returns:

  • (Integer)


23
24
25
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 23

def plan_hash
  @plan_hash
end

#positionInteger

Position Example: 1

Returns:

  • (Integer)


119
120
121
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 119

def position
  @position
end

#projectionString

Projection Example: ‘"COUNT(*)"`

Returns:

  • (String)


209
210
211
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 209

def projection
  @projection
end

#qblock_nameString

Qblock Name Example: ‘"SEL$1"`

Returns:

  • (String)


215
216
217
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 215

def qblock_name
  @qblock_name
end

#remarkString

Remark Example: ‘""`

Returns:

  • (String)


41
42
43
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 41

def remark
  @remark
end

#search_columnsInteger

Search Columns Example: 3

Returns:

  • (Integer)


95
96
97
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 95

def search_columns
  @search_columns
end

#sql_identifierString

[Required] Unique SQL_ID for a SQL Statement.

Returns:

  • (String)


19
20
21
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 19

def sql_identifier
  @sql_identifier
end

#temp_spaceInteger

Time space Example: 15614000

Returns:

  • (Integer)


191
192
193
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 191

def temp_space
  @temp_space
end

#time_collectedDateTime

[Required] Collection time stamp Example: ‘"2020-05-06T00:00:00.000Z"`

Returns:

  • (DateTime)


29
30
31
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 29

def time_collected
  @time_collected
end

#versionFloat

Version Example: 1

Returns:

  • (Float)


14
15
16
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 14

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 230

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'version': :'version',
    'sql_identifier': :'sqlIdentifier',
    'plan_hash': :'planHash',
    'time_collected': :'timeCollected',
    'operation': :'operation',
    'remark': :'remark',
    'options': :'options',
    'object_node': :'objectNode',
    'object_owner': :'objectOwner',
    'object_name': :'objectName',
    'object_alias': :'objectAlias',
    'object_instance': :'objectInstance',
    'object_type': :'objectType',
    'optimizer': :'optimizer',
    'search_columns': :'searchColumns',
    'identifier': :'identifier',
    'parent_identifier': :'parentIdentifier',
    'depth': :'depth',
    'position': :'position',
    'cost': :'cost',
    'cardinality': :'cardinality',
    'bytes': :'bytes',
    'other': :'other',
    'other_tag': :'otherTag',
    'partition_start': :'partitionStart',
    'partition_stop': :'partitionStop',
    'partition_identifier': :'partitionIdentifier',
    'distribution': :'distribution',
    'cpu_cost': :'cpuCost',
    'io_cost': :'ioCost',
    'temp_space': :'tempSpace',
    'access_predicates': :'accessPredicates',
    'filter_predicates': :'filterPredicates',
    'projection': :'projection',
    'qblock_name': :'qblockName',
    'elapsed_time_in_sec': :'elapsedTimeInSec',
    'other_xml': :'otherXML'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 275

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'version': :'Float',
    'sql_identifier': :'String',
    'plan_hash': :'Integer',
    'time_collected': :'DateTime',
    'operation': :'String',
    'remark': :'String',
    'options': :'String',
    'object_node': :'String',
    'object_owner': :'String',
    'object_name': :'String',
    'object_alias': :'String',
    'object_instance': :'Integer',
    'object_type': :'String',
    'optimizer': :'String',
    'search_columns': :'Integer',
    'identifier': :'Integer',
    'parent_identifier': :'Integer',
    'depth': :'Integer',
    'position': :'Integer',
    'cost': :'Integer',
    'cardinality': :'Integer',
    'bytes': :'Integer',
    'other': :'String',
    'other_tag': :'String',
    'partition_start': :'String',
    'partition_stop': :'String',
    'partition_identifier': :'Integer',
    'distribution': :'String',
    'cpu_cost': :'Integer',
    'io_cost': :'Integer',
    'temp_space': :'Integer',
    'access_predicates': :'String',
    'filter_predicates': :'String',
    'projection': :'String',
    'qblock_name': :'String',
    'elapsed_time_in_sec': :'Float',
    'other_xml': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 542

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    version == other.version &&
    sql_identifier == other.sql_identifier &&
    plan_hash == other.plan_hash &&
    time_collected == other.time_collected &&
    operation == other.operation &&
    remark == other.remark &&
    options == other.options &&
    object_node == other.object_node &&
    object_owner == other.object_owner &&
    object_name == other.object_name &&
    object_alias == other.object_alias &&
    object_instance == other.object_instance &&
    object_type == other.object_type &&
    optimizer == other.optimizer &&
    search_columns == other.search_columns &&
    identifier == other.identifier &&
    parent_identifier == other.parent_identifier &&
    depth == other.depth &&
    position == other.position &&
    cost == other.cost &&
    cardinality == other.cardinality &&
    bytes == other.bytes &&
    other == other.other &&
    other_tag == other.other_tag &&
    partition_start == other.partition_start &&
    partition_stop == other.partition_stop &&
    partition_identifier == other.partition_identifier &&
    distribution == other.distribution &&
    cpu_cost == other.cpu_cost &&
    io_cost == other.io_cost &&
    temp_space == other.temp_space &&
    access_predicates == other.access_predicates &&
    filter_predicates == other.filter_predicates &&
    projection == other.projection &&
    qblock_name == other.qblock_name &&
    elapsed_time_in_sec == other.elapsed_time_in_sec &&
    other_xml == other.other_xml
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 608

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


588
589
590
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 588

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



597
598
599
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 597

def hash
  [version, sql_identifier, plan_hash, time_collected, operation, remark, options, object_node, object_owner, object_name, object_alias, object_instance, object_type, optimizer, search_columns, identifier, parent_identifier, depth, position, cost, cardinality, bytes, other, other_tag, partition_start, partition_stop, partition_identifier, distribution, cpu_cost, io_cost, temp_space, access_predicates, filter_predicates, projection, qblock_name, elapsed_time_in_sec, other_xml].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



641
642
643
644
645
646
647
648
649
650
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 641

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



635
636
637
# File 'lib/oci/opsi/models/sql_plan_line.rb', line 635

def to_s
  to_hash.to_s
end