Class: OCI::Opsi::Models::SqlSearchCollection
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SqlSearchCollection
- Defined in:
- lib/oci/opsi/models/sql_search_collection.rb
Overview
Search SQL response.
Instance Attribute Summary collapse
-
#items ⇒ Array<OCI::Opsi::Models::SqlSearchSummary>
[Required] List of Databases executing the sql.
-
#sql_identifier ⇒ String
Unique SQL_ID for a SQL Statement.
-
#sql_text ⇒ String
SQL Statement Text.
-
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
-
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlSearchCollection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlSearchCollection
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 70 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.sql_identifier = attributes[:'sqlIdentifier'] if attributes[:'sqlIdentifier'] raise 'You cannot provide both :sqlIdentifier and :sql_identifier' if attributes.key?(:'sqlIdentifier') && attributes.key?(:'sql_identifier') self.sql_identifier = attributes[:'sql_identifier'] if attributes[:'sql_identifier'] self.sql_text = attributes[:'sqlText'] if attributes[:'sqlText'] raise 'You cannot provide both :sqlText and :sql_text' if attributes.key?(:'sqlText') && attributes.key?(:'sql_text') self.sql_text = attributes[:'sql_text'] if attributes[:'sql_text'] self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart'] raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start') self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start'] self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd'] raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end') self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end'] self.items = attributes[:'items'] if attributes[:'items'] end |
Instance Attribute Details
#items ⇒ Array<OCI::Opsi::Models::SqlSearchSummary>
[Required] List of Databases executing the sql.
31 32 33 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 31 def items @items end |
#sql_identifier ⇒ String
Unique SQL_ID for a SQL Statement.
14 15 16 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 14 def sql_identifier @sql_identifier end |
#sql_text ⇒ String
SQL Statement Text
19 20 21 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 19 def sql_text @sql_text end |
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
27 28 29 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 27 def time_interval_end @time_interval_end end |
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
23 24 25 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 23 def time_interval_start @time_interval_start end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'sql_identifier': :'sqlIdentifier', 'sql_text': :'sqlText', 'time_interval_start': :'timeIntervalStart', 'time_interval_end': :'timeIntervalEnd', 'items': :'items' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'sql_identifier': :'String', 'sql_text': :'String', 'time_interval_start': :'DateTime', 'time_interval_end': :'DateTime', 'items': :'Array<OCI::Opsi::Models::SqlSearchSummary>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 110 def ==(other) return true if equal?(other) self.class == other.class && sql_identifier == other.sql_identifier && sql_text == other.sql_text && time_interval_start == other.time_interval_start && time_interval_end == other.time_interval_end && items == other.items end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 144 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
124 125 126 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 124 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
133 134 135 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 133 def hash [sql_identifier, sql_text, time_interval_start, time_interval_end, items].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
171 172 173 |
# File 'lib/oci/opsi/models/sql_search_collection.rb', line 171 def to_s to_hash.to_s end |