Class: OCI::Opsi::Models::SqlSearchSummary
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SqlSearchSummary
- Defined in:
- lib/oci/opsi/models/sql_search_summary.rb
Overview
Database summary object resulting from a sql search operation.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
-
#database_display_name ⇒ String
**[Required]** The user-friendly name for the database.
-
#database_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
-
#database_name ⇒ String
**[Required]** The database name.
-
#database_type ⇒ String
**[Required]** Operations Insights internal representation of the database type.
-
#database_version ⇒ String
**[Required]** The version of the database.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlSearchSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlSearchSummary
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.database_name = attributes[:'databaseName'] if attributes[:'databaseName'] raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name') self.database_name = attributes[:'database_name'] if attributes[:'database_name'] self.database_display_name = attributes[:'databaseDisplayName'] if attributes[:'databaseDisplayName'] raise 'You cannot provide both :databaseDisplayName and :database_display_name' if attributes.key?(:'databaseDisplayName') && attributes.key?(:'database_display_name') self.database_display_name = attributes[:'database_display_name'] if attributes[:'database_display_name'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion'] raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version') self.database_version = attributes[:'database_version'] if attributes[:'database_version'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
20 21 22 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 20 def compartment_id @compartment_id end |
#database_display_name ⇒ String
**[Required]** The user-friendly name for the database. The name does not have to be unique.
28 29 30 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 28 def database_display_name @database_display_name end |
#database_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
16 17 18 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 16 def database_id @database_id end |
#database_name ⇒ String
**[Required]** The database name. The database name is unique within the tenancy.
24 25 26 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 24 def database_name @database_name end |
#database_type ⇒ String
**[Required]** Operations Insights internal representation of the database type.
32 33 34 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 32 def database_type @database_type end |
#database_version ⇒ String
**[Required]** The version of the database.
36 37 38 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 36 def database_version @database_version end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.
12 13 14 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 12 def id @id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'database_id': :'databaseId', 'compartment_id': :'compartmentId', 'database_name': :'databaseName', 'database_display_name': :'databaseDisplayName', 'database_type': :'databaseType', 'database_version': :'databaseVersion' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'database_id': :'String', 'compartment_id': :'String', 'database_name': :'String', 'database_display_name': :'String', 'database_type': :'String', 'database_version': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 133 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && database_id == other.database_id && compartment_id == other.compartment_id && database_name == other.database_name && database_display_name == other.database_display_name && database_type == other.database_type && database_version == other.database_version end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 169 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
149 150 151 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 149 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 158 def hash [id, database_id, compartment_id, database_name, database_display_name, database_type, database_version].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
196 197 198 |
# File 'lib/oci/opsi/models/sql_search_summary.rb', line 196 def to_s to_hash.to_s end |