Class: OCI::Opsi::Models::SqlStatisticAggregation
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SqlStatisticAggregation
- Defined in:
- lib/oci/opsi/models/sql_statistic_aggregation.rb
Overview
SQL Statistics
Instance Attribute Summary collapse
-
#category ⇒ Array<String>
[Required] SQL belongs to one or more categories based on the insights.
-
#database_details ⇒ OCI::Opsi::Models::DatabaseDetails
This attribute is required.
-
#sql_identifier ⇒ String
[Required] Unique SQL_ID for a SQL Statement.
- #statistics ⇒ OCI::Opsi::Models::SqlStatistics
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlStatisticAggregation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlStatisticAggregation
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 61 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.sql_identifier = attributes[:'sqlIdentifier'] if attributes[:'sqlIdentifier'] raise 'You cannot provide both :sqlIdentifier and :sql_identifier' if attributes.key?(:'sqlIdentifier') && attributes.key?(:'sql_identifier') self.sql_identifier = attributes[:'sql_identifier'] if attributes[:'sql_identifier'] self.database_details = attributes[:'databaseDetails'] if attributes[:'databaseDetails'] raise 'You cannot provide both :databaseDetails and :database_details' if attributes.key?(:'databaseDetails') && attributes.key?(:'database_details') self.database_details = attributes[:'database_details'] if attributes[:'database_details'] self.category = attributes[:'category'] if attributes[:'category'] self.statistics = attributes[:'statistics'] if attributes[:'statistics'] end |
Instance Attribute Details
#category ⇒ Array<String>
[Required] SQL belongs to one or more categories based on the insights.
22 23 24 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 22 def category @category end |
#database_details ⇒ OCI::Opsi::Models::DatabaseDetails
This attribute is required.
17 18 19 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 17 def database_details @database_details end |
#sql_identifier ⇒ String
[Required] Unique SQL_ID for a SQL Statement.
13 14 15 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 13 def sql_identifier @sql_identifier end |
#statistics ⇒ OCI::Opsi::Models::SqlStatistics
25 26 27 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 25 def statistics @statistics end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'sql_identifier': :'sqlIdentifier', 'database_details': :'databaseDetails', 'category': :'category', 'statistics': :'statistics' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'sql_identifier': :'String', 'database_details': :'OCI::Opsi::Models::DatabaseDetails', 'category': :'Array<String>', 'statistics': :'OCI::Opsi::Models::SqlStatistics' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 91 def ==(other) return true if equal?(other) self.class == other.class && sql_identifier == other.sql_identifier && database_details == other.database_details && category == other.category && statistics == other.statistics end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 124 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
104 105 106 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 104 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
113 114 115 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 113 def hash [sql_identifier, database_details, category, statistics].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 157 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
151 152 153 |
# File 'lib/oci/opsi/models/sql_statistic_aggregation.rb', line 151 def to_s to_hash.to_s end |