Class: OCI::Opsi::Models::SqlStatisticsTimeSeriesByPlanAggregationCollection

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb

Overview

SQL performance statistics by plan over the selected time window.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SqlStatisticsTimeSeriesByPlanAggregationCollection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 91

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.sql_identifier = attributes[:'sqlIdentifier'] if attributes[:'sqlIdentifier']

  raise 'You cannot provide both :sqlIdentifier and :sql_identifier' if attributes.key?(:'sqlIdentifier') && attributes.key?(:'sql_identifier')

  self.sql_identifier = attributes[:'sql_identifier'] if attributes[:'sql_identifier']

  self.id = attributes[:'id'] if attributes[:'id']

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart']

  raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start')

  self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start']

  self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd']

  raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end')

  self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end']

  self.item_duration_in_ms = attributes[:'itemDurationInMs'] if attributes[:'itemDurationInMs']

  raise 'You cannot provide both :itemDurationInMs and :item_duration_in_ms' if attributes.key?(:'itemDurationInMs') && attributes.key?(:'item_duration_in_ms')

  self.item_duration_in_ms = attributes[:'item_duration_in_ms'] if attributes[:'item_duration_in_ms']

  self.end_timestamps = attributes[:'endTimestamps'] if attributes[:'endTimestamps']

  raise 'You cannot provide both :endTimestamps and :end_timestamps' if attributes.key?(:'endTimestamps') && attributes.key?(:'end_timestamps')

  self.end_timestamps = attributes[:'end_timestamps'] if attributes[:'end_timestamps']

  self.items = attributes[:'items'] if attributes[:'items']
end

Instance Attribute Details

#database_idString

Returns:

  • (String)


22
23
24
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 22

def database_id
  @database_id
end

#end_timestampsArray<DateTime>

[Required] Array comprising of all the sampling period end timestamps in RFC 3339 format.

Returns:

  • (Array<DateTime>)


39
40
41
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 39

def end_timestamps
  @end_timestamps
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.

Returns:

  • (String)


18
19
20
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 18

def id
  @id
end

#item_duration_in_msInteger

[Required] Time duration in milliseconds between data points (one hour or one day).

Returns:

  • (Integer)


35
36
37
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 35

def item_duration_in_ms
  @item_duration_in_ms
end

#itemsArray<OCI::Opsi::Models::SqlStatisticsTimeSeriesByPlanAggregation>

[Required] array of SQL performance statistics by plans



43
44
45
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 43

def items
  @items
end

#sql_identifierString

[Required] Unique SQL_ID for a SQL Statement.

Returns:

  • (String)


14
15
16
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 14

def sql_identifier
  @sql_identifier
end

#time_interval_endDateTime

[Required] The end timestamp that was passed into the request.

Returns:

  • (DateTime)


30
31
32
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 30

def time_interval_end
  @time_interval_end
end

#time_interval_startDateTime

[Required] The start timestamp that was passed into the request.

Returns:

  • (DateTime)


26
27
28
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 26

def time_interval_start
  @time_interval_start
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 46

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'sql_identifier': :'sqlIdentifier',
    'id': :'id',
    'database_id': :'databaseId',
    'time_interval_start': :'timeIntervalStart',
    'time_interval_end': :'timeIntervalEnd',
    'item_duration_in_ms': :'itemDurationInMs',
    'end_timestamps': :'endTimestamps',
    'items': :'items'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 62

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'sql_identifier': :'String',
    'id': :'String',
    'database_id': :'String',
    'time_interval_start': :'DateTime',
    'time_interval_end': :'DateTime',
    'item_duration_in_ms': :'Integer',
    'end_timestamps': :'Array<DateTime>',
    'items': :'Array<OCI::Opsi::Models::SqlStatisticsTimeSeriesByPlanAggregation>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 145

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    sql_identifier == other.sql_identifier &&
    id == other.id &&
    database_id == other.database_id &&
    time_interval_start == other.time_interval_start &&
    time_interval_end == other.time_interval_end &&
    item_duration_in_ms == other.item_duration_in_ms &&
    end_timestamps == other.end_timestamps &&
    items == other.items
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 182

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 162

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



171
172
173
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 171

def hash
  [sql_identifier, id, database_id, time_interval_start, time_interval_end, item_duration_in_ms, end_timestamps, items].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



209
210
211
# File 'lib/oci/opsi/models/sql_statistics_time_series_by_plan_aggregation_collection.rb', line 209

def to_s
  to_hash.to_s
end