Class: OCI::Opsi::Models::SqlTextSummary
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SqlTextSummary
- Defined in:
- lib/oci/opsi/models/sql_text_summary.rb
Overview
SQL Text details
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
-
#database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.
-
#sql_identifier ⇒ String
[Required] Unique SQL_ID for a SQL Statement.
-
#sql_text ⇒ String
[Required] SQL Text.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlTextSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlTextSummary
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.sql_identifier = attributes[:'sqlIdentifier'] if attributes[:'sqlIdentifier'] raise 'You cannot provide both :sqlIdentifier and :sql_identifier' if attributes.key?(:'sqlIdentifier') && attributes.key?(:'sql_identifier') self.sql_identifier = attributes[:'sql_identifier'] if attributes[:'sql_identifier'] self.id = attributes[:'id'] if attributes[:'id'] self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.sql_text = attributes[:'sqlText'] if attributes[:'sqlText'] raise 'You cannot provide both :sqlText and :sql_text' if attributes.key?(:'sqlText') && attributes.key?(:'sql_text') self.sql_text = attributes[:'sql_text'] if attributes[:'sql_text'] end |
Instance Attribute Details
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
26 27 28 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 26 def compartment_id @compartment_id end |
#database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
22 23 24 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 22 def database_id @database_id end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.
18 19 20 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 18 def id @id end |
#sql_identifier ⇒ String
[Required] Unique SQL_ID for a SQL Statement.
14 15 16 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 14 def sql_identifier @sql_identifier end |
#sql_text ⇒ String
[Required] SQL Text
30 31 32 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 30 def sql_text @sql_text end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'sql_identifier': :'sqlIdentifier', 'id': :'id', 'database_id': :'databaseId', 'compartment_id': :'compartmentId', 'sql_text': :'sqlText' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'sql_identifier': :'String', 'id': :'String', 'database_id': :'String', 'compartment_id': :'String', 'sql_text': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 109 def ==(other) return true if equal?(other) self.class == other.class && sql_identifier == other.sql_identifier && id == other.id && database_id == other.database_id && compartment_id == other.compartment_id && sql_text == other.sql_text end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 143 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
123 124 125 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 123 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
132 133 134 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 132 def hash [sql_identifier, id, database_id, compartment_id, sql_text].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 176 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
170 171 172 |
# File 'lib/oci/opsi/models/sql_text_summary.rb', line 170 def to_s to_hash.to_s end |