Class: OCI::Opsi::Models::SummarizeDatabaseInsightResourceStatisticsAggregationCollection
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SummarizeDatabaseInsightResourceStatisticsAggregationCollection
- Defined in:
- lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb
Overview
Returns list of the Databases with resource statistics like usage,capacity,utilization and usage change percent.
Constant Summary collapse
- RESOURCE_METRIC_ENUM =
[ RESOURCE_METRIC_CPU = 'CPU'.freeze, RESOURCE_METRIC_STORAGE = 'STORAGE'.freeze, RESOURCE_METRIC_IO = 'IO'.freeze, RESOURCE_METRIC_MEMORY = 'MEMORY'.freeze, RESOURCE_METRIC_MEMORY_PGA = 'MEMORY_PGA'.freeze, RESOURCE_METRIC_MEMORY_SGA = 'MEMORY_SGA'.freeze, RESOURCE_METRIC_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- USAGE_UNIT_ENUM =
[ USAGE_UNIT_CORES = 'CORES'.freeze, USAGE_UNIT_GB = 'GB'.freeze, USAGE_UNIT_MBPS = 'MBPS'.freeze, USAGE_UNIT_IOPS = 'IOPS'.freeze, USAGE_UNIT_PERCENT = 'PERCENT'.freeze, USAGE_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#items ⇒ Array<OCI::Opsi::Models::ResourceStatisticsAggregation>
[Required] Collection of Resource Statistics items.
-
#resource_metric ⇒ String
[Required] Defines the type of resource metric (example: CPU, STORAGE).
-
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
-
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
-
#usage_unit ⇒ String
[Required] Displays usage unit ( CORES, GB).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SummarizeDatabaseInsightResourceStatisticsAggregationCollection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SummarizeDatabaseInsightResourceStatisticsAggregationCollection
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 89 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart'] raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start') self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start'] self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd'] raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end') self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end'] self.resource_metric = attributes[:'resourceMetric'] if attributes[:'resourceMetric'] raise 'You cannot provide both :resourceMetric and :resource_metric' if attributes.key?(:'resourceMetric') && attributes.key?(:'resource_metric') self.resource_metric = attributes[:'resource_metric'] if attributes[:'resource_metric'] self.usage_unit = attributes[:'usageUnit'] if attributes[:'usageUnit'] raise 'You cannot provide both :usageUnit and :usage_unit' if attributes.key?(:'usageUnit') && attributes.key?(:'usage_unit') self.usage_unit = attributes[:'usage_unit'] if attributes[:'usage_unit'] self.items = attributes[:'items'] if attributes[:'items'] end |
Instance Attribute Details
#items ⇒ Array<OCI::Opsi::Models::ResourceStatisticsAggregation>
[Required] Collection of Resource Statistics items
50 51 52 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 50 def items @items end |
#resource_metric ⇒ String
[Required] Defines the type of resource metric (example: CPU, STORAGE)
41 42 43 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 41 def resource_metric @resource_metric end |
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
36 37 38 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 36 def time_interval_end @time_interval_end end |
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
32 33 34 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 32 def time_interval_start @time_interval_start end |
#usage_unit ⇒ String
[Required] Displays usage unit ( CORES, GB)
46 47 48 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 46 def usage_unit @usage_unit end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 53 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'timeIntervalStart', 'time_interval_end': :'timeIntervalEnd', 'resource_metric': :'resourceMetric', 'usage_unit': :'usageUnit', 'items': :'items' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'DateTime', 'time_interval_end': :'DateTime', 'resource_metric': :'String', 'usage_unit': :'String', 'items': :'Array<OCI::Opsi::Models::ResourceStatisticsAggregation>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 155 def ==(other) return true if equal?(other) self.class == other.class && time_interval_start == other.time_interval_start && time_interval_end == other.time_interval_end && resource_metric == other.resource_metric && usage_unit == other.usage_unit && items == other.items end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 189 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
169 170 171 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 169 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 178 def hash [time_interval_start, time_interval_end, resource_metric, usage_unit, items].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/oci/opsi/models/summarize_database_insight_resource_statistics_aggregation_collection.rb', line 216 def to_s to_hash.to_s end |