Class: OCI::Opsi::Models::SummarizeDatabaseInsightTablespaceUsageTrendAggregationCollection
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SummarizeDatabaseInsightTablespaceUsageTrendAggregationCollection
- Defined in:
- lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb
Overview
Top level response object.
Constant Summary collapse
- USAGE_UNIT_ENUM =
[ USAGE_UNIT_CORES = 'CORES'.freeze, USAGE_UNIT_GB = 'GB'.freeze, USAGE_UNIT_MBPS = 'MBPS'.freeze, USAGE_UNIT_PERCENT = 'PERCENT'.freeze, USAGE_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#item_duration_in_ms ⇒ Integer
[Required] Time duration in milliseconds between data points (one hour or one day).
-
#items ⇒ Array<OCI::Opsi::Models::TablespaceUsageTrendAggregation>
[Required] Collection of Usage Data with time stamps for top five tablespace.
-
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
-
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
-
#usage_unit ⇒ String
[Required] Displays usage unit ( CORES, GB).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SummarizeDatabaseInsightTablespaceUsageTrendAggregationCollection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SummarizeDatabaseInsightTablespaceUsageTrendAggregationCollection
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart'] raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start') self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start'] self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd'] raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end') self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end'] self.usage_unit = attributes[:'usageUnit'] if attributes[:'usageUnit'] raise 'You cannot provide both :usageUnit and :usage_unit' if attributes.key?(:'usageUnit') && attributes.key?(:'usage_unit') self.usage_unit = attributes[:'usage_unit'] if attributes[:'usage_unit'] self.item_duration_in_ms = attributes[:'itemDurationInMs'] if attributes[:'itemDurationInMs'] raise 'You cannot provide both :itemDurationInMs and :item_duration_in_ms' if attributes.key?(:'itemDurationInMs') && attributes.key?(:'item_duration_in_ms') self.item_duration_in_ms = attributes[:'item_duration_in_ms'] if attributes[:'item_duration_in_ms'] self.items = attributes[:'items'] if attributes[:'items'] end |
Instance Attribute Details
#item_duration_in_ms ⇒ Integer
[Required] Time duration in milliseconds between data points (one hour or one day).
36 37 38 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 36 def item_duration_in_ms @item_duration_in_ms end |
#items ⇒ Array<OCI::Opsi::Models::TablespaceUsageTrendAggregation>
[Required] Collection of Usage Data with time stamps for top five tablespace
41 42 43 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 41 def items @items end |
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
26 27 28 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 26 def time_interval_end @time_interval_end end |
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
22 23 24 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 22 def time_interval_start @time_interval_start end |
#usage_unit ⇒ String
[Required] Displays usage unit ( CORES, GB)
31 32 33 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 31 def usage_unit @usage_unit end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'timeIntervalStart', 'time_interval_end': :'timeIntervalEnd', 'usage_unit': :'usageUnit', 'item_duration_in_ms': :'itemDurationInMs', 'items': :'items' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'DateTime', 'time_interval_end': :'DateTime', 'usage_unit': :'String', 'item_duration_in_ms': :'Integer', 'items': :'Array<OCI::Opsi::Models::TablespaceUsageTrendAggregation>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 133 def ==(other) return true if equal?(other) self.class == other.class && time_interval_start == other.time_interval_start && time_interval_end == other.time_interval_end && usage_unit == other.usage_unit && item_duration_in_ms == other.item_duration_in_ms && items == other.items end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 167 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
147 148 149 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 147 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 156 def hash [time_interval_start, time_interval_end, usage_unit, item_duration_in_ms, items].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
194 195 196 |
# File 'lib/oci/opsi/models/summarize_database_insight_tablespace_usage_trend_aggregation_collection.rb', line 194 def to_s to_hash.to_s end |