Class: OCI::Opsi::Models::SummarizeExadataInsightResourceForecastTrendAggregation

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb

Overview

Usage and Forecast results from the selected time period.

Constant Summary collapse

EXADATA_RESOURCE_METRIC_ENUM =
[
  EXADATA_RESOURCE_METRIC_CPU = 'CPU'.freeze,
  EXADATA_RESOURCE_METRIC_STORAGE = 'STORAGE'.freeze,
  EXADATA_RESOURCE_METRIC_IO = 'IO'.freeze,
  EXADATA_RESOURCE_METRIC_MEMORY = 'MEMORY'.freeze,
  EXADATA_RESOURCE_METRIC_IOPS = 'IOPS'.freeze,
  EXADATA_RESOURCE_METRIC_THROUGHPUT = 'THROUGHPUT'.freeze,
  EXADATA_RESOURCE_METRIC_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
EXADATA_RESOURCE_TYPE_ENUM =
[
  EXADATA_RESOURCE_TYPE_DATABASE = 'DATABASE'.freeze,
  EXADATA_RESOURCE_TYPE_HOST = 'HOST'.freeze,
  EXADATA_RESOURCE_TYPE_STORAGE_SERVER = 'STORAGE_SERVER'.freeze,
  EXADATA_RESOURCE_TYPE_DISKGROUP = 'DISKGROUP'.freeze,
  EXADATA_RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
USAGE_UNIT_ENUM =
[
  USAGE_UNIT_CORES = 'CORES'.freeze,
  USAGE_UNIT_GB = 'GB'.freeze,
  USAGE_UNIT_MBPS = 'MBPS'.freeze,
  USAGE_UNIT_IOPS = 'IOPS'.freeze,
  USAGE_UNIT_PERCENT = 'PERCENT'.freeze,
  USAGE_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PATTERN_ENUM =
[
  PATTERN_LINEAR = 'LINEAR'.freeze,
  PATTERN_MONTHLY_SEASONS = 'MONTHLY_SEASONS'.freeze,
  PATTERN_MONTHLY_AND_YEARLY_SEASONS = 'MONTHLY_AND_YEARLY_SEASONS'.freeze,
  PATTERN_WEEKLY_SEASONS = 'WEEKLY_SEASONS'.freeze,
  PATTERN_WEEKLY_AND_MONTHLY_SEASONS = 'WEEKLY_AND_MONTHLY_SEASONS'.freeze,
  PATTERN_WEEKLY_MONTHLY_AND_YEARLY_SEASONS = 'WEEKLY_MONTHLY_AND_YEARLY_SEASONS'.freeze,
  PATTERN_WEEKLY_AND_YEARLY_SEASONS = 'WEEKLY_AND_YEARLY_SEASONS'.freeze,
  PATTERN_YEARLY_SEASONS = 'YEARLY_SEASONS'.freeze,
  PATTERN_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SummarizeExadataInsightResourceForecastTrendAggregation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 138

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart']

  raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start')

  self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start']

  self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd']

  raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end')

  self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end']

  self.exadata_resource_metric = attributes[:'exadataResourceMetric'] if attributes[:'exadataResourceMetric']

  raise 'You cannot provide both :exadataResourceMetric and :exadata_resource_metric' if attributes.key?(:'exadataResourceMetric') && attributes.key?(:'exadata_resource_metric')

  self.exadata_resource_metric = attributes[:'exadata_resource_metric'] if attributes[:'exadata_resource_metric']

  self.exadata_resource_type = attributes[:'exadataResourceType'] if attributes[:'exadataResourceType']

  raise 'You cannot provide both :exadataResourceType and :exadata_resource_type' if attributes.key?(:'exadataResourceType') && attributes.key?(:'exadata_resource_type')

  self.exadata_resource_type = attributes[:'exadata_resource_type'] if attributes[:'exadata_resource_type']

  self.usage_unit = attributes[:'usageUnit'] if attributes[:'usageUnit']

  raise 'You cannot provide both :usageUnit and :usage_unit' if attributes.key?(:'usageUnit') && attributes.key?(:'usage_unit')

  self.usage_unit = attributes[:'usage_unit'] if attributes[:'usage_unit']

  self.pattern = attributes[:'pattern'] if attributes[:'pattern']

  self.days_to_reach_capacity = attributes[:'daysToReachCapacity'] if attributes[:'daysToReachCapacity']

  raise 'You cannot provide both :daysToReachCapacity and :days_to_reach_capacity' if attributes.key?(:'daysToReachCapacity') && attributes.key?(:'days_to_reach_capacity')

  self.days_to_reach_capacity = attributes[:'days_to_reach_capacity'] if attributes[:'days_to_reach_capacity']

  self.historical_data = attributes[:'historicalData'] if attributes[:'historicalData']

  raise 'You cannot provide both :historicalData and :historical_data' if attributes.key?(:'historicalData') && attributes.key?(:'historical_data')

  self.historical_data = attributes[:'historical_data'] if attributes[:'historical_data']

  self.projected_data = attributes[:'projectedData'] if attributes[:'projectedData']

  raise 'You cannot provide both :projectedData and :projected_data' if attributes.key?(:'projectedData') && attributes.key?(:'projected_data')

  self.projected_data = attributes[:'projected_data'] if attributes[:'projected_data']
end

Instance Attribute Details

#days_to_reach_capacityInteger

[Required] Days to reach capacity for a storage server

Returns:

  • (Integer)


79
80
81
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 79

def days_to_reach_capacity
  @days_to_reach_capacity
end

#exadata_resource_metricString

[Required] Defines the type of exadata resource metric (example: CPU, STORAGE)

Returns:

  • (String)


61
62
63
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 61

def exadata_resource_metric
  @exadata_resource_metric
end

#exadata_resource_typeString

[Required] Defines the resource type for an exadata (example: DATABASE, STORAGE_SERVER, HOST, DISKGROUP)

Returns:

  • (String)


66
67
68
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 66

def exadata_resource_type
  @exadata_resource_type
end

#historical_dataArray<OCI::Opsi::Models::HistoricalDataItem>

[Required] Time series data used for the forecast analysis.



83
84
85
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 83

def historical_data
  @historical_data
end

#patternString

[Required] Time series patterns used in the forecasting.

Returns:

  • (String)


75
76
77
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 75

def pattern
  @pattern
end

#projected_dataArray<OCI::Opsi::Models::ProjectedDataItem>

[Required] Time series data result of the forecasting analysis.



87
88
89
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 87

def projected_data
  @projected_data
end

#time_interval_endDateTime

[Required] The end timestamp that was passed into the request.

Returns:

  • (DateTime)


56
57
58
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 56

def time_interval_end
  @time_interval_end
end

#time_interval_startDateTime

[Required] The start timestamp that was passed into the request.

Returns:

  • (DateTime)


52
53
54
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 52

def time_interval_start
  @time_interval_start
end

#usage_unitString

[Required] Displays usage unit ( CORES, GB)

Returns:

  • (String)


71
72
73
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 71

def usage_unit
  @usage_unit
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 90

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'time_interval_start': :'timeIntervalStart',
    'time_interval_end': :'timeIntervalEnd',
    'exadata_resource_metric': :'exadataResourceMetric',
    'exadata_resource_type': :'exadataResourceType',
    'usage_unit': :'usageUnit',
    'pattern': :'pattern',
    'days_to_reach_capacity': :'daysToReachCapacity',
    'historical_data': :'historicalData',
    'projected_data': :'projectedData'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 107

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'time_interval_start': :'DateTime',
    'time_interval_end': :'DateTime',
    'exadata_resource_metric': :'String',
    'exadata_resource_type': :'String',
    'usage_unit': :'String',
    'pattern': :'String',
    'days_to_reach_capacity': :'Integer',
    'historical_data': :'Array<OCI::Opsi::Models::HistoricalDataItem>',
    'projected_data': :'Array<OCI::Opsi::Models::ProjectedDataItem>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 254

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    time_interval_start == other.time_interval_start &&
    time_interval_end == other.time_interval_end &&
    exadata_resource_metric == other.exadata_resource_metric &&
    exadata_resource_type == other.exadata_resource_type &&
    usage_unit == other.usage_unit &&
    pattern == other.pattern &&
    days_to_reach_capacity == other.days_to_reach_capacity &&
    historical_data == other.historical_data &&
    projected_data == other.projected_data
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 292

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 272

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



281
282
283
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 281

def hash
  [time_interval_start, time_interval_end, exadata_resource_metric, exadata_resource_type, usage_unit, pattern, days_to_reach_capacity, historical_data, projected_data].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
328
329
330
331
332
333
334
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 325

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



319
320
321
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_forecast_trend_aggregation.rb', line 319

def to_s
  to_hash.to_s
end