Class: OCI::Opsi::Models::SummarizeExadataInsightResourceStatisticsAggregationCollection
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SummarizeExadataInsightResourceStatisticsAggregationCollection
- Defined in:
- lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb
Overview
Returns list of the resources with resource statistics like usage,capacity,utilization and usage change percent.
Constant Summary collapse
- USAGE_UNIT_ENUM =
[ USAGE_UNIT_CORES = 'CORES'.freeze, USAGE_UNIT_GB = 'GB'.freeze, USAGE_UNIT_MBPS = 'MBPS'.freeze, USAGE_UNIT_IOPS = 'IOPS'.freeze, USAGE_UNIT_PERCENT = 'PERCENT'.freeze, USAGE_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- EXADATA_RESOURCE_METRIC_ENUM =
[ EXADATA_RESOURCE_METRIC_CPU = 'CPU'.freeze, EXADATA_RESOURCE_METRIC_STORAGE = 'STORAGE'.freeze, EXADATA_RESOURCE_METRIC_IO = 'IO'.freeze, EXADATA_RESOURCE_METRIC_MEMORY = 'MEMORY'.freeze, EXADATA_RESOURCE_METRIC_IOPS = 'IOPS'.freeze, EXADATA_RESOURCE_METRIC_THROUGHPUT = 'THROUGHPUT'.freeze, EXADATA_RESOURCE_METRIC_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#exadata_insight_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
-
#exadata_resource_metric ⇒ String
[Required] Defines the type of exadata resource metric (example: CPU, STORAGE).
-
#items ⇒ Array<OCI::Opsi::Models::ExadataInsightResourceStatisticsAggregation>
[Required] Collection of Resource Statistics items.
-
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
-
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
-
#usage_unit ⇒ String
[Required] Displays usage unit ( CORES, GB).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SummarizeExadataInsightResourceStatisticsAggregationCollection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SummarizeExadataInsightResourceStatisticsAggregationCollection
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 96 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart'] raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start') self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start'] self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd'] raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end') self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end'] self.items = attributes[:'items'] if attributes[:'items'] self.usage_unit = attributes[:'usageUnit'] if attributes[:'usageUnit'] raise 'You cannot provide both :usageUnit and :usage_unit' if attributes.key?(:'usageUnit') && attributes.key?(:'usage_unit') self.usage_unit = attributes[:'usage_unit'] if attributes[:'usage_unit'] self.exadata_resource_metric = attributes[:'exadataResourceMetric'] if attributes[:'exadataResourceMetric'] raise 'You cannot provide both :exadataResourceMetric and :exadata_resource_metric' if attributes.key?(:'exadataResourceMetric') && attributes.key?(:'exadata_resource_metric') self.exadata_resource_metric = attributes[:'exadata_resource_metric'] if attributes[:'exadata_resource_metric'] self.exadata_insight_id = attributes[:'exadataInsightId'] if attributes[:'exadataInsightId'] raise 'You cannot provide both :exadataInsightId and :exadata_insight_id' if attributes.key?(:'exadataInsightId') && attributes.key?(:'exadata_insight_id') self.exadata_insight_id = attributes[:'exadata_insight_id'] if attributes[:'exadata_insight_id'] end |
Instance Attribute Details
#exadata_insight_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
54 55 56 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 54 def exadata_insight_id @exadata_insight_id end |
#exadata_resource_metric ⇒ String
[Required] Defines the type of exadata resource metric (example: CPU, STORAGE)
50 51 52 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 50 def exadata_resource_metric @exadata_resource_metric end |
#items ⇒ Array<OCI::Opsi::Models::ExadataInsightResourceStatisticsAggregation>
[Required] Collection of Resource Statistics items
40 41 42 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 40 def items @items end |
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
36 37 38 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 36 def time_interval_end @time_interval_end end |
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
32 33 34 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 32 def time_interval_start @time_interval_start end |
#usage_unit ⇒ String
[Required] Displays usage unit ( CORES, GB)
45 46 47 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 45 def usage_unit @usage_unit end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'timeIntervalStart', 'time_interval_end': :'timeIntervalEnd', 'items': :'items', 'usage_unit': :'usageUnit', 'exadata_resource_metric': :'exadataResourceMetric', 'exadata_insight_id': :'exadataInsightId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 71 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'DateTime', 'time_interval_end': :'DateTime', 'items': :'Array<OCI::Opsi::Models::ExadataInsightResourceStatisticsAggregation>', 'usage_unit': :'String', 'exadata_resource_metric': :'String', 'exadata_insight_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 168 def ==(other) return true if equal?(other) self.class == other.class && time_interval_start == other.time_interval_start && time_interval_end == other.time_interval_end && items == other.items && usage_unit == other.usage_unit && exadata_resource_metric == other.exadata_resource_metric && exadata_insight_id == other.exadata_insight_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 203 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
183 184 185 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 183 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 192 def hash [time_interval_start, time_interval_end, items, usage_unit, exadata_resource_metric, exadata_insight_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
230 231 232 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_statistics_aggregation_collection.rb', line 230 def to_s to_hash.to_s end |