Class: OCI::Opsi::Models::SummarizeHostInsightResourceCapacityTrendAggregationCollection
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SummarizeHostInsightResourceCapacityTrendAggregationCollection
- Defined in:
- lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb
Overview
Top level response object.
Constant Summary collapse
- RESOURCE_METRIC_ENUM =
[ RESOURCE_METRIC_CPU = 'CPU'.freeze, RESOURCE_METRIC_MEMORY = 'MEMORY'.freeze, RESOURCE_METRIC_LOGICAL_MEMORY = 'LOGICAL_MEMORY'.freeze, RESOURCE_METRIC_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- USAGE_UNIT_ENUM =
[ USAGE_UNIT_CORES = 'CORES'.freeze, USAGE_UNIT_GB = 'GB'.freeze, USAGE_UNIT_MBPS = 'MBPS'.freeze, USAGE_UNIT_IOPS = 'IOPS'.freeze, USAGE_UNIT_PERCENT = 'PERCENT'.freeze, USAGE_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#capacity_data ⇒ Array<OCI::Opsi::Models::HostResourceCapacityTrendAggregation>
[Required] Capacity Data with timestamp.
-
#item_duration_in_ms ⇒ Integer
[Required] Time duration in milliseconds between data points (one hour or one day).
-
#resource_metric ⇒ String
[Required] Defines the type of resource metric (CPU, Physical Memory, Logical Memory).
-
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
-
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
-
#usage_unit ⇒ String
[Required] Displays usage unit (CORES, GB).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SummarizeHostInsightResourceCapacityTrendAggregationCollection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SummarizeHostInsightResourceCapacityTrendAggregationCollection
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 96 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart'] raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start') self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start'] self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd'] raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end') self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end'] self.resource_metric = attributes[:'resourceMetric'] if attributes[:'resourceMetric'] raise 'You cannot provide both :resourceMetric and :resource_metric' if attributes.key?(:'resourceMetric') && attributes.key?(:'resource_metric') self.resource_metric = attributes[:'resource_metric'] if attributes[:'resource_metric'] self.usage_unit = attributes[:'usageUnit'] if attributes[:'usageUnit'] raise 'You cannot provide both :usageUnit and :usage_unit' if attributes.key?(:'usageUnit') && attributes.key?(:'usage_unit') self.usage_unit = attributes[:'usage_unit'] if attributes[:'usage_unit'] self.item_duration_in_ms = attributes[:'itemDurationInMs'] if attributes[:'itemDurationInMs'] raise 'You cannot provide both :itemDurationInMs and :item_duration_in_ms' if attributes.key?(:'itemDurationInMs') && attributes.key?(:'item_duration_in_ms') self.item_duration_in_ms = attributes[:'item_duration_in_ms'] if attributes[:'item_duration_in_ms'] self.capacity_data = attributes[:'capacityData'] if attributes[:'capacityData'] raise 'You cannot provide both :capacityData and :capacity_data' if attributes.key?(:'capacityData') && attributes.key?(:'capacity_data') self.capacity_data = attributes[:'capacity_data'] if attributes[:'capacity_data'] end |
Instance Attribute Details
#capacity_data ⇒ Array<OCI::Opsi::Models::HostResourceCapacityTrendAggregation>
[Required] Capacity Data with timestamp.
54 55 56 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 54 def capacity_data @capacity_data end |
#item_duration_in_ms ⇒ Integer
[Required] Time duration in milliseconds between data points (one hour or one day).
49 50 51 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 49 def item_duration_in_ms @item_duration_in_ms end |
#resource_metric ⇒ String
[Required] Defines the type of resource metric (CPU, Physical Memory, Logical Memory)
39 40 41 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 39 def resource_metric @resource_metric end |
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
34 35 36 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 34 def time_interval_end @time_interval_end end |
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
30 31 32 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 30 def time_interval_start @time_interval_start end |
#usage_unit ⇒ String
[Required] Displays usage unit (CORES, GB)
44 45 46 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 44 def usage_unit @usage_unit end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'timeIntervalStart', 'time_interval_end': :'timeIntervalEnd', 'resource_metric': :'resourceMetric', 'usage_unit': :'usageUnit', 'item_duration_in_ms': :'itemDurationInMs', 'capacity_data': :'capacityData' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 71 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'DateTime', 'time_interval_end': :'DateTime', 'resource_metric': :'String', 'usage_unit': :'String', 'item_duration_in_ms': :'Integer', 'capacity_data': :'Array<OCI::Opsi::Models::HostResourceCapacityTrendAggregation>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 172 def ==(other) return true if equal?(other) self.class == other.class && time_interval_start == other.time_interval_start && time_interval_end == other.time_interval_end && resource_metric == other.resource_metric && usage_unit == other.usage_unit && item_duration_in_ms == other.item_duration_in_ms && capacity_data == other.capacity_data end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 207 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
187 188 189 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 187 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 196 def hash [time_interval_start, time_interval_end, resource_metric, usage_unit, item_duration_in_ms, capacity_data].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 240 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
234 235 236 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_capacity_trend_aggregation_collection.rb', line 234 def to_s to_hash.to_s end |