Class: OCI::Opsi::Models::SummarizeHostInsightResourceUsageAggregation
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SummarizeHostInsightResourceUsageAggregation
- Defined in:
- lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb
Overview
Resource usage summation for the current time period.
Constant Summary collapse
- RESOURCE_METRIC_ENUM =
[ RESOURCE_METRIC_CPU = 'CPU'.freeze, RESOURCE_METRIC_MEMORY = 'MEMORY'.freeze, RESOURCE_METRIC_LOGICAL_MEMORY = 'LOGICAL_MEMORY'.freeze, RESOURCE_METRIC_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- USAGE_UNIT_ENUM =
[ USAGE_UNIT_CORES = 'CORES'.freeze, USAGE_UNIT_GB = 'GB'.freeze, USAGE_UNIT_MBPS = 'MBPS'.freeze, USAGE_UNIT_IOPS = 'IOPS'.freeze, USAGE_UNIT_PERCENT = 'PERCENT'.freeze, USAGE_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#capacity ⇒ Float
[Required] The maximum allocated amount of the resource metric type (CPU, STORAGE).
-
#resource_metric ⇒ String
[Required] Defines the type of resource metric (CPU, Physical Memory, Logical Memory).
-
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
-
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
-
#usage ⇒ Float
[Required] Total amount used of the resource metric type (CPU, STORAGE).
-
#usage_change_percent ⇒ Float
[Required] Percentage change in resource usage during the current period calculated using linear regression functions.
-
#usage_unit ⇒ String
[Required] Displays usage unit (CORES, GB).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SummarizeHostInsightResourceUsageAggregation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SummarizeHostInsightResourceUsageAggregation
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 103 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart'] raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start') self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start'] self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd'] raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end') self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end'] self.resource_metric = attributes[:'resourceMetric'] if attributes[:'resourceMetric'] raise 'You cannot provide both :resourceMetric and :resource_metric' if attributes.key?(:'resourceMetric') && attributes.key?(:'resource_metric') self.resource_metric = attributes[:'resource_metric'] if attributes[:'resource_metric'] self.usage_unit = attributes[:'usageUnit'] if attributes[:'usageUnit'] raise 'You cannot provide both :usageUnit and :usage_unit' if attributes.key?(:'usageUnit') && attributes.key?(:'usage_unit') self.usage_unit = attributes[:'usage_unit'] if attributes[:'usage_unit'] self.usage = attributes[:'usage'] if attributes[:'usage'] self.capacity = attributes[:'capacity'] if attributes[:'capacity'] self.usage_change_percent = attributes[:'usageChangePercent'] if attributes[:'usageChangePercent'] raise 'You cannot provide both :usageChangePercent and :usage_change_percent' if attributes.key?(:'usageChangePercent') && attributes.key?(:'usage_change_percent') self.usage_change_percent = attributes[:'usage_change_percent'] if attributes[:'usage_change_percent'] end |
Instance Attribute Details
#capacity ⇒ Float
[Required] The maximum allocated amount of the resource metric type (CPU, STORAGE).
54 55 56 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 54 def capacity @capacity end |
#resource_metric ⇒ String
[Required] Defines the type of resource metric (CPU, Physical Memory, Logical Memory)
39 40 41 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 39 def resource_metric @resource_metric end |
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
34 35 36 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 34 def time_interval_end @time_interval_end end |
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
30 31 32 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 30 def time_interval_start @time_interval_start end |
#usage ⇒ Float
[Required] Total amount used of the resource metric type (CPU, STORAGE).
49 50 51 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 49 def usage @usage end |
#usage_change_percent ⇒ Float
[Required] Percentage change in resource usage during the current period calculated using linear regression functions
58 59 60 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 58 def usage_change_percent @usage_change_percent end |
#usage_unit ⇒ String
[Required] Displays usage unit (CORES, GB)
44 45 46 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 44 def usage_unit @usage_unit end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 61 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'timeIntervalStart', 'time_interval_end': :'timeIntervalEnd', 'resource_metric': :'resourceMetric', 'usage_unit': :'usageUnit', 'usage': :'usage', 'capacity': :'capacity', 'usage_change_percent': :'usageChangePercent' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 76 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'DateTime', 'time_interval_end': :'DateTime', 'resource_metric': :'String', 'usage_unit': :'String', 'usage': :'Float', 'capacity': :'Float', 'usage_change_percent': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 177 def ==(other) return true if equal?(other) self.class == other.class && time_interval_start == other.time_interval_start && time_interval_end == other.time_interval_end && resource_metric == other.resource_metric && usage_unit == other.usage_unit && usage == other.usage && capacity == other.capacity && usage_change_percent == other.usage_change_percent end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 213 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
193 194 195 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 193 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 202 def hash [time_interval_start, time_interval_end, resource_metric, usage_unit, usage, capacity, usage_change_percent].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 246 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
240 241 242 |
# File 'lib/oci/opsi/models/summarize_host_insight_resource_usage_aggregation.rb', line 240 def to_s to_hash.to_s end |