Class: OCI::Opsi::Models::TopProcessesUsageTrend
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::TopProcessesUsageTrend
- Defined in:
- lib/oci/opsi/models/top_processes_usage_trend.rb
Overview
Aggregated data for top processes
Instance Attribute Summary collapse
-
#cpu_usage ⇒ Float
**[Required]** Process CPU usage.
-
#cpu_utilization ⇒ Float
**[Required]** Process CPU utilization percentage.
-
#end_timestamp ⇒ DateTime
**[Required]** The timestamp in which the current sampling period ends in RFC 3339 format.
-
#max_process_count ⇒ Integer
**[Required]** Maximum number of processes running at time of collection.
-
#memory_utilization ⇒ Float
**[Required]** Process memory utilization percentage.
-
#physical_memory_in_mbs ⇒ Float
**[Required]** Procress physical memory in Megabytes.
-
#virtual_memory_in_mbs ⇒ Float
**[Required]** Process virtual memory in Megabytes.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TopProcessesUsageTrend
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TopProcessesUsageTrend
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'endTimestamp'] if attributes[:'endTimestamp'] raise 'You cannot provide both :endTimestamp and :end_timestamp' if attributes.key?(:'endTimestamp') && attributes.key?(:'end_timestamp') self. = attributes[:'end_timestamp'] if attributes[:'end_timestamp'] self.cpu_usage = attributes[:'cpuUsage'] if attributes[:'cpuUsage'] raise 'You cannot provide both :cpuUsage and :cpu_usage' if attributes.key?(:'cpuUsage') && attributes.key?(:'cpu_usage') self.cpu_usage = attributes[:'cpu_usage'] if attributes[:'cpu_usage'] self.cpu_utilization = attributes[:'cpuUtilization'] if attributes[:'cpuUtilization'] raise 'You cannot provide both :cpuUtilization and :cpu_utilization' if attributes.key?(:'cpuUtilization') && attributes.key?(:'cpu_utilization') self.cpu_utilization = attributes[:'cpu_utilization'] if attributes[:'cpu_utilization'] self.memory_utilization = attributes[:'memoryUtilization'] if attributes[:'memoryUtilization'] raise 'You cannot provide both :memoryUtilization and :memory_utilization' if attributes.key?(:'memoryUtilization') && attributes.key?(:'memory_utilization') self.memory_utilization = attributes[:'memory_utilization'] if attributes[:'memory_utilization'] self.virtual_memory_in_mbs = attributes[:'virtualMemoryInMBs'] if attributes[:'virtualMemoryInMBs'] raise 'You cannot provide both :virtualMemoryInMBs and :virtual_memory_in_mbs' if attributes.key?(:'virtualMemoryInMBs') && attributes.key?(:'virtual_memory_in_mbs') self.virtual_memory_in_mbs = attributes[:'virtual_memory_in_mbs'] if attributes[:'virtual_memory_in_mbs'] self.physical_memory_in_mbs = attributes[:'physicalMemoryInMBs'] if attributes[:'physicalMemoryInMBs'] raise 'You cannot provide both :physicalMemoryInMBs and :physical_memory_in_mbs' if attributes.key?(:'physicalMemoryInMBs') && attributes.key?(:'physical_memory_in_mbs') self.physical_memory_in_mbs = attributes[:'physical_memory_in_mbs'] if attributes[:'physical_memory_in_mbs'] self.max_process_count = attributes[:'maxProcessCount'] if attributes[:'maxProcessCount'] raise 'You cannot provide both :maxProcessCount and :max_process_count' if attributes.key?(:'maxProcessCount') && attributes.key?(:'max_process_count') self.max_process_count = attributes[:'max_process_count'] if attributes[:'max_process_count'] end |
Instance Attribute Details
#cpu_usage ⇒ Float
**[Required]** Process CPU usage.
16 17 18 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 16 def cpu_usage @cpu_usage end |
#cpu_utilization ⇒ Float
**[Required]** Process CPU utilization percentage
20 21 22 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 20 def cpu_utilization @cpu_utilization end |
#end_timestamp ⇒ DateTime
**[Required]** The timestamp in which the current sampling period ends in RFC 3339 format.
12 13 14 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 12 def @end_timestamp end |
#max_process_count ⇒ Integer
**[Required]** Maximum number of processes running at time of collection
36 37 38 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 36 def max_process_count @max_process_count end |
#memory_utilization ⇒ Float
**[Required]** Process memory utilization percentage
24 25 26 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 24 def memory_utilization @memory_utilization end |
#physical_memory_in_mbs ⇒ Float
**[Required]** Procress physical memory in Megabytes
32 33 34 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 32 def physical_memory_in_mbs @physical_memory_in_mbs end |
#virtual_memory_in_mbs ⇒ Float
**[Required]** Process virtual memory in Megabytes
28 29 30 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 28 def virtual_memory_in_mbs @virtual_memory_in_mbs end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'end_timestamp': :'endTimestamp', 'cpu_usage': :'cpuUsage', 'cpu_utilization': :'cpuUtilization', 'memory_utilization': :'memoryUtilization', 'virtual_memory_in_mbs': :'virtualMemoryInMBs', 'physical_memory_in_mbs': :'physicalMemoryInMBs', 'max_process_count': :'maxProcessCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'end_timestamp': :'DateTime', 'cpu_usage': :'Float', 'cpu_utilization': :'Float', 'memory_utilization': :'Float', 'virtual_memory_in_mbs': :'Float', 'physical_memory_in_mbs': :'Float', 'max_process_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 137 def ==(other) return true if equal?(other) self.class == other.class && == other. && cpu_usage == other.cpu_usage && cpu_utilization == other.cpu_utilization && memory_utilization == other.memory_utilization && virtual_memory_in_mbs == other.virtual_memory_in_mbs && physical_memory_in_mbs == other.physical_memory_in_mbs && max_process_count == other.max_process_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
153 154 155 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 153 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 162 def hash [, cpu_usage, cpu_utilization, memory_utilization, virtual_memory_in_mbs, physical_memory_in_mbs, max_process_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
200 201 202 |
# File 'lib/oci/opsi/models/top_processes_usage_trend.rb', line 200 def to_s to_hash.to_s end |