Class: OCI::Optimizer::Models::BulkApplyRecommendationsDetails
- Inherits:
-
Object
- Object
- OCI::Optimizer::Models::BulkApplyRecommendationsDetails
- Defined in:
- lib/oci/optimizer/models/bulk_apply_recommendations_details.rb
Overview
Details about bulk recommendation actions.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_PENDING = 'PENDING'.freeze, STATUS_DISMISSED = 'DISMISSED'.freeze, STATUS_POSTPONED = 'POSTPONED'.freeze, STATUS_IMPLEMENTED = 'IMPLEMENTED'.freeze ].freeze
Instance Attribute Summary collapse
-
#actions ⇒ Array<OCI::Optimizer::Models::BulkApplyResourceAction>
The unique resource actions that recommendations are applied to.
-
#resource_action_ids ⇒ Array<String>
The unique OCIDs of the resource actions that recommendations are applied to.
-
#status ⇒ String
**[Required]** The current status of the recommendation.
-
#time_status_end ⇒ DateTime
The date and time the current status will change.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BulkApplyRecommendationsDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BulkApplyRecommendationsDetails
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.resource_action_ids = attributes[:'resourceActionIds'] if attributes[:'resourceActionIds'] raise 'You cannot provide both :resourceActionIds and :resource_action_ids' if attributes.key?(:'resourceActionIds') && attributes.key?(:'resource_action_ids') self.resource_action_ids = attributes[:'resource_action_ids'] if attributes[:'resource_action_ids'] self.actions = attributes[:'actions'] if attributes[:'actions'] self.status = attributes[:'status'] if attributes[:'status'] self.time_status_end = attributes[:'timeStatusEnd'] if attributes[:'timeStatusEnd'] raise 'You cannot provide both :timeStatusEnd and :time_status_end' if attributes.key?(:'timeStatusEnd') && attributes.key?(:'time_status_end') self.time_status_end = attributes[:'time_status_end'] if attributes[:'time_status_end'] end |
Instance Attribute Details
#actions ⇒ Array<OCI::Optimizer::Models::BulkApplyResourceAction>
The unique resource actions that recommendations are applied to.
26 27 28 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 26 def actions @actions end |
#resource_action_ids ⇒ Array<String>
The unique OCIDs of the resource actions that recommendations are applied to.
This field is deprecated.
22 23 24 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 22 def resource_action_ids @resource_action_ids end |
#status ⇒ String
**[Required]** The current status of the recommendation.
30 31 32 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 30 def status @status end |
#time_status_end ⇒ DateTime
The date and time the current status will change. The format is defined by RFC3339.
For example, "The current `postponed` status of the resource action will end and change to `pending` on this date and time."
38 39 40 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 38 def time_status_end @time_status_end end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'resource_action_ids': :'resourceActionIds', 'actions': :'actions', 'status': :'status', 'time_status_end': :'timeStatusEnd' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'resource_action_ids': :'Array<String>', 'actions': :'Array<OCI::Optimizer::Models::BulkApplyResourceAction>', 'status': :'String', 'time_status_end': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && resource_action_ids == other.resource_action_ids && actions == other.actions && status == other.status && time_status_end == other.time_status_end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 134 def hash [resource_action_ids, actions, status, time_status_end].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/optimizer/models/bulk_apply_recommendations_details.rb', line 172 def to_s to_hash.to_s end |