Class: OCI::Optimizer::Models::CreateProfileDetails
- Inherits:
-
Object
- Object
- OCI::Optimizer::Models::CreateProfileDetails
- Defined in:
- lib/oci/optimizer/models/create_profile_details.rb
Overview
Details for creating a profile.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the tenancy.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
[Required] Text describing the profile.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair applied without any predefined name, type, or namespace.
-
#levels_configuration ⇒ OCI::Optimizer::Models::LevelsConfiguration
This attribute is required.
-
#name ⇒ String
[Required] The name assigned to the profile.
- #target_compartments ⇒ OCI::Optimizer::Models::TargetCompartments
- #target_tags ⇒ OCI::Optimizer::Models::TargetTags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateProfileDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateProfileDetails
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.levels_configuration = attributes[:'levelsConfiguration'] if attributes[:'levelsConfiguration'] raise 'You cannot provide both :levelsConfiguration and :levels_configuration' if attributes.key?(:'levelsConfiguration') && attributes.key?(:'levels_configuration') self.levels_configuration = attributes[:'levels_configuration'] if attributes[:'levels_configuration'] self.target_compartments = attributes[:'targetCompartments'] if attributes[:'targetCompartments'] raise 'You cannot provide both :targetCompartments and :target_compartments' if attributes.key?(:'targetCompartments') && attributes.key?(:'target_compartments') self.target_compartments = attributes[:'target_compartments'] if attributes[:'target_compartments'] self. = attributes[:'targetTags'] if attributes[:'targetTags'] raise 'You cannot provide both :targetTags and :target_tags' if attributes.key?(:'targetTags') && attributes.key?(:'target_tags') self. = attributes[:'target_tags'] if attributes[:'target_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the tenancy. The tenancy is the root compartment.
13 14 15 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 13 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"bar-key": "value"}`
29 30 31 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 29 def end |
#description ⇒ String
[Required] Text describing the profile. Avoid entering confidential information.
21 22 23 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 21 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair applied without any predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Exists for cross-compatibility only.
Example: ‘"value"`
37 38 39 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 37 def end |
#levels_configuration ⇒ OCI::Optimizer::Models::LevelsConfiguration
This attribute is required.
41 42 43 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 41 def levels_configuration @levels_configuration end |
#name ⇒ String
[Required] The name assigned to the profile. Avoid entering confidential information.
17 18 19 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 17 def name @name end |
#target_compartments ⇒ OCI::Optimizer::Models::TargetCompartments
44 45 46 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 44 def target_compartments @target_compartments end |
#target_tags ⇒ OCI::Optimizer::Models::TargetTags
47 48 49 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 47 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'levels_configuration': :'levelsConfiguration', 'target_compartments': :'targetCompartments', 'target_tags': :'targetTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'levels_configuration': :'OCI::Optimizer::Models::LevelsConfiguration', 'target_compartments': :'OCI::Optimizer::Models::TargetCompartments', 'target_tags': :'OCI::Optimizer::Models::TargetTags' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 149 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && name == other.name && description == other.description && == other. && == other. && levels_configuration == other.levels_configuration && target_compartments == other.target_compartments && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 186 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
166 167 168 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 166 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 175 def hash [compartment_id, name, description, , , levels_configuration, target_compartments, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 219 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
213 214 215 |
# File 'lib/oci/optimizer/models/create_profile_details.rb', line 213 def to_s to_hash.to_s end |