Class: OCI::Optimizer::Models::EnrollmentStatus
- Inherits:
-
Object
- Object
- OCI::Optimizer::Models::EnrollmentStatus
- Defined in:
- lib/oci/optimizer/models/enrollment_status.rb
Overview
The metadata associated with the enrollment status.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_ATTACHING = 'ATTACHING'.freeze, LIFECYCLE_STATE_DETACHING = 'DETACHING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_ACTIVE = 'ACTIVE'.freeze, STATUS_INACTIVE = 'INACTIVE'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment.
-
#id ⇒ String
[Required] The OCID of the enrollment status.
-
#lifecycle_state ⇒ String
[Required] The enrollment status’ current state.
-
#status ⇒ String
[Required] The current Cloud Advisor enrollment status.
-
#status_reason ⇒ String
The reason for the enrollment status of the tenancy.
-
#time_created ⇒ DateTime
The date and time the enrollment status was created, in the format defined by RFC3339.
-
#time_updated ⇒ DateTime
The date and time the enrollment status was last updated, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EnrollmentStatus
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EnrollmentStatus
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 102 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.status = attributes[:'status'] if attributes[:'status'] self.status_reason = attributes[:'statusReason'] if attributes[:'statusReason'] raise 'You cannot provide both :statusReason and :status_reason' if attributes.key?(:'statusReason') && attributes.key?(:'status_reason') self.status_reason = attributes[:'status_reason'] if attributes[:'status_reason'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment.
37 38 39 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 37 def compartment_id @compartment_id end |
#id ⇒ String
[Required] The OCID of the enrollment status.
33 34 35 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 33 def id @id end |
#lifecycle_state ⇒ String
[Required] The enrollment status’ current state.
41 42 43 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 41 def lifecycle_state @lifecycle_state end |
#status ⇒ String
[Required] The current Cloud Advisor enrollment status.
45 46 47 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 45 def status @status end |
#status_reason ⇒ String
The reason for the enrollment status of the tenancy.
49 50 51 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 49 def status_reason @status_reason end |
#time_created ⇒ DateTime
The date and time the enrollment status was created, in the format defined by RFC3339.
53 54 55 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 53 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the enrollment status was last updated, in the format defined by RFC3339.
57 58 59 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 57 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 60 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'status': :'status', 'status_reason': :'statusReason', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'status': :'String', 'status_reason': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 176 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && status == other.status && status_reason == other.status_reason && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 212 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
192 193 194 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 192 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
201 202 203 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 201 def hash [id, compartment_id, lifecycle_state, status, status_reason, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 254 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
239 240 241 |
# File 'lib/oci/optimizer/models/enrollment_status.rb', line 239 def to_s to_hash.to_s end |