Class: OCI::Optimizer::Models::EvaluatedMetric

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/optimizer/models/evaluated_metric.rb

Overview

One of the metrics that will be evaluated by profiles using this profile level.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EvaluatedMetric

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :name (String)

    The value to assign to the #name property

  • :statistic (String)

    The value to assign to the #statistic property

  • :threshold (Float)

    The value to assign to the #threshold property

  • :target (Float)

    The value to assign to the #target property



60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 60

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.statistic = attributes[:'statistic'] if attributes[:'statistic']

  self.threshold = attributes[:'threshold'] if attributes[:'threshold']

  self.target = attributes[:'target'] if attributes[:'target']
end

Instance Attribute Details

#nameString

**[Required]** The name of the metric (e.g., `CpuUtilization`).

Returns:

  • (String)


12
13
14
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 12

def name
  @name
end

#statisticString

**[Required]** The name of the statistic (e.g., `p95`).

Returns:

  • (String)


16
17
18
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 16

def statistic
  @statistic
end

#targetFloat

Optional. The metric value that the recommendation will target.

Returns:

  • (Float)


24
25
26
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 24

def target
  @target
end

#thresholdFloat

**[Required]** The threshold that must be crossed for the recommendation to appear.

Returns:

  • (Float)


20
21
22
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 20

def threshold
  @threshold
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 27

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'statistic': :'statistic',
    'threshold': :'threshold',
    'target': :'target'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'statistic': :'String',
    'threshold': :'Float',
    'target': :'Float'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



82
83
84
85
86
87
88
89
90
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 82

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    statistic == other.statistic &&
    threshold == other.threshold &&
    target == other.target
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 115

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


95
96
97
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 95

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



104
105
106
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 104

def hash
  [name, statistic, threshold, target].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 148

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



142
143
144
# File 'lib/oci/optimizer/models/evaluated_metric.rb', line 142

def to_s
  to_hash.to_s
end