Class: OCI::Optimizer::Models::RecommendationCount

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/optimizer/models/recommendation_count.rb

Overview

The count of recommendations in a category, grouped by importance.

Constant Summary collapse

IMPORTANCE_ENUM =
[
  IMPORTANCE_CRITICAL = 'CRITICAL'.freeze,
  IMPORTANCE_HIGH = 'HIGH'.freeze,
  IMPORTANCE_MODERATE = 'MODERATE'.freeze,
  IMPORTANCE_LOW = 'LOW'.freeze,
  IMPORTANCE_MINOR = 'MINOR'.freeze,
  IMPORTANCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RecommendationCount

Initializes the object

Options Hash (attributes):

  • :importance (String)

    The value to assign to the #importance property

  • :count (Integer)

    The value to assign to the #count property



56
57
58
59
60
61
62
63
64
65
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 56

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.importance = attributes[:'importance'] if attributes[:'importance']

  self.count = attributes[:'count'] if attributes[:'count']
end

Instance Attribute Details

#countInteger

[Required] The count of recommendations.



26
27
28
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 26

def count
  @count
end

#importanceString

[Required] The level of importance assigned to the recommendation.



22
23
24
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 22

def importance
  @importance
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 29

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'importance': :'importance',
    'count': :'count'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
46
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 39

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'importance': :'String',
    'count': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



87
88
89
90
91
92
93
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 87

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    importance == other.importance &&
    count == other.count
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 118

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


98
99
100
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 98

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



107
108
109
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 107

def hash
  [importance, count].hash
end

#to_hashHash

Returns the object in the form of hash



151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 151

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



145
146
147
# File 'lib/oci/optimizer/models/recommendation_count.rb', line 145

def to_s
  to_hash.to_s
end