Class: OCI::Optimizer::Models::Strategy
- Inherits:
-
Object
- Object
- OCI::Optimizer::Models::Strategy
- Defined in:
- lib/oci/optimizer/models/strategy.rb
Overview
The metadata associated with the strategy. The strategy is the method used to apply the recommendation.
Instance Attribute Summary collapse
-
#is_default ⇒ BOOLEAN
[Required] Whether this is the default recommendation strategy.
-
#parameters_definition ⇒ Array<OCI::Optimizer::Models::StrategyParameter>
The list of strategies for the parameters.
-
#strategy_name ⇒ String
[Required] The name of the strategy.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Strategy
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Strategy
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/optimizer/models/strategy.rb', line 54 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.strategy_name = attributes[:'strategyName'] if attributes[:'strategyName'] raise 'You cannot provide both :strategyName and :strategy_name' if attributes.key?(:'strategyName') && attributes.key?(:'strategy_name') self.strategy_name = attributes[:'strategy_name'] if attributes[:'strategy_name'] self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil? raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil? self.parameters_definition = attributes[:'parametersDefinition'] if attributes[:'parametersDefinition'] raise 'You cannot provide both :parametersDefinition and :parameters_definition' if attributes.key?(:'parametersDefinition') && attributes.key?(:'parameters_definition') self.parameters_definition = attributes[:'parameters_definition'] if attributes[:'parameters_definition'] end |
Instance Attribute Details
#is_default ⇒ BOOLEAN
[Required] Whether this is the default recommendation strategy.
17 18 19 |
# File 'lib/oci/optimizer/models/strategy.rb', line 17 def is_default @is_default end |
#parameters_definition ⇒ Array<OCI::Optimizer::Models::StrategyParameter>
The list of strategies for the parameters.
21 22 23 |
# File 'lib/oci/optimizer/models/strategy.rb', line 21 def parameters_definition @parameters_definition end |
#strategy_name ⇒ String
[Required] The name of the strategy.
13 14 15 |
# File 'lib/oci/optimizer/models/strategy.rb', line 13 def strategy_name @strategy_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 32 |
# File 'lib/oci/optimizer/models/strategy.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'strategy_name': :'strategyName', 'is_default': :'isDefault', 'parameters_definition': :'parametersDefinition' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/optimizer/models/strategy.rb', line 35 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'strategy_name': :'String', 'is_default': :'BOOLEAN', 'parameters_definition': :'Array<OCI::Optimizer::Models::StrategyParameter>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
86 87 88 89 90 91 92 93 |
# File 'lib/oci/optimizer/models/strategy.rb', line 86 def ==(other) return true if equal?(other) self.class == other.class && strategy_name == other.strategy_name && is_default == other.is_default && parameters_definition == other.parameters_definition end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/optimizer/models/strategy.rb', line 118 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
98 99 100 |
# File 'lib/oci/optimizer/models/strategy.rb', line 98 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
107 108 109 |
# File 'lib/oci/optimizer/models/strategy.rb', line 107 def hash [strategy_name, is_default, parameters_definition].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/optimizer/models/strategy.rb', line 151 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
145 146 147 |
# File 'lib/oci/optimizer/models/strategy.rb', line 145 def to_s to_hash.to_s end |