Class: OCI::Optimizer::Models::UpdateProfileDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/optimizer/models/update_profile_details.rb

Overview

Details for updating a profile.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateProfileDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 94

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.aggregation_interval_in_days = attributes[:'aggregationIntervalInDays'] if attributes[:'aggregationIntervalInDays']

  raise 'You cannot provide both :aggregationIntervalInDays and :aggregation_interval_in_days' if attributes.key?(:'aggregationIntervalInDays') && attributes.key?(:'aggregation_interval_in_days')

  self.aggregation_interval_in_days = attributes[:'aggregation_interval_in_days'] if attributes[:'aggregation_interval_in_days']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.levels_configuration = attributes[:'levelsConfiguration'] if attributes[:'levelsConfiguration']

  raise 'You cannot provide both :levelsConfiguration and :levels_configuration' if attributes.key?(:'levelsConfiguration') && attributes.key?(:'levels_configuration')

  self.levels_configuration = attributes[:'levels_configuration'] if attributes[:'levels_configuration']

  self.target_compartments = attributes[:'targetCompartments'] if attributes[:'targetCompartments']

  raise 'You cannot provide both :targetCompartments and :target_compartments' if attributes.key?(:'targetCompartments') && attributes.key?(:'target_compartments')

  self.target_compartments = attributes[:'target_compartments'] if attributes[:'target_compartments']

  self.target_tags = attributes[:'targetTags'] if attributes[:'targetTags']

  raise 'You cannot provide both :targetTags and :target_tags' if attributes.key?(:'targetTags') && attributes.key?(:'target_tags')

  self.target_tags = attributes[:'target_tags'] if attributes[:'target_tags']

  self.name = attributes[:'name'] if attributes[:'name']
end

Instance Attribute Details

#aggregation_interval_in_daysInteger

The time period over which to collect data for the recommendations, measured in number of days.

Returns:

  • (Integer)


17
18
19
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 17

def aggregation_interval_in_days
  @aggregation_interval_in_days
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


25
26
27
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 25

def defined_tags
  @defined_tags
end

#descriptionString

Text describing the profile. Avoid entering confidential information.

Returns:

  • (String)


13
14
15
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 13

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair applied without any predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Exists for cross-compatibility only.

Example: ‘"value"`

Returns:

  • (Hash<String, String>)


33
34
35
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 33

def freeform_tags
  @freeform_tags
end

#levels_configurationOCI::Optimizer::Models::LevelsConfiguration



36
37
38
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 36

def levels_configuration
  @levels_configuration
end

#nameString

The name assigned to the profile. Avoid entering confidential information.

Returns:

  • (String)


46
47
48
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 46

def name
  @name
end

#target_compartmentsOCI::Optimizer::Models::TargetCompartments



39
40
41
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 39

def target_compartments
  @target_compartments
end

#target_tagsOCI::Optimizer::Models::TargetTags



42
43
44
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 42

def target_tags
  @target_tags
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 49

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'aggregation_interval_in_days': :'aggregationIntervalInDays',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags',
    'levels_configuration': :'levelsConfiguration',
    'target_compartments': :'targetCompartments',
    'target_tags': :'targetTags',
    'name': :'name'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 65

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'aggregation_interval_in_days': :'Integer',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>',
    'levels_configuration': :'OCI::Optimizer::Models::LevelsConfiguration',
    'target_compartments': :'OCI::Optimizer::Models::TargetCompartments',
    'target_tags': :'OCI::Optimizer::Models::TargetTags',
    'name': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 148

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    aggregation_interval_in_days == other.aggregation_interval_in_days &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags &&
    levels_configuration == other.levels_configuration &&
    target_compartments == other.target_compartments &&
    target_tags == other.target_tags &&
    name == other.name
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 185

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 165

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



174
175
176
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 174

def hash
  [description, aggregation_interval_in_days, defined_tags, freeform_tags, levels_configuration, target_compartments, target_tags, name].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



212
213
214
# File 'lib/oci/optimizer/models/update_profile_details.rb', line 212

def to_s
  to_hash.to_s
end