Class: OCI::Optimizer::Models::UpdateResourceActionDetails
- Inherits:
-
Object
- Object
- OCI::Optimizer::Models::UpdateResourceActionDetails
- Defined in:
- lib/oci/optimizer/models/update_resource_action_details.rb
Overview
The request object for updating the resource action details.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_PENDING = 'PENDING'.freeze, STATUS_DISMISSED = 'DISMISSED'.freeze, STATUS_POSTPONED = 'POSTPONED'.freeze, STATUS_IMPLEMENTED = 'IMPLEMENTED'.freeze ].freeze
Instance Attribute Summary collapse
-
#status ⇒ String
[Required] The status of the resource action.
-
#time_status_end ⇒ DateTime
The date and time the current status will change.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateResourceActionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateResourceActionDetails
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 57 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.status = attributes[:'status'] if attributes[:'status'] self.time_status_end = attributes[:'timeStatusEnd'] if attributes[:'timeStatusEnd'] raise 'You cannot provide both :timeStatusEnd and :time_status_end' if attributes.key?(:'timeStatusEnd') && attributes.key?(:'time_status_end') self.time_status_end = attributes[:'time_status_end'] if attributes[:'time_status_end'] end |
Instance Attribute Details
#status ⇒ String
[Required] The status of the resource action.
19 20 21 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 19 def status @status end |
#time_status_end ⇒ DateTime
The date and time the current status will change. The format is defined by RFC3339.
For example, "The current postponed status of the resource action will end and change to pending on this date and time."
27 28 29 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 27 def time_status_end @time_status_end end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'status': :'status', 'time_status_end': :'timeStatusEnd' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'status': :'String', 'time_status_end': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
87 88 89 90 91 92 93 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 87 def ==(other) return true if equal?(other) self.class == other.class && status == other.status && time_status_end == other.time_status_end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 118 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
98 99 100 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 98 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
107 108 109 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 107 def hash [status, time_status_end].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 151 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
145 146 147 |
# File 'lib/oci/optimizer/models/update_resource_action_details.rb', line 145 def to_s to_hash.to_s end |