Class: OCI::Optimizer::Models::WorkRequest
- Inherits:
-
Object
- Object
- OCI::Optimizer::Models::WorkRequest
- Defined in:
- lib/oci/optimizer/models/work_request.rb
Overview
The asynchronous API request does not take effect immediately. This request spawns an asynchronous workflow to fulfill the request. WorkRequest objects provide visibility for in-progress workflows.
Constant Summary collapse
- OPERATION_TYPE_ENUM =
[ OPERATION_TYPE_BULK_APPLY_RECOMMENDATIONS = 'BULK_APPLY_RECOMMENDATIONS'.freeze, OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_ACCEPTED = 'ACCEPTED'.freeze, STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze, STATUS_FAILED = 'FAILED'.freeze, STATUS_SUCCEEDED = 'SUCCEEDED'.freeze, STATUS_CANCELING = 'CANCELING'.freeze, STATUS_CANCELED = 'CANCELED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the work request.
-
#id ⇒ String
[Required] The OCID of the work request.
-
#operation_type ⇒ String
[Required] An enum-like description of the type of work the work request is doing.
-
#percent_complete ⇒ Float
[Required] How much progress the operation has made.
-
#resources ⇒ Array<OCI::Optimizer::Models::WorkRequestResource>
[Required] The resources this work request affects.
-
#status ⇒ String
[Required] The current status of the work request.
-
#time_accepted ⇒ DateTime
[Required] Date and time the work was accepted, in the format defined by RFC3339.
-
#time_finished ⇒ DateTime
Date and time the work completed, in the format defined by RFC3339.
-
#time_started ⇒ DateTime
Date and time the work started, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequest
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequest
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/optimizer/models/work_request.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operation_type = attributes[:'operationType'] if attributes[:'operationType'] raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type'] self.status = attributes[:'status'] if attributes[:'status'] self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.resources = attributes[:'resources'] if attributes[:'resources'] self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete'] raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the work request.
41 42 43 |
# File 'lib/oci/optimizer/models/work_request.rb', line 41 def compartment_id @compartment_id end |
#id ⇒ String
[Required] The OCID of the work request.
36 37 38 |
# File 'lib/oci/optimizer/models/work_request.rb', line 36 def id @id end |
#operation_type ⇒ String
[Required] An enum-like description of the type of work the work request is doing.
28 29 30 |
# File 'lib/oci/optimizer/models/work_request.rb', line 28 def operation_type @operation_type end |
#percent_complete ⇒ Float
[Required] How much progress the operation has made.
49 50 51 |
# File 'lib/oci/optimizer/models/work_request.rb', line 49 def percent_complete @percent_complete end |
#resources ⇒ Array<OCI::Optimizer::Models::WorkRequestResource>
[Required] The resources this work request affects.
45 46 47 |
# File 'lib/oci/optimizer/models/work_request.rb', line 45 def resources @resources end |
#status ⇒ String
[Required] The current status of the work request.
32 33 34 |
# File 'lib/oci/optimizer/models/work_request.rb', line 32 def status @status end |
#time_accepted ⇒ DateTime
[Required] Date and time the work was accepted, in the format defined by RFC3339. Example: 2016-08-25T21:10:29.600Z
54 55 56 |
# File 'lib/oci/optimizer/models/work_request.rb', line 54 def time_accepted @time_accepted end |
#time_finished ⇒ DateTime
Date and time the work completed, in the format defined by RFC3339. Example: 2016-08-25T21:10:29.600Z
64 65 66 |
# File 'lib/oci/optimizer/models/work_request.rb', line 64 def time_finished @time_finished end |
#time_started ⇒ DateTime
Date and time the work started, in the format defined by RFC3339. Example: 2016-08-25T21:10:29.600Z
59 60 61 |
# File 'lib/oci/optimizer/models/work_request.rb', line 59 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/optimizer/models/work_request.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operation_type': :'operationType', 'status': :'status', 'id': :'id', 'compartment_id': :'compartmentId', 'resources': :'resources', 'percent_complete': :'percentComplete', 'time_accepted': :'timeAccepted', 'time_started': :'timeStarted', 'time_finished': :'timeFinished' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/optimizer/models/work_request.rb', line 84 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operation_type': :'String', 'status': :'String', 'id': :'String', 'compartment_id': :'String', 'resources': :'Array<OCI::Optimizer::Models::WorkRequestResource>', 'percent_complete': :'Float', 'time_accepted': :'DateTime', 'time_started': :'DateTime', 'time_finished': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/optimizer/models/work_request.rb', line 197 def ==(other) return true if equal?(other) self.class == other.class && operation_type == other.operation_type && status == other.status && id == other.id && compartment_id == other.compartment_id && resources == other.resources && percent_complete == other.percent_complete && time_accepted == other.time_accepted && time_started == other.time_started && time_finished == other.time_finished end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/oci/optimizer/models/work_request.rb', line 235 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
215 216 217 |
# File 'lib/oci/optimizer/models/work_request.rb', line 215 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/oci/optimizer/models/work_request.rb', line 224 def hash [operation_type, status, id, compartment_id, resources, percent_complete, time_accepted, time_started, time_finished].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/optimizer/models/work_request.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
262 263 264 |
# File 'lib/oci/optimizer/models/work_request.rb', line 262 def to_s to_hash.to_s end |