Class: OCI::Optimizer::OptimizerClientCompositeOperations
- Inherits:
-
Object
- Object
- OCI::Optimizer::OptimizerClientCompositeOperations
- Defined in:
- lib/oci/optimizer/optimizer_client_composite_operations.rb
Overview
This class provides a wrapper around OptimizerClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality
Instance Attribute Summary collapse
-
#service_client ⇒ OCI::Optimizer::OptimizerClient
readonly
The OptimizerClient used to communicate with the service_client.
Instance Method Summary collapse
-
#bulk_apply_recommendations_and_wait_for_state(recommendation_id, bulk_apply_recommendations_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#bulk_apply_recommendations and then waits for the Models::WorkRequest to enter the given state(s).
-
#create_profile_and_wait_for_state(create_profile_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#create_profile and then waits for the Models::Profile acted upon to enter the given state(s).
-
#delete_profile_and_wait_for_state(profile_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#delete_profile and then waits for the Models::Profile acted upon to enter the given state(s).
-
#initialize(service_client = OCI::Optimizer::OptimizerClient.new) ⇒ OptimizerClientCompositeOperations
constructor
Initializes a new OptimizerClientCompositeOperations.
-
#update_enrollment_status_and_wait_for_state(enrollment_status_id, update_enrollment_status_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#update_enrollment_status and then waits for the Models::EnrollmentStatus acted upon to enter the given state(s).
-
#update_profile_and_wait_for_state(profile_id, update_profile_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#update_profile and then waits for the Models::Profile acted upon to enter the given state(s).
-
#update_recommendation_and_wait_for_state(recommendation_id, update_recommendation_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#update_recommendation and then waits for the Models::Recommendation acted upon to enter the given state(s).
-
#update_resource_action_and_wait_for_state(resource_action_id, update_resource_action_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#update_resource_action and then waits for the Models::ResourceAction acted upon to enter the given state(s).
Constructor Details
#initialize(service_client = OCI::Optimizer::OptimizerClient.new) ⇒ OptimizerClientCompositeOperations
Initializes a new OptimizerClientCompositeOperations
20 21 22 |
# File 'lib/oci/optimizer/optimizer_client_composite_operations.rb', line 20 def initialize(service_client = OCI::Optimizer::OptimizerClient.new) @service_client = service_client end |
Instance Attribute Details
#service_client ⇒ OCI::Optimizer::OptimizerClient (readonly)
The OCI::Optimizer::OptimizerClient used to communicate with the service_client
14 15 16 |
# File 'lib/oci/optimizer/optimizer_client_composite_operations.rb', line 14 def service_client @service_client end |
Instance Method Details
#bulk_apply_recommendations_and_wait_for_state(recommendation_id, bulk_apply_recommendations_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#bulk_apply_recommendations and then waits for the Models::WorkRequest to enter the given state(s).
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/optimizer/optimizer_client_composite_operations.rb', line 40 def bulk_apply_recommendations_and_wait_for_state(recommendation_id, bulk_apply_recommendations_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.bulk_apply_recommendations(recommendation_id, bulk_apply_recommendations_details, base_operation_opts) use_util = OCI::Optimizer::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::Optimizer::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#create_profile_and_wait_for_state(create_profile_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#create_profile and then waits for the Models::Profile acted upon to enter the given state(s).
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/optimizer/optimizer_client_composite_operations.rb', line 89 def create_profile_and_wait_for_state(create_profile_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.create_profile(create_profile_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_profile(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#delete_profile_and_wait_for_state(profile_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#delete_profile and then waits for the Models::Profile acted upon to enter the given state(s).
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/optimizer/optimizer_client_composite_operations.rb', line 128 def delete_profile_and_wait_for_state(profile_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) initial_get_result = @service_client.get_profile(profile_id) operation_result = @service_client.delete_profile(profile_id, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) begin waiter_result = initial_get_result.wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200, succeed_on_not_found: true ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_enrollment_status_and_wait_for_state(enrollment_status_id, update_enrollment_status_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#update_enrollment_status and then waits for the Models::EnrollmentStatus acted upon to enter the given state(s).
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/optimizer/optimizer_client_composite_operations.rb', line 169 def update_enrollment_status_and_wait_for_state(enrollment_status_id, update_enrollment_status_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_enrollment_status(enrollment_status_id, update_enrollment_status_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_enrollment_status(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_profile_and_wait_for_state(profile_id, update_profile_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#update_profile and then waits for the Models::Profile acted upon to enter the given state(s).
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/optimizer/optimizer_client_composite_operations.rb', line 209 def update_profile_and_wait_for_state(profile_id, update_profile_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_profile(profile_id, update_profile_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_profile(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_recommendation_and_wait_for_state(recommendation_id, update_recommendation_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#update_recommendation and then waits for the Models::Recommendation acted upon to enter the given state(s).
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/optimizer/optimizer_client_composite_operations.rb', line 249 def update_recommendation_and_wait_for_state(recommendation_id, update_recommendation_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_recommendation(recommendation_id, update_recommendation_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_recommendation(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_resource_action_and_wait_for_state(resource_action_id, update_resource_action_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::Optimizer::OptimizerClient#update_resource_action and then waits for the Models::ResourceAction acted upon to enter the given state(s).
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/oci/optimizer/optimizer_client_composite_operations.rb', line 289 def update_resource_action_and_wait_for_state(resource_action_id, update_resource_action_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_resource_action(resource_action_id, update_resource_action_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_resource_action(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |