Class: OCI::OsManagement::Models::ErratumSummary
- Inherits:
-
Object
- Object
- OCI::OsManagement::Models::ErratumSummary
- Defined in:
- lib/oci/os_management/models/erratum_summary.rb
Overview
Important changes for software. This can include security | advisories, bug fixes, or enhancements.
Constant Summary collapse
- ADVISORY_TYPE_ENUM =
[ ADVISORY_TYPE_SECURITY = 'SECURITY'.freeze, ADVISORY_TYPE_BUG = 'BUG'.freeze, ADVISORY_TYPE_ENHANCEMENT = 'ENHANCEMENT'.freeze, ADVISORY_TYPE_OTHER = 'OTHER'.freeze, ADVISORY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#advisory_type ⇒ String
Type of the erratum.
-
#compartment_id ⇒ String
**[Required]** OCID for the Compartment.
-
#id ⇒ String
**[Required]** OCID for the Erratum.
-
#issued ⇒ String
date the erratum was issued.
-
#name ⇒ String
**[Required]** Advisory name.
-
#related_cves ⇒ Array<String>
list of CVEs applicable to this erratum.
-
#synopsis ⇒ String
Summary description of the erratum.
-
#updated ⇒ String
most recent date the erratum was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ErratumSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ErratumSummary
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.synopsis = attributes[:'synopsis'] if attributes[:'synopsis'] self.issued = attributes[:'issued'] if attributes[:'issued'] self.updated = attributes[:'updated'] if attributes[:'updated'] self.advisory_type = attributes[:'advisoryType'] if attributes[:'advisoryType'] raise 'You cannot provide both :advisoryType and :advisory_type' if attributes.key?(:'advisoryType') && attributes.key?(:'advisory_type') self.advisory_type = attributes[:'advisory_type'] if attributes[:'advisory_type'] self. = attributes[:'relatedCves'] if attributes[:'relatedCves'] raise 'You cannot provide both :relatedCves and :related_cves' if attributes.key?(:'relatedCves') && attributes.key?(:'related_cves') self. = attributes[:'related_cves'] if attributes[:'related_cves'] end |
Instance Attribute Details
#advisory_type ⇒ String
Type of the erratum.
45 46 47 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 45 def advisory_type @advisory_type end |
#compartment_id ⇒ String
**[Required]** OCID for the Compartment.
29 30 31 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 29 def compartment_id @compartment_id end |
#id ⇒ String
**[Required]** OCID for the Erratum.
25 26 27 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 25 def id @id end |
#issued ⇒ String
date the erratum was issued
37 38 39 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 37 def issued @issued end |
#name ⇒ String
**[Required]** Advisory name
21 22 23 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 21 def name @name end |
#related_cves ⇒ Array<String>
list of CVEs applicable to this erratum
49 50 51 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 49 def @related_cves end |
#synopsis ⇒ String
Summary description of the erratum.
33 34 35 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 33 def synopsis @synopsis end |
#updated ⇒ String
most recent date the erratum was updated
41 42 43 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 41 def updated @updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'id': :'id', 'compartment_id': :'compartmentId', 'synopsis': :'synopsis', 'issued': :'issued', 'updated': :'updated', 'advisory_type': :'advisoryType', 'related_cves': :'relatedCves' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'id': :'String', 'compartment_id': :'String', 'synopsis': :'String', 'issued': :'String', 'updated': :'String', 'advisory_type': :'String', 'related_cves': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 152 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && id == other.id && compartment_id == other.compartment_id && synopsis == other.synopsis && issued == other.issued && updated == other.updated && advisory_type == other.advisory_type && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 189 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
169 170 171 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 169 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 178 def hash [name, id, compartment_id, synopsis, issued, updated, advisory_type, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/oci/os_management/models/erratum_summary.rb', line 216 def to_s to_hash.to_s end |