Class: OCI::OsManagement::Models::EventSummary
- Inherits:
-
Object
- Object
- OCI::OsManagement::Models::EventSummary
- Defined in:
- lib/oci/os_management/models/event_summary.rb
Overview
Summary of the Event.
Constant Summary collapse
- EVENT_TYPE_ENUM =
[ EVENT_TYPE_KERNEL_OOPS = 'KERNEL_OOPS'.freeze, EVENT_TYPE_KERNEL_CRASH = 'KERNEL_CRASH'.freeze, EVENT_TYPE_CRASH = 'CRASH'.freeze, EVENT_TYPE_EXPLOIT_ATTEMPT = 'EXPLOIT_ATTEMPT'.freeze, EVENT_TYPE_COMPLIANCE = 'COMPLIANCE'.freeze, EVENT_TYPE_TUNING_SUGGESTION = 'TUNING_SUGGESTION'.freeze, EVENT_TYPE_TUNING_APPLIED = 'TUNING_APPLIED'.freeze, EVENT_TYPE_SECURITY = 'SECURITY'.freeze, EVENT_TYPE_ERROR = 'ERROR'.freeze, EVENT_TYPE_WARNING = 'WARNING'.freeze, EVENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#count ⇒ Integer
Event occurrence count.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#event_type ⇒ String
[Required] Type of the event.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] OCID identifier of the event.
-
#instance_id ⇒ String
[Required] Unique OCI identifier of the instance where the event occurred.
-
#summary ⇒ String
human readable description of the event.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#timestamp ⇒ DateTime
Time of the occurrence of the event.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EventSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EventSummary
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/os_management/models/event_summary.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.instance_id = attributes[:'instanceId'] if attributes[:'instanceId'] raise 'You cannot provide both :instanceId and :instance_id' if attributes.key?(:'instanceId') && attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] if attributes[:'instance_id'] self.summary = attributes[:'summary'] if attributes[:'summary'] self.event_type = attributes[:'eventType'] if attributes[:'eventType'] raise 'You cannot provide both :eventType and :event_type' if attributes.key?(:'eventType') && attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] if attributes[:'event_type'] self.count = attributes[:'count'] if attributes[:'count'] self. = attributes[:'timestamp'] if attributes[:'timestamp'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#count ⇒ Integer
Event occurrence count. Number of time the same event happened on the system.
43 44 45 |
# File 'lib/oci/os_management/models/event_summary.rb', line 43 def count @count end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
59 60 61 |
# File 'lib/oci/os_management/models/event_summary.rb', line 59 def end |
#event_type ⇒ String
[Required] Type of the event.
39 40 41 |
# File 'lib/oci/os_management/models/event_summary.rb', line 39 def event_type @event_type end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
53 54 55 |
# File 'lib/oci/os_management/models/event_summary.rb', line 53 def end |
#id ⇒ String
[Required] OCID identifier of the event
27 28 29 |
# File 'lib/oci/os_management/models/event_summary.rb', line 27 def id @id end |
#instance_id ⇒ String
[Required] Unique OCI identifier of the instance where the event occurred
31 32 33 |
# File 'lib/oci/os_management/models/event_summary.rb', line 31 def instance_id @instance_id end |
#summary ⇒ String
human readable description of the event
35 36 37 |
# File 'lib/oci/os_management/models/event_summary.rb', line 35 def summary @summary end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`
65 66 67 |
# File 'lib/oci/os_management/models/event_summary.rb', line 65 def end |
#timestamp ⇒ DateTime
Time of the occurrence of the event
47 48 49 |
# File 'lib/oci/os_management/models/event_summary.rb', line 47 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/os_management/models/event_summary.rb', line 68 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'instance_id': :'instanceId', 'summary': :'summary', 'event_type': :'eventType', 'count': :'count', 'timestamp': :'timestamp', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/os_management/models/event_summary.rb', line 85 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'instance_id': :'String', 'summary': :'String', 'event_type': :'String', 'count': :'Integer', 'timestamp': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/os_management/models/event_summary.rb', line 181 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && instance_id == other.instance_id && summary == other.summary && event_type == other.event_type && count == other.count && == other. && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/os_management/models/event_summary.rb', line 219 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
199 200 201 |
# File 'lib/oci/os_management/models/event_summary.rb', line 199 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/oci/os_management/models/event_summary.rb', line 208 def hash [id, instance_id, summary, event_type, count, , , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/os_management/models/event_summary.rb', line 252 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
246 247 248 |
# File 'lib/oci/os_management/models/event_summary.rb', line 246 def to_s to_hash.to_s end |