Class: OCI::OsManagement::Models::InstalledPackageSummary
- Inherits:
-
Object
- Object
- OCI::OsManagement::Models::InstalledPackageSummary
- Defined in:
- lib/oci/os_management/models/installed_package_summary.rb
Overview
A software package installed on a managed instance
Instance Attribute Summary collapse
-
#architecture ⇒ String
The architecture for which this package was built.
-
#display_name ⇒ String
**[Required]** Package name.
-
#install_time ⇒ String
Install time of the package.
-
#issued ⇒ String
date the package was issued by a providing erratum (if available).
-
#name ⇒ String
**[Required]** Unique identifier for the package.
-
#software_sources ⇒ Array<OCI::OsManagement::Models::SoftwareSourceId>
list of software sources that provide the software package.
-
#type ⇒ String
**[Required]** Type of the package.
-
#version ⇒ String
**[Required]** Version of the installed package.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InstalledPackageSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ InstalledPackageSummary
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.name = attributes[:'name'] if attributes[:'name'] self.type = attributes[:'type'] if attributes[:'type'] self.version = attributes[:'version'] if attributes[:'version'] self.architecture = attributes[:'architecture'] if attributes[:'architecture'] self.install_time = attributes[:'installTime'] if attributes[:'installTime'] raise 'You cannot provide both :installTime and :install_time' if attributes.key?(:'installTime') && attributes.key?(:'install_time') self.install_time = attributes[:'install_time'] if attributes[:'install_time'] self.issued = attributes[:'issued'] if attributes[:'issued'] self.software_sources = attributes[:'softwareSources'] if attributes[:'softwareSources'] raise 'You cannot provide both :softwareSources and :software_sources' if attributes.key?(:'softwareSources') && attributes.key?(:'software_sources') self.software_sources = attributes[:'software_sources'] if attributes[:'software_sources'] end |
Instance Attribute Details
#architecture ⇒ String
The architecture for which this package was built
28 29 30 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 28 def architecture @architecture end |
#display_name ⇒ String
**[Required]** Package name
12 13 14 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 12 def display_name @display_name end |
#install_time ⇒ String
Install time of the package
32 33 34 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 32 def install_time @install_time end |
#issued ⇒ String
date the package was issued by a providing erratum (if available)
36 37 38 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 36 def issued @issued end |
#name ⇒ String
**[Required]** Unique identifier for the package. NOTE - This is not an OCID
16 17 18 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 16 def name @name end |
#software_sources ⇒ Array<OCI::OsManagement::Models::SoftwareSourceId>
list of software sources that provide the software package
40 41 42 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 40 def software_sources @software_sources end |
#type ⇒ String
**[Required]** Type of the package
20 21 22 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 20 def type @type end |
#version ⇒ String
**[Required]** Version of the installed package
24 25 26 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 24 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'name': :'name', 'type': :'type', 'version': :'version', 'architecture': :'architecture', 'install_time': :'installTime', 'issued': :'issued', 'software_sources': :'softwareSources' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'name': :'String', 'type': :'String', 'version': :'String', 'architecture': :'String', 'install_time': :'String', 'issued': :'String', 'software_sources': :'Array<OCI::OsManagement::Models::SoftwareSourceId>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 130 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && name == other.name && type == other.type && version == other.version && architecture == other.architecture && install_time == other.install_time && issued == other.issued && software_sources == other.software_sources end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 167 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
147 148 149 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 147 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 156 def hash [display_name, name, type, version, architecture, install_time, issued, software_sources].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
194 195 196 |
# File 'lib/oci/os_management/models/installed_package_summary.rb', line 194 def to_s to_hash.to_s end |