Class: OCI::OsManagement::Models::ManageModuleStreamsOnManagedInstanceDetails
- Inherits:
-
Object
- Object
- OCI::OsManagement::Models::ManageModuleStreamsOnManagedInstanceDetails
- Defined in:
- lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb
Overview
The set of changes to make to the state of the modules, streams, and profiles on a managed instance
Instance Attribute Summary collapse
-
#disable ⇒ Array<OCI::OsManagement::Models::ModuleStreamDetails>
The set of module streams to disable.
-
#enable ⇒ Array<OCI::OsManagement::Models::ModuleStreamDetails>
The set of module streams to enable.
-
#install ⇒ Array<OCI::OsManagement::Models::ModuleStreamProfileDetails>
The set of module stream profiles to install.
-
#is_dry_run ⇒ BOOLEAN
Indicates if this operation is a dry run or if the operation should be commited.
-
#remove ⇒ Array<OCI::OsManagement::Models::ModuleStreamProfileDetails>
The set of module stream profiles to remove.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManageModuleStreamsOnManagedInstanceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ManageModuleStreamsOnManagedInstanceDetails
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.is_dry_run = attributes[:'isDryRun'] unless attributes[:'isDryRun'].nil? raise 'You cannot provide both :isDryRun and :is_dry_run' if attributes.key?(:'isDryRun') && attributes.key?(:'is_dry_run') self.is_dry_run = attributes[:'is_dry_run'] unless attributes[:'is_dry_run'].nil? self.enable = attributes[:'enable'] if attributes[:'enable'] self.disable = attributes[:'disable'] if attributes[:'disable'] self.install = attributes[:'install'] if attributes[:'install'] self.remove = attributes[:'remove'] if attributes[:'remove'] end |
Instance Attribute Details
#disable ⇒ Array<OCI::OsManagement::Models::ModuleStreamDetails>
The set of module streams to disable.
25 26 27 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 25 def disable @disable end |
#enable ⇒ Array<OCI::OsManagement::Models::ModuleStreamDetails>
The set of module streams to enable.
21 22 23 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 21 def enable @enable end |
#install ⇒ Array<OCI::OsManagement::Models::ModuleStreamProfileDetails>
The set of module stream profiles to install.
29 30 31 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 29 def install @install end |
#is_dry_run ⇒ BOOLEAN
Indicates if this operation is a dry run or if the operation should be commited. If set to true, the result of the operation will be evaluated but not committed. If set to false, the operation is committed to the managed instance. The default is false.
17 18 19 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 17 def is_dry_run @is_dry_run end |
#remove ⇒ Array<OCI::OsManagement::Models::ModuleStreamProfileDetails>
The set of module stream profiles to remove.
33 34 35 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 33 def remove @remove end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'is_dry_run': :'isDryRun', 'enable': :'enable', 'disable': :'disable', 'install': :'install', 'remove': :'remove' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'is_dry_run': :'BOOLEAN', 'enable': :'Array<OCI::OsManagement::Models::ModuleStreamDetails>', 'disable': :'Array<OCI::OsManagement::Models::ModuleStreamDetails>', 'install': :'Array<OCI::OsManagement::Models::ModuleStreamProfileDetails>', 'remove': :'Array<OCI::OsManagement::Models::ModuleStreamProfileDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 100 def ==(other) return true if equal?(other) self.class == other.class && is_dry_run == other.is_dry_run && enable == other.enable && disable == other.disable && install == other.install && remove == other.remove end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 134 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
114 115 116 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 114 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
123 124 125 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 123 def hash [is_dry_run, enable, disable, install, remove].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 167 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
161 162 163 |
# File 'lib/oci/os_management/models/manage_module_streams_on_managed_instance_details.rb', line 161 def to_s to_hash.to_s end |