Class: OCI::OsManagement::Models::ModuleStream

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/os_management/models/module_stream.rb

Overview

A module stream provided by a software source

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ModuleStream

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :module_name (String)

    The value to assign to the #module_name property

  • :stream_name (String)

    The value to assign to the #stream_name property

  • :is_default (BOOLEAN)

    The value to assign to the #is_default property

  • :software_source_id (String)

    The value to assign to the #software_source_id property

  • :architecture (String)

    The value to assign to the #architecture property

  • :description (String)

    The value to assign to the #description property

  • :profiles (Array<String>)

    The value to assign to the #profiles property

  • :packages (Array<String>)

    The value to assign to the #packages property



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/oci/os_management/models/module_stream.rb', line 96

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.module_name = attributes[:'moduleName'] if attributes[:'moduleName']

  raise 'You cannot provide both :moduleName and :module_name' if attributes.key?(:'moduleName') && attributes.key?(:'module_name')

  self.module_name = attributes[:'module_name'] if attributes[:'module_name']

  self.stream_name = attributes[:'streamName'] if attributes[:'streamName']

  raise 'You cannot provide both :streamName and :stream_name' if attributes.key?(:'streamName') && attributes.key?(:'stream_name')

  self.stream_name = attributes[:'stream_name'] if attributes[:'stream_name']

  self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil?

  raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default')

  self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil?

  self.software_source_id = attributes[:'softwareSourceId'] if attributes[:'softwareSourceId']

  raise 'You cannot provide both :softwareSourceId and :software_source_id' if attributes.key?(:'softwareSourceId') && attributes.key?(:'software_source_id')

  self.software_source_id = attributes[:'software_source_id'] if attributes[:'software_source_id']

  self.architecture = attributes[:'architecture'] if attributes[:'architecture']

  self.description = attributes[:'description'] if attributes[:'description']

  self.profiles = attributes[:'profiles'] if attributes[:'profiles']

  self.packages = attributes[:'packages'] if attributes[:'packages']
end

Instance Attribute Details

#architectureString

The architecture for which the packages in this module stream were built

Returns:

  • (String)


28
29
30
# File 'lib/oci/os_management/models/module_stream.rb', line 28

def architecture
  @architecture
end

#descriptionString

A description of the contents of the module stream

Returns:

  • (String)


32
33
34
# File 'lib/oci/os_management/models/module_stream.rb', line 32

def description
  @description
end

#is_defaultBOOLEAN

Indicates if this stream is the default for its module.

Returns:

  • (BOOLEAN)


20
21
22
# File 'lib/oci/os_management/models/module_stream.rb', line 20

def is_default
  @is_default
end

#module_nameString

**[Required]** The name of the module that contains the stream

Returns:

  • (String)


12
13
14
# File 'lib/oci/os_management/models/module_stream.rb', line 12

def module_name
  @module_name
end

#packagesArray<String>

A list of packages that are contained by the stream. Each element in the list is the name of a package. The name is suitable to use as an argument to other OS Management APIs that interact directly with packages.

Returns:

  • (Array<String>)


48
49
50
# File 'lib/oci/os_management/models/module_stream.rb', line 48

def packages
  @packages
end

#profilesArray<String>

A list of profiles that are part of the stream. Each element in the list is the name of a profile. The name is suitable to use as an argument to other OS Management APIs that interact directly with module stream profiles. However, it is not URL encoded.

Returns:

  • (Array<String>)


40
41
42
# File 'lib/oci/os_management/models/module_stream.rb', line 40

def profiles
  @profiles
end

#software_source_idString

The OCID of the software source that provides this module stream.

Returns:

  • (String)


24
25
26
# File 'lib/oci/os_management/models/module_stream.rb', line 24

def software_source_id
  @software_source_id
end

#stream_nameString

**[Required]** The name of the stream

Returns:

  • (String)


16
17
18
# File 'lib/oci/os_management/models/module_stream.rb', line 16

def stream_name
  @stream_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/os_management/models/module_stream.rb', line 51

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'module_name': :'moduleName',
    'stream_name': :'streamName',
    'is_default': :'isDefault',
    'software_source_id': :'softwareSourceId',
    'architecture': :'architecture',
    'description': :'description',
    'profiles': :'profiles',
    'packages': :'packages'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/oci/os_management/models/module_stream.rb', line 67

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'module_name': :'String',
    'stream_name': :'String',
    'is_default': :'BOOLEAN',
    'software_source_id': :'String',
    'architecture': :'String',
    'description': :'String',
    'profiles': :'Array<String>',
    'packages': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/oci/os_management/models/module_stream.rb', line 142

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    module_name == other.module_name &&
    stream_name == other.stream_name &&
    is_default == other.is_default &&
    software_source_id == other.software_source_id &&
    architecture == other.architecture &&
    description == other.description &&
    profiles == other.profiles &&
    packages == other.packages
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/os_management/models/module_stream.rb', line 179

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


159
160
161
# File 'lib/oci/os_management/models/module_stream.rb', line 159

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



168
169
170
# File 'lib/oci/os_management/models/module_stream.rb', line 168

def hash
  [module_name, stream_name, is_default, software_source_id, architecture, description, profiles, packages].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/os_management/models/module_stream.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



206
207
208
# File 'lib/oci/os_management/models/module_stream.rb', line 206

def to_s
  to_hash.to_s
end