Class: OCI::OsManagement::Models::ModuleStreamOnManagedInstanceSummary
- Inherits:
-
Object
- Object
- OCI::OsManagement::Models::ModuleStreamOnManagedInstanceSummary
- Defined in:
- lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb
Overview
Summary information pertaining to a module stream on a managed instance
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_ENABLED = 'ENABLED'.freeze, STATUS_DISABLED = 'DISABLED'.freeze, STATUS_ACTIVE = 'ACTIVE'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#module_name ⇒ String
**[Required]** The name of the module that contains the stream.
-
#profiles ⇒ Array<OCI::OsManagement::Models::ModuleStreamProfileOnManagedInstanceSummary>
The set of profiles that the module stream contains.
-
#software_source_id ⇒ String
The OCID of the software source that provides this module stream.
-
#status ⇒ String
**[Required]** The status of the stream.
-
#stream_name ⇒ String
**[Required]** The name of the stream.
-
#time_modified ⇒ DateTime
The date and time of the last status change for this profile, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModuleStreamOnManagedInstanceSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ModuleStreamOnManagedInstanceSummary
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 101 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.module_name = attributes[:'moduleName'] if attributes[:'moduleName'] raise 'You cannot provide both :moduleName and :module_name' if attributes.key?(:'moduleName') && attributes.key?(:'module_name') self.module_name = attributes[:'module_name'] if attributes[:'module_name'] self.stream_name = attributes[:'streamName'] if attributes[:'streamName'] raise 'You cannot provide both :streamName and :stream_name' if attributes.key?(:'streamName') && attributes.key?(:'stream_name') self.stream_name = attributes[:'stream_name'] if attributes[:'stream_name'] self.status = attributes[:'status'] if attributes[:'status'] self.profiles = attributes[:'profiles'] if attributes[:'profiles'] self.software_source_id = attributes[:'softwareSourceId'] if attributes[:'softwareSourceId'] raise 'You cannot provide both :softwareSourceId and :software_source_id' if attributes.key?(:'softwareSourceId') && attributes.key?(:'software_source_id') self.software_source_id = attributes[:'software_source_id'] if attributes[:'software_source_id'] self.time_modified = attributes[:'timeModified'] if attributes[:'timeModified'] raise 'You cannot provide both :timeModified and :time_modified' if attributes.key?(:'timeModified') && attributes.key?(:'time_modified') self.time_modified = attributes[:'time_modified'] if attributes[:'time_modified'] end |
Instance Attribute Details
#module_name ⇒ String
**[Required]** The name of the module that contains the stream.
21 22 23 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 21 def module_name @module_name end |
#profiles ⇒ Array<OCI::OsManagement::Models::ModuleStreamProfileOnManagedInstanceSummary>
The set of profiles that the module stream contains.
48 49 50 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 48 def profiles @profiles end |
#software_source_id ⇒ String
The OCID of the software source that provides this module stream.
52 53 54 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 52 def software_source_id @software_source_id end |
#status ⇒ String
**[Required]** The status of the stream
A stream with the "ENABLED" status can be used as a source for installing profiles. Streams with this status are also "ACTIVE".
A stream with the "DISABLED" status cannot be the source for installing profiles. To install profiles and packages from this stream, it must be enabled.
A stream with the "ACTIVE" status can be used as a source for installing profiles. The packages that comprise the stream are also used when a matching package is installed directly. In general, a stream can have this status if it is the default stream for the module and no stream has been explicitly enabled.
44 45 46 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 44 def status @status end |
#stream_name ⇒ String
**[Required]** The name of the stream.
26 27 28 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 26 def stream_name @stream_name end |
#time_modified ⇒ DateTime
The date and time of the last status change for this profile, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
59 60 61 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 59 def time_modified @time_modified end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 62 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'module_name': :'moduleName', 'stream_name': :'streamName', 'status': :'status', 'profiles': :'profiles', 'software_source_id': :'softwareSourceId', 'time_modified': :'timeModified' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 76 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'module_name': :'String', 'stream_name': :'String', 'status': :'String', 'profiles': :'Array<OCI::OsManagement::Models::ModuleStreamProfileOnManagedInstanceSummary>', 'software_source_id': :'String', 'time_modified': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 156 def ==(other) return true if equal?(other) self.class == other.class && module_name == other.module_name && stream_name == other.stream_name && status == other.status && profiles == other.profiles && software_source_id == other.software_source_id && time_modified == other.time_modified end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 191 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
171 172 173 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 171 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 180 def hash [module_name, stream_name, status, profiles, software_source_id, time_modified].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/oci/os_management/models/module_stream_on_managed_instance_summary.rb', line 218 def to_s to_hash.to_s end |