Class: OCI::OsManagement::Models::ModuleStreamProfile
- Inherits:
-
Object
- Object
- OCI::OsManagement::Models::ModuleStreamProfile
- Defined in:
- lib/oci/os_management/models/module_stream_profile.rb
Overview
A module stream profile provided by a software source
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the contents of the module stream profile.
-
#is_default ⇒ BOOLEAN
Indicates if this profile is the default for its module stream.
-
#module_name ⇒ String
**[Required]** The name of the module that contains the stream profile.
-
#packages ⇒ Array<String>
**[Required]** A list of packages that constitute the profile.
-
#profile_name ⇒ String
**[Required]** The name of the profile.
-
#stream_name ⇒ String
**[Required]** The name of the stream that contains the profile.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModuleStreamProfile
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ModuleStreamProfile
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.module_name = attributes[:'moduleName'] if attributes[:'moduleName'] raise 'You cannot provide both :moduleName and :module_name' if attributes.key?(:'moduleName') && attributes.key?(:'module_name') self.module_name = attributes[:'module_name'] if attributes[:'module_name'] self.stream_name = attributes[:'streamName'] if attributes[:'streamName'] raise 'You cannot provide both :streamName and :stream_name' if attributes.key?(:'streamName') && attributes.key?(:'stream_name') self.stream_name = attributes[:'stream_name'] if attributes[:'stream_name'] self.profile_name = attributes[:'profileName'] if attributes[:'profileName'] raise 'You cannot provide both :profileName and :profile_name' if attributes.key?(:'profileName') && attributes.key?(:'profile_name') self.profile_name = attributes[:'profile_name'] if attributes[:'profile_name'] self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil? raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil? self.description = attributes[:'description'] if attributes[:'description'] self.packages = attributes[:'packages'] if attributes[:'packages'] end |
Instance Attribute Details
#description ⇒ String
A description of the contents of the module stream profile
28 29 30 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 28 def description @description end |
#is_default ⇒ BOOLEAN
Indicates if this profile is the default for its module stream.
24 25 26 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 24 def is_default @is_default end |
#module_name ⇒ String
**[Required]** The name of the module that contains the stream profile
12 13 14 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 12 def module_name @module_name end |
#packages ⇒ Array<String>
**[Required]** A list of packages that constitute the profile. Each element in the list is the name of a package. The name is suitable to use as an argument to other OS Management APIs that interact directly with packages.
36 37 38 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 36 def packages @packages end |
#profile_name ⇒ String
**[Required]** The name of the profile
20 21 22 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 20 def profile_name @profile_name end |
#stream_name ⇒ String
**[Required]** The name of the stream that contains the profile
16 17 18 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 16 def stream_name @stream_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'module_name': :'moduleName', 'stream_name': :'streamName', 'profile_name': :'profileName', 'is_default': :'isDefault', 'description': :'description', 'packages': :'packages' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'module_name': :'String', 'stream_name': :'String', 'profile_name': :'String', 'is_default': :'BOOLEAN', 'description': :'String', 'packages': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 120 def ==(other) return true if equal?(other) self.class == other.class && module_name == other.module_name && stream_name == other.stream_name && profile_name == other.profile_name && is_default == other.is_default && description == other.description && packages == other.packages end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 155 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
135 136 137 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 135 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 144 def hash [module_name, stream_name, profile_name, is_default, description, packages].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 188 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
182 183 184 |
# File 'lib/oci/os_management/models/module_stream_profile.rb', line 182 def to_s to_hash.to_s end |