Class: OCI::OsManagement::Models::SoftwarePackageSearchSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/os_management/models/software_package_search_summary.rb

Overview

Summary information for a software package

Constant Summary collapse

ADVISORY_TYPE_ENUM =
[
  ADVISORY_TYPE_SECURITY = 'SECURITY'.freeze,
  ADVISORY_TYPE_BUG = 'BUG'.freeze,
  ADVISORY_TYPE_ENHANCEMENT = 'ENHANCEMENT'.freeze,
  ADVISORY_TYPE_OTHER = 'OTHER'.freeze,
  ADVISORY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SoftwarePackageSearchSummary

Initializes the object

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :name (String)

    The value to assign to the #name property

  • :type (String)

    The value to assign to the #type property

  • :version (String)

    The value to assign to the #version property

  • :architecture (String)

    The value to assign to the #architecture property

  • :summary (String)

    The value to assign to the #summary property

  • :advisory_type (String)

    The value to assign to the #advisory_type property

  • :errata (Array<OCI::OsManagement::Models::Id>)

    The value to assign to the #errata property

  • :software_sources (Array<OCI::OsManagement::Models::SoftwareSourceId>)

    The value to assign to the #software_sources property



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 104

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.name = attributes[:'name'] if attributes[:'name']

  self.type = attributes[:'type'] if attributes[:'type']

  self.version = attributes[:'version'] if attributes[:'version']

  self.architecture = attributes[:'architecture'] if attributes[:'architecture']

  self.summary = attributes[:'summary'] if attributes[:'summary']

  self.advisory_type = attributes[:'advisoryType'] if attributes[:'advisoryType']

  raise 'You cannot provide both :advisoryType and :advisory_type' if attributes.key?(:'advisoryType') && attributes.key?(:'advisory_type')

  self.advisory_type = attributes[:'advisory_type'] if attributes[:'advisory_type']

  self.errata = attributes[:'errata'] if attributes[:'errata']

  self.software_sources = attributes[:'softwareSources'] if attributes[:'softwareSources']

  raise 'You cannot provide both :softwareSources and :software_sources' if attributes.key?(:'softwareSources') && attributes.key?(:'software_sources')

  self.software_sources = attributes[:'software_sources'] if attributes[:'software_sources']
end

Instance Attribute Details

#advisory_typeString

Type of the erratum.



45
46
47
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 45

def advisory_type
  @advisory_type
end

#architectureString

the architecture for which this software was built



37
38
39
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 37

def architecture
  @architecture
end

#display_nameString

[Required] Package name



21
22
23
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 21

def display_name
  @display_name
end

#errataArray<OCI::OsManagement::Models::Id>

List of errata containing this software package



49
50
51
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 49

def errata
  @errata
end

#nameString

[Required] Unique identifier for the package. NOTE - This is not an OCID



25
26
27
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 25

def name
  @name
end

#software_sourcesArray<OCI::OsManagement::Models::SoftwareSourceId>

list of software sources that provide the software package



53
54
55
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 53

def software_sources
  @software_sources
end

#summaryString

a summary description of the software package



41
42
43
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 41

def summary
  @summary
end

#typeString

[Required] Type of the package



29
30
31
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 29

def type
  @type
end

#versionString

[Required] Version of the package



33
34
35
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 33

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 56

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'name': :'name',
    'type': :'type',
    'version': :'version',
    'architecture': :'architecture',
    'summary': :'summary',
    'advisory_type': :'advisoryType',
    'errata': :'errata',
    'software_sources': :'softwareSources'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 73

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'name': :'String',
    'type': :'String',
    'version': :'String',
    'architecture': :'String',
    'summary': :'String',
    'advisory_type': :'String',
    'errata': :'Array<OCI::OsManagement::Models::Id>',
    'software_sources': :'Array<OCI::OsManagement::Models::SoftwareSourceId>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 161

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    name == other.name &&
    type == other.type &&
    version == other.version &&
    architecture == other.architecture &&
    summary == other.summary &&
    advisory_type == other.advisory_type &&
    errata == other.errata &&
    software_sources == other.software_sources
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 199

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


179
180
181
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 179

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



188
189
190
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 188

def hash
  [display_name, name, type, version, architecture, summary, advisory_type, errata, software_sources].hash
end

#to_hashHash

Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



226
227
228
# File 'lib/oci/os_management/models/software_package_search_summary.rb', line 226

def to_s
  to_hash.to_s
end