Class: OCI::OsManagement::Models::UpdateModuleStreamDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/os_management/models/update_module_stream_details.rb

Overview

Information detailing the state of a module stream

Constant Summary collapse

STATUS_ENUM =
[
  STATUS_ENABLED = 'ENABLED'.freeze,
  STATUS_DISABLED = 'DISABLED'.freeze,
  STATUS_ACTIVE = 'ACTIVE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateModuleStreamDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 104

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.stream_name = attributes[:'streamName'] if attributes[:'streamName']

  raise 'You cannot provide both :streamName and :stream_name' if attributes.key?(:'streamName') && attributes.key?(:'stream_name')

  self.stream_name = attributes[:'stream_name'] if attributes[:'stream_name']

  self.status = attributes[:'status'] if attributes[:'status']

  self.time_modified = attributes[:'timeModified'] if attributes[:'timeModified']

  raise 'You cannot provide both :timeModified and :time_modified' if attributes.key?(:'timeModified') && attributes.key?(:'time_modified')

  self.time_modified = attributes[:'time_modified'] if attributes[:'time_modified']

  self.software_source_name = attributes[:'softwareSourceName'] if attributes[:'softwareSourceName']

  raise 'You cannot provide both :softwareSourceName and :software_source_name' if attributes.key?(:'softwareSourceName') && attributes.key?(:'software_source_name')

  self.software_source_name = attributes[:'software_source_name'] if attributes[:'software_source_name']

  self.software_source_url = attributes[:'softwareSourceUrl'] if attributes[:'softwareSourceUrl']

  raise 'You cannot provide both :softwareSourceUrl and :software_source_url' if attributes.key?(:'softwareSourceUrl') && attributes.key?(:'software_source_url')

  self.software_source_url = attributes[:'software_source_url'] if attributes[:'software_source_url']

  self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil?

  raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default')

  self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil?

  self.profiles = attributes[:'profiles'] if attributes[:'profiles']
end

Instance Attribute Details

#is_defaultBOOLEAN

Indicates if the module stream is the default

Returns:

  • (BOOLEAN)


55
56
57
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 55

def is_default
  @is_default
end

#profilesArray<OCI::OsManagement::Models::UpdateModuleStreamProfileDetails>

The profiles of the stream



59
60
61
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 59

def profiles
  @profiles
end

#software_source_nameString

The name of the software source that publishes this stream.

Returns:

  • (String)


47
48
49
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 47

def software_source_name
  @software_source_name
end

#software_source_urlString

The URL of the software source that publishes this stream.

Returns:

  • (String)


51
52
53
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 51

def software_source_url
  @software_source_url
end

#statusString

**[Required]** The status of the stream

A stream with the "ENABLED" status can be used as a source for installing profiles. Streams with this status are also "ACTIVE".

A stream with the "DISABLED" status cannot be the source for installing profiles. To install profiles and packages from this stream, it must be enabled.

A stream with the "ACTIVE" status can be used as a source for installing profiles. The packages that comprise the stream are also used when a matching package is installed directly. In general, a stream can have this status if it is the default stream for the module and no stream has been explicitly enabled.

Returns:

  • (String)


36
37
38
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 36

def status
  @status
end

#stream_nameString

**[Required]** The name of the stream of the parent module

Returns:

  • (String)


18
19
20
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 18

def stream_name
  @stream_name
end

#time_modifiedDateTime

**[Required]** The date and time of the last status change for this object, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.

Returns:

  • (DateTime)


43
44
45
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 43

def time_modified
  @time_modified
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 62

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'stream_name': :'streamName',
    'status': :'status',
    'time_modified': :'timeModified',
    'software_source_name': :'softwareSourceName',
    'software_source_url': :'softwareSourceUrl',
    'is_default': :'isDefault',
    'profiles': :'profiles'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 77

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'stream_name': :'String',
    'status': :'String',
    'time_modified': :'DateTime',
    'software_source_name': :'String',
    'software_source_url': :'String',
    'is_default': :'BOOLEAN',
    'profiles': :'Array<OCI::OsManagement::Models::UpdateModuleStreamProfileDetails>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 160

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    stream_name == other.stream_name &&
    status == other.status &&
    time_modified == other.time_modified &&
    software_source_name == other.software_source_name &&
    software_source_url == other.software_source_url &&
    is_default == other.is_default &&
    profiles == other.profiles
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 196

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 176

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



185
186
187
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 185

def hash
  [stream_name, status, time_modified, software_source_name, software_source_url, is_default, profiles].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



223
224
225
# File 'lib/oci/os_management/models/update_module_stream_details.rb', line 223

def to_s
  to_hash.to_s
end