Class: OCI::OspGateway::InvoiceServiceClient

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/osp_gateway/invoice_service_client.rb

Overview

This site describes all the Rest endpoints of OSP Gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ InvoiceServiceClient

Creates a new InvoiceServiceClient. Notes:

If a config is not specified, then the global OCI.config will be used.

This client is not thread-safe

Either a region or an endpoint must be specified.  If an endpoint is specified, it will be used instead of the
  region. A region may be specified in the config or via or the region parameter. If specified in both, then the
  region parameter will be used.


53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 53

def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil)
  # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers)
  # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals
  # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then
  # pass it to this constructor.
  #
  # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid
  # so try and load the config from the default file.
  config = OCI::Config.validate_and_build_config_with_signer(config, signer)

  signer = OCI::Signer.config_file_auth_builder(config) if signer.nil?

  @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings)
  @retry_config = retry_config

  if endpoint
    @endpoint = endpoint + '/20191001'
  else
    region ||= config.region
    region ||= signer.region if signer.respond_to?(:region)
    self.region = region
  end
  logger.info "InvoiceServiceClient endpoint set to '#{@endpoint}'." if logger
end

Instance Attribute Details

#api_clientOCI::ApiClient (readonly)

Client used to make HTTP requests.



13
14
15
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 13

def api_client
  @api_client
end

#endpointString (readonly)

Fully qualified endpoint URL



17
18
19
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 17

def endpoint
  @endpoint
end

#regionString

The region, which will usually correspond to a value in Regions::REGION_ENUM.



27
28
29
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 27

def region
  @region
end

#retry_configOCI::Retry::RetryConfig (readonly)

The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries



23
24
25
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 23

def retry_config
  @retry_config
end

Instance Method Details

#download_pdf_content(osp_home_region, compartment_id, internal_invoice_id, opts = {}, &block) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ospgateway/download_pdf_content.rb.html) to see an example of how to use download_pdf_content API.

Returns an invoice in pdf format

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.

  • :response_target (String, IO)

    Streaming http body into a file (specified by file name or File object) or IO object if the block is not given



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 117

def download_pdf_content(osp_home_region, compartment_id, internal_invoice_id, opts = {}, &block)
  logger.debug 'Calling operation InvoiceServiceClient#download_pdf_content.' if logger

  raise "Missing the required parameter 'osp_home_region' when calling download_pdf_content." if osp_home_region.nil?
  raise "Missing the required parameter 'compartment_id' when calling download_pdf_content." if compartment_id.nil?
  raise "Missing the required parameter 'internal_invoice_id' when calling download_pdf_content." if internal_invoice_id.nil?
  raise "Parameter value for 'internal_invoice_id' must not be blank" if OCI::Internal::Util.blank_string?(internal_invoice_id)

  path = '/invoices/{internalInvoiceId}/actions/downloadPdfContent'.sub('{internalInvoiceId}', internal_invoice_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:ospHomeRegion] = osp_home_region
  query_params[:compartmentId] = compartment_id

  # Header Params
  header_params = {}
  header_params[:accept] = opts[:accept] if opts[:accept]
  header_params[:accept] ||= 'application/pdf'
  header_params[:'accept-encoding'] = opts[:accept_encoding] if opts[:accept_encoding]
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'InvoiceServiceClient#download_pdf_content') do
    if !block.nil?
      @api_client.call_api(
        :POST,
        path,
        endpoint,
        header_params: header_params,
        query_params: query_params,
        operation_signing_strategy: operation_signing_strategy,
        body: post_body,
        return_type: 'Stream',
        &block
      )
    elsif opts[:response_target]
      if opts[:response_target].respond_to? :write
        @api_client.call_api(
          :POST,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'Stream',
          &proc { |chunk, _response| opts[:response_target].write(chunk) }
        )
      elsif opts[:response_target].is_a?(String)
        File.open(opts[:response_target], 'wb') do |output|
          return @api_client.call_api(
            :POST,
            path,
            endpoint,
            header_params: header_params,
            query_params: query_params,
            operation_signing_strategy: operation_signing_strategy,
            body: post_body,
            return_type: 'Stream',
            &proc { |chunk, _response| output.write(chunk) }
          )
        end
      end
    else
      @api_client.call_api(
        :POST,
        path,
        endpoint,
        header_params: header_params,
        query_params: query_params,
        operation_signing_strategy: operation_signing_strategy,
        body: post_body,
        return_type: 'String'
      )
    end
  end
  # rubocop:enable Metrics/BlockLength
end

#get_invoice(osp_home_region, compartment_id, internal_invoice_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ospgateway/get_invoice.rb.html) to see an example of how to use get_invoice API.

Returns an invoice by invoice id

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 225

def get_invoice(osp_home_region, compartment_id, internal_invoice_id, opts = {})
  logger.debug 'Calling operation InvoiceServiceClient#get_invoice.' if logger

  raise "Missing the required parameter 'osp_home_region' when calling get_invoice." if osp_home_region.nil?
  raise "Missing the required parameter 'compartment_id' when calling get_invoice." if compartment_id.nil?
  raise "Missing the required parameter 'internal_invoice_id' when calling get_invoice." if internal_invoice_id.nil?
  raise "Parameter value for 'internal_invoice_id' must not be blank" if OCI::Internal::Util.blank_string?(internal_invoice_id)

  path = '/invoices/{internalInvoiceId}'.sub('{internalInvoiceId}', internal_invoice_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:ospHomeRegion] = osp_home_region
  query_params[:compartmentId] = compartment_id

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'InvoiceServiceClient#get_invoice') do
    @api_client.call_api(
      :GET,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::OspGateway::Models::Invoice'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#list_invoice_lines(osp_home_region, compartment_id, internal_invoice_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ospgateway/list_invoice_lines.rb.html) to see an example of how to use list_invoice_lines API.

Returns the invoice product list by invoice id

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.

  • :page (String)

    For list pagination. The value of the opc-next-page response header from the previous "List" call.

  • :limit (Integer)

    For list pagination. The maximum number of results per page, or items to return in a paginated "List" call. (default to 500)



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 293

def list_invoice_lines(osp_home_region, compartment_id, internal_invoice_id, opts = {})
  logger.debug 'Calling operation InvoiceServiceClient#list_invoice_lines.' if logger

  raise "Missing the required parameter 'osp_home_region' when calling list_invoice_lines." if osp_home_region.nil?
  raise "Missing the required parameter 'compartment_id' when calling list_invoice_lines." if compartment_id.nil?
  raise "Missing the required parameter 'internal_invoice_id' when calling list_invoice_lines." if internal_invoice_id.nil?
  raise "Parameter value for 'internal_invoice_id' must not be blank" if OCI::Internal::Util.blank_string?(internal_invoice_id)

  path = '/invoices/{internalInvoiceId}/invoiceLines'.sub('{internalInvoiceId}', internal_invoice_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:ospHomeRegion] = osp_home_region
  query_params[:compartmentId] = compartment_id
  query_params[:page] = opts[:page] if opts[:page]
  query_params[:limit] = opts[:limit] if opts[:limit]

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'InvoiceServiceClient#list_invoice_lines') do
    @api_client.call_api(
      :GET,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::OspGateway::Models::InvoiceLineCollection'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#list_invoices(osp_home_region, compartment_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ospgateway/list_invoices.rb.html) to see an example of how to use list_invoices API.

Returns a list of invoices

Allowed values are: HARDWARE, SUBSCRIPTION, SUPPORT, LICENSE, EDUCATION, CONSULTING, SERVICE, USAGE
Allowed values are: OPEN, PAST_DUE, , CLOSED
Allowed values are: INVOICE_NO, REF_NO, STATUS, TYPE, INVOICE_DATE, DUE_DATE, PAYM_REF, TOTAL_AMOUNT, BALANCE_DUE
Allowed values are: ASC, DESC

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.

  • :invoice_id (String)

    The invoice query param (not unique).

  • :type (Array<String>)

    A filter to only return resources that match the given type exactly. (default to [HARDWARE, SUBSCRIPTION, SUPPORT, LICENSE, EDUCATION, CONSULTING, SERVICE, USAGE])

  • :search_text (String)

    A filter to only return resources that match the given value. Looking for partial matches in the following fileds: Invoice No., Reference No. (plan number), Payment Ref, Total Amount(plan number), Balance Due(plan number) and Party/Customer Name

  • :time_invoice_start (DateTime)

    description: Start time (UTC) of the target invoice date range for which to fetch invoice data (inclusive).

  • :time_invoice_end (DateTime)

    description: End time (UTC) of the target invoice date range for which to fetch invoice data (exclusive).

  • :time_payment_start (DateTime)

    description: Start time (UTC) of the target payment date range for which to fetch invoice data (inclusive).

  • :time_payment_end (DateTime)

    description: End time (UTC) of the target payment date range for which to fetch invoice data (exclusive).

  • :status (Array<String>)

    A filter to only return resources that match one of the status elements. (default to [OPEN, PAST_DUE, PAYMENT_SUBMITTED, CLOSED])

  • :page (String)

    For list pagination. The value of the opc-next-page response header from the previous "List" call.

  • :limit (Integer)

    For list pagination. The maximum number of results per page, or items to return in a paginated "List" call. (default to 500)

  • :sort_by (String)

    The field to sort by. Only one field can be selected for sorting. (default to INVOICE_NO)

  • :sort_order (String)

    The sort order to use (ascending or descending). (default to ASC)



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 388

def list_invoices(osp_home_region, compartment_id, opts = {})
  logger.debug 'Calling operation InvoiceServiceClient#list_invoices.' if logger

  raise "Missing the required parameter 'osp_home_region' when calling list_invoices." if osp_home_region.nil?
  raise "Missing the required parameter 'compartment_id' when calling list_invoices." if compartment_id.nil?


  type_allowable_values = %w[HARDWARE SUBSCRIPTION SUPPORT LICENSE EDUCATION CONSULTING SERVICE USAGE]
  if opts[:type] && !opts[:type].empty?
    opts[:type].each do |val_to_check|
      unless type_allowable_values.include?(val_to_check)
        raise 'Invalid value for "type", must be one of HARDWARE, SUBSCRIPTION, SUPPORT, LICENSE, EDUCATION, CONSULTING, SERVICE, USAGE.'
      end
    end
  end


  status_allowable_values = %w[OPEN PAST_DUE PAYMENT_SUBMITTED CLOSED]
  if opts[:status] && !opts[:status].empty?
    opts[:status].each do |val_to_check|
      unless status_allowable_values.include?(val_to_check)
        raise 'Invalid value for "status", must be one of OPEN, PAST_DUE, PAYMENT_SUBMITTED, CLOSED.'
      end
    end
  end

  if opts[:sort_by] && !%w[INVOICE_NO REF_NO STATUS TYPE INVOICE_DATE DUE_DATE PAYM_REF TOTAL_AMOUNT BALANCE_DUE].include?(opts[:sort_by])
    raise 'Invalid value for "sort_by", must be one of INVOICE_NO, REF_NO, STATUS, TYPE, INVOICE_DATE, DUE_DATE, PAYM_REF, TOTAL_AMOUNT, BALANCE_DUE.'
  end

  if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order])
    raise 'Invalid value for "sort_order", must be one of ASC, DESC.'
  end

  path = '/invoices'
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:ospHomeRegion] = osp_home_region
  query_params[:compartmentId] = compartment_id
  query_params[:invoiceId] = opts[:invoice_id] if opts[:invoice_id]
  query_params[:type] = OCI::ApiClient.build_collection_params(opts[:type], :multi) if opts[:type] && !opts[:type].empty?
  query_params[:searchText] = opts[:search_text] if opts[:search_text]
  query_params[:timeInvoiceStart] = opts[:time_invoice_start] if opts[:time_invoice_start]
  query_params[:timeInvoiceEnd] = opts[:time_invoice_end] if opts[:time_invoice_end]
  query_params[:timePaymentStart] = opts[:time_payment_start] if opts[:time_payment_start]
  query_params[:timePaymentEnd] = opts[:time_payment_end] if opts[:time_payment_end]
  query_params[:status] = OCI::ApiClient.build_collection_params(opts[:status], :multi) if opts[:status] && !opts[:status].empty?
  query_params[:page] = opts[:page] if opts[:page]
  query_params[:limit] = opts[:limit] if opts[:limit]
  query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]
  query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'InvoiceServiceClient#list_invoices') do
    @api_client.call_api(
      :GET,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::OspGateway::Models::InvoiceCollection'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#loggerLogger



92
93
94
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 92

def logger
  @api_client.config.logger
end

#pay_invoice(osp_home_region, internal_invoice_id, compartment_id, pay_invoice_details, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ospgateway/pay_invoice.rb.html) to see an example of how to use pay_invoice API.

Pay an invoice

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :if_match (String)

    For optimistic concurrency control. In the PUT or DELETE call for a resource, set the if-match parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

  • :opc_retry_token (String)

    For requests that are not idempotent (creates being the main place of interest), THE APIs should take a header called opc-retry-token to identify the customer desire across requests, to introduce some level of idempotency.

  • :opc_request_id (String)

    The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.



500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/oci/osp_gateway/invoice_service_client.rb', line 500

def pay_invoice(osp_home_region, internal_invoice_id, compartment_id, pay_invoice_details, opts = {})
  logger.debug 'Calling operation InvoiceServiceClient#pay_invoice.' if logger

  raise "Missing the required parameter 'osp_home_region' when calling pay_invoice." if osp_home_region.nil?
  raise "Missing the required parameter 'internal_invoice_id' when calling pay_invoice." if internal_invoice_id.nil?
  raise "Missing the required parameter 'compartment_id' when calling pay_invoice." if compartment_id.nil?
  raise "Missing the required parameter 'pay_invoice_details' when calling pay_invoice." if pay_invoice_details.nil?
  raise "Parameter value for 'internal_invoice_id' must not be blank" if OCI::Internal::Util.blank_string?(internal_invoice_id)

  path = '/invoices/{internalInvoiceId}/actions/pay'.sub('{internalInvoiceId}', internal_invoice_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:ospHomeRegion] = osp_home_region
  query_params[:compartmentId] = compartment_id

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
  header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token]
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf
  header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token

  post_body = @api_client.object_to_http_body(pay_invoice_details)

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'InvoiceServiceClient#pay_invoice') do
    @api_client.call_api(
      :POST,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::OspGateway::Models::PayInvoiceReceipt'
    )
  end
  # rubocop:enable Metrics/BlockLength
end