Class: OCI::OspGateway::Models::Country
- Inherits:
-
Object
- Object
- OCI::OspGateway::Models::Country
- Defined in:
- lib/oci/osp_gateway/models/country.rb
Overview
Country details model
Instance Attribute Summary collapse
-
#ascii3_country_code ⇒ String
Country code in ISO-3166-1 3-letter format.
-
#country_code ⇒ String
Country code in ISO-3166-1 2-letter format.
-
#country_id ⇒ Float
Indentifier of the country.
-
#country_name ⇒ String
Name of the country.
-
#language_id ⇒ Float
Language identifier.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Country
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Country
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/osp_gateway/models/country.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.country_id = attributes[:'countryId'] if attributes[:'countryId'] raise 'You cannot provide both :countryId and :country_id' if attributes.key?(:'countryId') && attributes.key?(:'country_id') self.country_id = attributes[:'country_id'] if attributes[:'country_id'] self.country_code = attributes[:'countryCode'] if attributes[:'countryCode'] raise 'You cannot provide both :countryCode and :country_code' if attributes.key?(:'countryCode') && attributes.key?(:'country_code') self.country_code = attributes[:'country_code'] if attributes[:'country_code'] self.country_name = attributes[:'countryName'] if attributes[:'countryName'] raise 'You cannot provide both :countryName and :country_name' if attributes.key?(:'countryName') && attributes.key?(:'country_name') self.country_name = attributes[:'country_name'] if attributes[:'country_name'] self.language_id = attributes[:'languageId'] if attributes[:'languageId'] raise 'You cannot provide both :languageId and :language_id' if attributes.key?(:'languageId') && attributes.key?(:'language_id') self.language_id = attributes[:'language_id'] if attributes[:'language_id'] self.ascii3_country_code = attributes[:'ascii3CountryCode'] if attributes[:'ascii3CountryCode'] raise 'You cannot provide both :ascii3CountryCode and :ascii3_country_code' if attributes.key?(:'ascii3CountryCode') && attributes.key?(:'ascii3_country_code') self.ascii3_country_code = attributes[:'ascii3_country_code'] if attributes[:'ascii3_country_code'] end |
Instance Attribute Details
#ascii3_country_code ⇒ String
Country code in ISO-3166-1 3-letter format
28 29 30 |
# File 'lib/oci/osp_gateway/models/country.rb', line 28 def ascii3_country_code @ascii3_country_code end |
#country_code ⇒ String
Country code in ISO-3166-1 2-letter format
16 17 18 |
# File 'lib/oci/osp_gateway/models/country.rb', line 16 def country_code @country_code end |
#country_id ⇒ Float
Indentifier of the country. This is a DB side unique id which was generated when the entity was created in the table
12 13 14 |
# File 'lib/oci/osp_gateway/models/country.rb', line 12 def country_id @country_id end |
#country_name ⇒ String
Name of the country
20 21 22 |
# File 'lib/oci/osp_gateway/models/country.rb', line 20 def country_name @country_name end |
#language_id ⇒ Float
Language identifier
24 25 26 |
# File 'lib/oci/osp_gateway/models/country.rb', line 24 def language_id @language_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/osp_gateway/models/country.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'country_id': :'countryId', 'country_code': :'countryCode', 'country_name': :'countryName', 'language_id': :'languageId', 'ascii3_country_code': :'ascii3CountryCode' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/osp_gateway/models/country.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'country_id': :'Float', 'country_code': :'String', 'country_name': :'String', 'language_id': :'Float', 'ascii3_country_code': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/osp_gateway/models/country.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && country_id == other.country_id && country_code == other.country_code && country_name == other.country_name && language_id == other.language_id && ascii3_country_code == other.ascii3_country_code end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/osp_gateway/models/country.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/osp_gateway/models/country.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/osp_gateway/models/country.rb', line 134 def hash [country_id, country_code, country_name, language_id, ascii3_country_code].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/osp_gateway/models/country.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/osp_gateway/models/country.rb', line 172 def to_s to_hash.to_s end |