Class: OCI::OspGateway::Models::Currency

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/osp_gateway/models/currency.rb

Overview

Currency details model

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Currency

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :currency_code (String)

    The value to assign to the #currency_code property

  • :currency_symbol (String)

    The value to assign to the #currency_symbol property

  • :name (String)

    The value to assign to the #name property

  • :usd_conversion (Float)

    The value to assign to the #usd_conversion property

  • :round_decimal_point (Float)

    The value to assign to the #round_decimal_point property



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/osp_gateway/models/currency.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.currency_code = attributes[:'currencyCode'] if attributes[:'currencyCode']

  raise 'You cannot provide both :currencyCode and :currency_code' if attributes.key?(:'currencyCode') && attributes.key?(:'currency_code')

  self.currency_code = attributes[:'currency_code'] if attributes[:'currency_code']

  self.currency_symbol = attributes[:'currencySymbol'] if attributes[:'currencySymbol']

  raise 'You cannot provide both :currencySymbol and :currency_symbol' if attributes.key?(:'currencySymbol') && attributes.key?(:'currency_symbol')

  self.currency_symbol = attributes[:'currency_symbol'] if attributes[:'currency_symbol']

  self.name = attributes[:'name'] if attributes[:'name']

  self.usd_conversion = attributes[:'usdConversion'] if attributes[:'usdConversion']

  raise 'You cannot provide both :usdConversion and :usd_conversion' if attributes.key?(:'usdConversion') && attributes.key?(:'usd_conversion')

  self.usd_conversion = attributes[:'usd_conversion'] if attributes[:'usd_conversion']

  self.round_decimal_point = attributes[:'roundDecimalPoint'] if attributes[:'roundDecimalPoint']

  raise 'You cannot provide both :roundDecimalPoint and :round_decimal_point' if attributes.key?(:'roundDecimalPoint') && attributes.key?(:'round_decimal_point')

  self.round_decimal_point = attributes[:'round_decimal_point'] if attributes[:'round_decimal_point']
end

Instance Attribute Details

#currency_codeString

Currency code

Returns:

  • (String)


12
13
14
# File 'lib/oci/osp_gateway/models/currency.rb', line 12

def currency_code
  @currency_code
end

#currency_symbolString

Currency symbol

Returns:

  • (String)


16
17
18
# File 'lib/oci/osp_gateway/models/currency.rb', line 16

def currency_symbol
  @currency_symbol
end

#nameString

Name of the currency

Returns:

  • (String)


20
21
22
# File 'lib/oci/osp_gateway/models/currency.rb', line 20

def name
  @name
end

#round_decimal_pointFloat

Round decimal point

Returns:

  • (Float)


28
29
30
# File 'lib/oci/osp_gateway/models/currency.rb', line 28

def round_decimal_point
  @round_decimal_point
end

#usd_conversionFloat

USD conversion rate of the currency

Returns:

  • (Float)


24
25
26
# File 'lib/oci/osp_gateway/models/currency.rb', line 24

def usd_conversion
  @usd_conversion
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/osp_gateway/models/currency.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'currency_code': :'currencyCode',
    'currency_symbol': :'currencySymbol',
    'name': :'name',
    'usd_conversion': :'usdConversion',
    'round_decimal_point': :'roundDecimalPoint'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/osp_gateway/models/currency.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'currency_code': :'String',
    'currency_symbol': :'String',
    'name': :'String',
    'usd_conversion': :'Float',
    'round_decimal_point': :'Float'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



107
108
109
110
111
112
113
114
115
116
# File 'lib/oci/osp_gateway/models/currency.rb', line 107

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    currency_code == other.currency_code &&
    currency_symbol == other.currency_symbol &&
    name == other.name &&
    usd_conversion == other.usd_conversion &&
    round_decimal_point == other.round_decimal_point
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/osp_gateway/models/currency.rb', line 141

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


121
122
123
# File 'lib/oci/osp_gateway/models/currency.rb', line 121

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



130
131
132
# File 'lib/oci/osp_gateway/models/currency.rb', line 130

def hash
  [currency_code, currency_symbol, name, usd_conversion, round_decimal_point].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



174
175
176
177
178
179
180
181
182
183
# File 'lib/oci/osp_gateway/models/currency.rb', line 174

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



168
169
170
# File 'lib/oci/osp_gateway/models/currency.rb', line 168

def to_s
  to_hash.to_s
end