Class: OCI::OspGateway::Models::Invoice
- Inherits:
-
Object
- Object
- OCI::OspGateway::Models::Invoice
- Defined in:
- lib/oci/osp_gateway/models/invoice.rb
Overview
Invoice details
Constant Summary collapse
- INVOICE_TYPE_ENUM =
[ INVOICE_TYPE_HARDWARE = 'HARDWARE'.freeze, INVOICE_TYPE_SUBSCRIPTION = 'SUBSCRIPTION'.freeze, INVOICE_TYPE_SUPPORT = 'SUPPORT'.freeze, INVOICE_TYPE_LICENSE = 'LICENSE'.freeze, INVOICE_TYPE_EDUCATION = 'EDUCATION'.freeze, INVOICE_TYPE_CONSULTING = 'CONSULTING'.freeze, INVOICE_TYPE_SERVICE = 'SERVICE'.freeze, INVOICE_TYPE_USAGE = 'USAGE'.freeze, INVOICE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- INVOICE_STATUS_ENUM =
[ INVOICE_STATUS_OPEN = 'OPEN'.freeze, INVOICE_STATUS_PAST_DUE = 'PAST_DUE'.freeze, INVOICE_STATUS_PAYMENT_SUBMITTED = 'PAYMENT_SUBMITTED'.freeze, INVOICE_STATUS_CLOSED = 'CLOSED'.freeze, INVOICE_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #bill_to_address ⇒ OCI::OspGateway::Models::BillToAddress
- #currency ⇒ OCI::OspGateway::Models::Currency
-
#internal_invoice_id ⇒ String
Transaction identifier.
-
#invoice_amount ⇒ Float
Total amount of invoice.
-
#invoice_amount_adjusted ⇒ Float
Invoice amount adjust.
-
#invoice_amount_applied ⇒ Float
Invoice amount applied.
-
#invoice_amount_credited ⇒ Float
Invoice amount credit.
-
#invoice_amount_due ⇒ Float
Balance of invoice.
-
#invoice_id ⇒ String
**[Required]** Invoice identifier which is generated on the on-premise sie.
-
#invoice_number ⇒ String
Invoice external reference.
-
#invoice_po_number ⇒ String
Invoice PO number.
-
#invoice_ref_number ⇒ String
Invoice reference number.
-
#invoice_status ⇒ String
Invoice status.
-
#invoice_type ⇒ String
Type of invoice.
-
#is_credit_card_payable ⇒ BOOLEAN
Is credit card payment eligible.
-
#is_display_download_pdf ⇒ BOOLEAN
Is pdf download access allowed.
-
#is_payable ⇒ BOOLEAN
Whether invoice can be payed.
-
#is_pdf_email_available ⇒ BOOLEAN
Is emailing pdf allowed.
- #last_payment_detail ⇒ OCI::OspGateway::Models::PaymentDetail
-
#payment_terms ⇒ String
Payment terms.
-
#preferred_email ⇒ String
Preferred Email on the invoice.
-
#subscription_ids ⇒ Array<String>
List of subscription identifiers.
-
#tax ⇒ Float
Tax of invoice amount.
-
#time_invoice ⇒ DateTime
Date of invoice.
-
#time_invoice_due ⇒ DateTime
Due date of invoice.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Invoice
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Invoice
Initializes the object
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 225 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.invoice_id = attributes[:'invoiceId'] if attributes[:'invoiceId'] raise 'You cannot provide both :invoiceId and :invoice_id' if attributes.key?(:'invoiceId') && attributes.key?(:'invoice_id') self.invoice_id = attributes[:'invoice_id'] if attributes[:'invoice_id'] self.invoice_number = attributes[:'invoiceNumber'] if attributes[:'invoiceNumber'] raise 'You cannot provide both :invoiceNumber and :invoice_number' if attributes.key?(:'invoiceNumber') && attributes.key?(:'invoice_number') self.invoice_number = attributes[:'invoice_number'] if attributes[:'invoice_number'] self.internal_invoice_id = attributes[:'internalInvoiceId'] if attributes[:'internalInvoiceId'] raise 'You cannot provide both :internalInvoiceId and :internal_invoice_id' if attributes.key?(:'internalInvoiceId') && attributes.key?(:'internal_invoice_id') self.internal_invoice_id = attributes[:'internal_invoice_id'] if attributes[:'internal_invoice_id'] self.is_credit_card_payable = attributes[:'isCreditCardPayable'] unless attributes[:'isCreditCardPayable'].nil? raise 'You cannot provide both :isCreditCardPayable and :is_credit_card_payable' if attributes.key?(:'isCreditCardPayable') && attributes.key?(:'is_credit_card_payable') self.is_credit_card_payable = attributes[:'is_credit_card_payable'] unless attributes[:'is_credit_card_payable'].nil? self.time_invoice = attributes[:'timeInvoice'] if attributes[:'timeInvoice'] raise 'You cannot provide both :timeInvoice and :time_invoice' if attributes.key?(:'timeInvoice') && attributes.key?(:'time_invoice') self.time_invoice = attributes[:'time_invoice'] if attributes[:'time_invoice'] self.tax = attributes[:'tax'] if attributes[:'tax'] self.invoice_amount = attributes[:'invoiceAmount'] if attributes[:'invoiceAmount'] raise 'You cannot provide both :invoiceAmount and :invoice_amount' if attributes.key?(:'invoiceAmount') && attributes.key?(:'invoice_amount') self.invoice_amount = attributes[:'invoice_amount'] if attributes[:'invoice_amount'] self.invoice_amount_due = attributes[:'invoiceAmountDue'] if attributes[:'invoiceAmountDue'] raise 'You cannot provide both :invoiceAmountDue and :invoice_amount_due' if attributes.key?(:'invoiceAmountDue') && attributes.key?(:'invoice_amount_due') self.invoice_amount_due = attributes[:'invoice_amount_due'] if attributes[:'invoice_amount_due'] self.invoice_amount_credited = attributes[:'invoiceAmountCredited'] if attributes[:'invoiceAmountCredited'] raise 'You cannot provide both :invoiceAmountCredited and :invoice_amount_credited' if attributes.key?(:'invoiceAmountCredited') && attributes.key?(:'invoice_amount_credited') self.invoice_amount_credited = attributes[:'invoice_amount_credited'] if attributes[:'invoice_amount_credited'] self.invoice_amount_adjusted = attributes[:'invoiceAmountAdjusted'] if attributes[:'invoiceAmountAdjusted'] raise 'You cannot provide both :invoiceAmountAdjusted and :invoice_amount_adjusted' if attributes.key?(:'invoiceAmountAdjusted') && attributes.key?(:'invoice_amount_adjusted') self.invoice_amount_adjusted = attributes[:'invoice_amount_adjusted'] if attributes[:'invoice_amount_adjusted'] self.invoice_amount_applied = attributes[:'invoiceAmountApplied'] if attributes[:'invoiceAmountApplied'] raise 'You cannot provide both :invoiceAmountApplied and :invoice_amount_applied' if attributes.key?(:'invoiceAmountApplied') && attributes.key?(:'invoice_amount_applied') self.invoice_amount_applied = attributes[:'invoice_amount_applied'] if attributes[:'invoice_amount_applied'] self.currency = attributes[:'currency'] if attributes[:'currency'] self.invoice_type = attributes[:'invoiceType'] if attributes[:'invoiceType'] raise 'You cannot provide both :invoiceType and :invoice_type' if attributes.key?(:'invoiceType') && attributes.key?(:'invoice_type') self.invoice_type = attributes[:'invoice_type'] if attributes[:'invoice_type'] self.time_invoice_due = attributes[:'timeInvoiceDue'] if attributes[:'timeInvoiceDue'] raise 'You cannot provide both :timeInvoiceDue and :time_invoice_due' if attributes.key?(:'timeInvoiceDue') && attributes.key?(:'time_invoice_due') self.time_invoice_due = attributes[:'time_invoice_due'] if attributes[:'time_invoice_due'] self.invoice_ref_number = attributes[:'invoiceRefNumber'] if attributes[:'invoiceRefNumber'] raise 'You cannot provide both :invoiceRefNumber and :invoice_ref_number' if attributes.key?(:'invoiceRefNumber') && attributes.key?(:'invoice_ref_number') self.invoice_ref_number = attributes[:'invoice_ref_number'] if attributes[:'invoice_ref_number'] self.invoice_po_number = attributes[:'invoicePoNumber'] if attributes[:'invoicePoNumber'] raise 'You cannot provide both :invoicePoNumber and :invoice_po_number' if attributes.key?(:'invoicePoNumber') && attributes.key?(:'invoice_po_number') self.invoice_po_number = attributes[:'invoice_po_number'] if attributes[:'invoice_po_number'] self.invoice_status = attributes[:'invoiceStatus'] if attributes[:'invoiceStatus'] raise 'You cannot provide both :invoiceStatus and :invoice_status' if attributes.key?(:'invoiceStatus') && attributes.key?(:'invoice_status') self.invoice_status = attributes[:'invoice_status'] if attributes[:'invoice_status'] self.preferred_email = attributes[:'preferredEmail'] if attributes[:'preferredEmail'] raise 'You cannot provide both :preferredEmail and :preferred_email' if attributes.key?(:'preferredEmail') && attributes.key?(:'preferred_email') self.preferred_email = attributes[:'preferred_email'] if attributes[:'preferred_email'] self.is_pdf_email_available = attributes[:'isPdfEmailAvailable'] unless attributes[:'isPdfEmailAvailable'].nil? raise 'You cannot provide both :isPdfEmailAvailable and :is_pdf_email_available' if attributes.key?(:'isPdfEmailAvailable') && attributes.key?(:'is_pdf_email_available') self.is_pdf_email_available = attributes[:'is_pdf_email_available'] unless attributes[:'is_pdf_email_available'].nil? self.is_display_download_pdf = attributes[:'isDisplayDownloadPdf'] unless attributes[:'isDisplayDownloadPdf'].nil? raise 'You cannot provide both :isDisplayDownloadPdf and :is_display_download_pdf' if attributes.key?(:'isDisplayDownloadPdf') && attributes.key?(:'is_display_download_pdf') self.is_display_download_pdf = attributes[:'is_display_download_pdf'] unless attributes[:'is_display_download_pdf'].nil? self.is_payable = attributes[:'isPayable'] unless attributes[:'isPayable'].nil? raise 'You cannot provide both :isPayable and :is_payable' if attributes.key?(:'isPayable') && attributes.key?(:'is_payable') self.is_payable = attributes[:'is_payable'] unless attributes[:'is_payable'].nil? self.payment_terms = attributes[:'paymentTerms'] if attributes[:'paymentTerms'] raise 'You cannot provide both :paymentTerms and :payment_terms' if attributes.key?(:'paymentTerms') && attributes.key?(:'payment_terms') self.payment_terms = attributes[:'payment_terms'] if attributes[:'payment_terms'] self.last_payment_detail = attributes[:'lastPaymentDetail'] if attributes[:'lastPaymentDetail'] raise 'You cannot provide both :lastPaymentDetail and :last_payment_detail' if attributes.key?(:'lastPaymentDetail') && attributes.key?(:'last_payment_detail') self.last_payment_detail = attributes[:'last_payment_detail'] if attributes[:'last_payment_detail'] self.bill_to_address = attributes[:'billToAddress'] if attributes[:'billToAddress'] raise 'You cannot provide both :billToAddress and :bill_to_address' if attributes.key?(:'billToAddress') && attributes.key?(:'bill_to_address') self.bill_to_address = attributes[:'bill_to_address'] if attributes[:'bill_to_address'] self.subscription_ids = attributes[:'subscriptionIds'] if attributes[:'subscriptionIds'] raise 'You cannot provide both :subscriptionIds and :subscription_ids' if attributes.key?(:'subscriptionIds') && attributes.key?(:'subscription_ids') self.subscription_ids = attributes[:'subscription_ids'] if attributes[:'subscription_ids'] end |
Instance Attribute Details
#bill_to_address ⇒ OCI::OspGateway::Models::BillToAddress
122 123 124 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 122 def bill_to_address @bill_to_address end |
#currency ⇒ OCI::OspGateway::Models::Currency
76 77 78 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 76 def currency @currency end |
#internal_invoice_id ⇒ String
Transaction identifier
41 42 43 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 41 def internal_invoice_id @internal_invoice_id end |
#invoice_amount ⇒ Float
Total amount of invoice
57 58 59 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 57 def invoice_amount @invoice_amount end |
#invoice_amount_adjusted ⇒ Float
Invoice amount adjust
69 70 71 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 69 def invoice_amount_adjusted @invoice_amount_adjusted end |
#invoice_amount_applied ⇒ Float
Invoice amount applied
73 74 75 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 73 def invoice_amount_applied @invoice_amount_applied end |
#invoice_amount_credited ⇒ Float
Invoice amount credit
65 66 67 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 65 def invoice_amount_credited @invoice_amount_credited end |
#invoice_amount_due ⇒ Float
Balance of invoice
61 62 63 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 61 def invoice_amount_due @invoice_amount_due end |
#invoice_id ⇒ String
**[Required]** Invoice identifier which is generated on the on-premise sie. Pls note this is not an OCID
33 34 35 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 33 def invoice_id @invoice_id end |
#invoice_number ⇒ String
Invoice external reference
37 38 39 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 37 def invoice_number @invoice_number end |
#invoice_po_number ⇒ String
Invoice PO number
92 93 94 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 92 def invoice_po_number @invoice_po_number end |
#invoice_ref_number ⇒ String
Invoice reference number
88 89 90 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 88 def invoice_ref_number @invoice_ref_number end |
#invoice_status ⇒ String
Invoice status
96 97 98 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 96 def invoice_status @invoice_status end |
#invoice_type ⇒ String
Type of invoice
80 81 82 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 80 def invoice_type @invoice_type end |
#is_credit_card_payable ⇒ BOOLEAN
Is credit card payment eligible
45 46 47 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 45 def is_credit_card_payable @is_credit_card_payable end |
#is_display_download_pdf ⇒ BOOLEAN
Is pdf download access allowed
108 109 110 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 108 def is_display_download_pdf @is_display_download_pdf end |
#is_payable ⇒ BOOLEAN
Whether invoice can be payed
112 113 114 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 112 def is_payable @is_payable end |
#is_pdf_email_available ⇒ BOOLEAN
Is emailing pdf allowed
104 105 106 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 104 def is_pdf_email_available @is_pdf_email_available end |
#last_payment_detail ⇒ OCI::OspGateway::Models::PaymentDetail
119 120 121 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 119 def last_payment_detail @last_payment_detail end |
#payment_terms ⇒ String
Payment terms
116 117 118 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 116 def payment_terms @payment_terms end |
#preferred_email ⇒ String
Preferred Email on the invoice
100 101 102 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 100 def preferred_email @preferred_email end |
#subscription_ids ⇒ Array<String>
List of subscription identifiers
126 127 128 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 126 def subscription_ids @subscription_ids end |
#tax ⇒ Float
Tax of invoice amount
53 54 55 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 53 def tax @tax end |
#time_invoice ⇒ DateTime
Date of invoice
49 50 51 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 49 def time_invoice @time_invoice end |
#time_invoice_due ⇒ DateTime
Due date of invoice
84 85 86 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 84 def time_invoice_due @time_invoice_due end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 129 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'invoice_id': :'invoiceId', 'invoice_number': :'invoiceNumber', 'internal_invoice_id': :'internalInvoiceId', 'is_credit_card_payable': :'isCreditCardPayable', 'time_invoice': :'timeInvoice', 'tax': :'tax', 'invoice_amount': :'invoiceAmount', 'invoice_amount_due': :'invoiceAmountDue', 'invoice_amount_credited': :'invoiceAmountCredited', 'invoice_amount_adjusted': :'invoiceAmountAdjusted', 'invoice_amount_applied': :'invoiceAmountApplied', 'currency': :'currency', 'invoice_type': :'invoiceType', 'time_invoice_due': :'timeInvoiceDue', 'invoice_ref_number': :'invoiceRefNumber', 'invoice_po_number': :'invoicePoNumber', 'invoice_status': :'invoiceStatus', 'preferred_email': :'preferredEmail', 'is_pdf_email_available': :'isPdfEmailAvailable', 'is_display_download_pdf': :'isDisplayDownloadPdf', 'is_payable': :'isPayable', 'payment_terms': :'paymentTerms', 'last_payment_detail': :'lastPaymentDetail', 'bill_to_address': :'billToAddress', 'subscription_ids': :'subscriptionIds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 162 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'invoice_id': :'String', 'invoice_number': :'String', 'internal_invoice_id': :'String', 'is_credit_card_payable': :'BOOLEAN', 'time_invoice': :'DateTime', 'tax': :'Float', 'invoice_amount': :'Float', 'invoice_amount_due': :'Float', 'invoice_amount_credited': :'Float', 'invoice_amount_adjusted': :'Float', 'invoice_amount_applied': :'Float', 'currency': :'OCI::OspGateway::Models::Currency', 'invoice_type': :'String', 'time_invoice_due': :'DateTime', 'invoice_ref_number': :'String', 'invoice_po_number': :'String', 'invoice_status': :'String', 'preferred_email': :'String', 'is_pdf_email_available': :'BOOLEAN', 'is_display_download_pdf': :'BOOLEAN', 'is_payable': :'BOOLEAN', 'payment_terms': :'String', 'last_payment_detail': :'OCI::OspGateway::Models::PaymentDetail', 'bill_to_address': :'OCI::OspGateway::Models::BillToAddress', 'subscription_ids': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 407 def ==(other) return true if equal?(other) self.class == other.class && invoice_id == other.invoice_id && invoice_number == other.invoice_number && internal_invoice_id == other.internal_invoice_id && is_credit_card_payable == other.is_credit_card_payable && time_invoice == other.time_invoice && tax == other.tax && invoice_amount == other.invoice_amount && invoice_amount_due == other.invoice_amount_due && invoice_amount_credited == other.invoice_amount_credited && invoice_amount_adjusted == other.invoice_amount_adjusted && invoice_amount_applied == other.invoice_amount_applied && currency == other.currency && invoice_type == other.invoice_type && time_invoice_due == other.time_invoice_due && invoice_ref_number == other.invoice_ref_number && invoice_po_number == other.invoice_po_number && invoice_status == other.invoice_status && preferred_email == other.preferred_email && is_pdf_email_available == other.is_pdf_email_available && is_display_download_pdf == other.is_display_download_pdf && is_payable == other.is_payable && payment_terms == other.payment_terms && last_payment_detail == other.last_payment_detail && bill_to_address == other.bill_to_address && subscription_ids == other.subscription_ids end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 461 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
441 442 443 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 441 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
450 451 452 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 450 def hash [invoice_id, invoice_number, internal_invoice_id, is_credit_card_payable, time_invoice, tax, invoice_amount, invoice_amount_due, invoice_amount_credited, invoice_amount_adjusted, invoice_amount_applied, currency, invoice_type, time_invoice_due, invoice_ref_number, invoice_po_number, invoice_status, preferred_email, is_pdf_email_available, is_display_download_pdf, is_payable, payment_terms, last_payment_detail, bill_to_address, subscription_ids].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
494 495 496 497 498 499 500 501 502 503 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 494 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
488 489 490 |
# File 'lib/oci/osp_gateway/models/invoice.rb', line 488 def to_s to_hash.to_s end |