Class: OCI::OspGateway::Models::PaymentDetail
- Inherits:
-
Object
- Object
- OCI::OspGateway::Models::PaymentDetail
- Defined in:
- lib/oci/osp_gateway/models/payment_detail.rb
Overview
Payment related details This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreditCardPaymentDetail, OtherPaymentDetail, PaypalPaymentDetail
Constant Summary collapse
- PAYMENT_METHOD_ENUM =
[ PAYMENT_METHOD_CREDIT_CARD = 'CREDIT_CARD'.freeze, PAYMENT_METHOD_PAYPAL = 'PAYPAL'.freeze, PAYMENT_METHOD_OTHER = 'OTHER'.freeze, PAYMENT_METHOD_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#amount_paid ⇒ Float
Amount that paid.
-
#paid_by ⇒ String
example.
-
#payment_method ⇒ String
**[Required]** Payment method.
-
#time_paid_on ⇒ DateTime
Paid the invoice on this day.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentDetail
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentDetail
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_paid_on = attributes[:'timePaidOn'] if attributes[:'timePaidOn'] raise 'You cannot provide both :timePaidOn and :time_paid_on' if attributes.key?(:'timePaidOn') && attributes.key?(:'time_paid_on') self.time_paid_on = attributes[:'time_paid_on'] if attributes[:'time_paid_on'] self.paid_by = attributes[:'paidBy'] if attributes[:'paidBy'] raise 'You cannot provide both :paidBy and :paid_by' if attributes.key?(:'paidBy') && attributes.key?(:'paid_by') self.paid_by = attributes[:'paid_by'] if attributes[:'paid_by'] self.payment_method = attributes[:'paymentMethod'] if attributes[:'paymentMethod'] raise 'You cannot provide both :paymentMethod and :payment_method' if attributes.key?(:'paymentMethod') && attributes.key?(:'payment_method') self.payment_method = attributes[:'payment_method'] if attributes[:'payment_method'] self.amount_paid = attributes[:'amountPaid'] if attributes[:'amountPaid'] raise 'You cannot provide both :amountPaid and :amount_paid' if attributes.key?(:'amountPaid') && attributes.key?(:'amount_paid') self.amount_paid = attributes[:'amount_paid'] if attributes[:'amount_paid'] end |
Instance Attribute Details
#amount_paid ⇒ Float
Amount that paid
33 34 35 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 33 def amount_paid @amount_paid end |
#paid_by ⇒ String
example
25 26 27 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 25 def paid_by @paid_by end |
#payment_method ⇒ String
**[Required]** Payment method
29 30 31 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 29 def payment_method @payment_method end |
#time_paid_on ⇒ DateTime
Paid the invoice on this day
21 22 23 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 21 def time_paid_on @time_paid_on end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_paid_on': :'timePaidOn', 'paid_by': :'paidBy', 'payment_method': :'paymentMethod', 'amount_paid': :'amountPaid' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 64 def self.get_subtype(object_hash) type = object_hash[:'paymentMethod'] # rubocop:disable Style/SymbolLiteral return 'OCI::OspGateway::Models::OtherPaymentDetail' if type == 'OTHER' return 'OCI::OspGateway::Models::PaypalPaymentDetail' if type == 'PAYPAL' return 'OCI::OspGateway::Models::CreditCardPaymentDetail' if type == 'CREDIT_CARD' # TODO: Log a warning when the subtype is not found. 'OCI::OspGateway::Models::PaymentDetail' end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_paid_on': :'DateTime', 'paid_by': :'String', 'payment_method': :'String', 'amount_paid': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 137 def ==(other) return true if equal?(other) self.class == other.class && time_paid_on == other.time_paid_on && paid_by == other.paid_by && payment_method == other.payment_method && amount_paid == other.amount_paid end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 170 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
150 151 152 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 150 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 159 def hash [time_paid_on, paid_by, payment_method, amount_paid].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
197 198 199 |
# File 'lib/oci/osp_gateway/models/payment_detail.rb', line 197 def to_s to_hash.to_s end |