Class: OsubSubscription::Models::Product
- Inherits:
-
Object
- Object
- OsubSubscription::Models::Product
- Defined in:
- lib/oci/osub_subscription/models/product.rb
Overview
Product description
Instance Attribute Summary collapse
-
#billing_category ⇒ String
Metered service billing category.
-
#name ⇒ String
**[Required]** Product name.
-
#part_number ⇒ String
**[Required]** Product part numner.
-
#product_category ⇒ String
Product category.
-
#ucm_rate_card_part_type ⇒ String
Rate card part type of Product.
-
#unit_of_measure ⇒ String
**[Required]** Unit of measure.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Product
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Product
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/osub_subscription/models/product.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.part_number = attributes[:'partNumber'] if attributes[:'partNumber'] raise 'You cannot provide both :partNumber and :part_number' if attributes.key?(:'partNumber') && attributes.key?(:'part_number') self.part_number = attributes[:'part_number'] if attributes[:'part_number'] self.name = attributes[:'name'] if attributes[:'name'] self.unit_of_measure = attributes[:'unitOfMeasure'] if attributes[:'unitOfMeasure'] raise 'You cannot provide both :unitOfMeasure and :unit_of_measure' if attributes.key?(:'unitOfMeasure') && attributes.key?(:'unit_of_measure') self.unit_of_measure = attributes[:'unit_of_measure'] if attributes[:'unit_of_measure'] self.billing_category = attributes[:'billingCategory'] if attributes[:'billingCategory'] raise 'You cannot provide both :billingCategory and :billing_category' if attributes.key?(:'billingCategory') && attributes.key?(:'billing_category') self.billing_category = attributes[:'billing_category'] if attributes[:'billing_category'] self.product_category = attributes[:'productCategory'] if attributes[:'productCategory'] raise 'You cannot provide both :productCategory and :product_category' if attributes.key?(:'productCategory') && attributes.key?(:'product_category') self.product_category = attributes[:'product_category'] if attributes[:'product_category'] self.ucm_rate_card_part_type = attributes[:'ucmRateCardPartType'] if attributes[:'ucmRateCardPartType'] raise 'You cannot provide both :ucmRateCardPartType and :ucm_rate_card_part_type' if attributes.key?(:'ucmRateCardPartType') && attributes.key?(:'ucm_rate_card_part_type') self.ucm_rate_card_part_type = attributes[:'ucm_rate_card_part_type'] if attributes[:'ucm_rate_card_part_type'] end |
Instance Attribute Details
#billing_category ⇒ String
Metered service billing category
29 30 31 |
# File 'lib/oci/osub_subscription/models/product.rb', line 29 def billing_category @billing_category end |
#name ⇒ String
**[Required]** Product name
19 20 21 |
# File 'lib/oci/osub_subscription/models/product.rb', line 19 def name @name end |
#part_number ⇒ String
**[Required]** Product part numner
14 15 16 |
# File 'lib/oci/osub_subscription/models/product.rb', line 14 def part_number @part_number end |
#product_category ⇒ String
Product category
34 35 36 |
# File 'lib/oci/osub_subscription/models/product.rb', line 34 def product_category @product_category end |
#ucm_rate_card_part_type ⇒ String
Rate card part type of Product
39 40 41 |
# File 'lib/oci/osub_subscription/models/product.rb', line 39 def ucm_rate_card_part_type @ucm_rate_card_part_type end |
#unit_of_measure ⇒ String
**[Required]** Unit of measure
24 25 26 |
# File 'lib/oci/osub_subscription/models/product.rb', line 24 def unit_of_measure @unit_of_measure end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/osub_subscription/models/product.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'part_number': :'partNumber', 'name': :'name', 'unit_of_measure': :'unitOfMeasure', 'billing_category': :'billingCategory', 'product_category': :'productCategory', 'ucm_rate_card_part_type': :'ucmRateCardPartType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/osub_subscription/models/product.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'part_number': :'String', 'name': :'String', 'unit_of_measure': :'String', 'billing_category': :'String', 'product_category': :'String', 'ucm_rate_card_part_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/osub_subscription/models/product.rb', line 127 def ==(other) return true if equal?(other) self.class == other.class && part_number == other.part_number && name == other.name && unit_of_measure == other.unit_of_measure && billing_category == other.billing_category && product_category == other.product_category && ucm_rate_card_part_type == other.ucm_rate_card_part_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/osub_subscription/models/product.rb', line 162 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
142 143 144 |
# File 'lib/oci/osub_subscription/models/product.rb', line 142 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/oci/osub_subscription/models/product.rb', line 151 def hash [part_number, name, unit_of_measure, billing_category, product_category, ucm_rate_card_part_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/osub_subscription/models/product.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
189 190 191 |
# File 'lib/oci/osub_subscription/models/product.rb', line 189 def to_s to_hash.to_s end |