Class: OCI::OsubSubscription::Models::SubscriptionSummary
- Inherits:
-
Object
- Object
- OCI::OsubSubscription::Models::SubscriptionSummary
- Defined in:
- lib/oci/osub_subscription/models/subscription_summary.rb
Overview
Subscription summary
Instance Attribute Summary collapse
- #currency ⇒ OCI::OsubSubscription::Models::Currency
-
#service_name ⇒ String
Customer friendly service name provided by PRG.
-
#status ⇒ String
Status of the plan.
-
#subscribed_services ⇒ Array<OCI::OsubSubscription::Models::SubscribedServiceSummary>
List of Subscribed Services of the plan.
-
#time_end ⇒ DateTime
Represents the date when the last service of the subscription ends.
-
#time_start ⇒ DateTime
Represents the date when the first service of the subscription was activated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubscriptionSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SubscriptionSummary
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.status = attributes[:'status'] if attributes[:'status'] self.time_start = attributes[:'timeStart'] if attributes[:'timeStart'] raise 'You cannot provide both :timeStart and :time_start' if attributes.key?(:'timeStart') && attributes.key?(:'time_start') self.time_start = attributes[:'time_start'] if attributes[:'time_start'] self.time_end = attributes[:'timeEnd'] if attributes[:'timeEnd'] raise 'You cannot provide both :timeEnd and :time_end' if attributes.key?(:'timeEnd') && attributes.key?(:'time_end') self.time_end = attributes[:'time_end'] if attributes[:'time_end'] self.currency = attributes[:'currency'] if attributes[:'currency'] self.service_name = attributes[:'serviceName'] if attributes[:'serviceName'] raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] if attributes[:'service_name'] self.subscribed_services = attributes[:'subscribedServices'] if attributes[:'subscribedServices'] raise 'You cannot provide both :subscribedServices and :subscribed_services' if attributes.key?(:'subscribedServices') && attributes.key?(:'subscribed_services') self.subscribed_services = attributes[:'subscribed_services'] if attributes[:'subscribed_services'] end |
Instance Attribute Details
#currency ⇒ OCI::OsubSubscription::Models::Currency
28 29 30 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 28 def currency @currency end |
#service_name ⇒ String
Customer friendly service name provided by PRG
33 34 35 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 33 def service_name @service_name end |
#status ⇒ String
Status of the plan
15 16 17 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 15 def status @status end |
#subscribed_services ⇒ Array<OCI::OsubSubscription::Models::SubscribedServiceSummary>
List of Subscribed Services of the plan
38 39 40 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 38 def subscribed_services @subscribed_services end |
#time_end ⇒ DateTime
Represents the date when the last service of the subscription ends
25 26 27 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 25 def time_end @time_end end |
#time_start ⇒ DateTime
Represents the date when the first service of the subscription was activated
20 21 22 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 20 def time_start @time_start end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'status': :'status', 'time_start': :'timeStart', 'time_end': :'timeEnd', 'currency': :'currency', 'service_name': :'serviceName', 'subscribed_services': :'subscribedServices' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'status': :'String', 'time_start': :'DateTime', 'time_end': :'DateTime', 'currency': :'OCI::OsubSubscription::Models::Currency', 'service_name': :'String', 'subscribed_services': :'Array<OCI::OsubSubscription::Models::SubscribedServiceSummary>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && status == other.status && time_start == other.time_start && time_end == other.time_end && currency == other.currency && service_name == other.service_name && subscribed_services == other.subscribed_services end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 146 def hash [status, time_start, time_end, currency, service_name, subscribed_services].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/osub_subscription/models/subscription_summary.rb', line 184 def to_s to_hash.to_s end |