Class: OCI::OsubUsage::Models::ComputedUsageAggregation
- Inherits:
-
Object
- Object
- OCI::OsubUsage::Models::ComputedUsageAggregation
- Defined in:
- lib/oci/osub_usage/models/computed_usage_aggregation.rb
Overview
Computed Usage Aggregation object
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_PROMOTION = 'PROMOTION'.freeze, TYPE_DO_NOT_BILL = 'DO_NOT_BILL'.freeze, TYPE_USAGE = 'USAGE'.freeze, TYPE_COMMIT = 'COMMIT'.freeze, TYPE_OVERAGE = 'OVERAGE'.freeze, TYPE_PAY_AS_YOU_GO = 'PAY_AS_YOU_GO'.freeze, TYPE_MONTHLY_MINIMUM = 'MONTHLY_MINIMUM'.freeze, TYPE_DELAYED_USAGE_INVOICE_TIMING = 'DELAYED_USAGE_INVOICE_TIMING'.freeze, TYPE_DELAYED_USAGE_COMMITMENT_EXP = 'DELAYED_USAGE_COMMITMENT_EXP'.freeze, TYPE_ON_ACCOUNT_CREDIT = 'ON_ACCOUNT_CREDIT'.freeze, TYPE_SERVICE_CREDIT = 'SERVICE_CREDIT'.freeze, TYPE_COMMITMENT_EXPIRATION = 'COMMITMENT_EXPIRATION'.freeze, TYPE_FUNDED_ALLOCATION = 'FUNDED_ALLOCATION'.freeze, TYPE_DONOT_BILL_USAGE_POST_TERMINATION = 'DONOT_BILL_USAGE_POST_TERMINATION'.freeze, TYPE_DELAYED_USAGE_POST_TERMINATION = 'DELAYED_USAGE_POST_TERMINATION'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cost ⇒ String
Sum of Computed Line Amount rounded.
-
#cost_unrounded ⇒ String
Sum of Computed Line Amount unrounded.
-
#data_center ⇒ String
Data Center Attribute as sent by MQS to SPM.
-
#net_unit_price ⇒ String
Net Unit Price for the product in consideration.
- #product ⇒ OCI::OsubUsage::Models::Product
-
#quantity ⇒ String
Total Quantity that was used for computation.
-
#time_metered_on ⇒ DateTime
Metered Service date , expressed in RFC 3339 timestamp format.
-
#type ⇒ String
Usage compute type in SPM.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ComputedUsageAggregation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ComputedUsageAggregation
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.quantity = attributes[:'quantity'] if attributes[:'quantity'] self.product = attributes[:'product'] if attributes[:'product'] self.data_center = attributes[:'dataCenter'] if attributes[:'dataCenter'] raise 'You cannot provide both :dataCenter and :data_center' if attributes.key?(:'dataCenter') && attributes.key?(:'data_center') self.data_center = attributes[:'data_center'] if attributes[:'data_center'] self.time_metered_on = attributes[:'timeMeteredOn'] if attributes[:'timeMeteredOn'] raise 'You cannot provide both :timeMeteredOn and :time_metered_on' if attributes.key?(:'timeMeteredOn') && attributes.key?(:'time_metered_on') self.time_metered_on = attributes[:'time_metered_on'] if attributes[:'time_metered_on'] self.net_unit_price = attributes[:'netUnitPrice'] if attributes[:'netUnitPrice'] raise 'You cannot provide both :netUnitPrice and :net_unit_price' if attributes.key?(:'netUnitPrice') && attributes.key?(:'net_unit_price') self.net_unit_price = attributes[:'net_unit_price'] if attributes[:'net_unit_price'] self.cost_unrounded = attributes[:'costUnrounded'] if attributes[:'costUnrounded'] raise 'You cannot provide both :costUnrounded and :cost_unrounded' if attributes.key?(:'costUnrounded') && attributes.key?(:'cost_unrounded') self.cost_unrounded = attributes[:'cost_unrounded'] if attributes[:'cost_unrounded'] self.cost = attributes[:'cost'] if attributes[:'cost'] self.type = attributes[:'type'] if attributes[:'type'] end |
Instance Attribute Details
#cost ⇒ String
Sum of Computed Line Amount rounded
62 63 64 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 62 def cost @cost end |
#cost_unrounded ⇒ String
Sum of Computed Line Amount unrounded
57 58 59 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 57 def cost_unrounded @cost_unrounded end |
#data_center ⇒ String
Data Center Attribute as sent by MQS to SPM.
42 43 44 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 42 def data_center @data_center end |
#net_unit_price ⇒ String
Net Unit Price for the product in consideration.
52 53 54 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 52 def net_unit_price @net_unit_price end |
#product ⇒ OCI::OsubUsage::Models::Product
37 38 39 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 37 def product @product end |
#quantity ⇒ String
Total Quantity that was used for computation
34 35 36 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 34 def quantity @quantity end |
#time_metered_on ⇒ DateTime
Metered Service date , expressed in RFC 3339 timestamp format.
47 48 49 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 47 def time_metered_on @time_metered_on end |
#type ⇒ String
Usage compute type in SPM.
67 68 69 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 67 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 70 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'quantity': :'quantity', 'product': :'product', 'data_center': :'dataCenter', 'time_metered_on': :'timeMeteredOn', 'net_unit_price': :'netUnitPrice', 'cost_unrounded': :'costUnrounded', 'cost': :'cost', 'type': :'type' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 86 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'quantity': :'String', 'product': :'OCI::OsubUsage::Models::Product', 'data_center': :'String', 'time_metered_on': :'DateTime', 'net_unit_price': :'String', 'cost_unrounded': :'String', 'cost': :'String', 'type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 174 def ==(other) return true if equal?(other) self.class == other.class && quantity == other.quantity && product == other.product && data_center == other.data_center && time_metered_on == other.time_metered_on && net_unit_price == other.net_unit_price && cost_unrounded == other.cost_unrounded && cost == other.cost && type == other.type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 211 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
191 192 193 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 191 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 200 def hash [quantity, product, data_center, time_metered_on, net_unit_price, cost_unrounded, cost, type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
244 245 246 247 248 249 250 251 252 253 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 244 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
238 239 240 |
# File 'lib/oci/osub_usage/models/computed_usage_aggregation.rb', line 238 def to_s to_hash.to_s end |