Class: OCI::ResourceManager::Models::ApplyJobOperationDetails
- Inherits:
-
JobOperationDetails
- Object
- JobOperationDetails
- OCI::ResourceManager::Models::ApplyJobOperationDetails
- Defined in:
- lib/oci/resource_manager/models/apply_job_operation_details.rb
Overview
Job details that are specific to apply operations.
Constant Summary collapse
- EXECUTION_PLAN_STRATEGY_ENUM =
[ EXECUTION_PLAN_STRATEGY_FROM_PLAN_JOB_ID = 'FROM_PLAN_JOB_ID'.freeze, EXECUTION_PLAN_STRATEGY_FROM_LATEST_PLAN_JOB = 'FROM_LATEST_PLAN_JOB'.freeze, EXECUTION_PLAN_STRATEGY_AUTO_APPROVED = 'AUTO_APPROVED'.freeze, EXECUTION_PLAN_STRATEGY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#execution_plan_job_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the plan job that contains the execution plan used for this job, or
nullif no execution plan was used. -
#execution_plan_strategy ⇒ String
[Required] Specifies the source of the execution plan to apply.
- #terraform_advanced_options ⇒ OCI::ResourceManager::Models::TerraformAdvancedOptions
Attributes inherited from JobOperationDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplyJobOperationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from JobOperationDetails
Constructor Details
#initialize(attributes = {}) ⇒ ApplyJobOperationDetails
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['operation'] = 'APPLY' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'terraformAdvancedOptions'] if attributes[:'terraformAdvancedOptions'] raise 'You cannot provide both :terraformAdvancedOptions and :terraform_advanced_options' if attributes.key?(:'terraformAdvancedOptions') && attributes.key?(:'terraform_advanced_options') self. = attributes[:'terraform_advanced_options'] if attributes[:'terraform_advanced_options'] self.execution_plan_strategy = attributes[:'executionPlanStrategy'] if attributes[:'executionPlanStrategy'] raise 'You cannot provide both :executionPlanStrategy and :execution_plan_strategy' if attributes.key?(:'executionPlanStrategy') && attributes.key?(:'execution_plan_strategy') self.execution_plan_strategy = attributes[:'execution_plan_strategy'] if attributes[:'execution_plan_strategy'] self.execution_plan_job_id = attributes[:'executionPlanJobId'] if attributes[:'executionPlanJobId'] raise 'You cannot provide both :executionPlanJobId and :execution_plan_job_id' if attributes.key?(:'executionPlanJobId') && attributes.key?(:'execution_plan_job_id') self.execution_plan_job_id = attributes[:'execution_plan_job_id'] if attributes[:'execution_plan_job_id'] end |
Instance Attribute Details
#execution_plan_job_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the plan job that contains the execution plan used for this job, or null if no execution plan was used.
33 34 35 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 33 def execution_plan_job_id @execution_plan_job_id end |
#execution_plan_strategy ⇒ String
[Required] Specifies the source of the execution plan to apply. Use AUTO_APPROVED to run the job without an execution plan.
27 28 29 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 27 def execution_plan_strategy @execution_plan_strategy end |
#terraform_advanced_options ⇒ OCI::ResourceManager::Models::TerraformAdvancedOptions
21 22 23 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 21 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operation': :'operation', 'terraform_advanced_options': :'terraformAdvancedOptions', 'execution_plan_strategy': :'executionPlanStrategy', 'execution_plan_job_id': :'executionPlanJobId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operation': :'String', 'terraform_advanced_options': :'OCI::ResourceManager::Models::TerraformAdvancedOptions', 'execution_plan_strategy': :'String', 'execution_plan_job_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 117 def ==(other) return true if equal?(other) self.class == other.class && operation == other.operation && == other. && execution_plan_strategy == other.execution_plan_strategy && execution_plan_job_id == other.execution_plan_job_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 150 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
130 131 132 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 130 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
139 140 141 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 139 def hash [operation, , execution_plan_strategy, execution_plan_job_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 183 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
177 178 179 |
# File 'lib/oci/resource_manager/models/apply_job_operation_details.rb', line 177 def to_s to_hash.to_s end |