Class: OCI::ResourceManager::Models::ConfigSourceRecord
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::ConfigSourceRecord
- Defined in:
- lib/oci/resource_manager/models/config_source_record.rb
Overview
Information about the Terraform configuration.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
GitConfigSourceRecord, ObjectStorageConfigSourceRecord, ZipUploadConfigSourceRecord
Constant Summary collapse
- CONFIG_SOURCE_RECORD_TYPE_ENUM =
[ CONFIG_SOURCE_RECORD_TYPE_ZIP_UPLOAD = 'ZIP_UPLOAD'.freeze, CONFIG_SOURCE_RECORD_TYPE_GIT_CONFIG_SOURCE = 'GIT_CONFIG_SOURCE'.freeze, CONFIG_SOURCE_RECORD_TYPE_OBJECT_STORAGE_CONFIG_SOURCE = 'OBJECT_STORAGE_CONFIG_SOURCE'.freeze, CONFIG_SOURCE_RECORD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#config_source_record_type ⇒ String
[Required] The type of configuration source to use for the Terraform configuration.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConfigSourceRecord
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConfigSourceRecord
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.config_source_record_type = attributes[:'configSourceRecordType'] if attributes[:'configSourceRecordType'] raise 'You cannot provide both :configSourceRecordType and :config_source_record_type' if attributes.key?(:'configSourceRecordType') && attributes.key?(:'config_source_record_type') self.config_source_record_type = attributes[:'config_source_record_type'] if attributes[:'config_source_record_type'] end |
Instance Attribute Details
#config_source_record_type ⇒ String
[Required] The type of configuration source to use for the Terraform configuration.
23 24 25 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 23 def config_source_record_type @config_source_record_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'config_source_record_type': :'configSourceRecordType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 48 def self.get_subtype(object_hash) type = object_hash[:'configSourceRecordType'] # rubocop:disable Style/SymbolLiteral return 'OCI::ResourceManager::Models::GitConfigSourceRecord' if type == 'GIT_CONFIG_SOURCE' return 'OCI::ResourceManager::Models::ZipUploadConfigSourceRecord' if type == 'ZIP_UPLOAD' return 'OCI::ResourceManager::Models::ObjectStorageConfigSourceRecord' if type == 'OBJECT_STORAGE_CONFIG_SOURCE' # TODO: Log a warning when the subtype is not found. 'OCI::ResourceManager::Models::ConfigSourceRecord' end |
.swagger_types ⇒ Object
Attribute type mapping.
35 36 37 38 39 40 41 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 35 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'config_source_record_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
100 101 102 103 104 105 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 100 def ==(other) return true if equal?(other) self.class == other.class && config_source_record_type == other.config_source_record_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 130 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
110 111 112 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 110 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
119 120 121 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 119 def hash [config_source_record_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
157 158 159 |
# File 'lib/oci/resource_manager/models/config_source_record.rb', line 157 def to_s to_hash.to_s end |