Class: OCI::ResourceManager::Models::ConfigurationSourceProviderSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/resource_manager/models/configuration_source_provider_summary.rb

Overview

Summary information for a configuration source provider.

This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConfigurationSourceProviderSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 136

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.config_source_provider_type = attributes[:'configSourceProviderType'] if attributes[:'configSourceProviderType']

  raise 'You cannot provide both :configSourceProviderType and :config_source_provider_type' if attributes.key?(:'configSourceProviderType') && attributes.key?(:'config_source_provider_type')

  self.config_source_provider_type = attributes[:'config_source_provider_type'] if attributes[:'config_source_provider_type']

  self.private_server_config_details = attributes[:'privateServerConfigDetails'] if attributes[:'privateServerConfigDetails']

  raise 'You cannot provide both :privateServerConfigDetails and :private_server_config_details' if attributes.key?(:'privateServerConfigDetails') && attributes.key?(:'private_server_config_details')

  self.private_server_config_details = attributes[:'private_server_config_details'] if attributes[:'private_server_config_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where the configuration source provider is located.

Returns:

  • (String)


18
19
20
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 18

def compartment_id
  @compartment_id
end

#config_source_provider_typeString

**[Required]** The type of configuration source provider. The `GITLAB_ACCESS_TOKEN` type corresponds to GitLab. The `GITHUB_ACCESS_TOKEN` type corresponds to GitHub.

Returns:

  • (String)


49
50
51
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 49

def config_source_provider_type
  @config_source_provider_type
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


66
67
68
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 66

def defined_tags
  @defined_tags
end

#descriptionString

General description of the configuration source provider.

Returns:

  • (String)


26
27
28
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 26

def description
  @description
end

#display_nameString

Human-readable display name for the configuration source provider.

Returns:

  • (String)


22
23
24
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 22

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags associated with this resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


59
60
61
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 59

def freeform_tags
  @freeform_tags
end

#idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the configuration source provider.

Returns:

  • (String)


14
15
16
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 14

def id
  @id
end

#lifecycle_stateString

Current state of the specified configuration source provider. For more information about configuration source provider lifecycle states in Resource Manager, see [Key Concepts](docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/resourcemanager.htm#concepts__CSPStates).

Allowable values:

  • ACTIVE

Returns:

  • (String)


43
44
45
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 43

def lifecycle_state
  @lifecycle_state
end

#private_server_config_detailsOCI::ResourceManager::Models::PrivateServerConfigDetails



52
53
54
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 52

def private_server_config_details
  @private_server_config_details
end

#time_createdDateTime

The date and time when the configuration source provider was created. Format is defined by RFC3339. Example: `2020-01-25T21:10:29.600Z`

Returns:

  • (DateTime)


33
34
35
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 33

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 69

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'time_created': :'timeCreated',
    'lifecycle_state': :'lifecycleState',
    'config_source_provider_type': :'configSourceProviderType',
    'private_server_config_details': :'privateServerConfigDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



109
110
111
112
113
114
115
116
117
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 109

def self.get_subtype(object_hash)
  type = object_hash[:'configSourceProviderType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::ResourceManager::Models::GitlabAccessTokenConfigurationSourceProviderSummary' if type == 'GITLAB_ACCESS_TOKEN'
  return 'OCI::ResourceManager::Models::GithubAccessTokenConfigurationSourceProviderSummary' if type == 'GITHUB_ACCESS_TOKEN'

  # TODO: Log a warning when the subtype is not found.
  'OCI::ResourceManager::Models::ConfigurationSourceProviderSummary'
end

.swagger_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 87

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'time_created': :'DateTime',
    'lifecycle_state': :'String',
    'config_source_provider_type': :'String',
    'private_server_config_details': :'OCI::ResourceManager::Models::PrivateServerConfigDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 202

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    time_created == other.time_created &&
    lifecycle_state == other.lifecycle_state &&
    config_source_provider_type == other.config_source_provider_type &&
    private_server_config_details == other.private_server_config_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 221

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



230
231
232
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 230

def hash
  [id, compartment_id, display_name, description, time_created, lifecycle_state, config_source_provider_type, private_server_config_details, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



268
269
270
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 268

def to_s
  to_hash.to_s
end