Class: OCI::ResourceManager::Models::CreateConfigurationSourceProviderDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/resource_manager/models/create_configuration_source_provider_details.rb

Overview

The details for creating a configuration source provider.

This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateConfigurationSourceProviderDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 109

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.config_source_provider_type = attributes[:'configSourceProviderType'] if attributes[:'configSourceProviderType']

  raise 'You cannot provide both :configSourceProviderType and :config_source_provider_type' if attributes.key?(:'configSourceProviderType') && attributes.key?(:'config_source_provider_type')

  self.config_source_provider_type = attributes[:'config_source_provider_type'] if attributes[:'config_source_provider_type']

  self.private_server_config_details = attributes[:'privateServerConfigDetails'] if attributes[:'privateServerConfigDetails']

  raise 'You cannot provide both :privateServerConfigDetails and :private_server_config_details' if attributes.key?(:'privateServerConfigDetails') && attributes.key?(:'private_server_config_details')

  self.private_server_config_details = attributes[:'private_server_config_details'] if attributes[:'private_server_config_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the configuration source provider.

Returns:

  • (String)


16
17
18
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 16

def compartment_id
  @compartment_id
end

#config_source_provider_typeString

**[Required]** The type of configuration source provider. The `GITLAB_ACCESS_TOKEN` type corresponds to GitLab. The `GITHUB_ACCESS_TOKEN` type corresponds to GitHub.

Returns:

  • (String)


31
32
33
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 31

def config_source_provider_type
  @config_source_provider_type
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


48
49
50
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 48

def defined_tags
  @defined_tags
end

#descriptionString

Description of the configuration source provider. Avoid entering confidential information.

Returns:

  • (String)


24
25
26
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 24

def description
  @description
end

#display_nameString

Human-readable name of the configuration source provider. Avoid entering confidential information.

Returns:

  • (String)


20
21
22
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 20

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


41
42
43
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 41

def freeform_tags
  @freeform_tags
end

#private_server_config_detailsOCI::ResourceManager::Models::PrivateServerConfigDetails



34
35
36
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 34

def private_server_config_details
  @private_server_config_details
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 51

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'config_source_provider_type': :'configSourceProviderType',
    'private_server_config_details': :'privateServerConfigDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



85
86
87
88
89
90
91
92
93
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 85

def self.get_subtype(object_hash)
  type = object_hash[:'configSourceProviderType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::ResourceManager::Models::CreateGitlabAccessTokenConfigurationSourceProviderDetails' if type == 'GITLAB_ACCESS_TOKEN'
  return 'OCI::ResourceManager::Models::CreateGithubAccessTokenConfigurationSourceProviderDetails' if type == 'GITHUB_ACCESS_TOKEN'

  # TODO: Log a warning when the subtype is not found.
  'OCI::ResourceManager::Models::CreateConfigurationSourceProviderDetails'
end

.swagger_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 66

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'config_source_provider_type': :'String',
    'private_server_config_details': :'OCI::ResourceManager::Models::PrivateServerConfigDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 161

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    config_source_provider_type == other.config_source_provider_type &&
    private_server_config_details == other.private_server_config_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 197

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 177

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



186
187
188
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 186

def hash
  [compartment_id, display_name, description, config_source_provider_type, private_server_config_details, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



224
225
226
# File 'lib/oci/resource_manager/models/create_configuration_source_provider_details.rb', line 224

def to_s
  to_hash.to_s
end