Class: OCI::ResourceManager::Models::CreateGithubAccessTokenConfigurationSourceProviderDetails
- Inherits:
-
CreateConfigurationSourceProviderDetails
- Object
- CreateConfigurationSourceProviderDetails
- OCI::ResourceManager::Models::CreateGithubAccessTokenConfigurationSourceProviderDetails
- Defined in:
- lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb
Overview
The details for creating a configuration source provider of the type GITHUB_ACCESS_TOKEN. This type corresponds to a configuration source provider in GitHub that is authenticated with a personal access token.
Instance Attribute Summary collapse
-
#access_token ⇒ String
[Required] The personal access token to be configured on the GitHub repository.
-
#api_endpoint ⇒ String
[Required] The GitHub service endpoint.
Attributes inherited from CreateConfigurationSourceProviderDetails
#compartment_id, #config_source_provider_type, #defined_tags, #description, #display_name, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateGithubAccessTokenConfigurationSourceProviderDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateConfigurationSourceProviderDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateGithubAccessTokenConfigurationSourceProviderDetails
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['configSourceProviderType'] = 'GITHUB_ACCESS_TOKEN' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.api_endpoint = attributes[:'apiEndpoint'] if attributes[:'apiEndpoint'] raise 'You cannot provide both :apiEndpoint and :api_endpoint' if attributes.key?(:'apiEndpoint') && attributes.key?(:'api_endpoint') self.api_endpoint = attributes[:'api_endpoint'] if attributes[:'api_endpoint'] self.access_token = attributes[:'accessToken'] if attributes[:'accessToken'] raise 'You cannot provide both :accessToken and :access_token' if attributes.key?(:'accessToken') && attributes.key?(:'access_token') self.access_token = attributes[:'access_token'] if attributes[:'access_token'] end |
Instance Attribute Details
#access_token ⇒ String
[Required] The personal access token to be configured on the GitHub repository. Avoid entering confidential information.
21 22 23 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 21 def access_token @access_token end |
#api_endpoint ⇒ String
[Required] The GitHub service endpoint. Example: https://github.com/
17 18 19 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 17 def api_endpoint @api_endpoint end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 32 33 34 35 36 37 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 24 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'config_source_provider_type': :'configSourceProviderType', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'api_endpoint': :'apiEndpoint', 'access_token': :'accessToken' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 40 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'config_source_provider_type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'api_endpoint': :'String', 'access_token': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && config_source_provider_type == other.config_source_provider_type && == other. && == other. && api_endpoint == other.api_endpoint && access_token == other.access_token end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 135 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
115 116 117 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 115 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
124 125 126 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 124 def hash [compartment_id, display_name, description, config_source_provider_type, , , api_endpoint, access_token].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 168 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
162 163 164 |
# File 'lib/oci/resource_manager/models/create_github_access_token_configuration_source_provider_details.rb', line 162 def to_s to_hash.to_s end |