Class: OCI::ResourceManager::Models::CreatePrivateEndpointDetails
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::CreatePrivateEndpointDetails
- Defined in:
- lib/oci/resource_manager/models/create_private_endpoint_details.rb
Overview
Creation details for a private endpoint.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing this private endpoint details.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the private endpoint.
-
#display_name ⇒ String
**[Required]** The private endpoint display name.
-
#dns_zones ⇒ Array<String>
DNS Proxy forwards any DNS FQDN queries over into the consumer DNS resolver if the DNS FQDN is included in the dns zones list otherwise it goes to service provider VCN resolver.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with the resource.
-
#is_used_with_configuration_source_provider ⇒ BOOLEAN
When `true`, allows the private endpoint to be used with a configuration source provider.
-
#nsg_id_list ⇒ Array<String>
An array of network security group (NSG) [OCIDs](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the private endpoint.
-
#subnet_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet within the VCN for the private endpoint.
-
#vcn_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN for the private endpoint.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePrivateEndpointDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreatePrivateEndpointDetails
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 110 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.dns_zones = attributes[:'dnsZones'] if attributes[:'dnsZones'] raise 'You cannot provide both :dnsZones and :dns_zones' if attributes.key?(:'dnsZones') && attributes.key?(:'dns_zones') self.dns_zones = attributes[:'dns_zones'] if attributes[:'dns_zones'] self.nsg_id_list = attributes[:'nsgIdList'] if attributes[:'nsgIdList'] raise 'You cannot provide both :nsgIdList and :nsg_id_list' if attributes.key?(:'nsgIdList') && attributes.key?(:'nsg_id_list') self.nsg_id_list = attributes[:'nsg_id_list'] if attributes[:'nsg_id_list'] self.is_used_with_configuration_source_provider = attributes[:'isUsedWithConfigurationSourceProvider'] unless attributes[:'isUsedWithConfigurationSourceProvider'].nil? raise 'You cannot provide both :isUsedWithConfigurationSourceProvider and :is_used_with_configuration_source_provider' if attributes.key?(:'isUsedWithConfigurationSourceProvider') && attributes.key?(:'is_used_with_configuration_source_provider') self.is_used_with_configuration_source_provider = attributes[:'is_used_with_configuration_source_provider'] unless attributes[:'is_used_with_configuration_source_provider'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing this private endpoint details.
13 14 15 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 13 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
56 57 58 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 56 def @defined_tags end |
#description ⇒ String
Description of the private endpoint. Avoid entering confidential information.
21 22 23 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 21 def description @description end |
#display_name ⇒ String
**[Required]** The private endpoint display name. Avoid entering confidential information.
17 18 19 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 17 def display_name @display_name end |
#dns_zones ⇒ Array<String>
DNS Proxy forwards any DNS FQDN queries over into the consumer DNS resolver if the DNS FQDN is included in the dns zones list otherwise it goes to service provider VCN resolver.
34 35 36 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 34 def dns_zones @dns_zones end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
49 50 51 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 49 def @freeform_tags end |
#is_used_with_configuration_source_provider ⇒ BOOLEAN
When `true`, allows the private endpoint to be used with a configuration source provider.
42 43 44 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 42 def is_used_with_configuration_source_provider @is_used_with_configuration_source_provider end |
#nsg_id_list ⇒ Array<String>
An array of network security group (NSG) [OCIDs](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the private endpoint. Order does not matter.
38 39 40 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 38 def nsg_id_list @nsg_id_list end |
#subnet_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet within the VCN for the private endpoint.
29 30 31 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 29 def subnet_id @subnet_id end |
#vcn_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN for the private endpoint.
25 26 27 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 25 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 59 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'vcn_id': :'vcnId', 'subnet_id': :'subnetId', 'dns_zones': :'dnsZones', 'nsg_id_list': :'nsgIdList', 'is_used_with_configuration_source_provider': :'isUsedWithConfigurationSourceProvider', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 77 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'vcn_id': :'String', 'subnet_id': :'String', 'dns_zones': :'Array<String>', 'nsg_id_list': :'Array<String>', 'is_used_with_configuration_source_provider': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 180 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && vcn_id == other.vcn_id && subnet_id == other.subnet_id && dns_zones == other.dns_zones && nsg_id_list == other.nsg_id_list && is_used_with_configuration_source_provider == other.is_used_with_configuration_source_provider && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 219 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
199 200 201 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 199 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 208 def hash [compartment_id, display_name, description, vcn_id, subnet_id, dns_zones, nsg_id_list, is_used_with_configuration_source_provider, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 252 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
246 247 248 |
# File 'lib/oci/resource_manager/models/create_private_endpoint_details.rb', line 246 def to_s to_hash.to_s end |