Class: OCI::ResourceManager::Models::CreateStackDetails
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::CreateStackDetails
- Defined in:
- lib/oci/resource_manager/models/create_stack_details.rb
Overview
The configuration details for creating a stack.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Unique identifier ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment in which the stack resides.
-
#config_source ⇒ OCI::ResourceManager::Models::CreateConfigSourceDetails
This attribute is required.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags associated with this resource.
-
#description ⇒ String
Description of the stack.
-
#display_name ⇒ String
The stack’s display name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with this resource.
-
#terraform_version ⇒ String
The version of Terraform to use with the stack.
-
#variables ⇒ Hash<String, String>
Terraform variables associated with this resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateStackDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateStackDetails
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 100 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.config_source = attributes[:'configSource'] if attributes[:'configSource'] raise 'You cannot provide both :configSource and :config_source' if attributes.key?(:'configSource') && attributes.key?(:'config_source') self.config_source = attributes[:'config_source'] if attributes[:'config_source'] self.variables = attributes[:'variables'] if attributes[:'variables'] self.terraform_version = attributes[:'terraformVersion'] if attributes[:'terraformVersion'] raise 'You cannot provide both :terraformVersion and :terraform_version' if attributes.key?(:'terraformVersion') && attributes.key?(:'terraform_version') self.terraform_version = attributes[:'terraform_version'] if attributes[:'terraform_version'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Unique identifier ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment in which the stack resides.
13 14 15 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 13 def compartment_id @compartment_id end |
#config_source ⇒ OCI::ResourceManager::Models::CreateConfigSourceDetails
This attribute is required.
25 26 27 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 25 def config_source @config_source end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags associated with this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
52 53 54 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 52 def end |
#description ⇒ String
Description of the stack.
21 22 23 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 21 def description @description end |
#display_name ⇒ String
The stack’s display name.
17 18 19 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 17 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
45 46 47 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 45 def end |
#terraform_version ⇒ String
The version of Terraform to use with the stack. Example: 0.12.x
38 39 40 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 38 def terraform_version @terraform_version end |
#variables ⇒ Hash<String, String>
Terraform variables associated with this resource. Maximum number of variables supported is 250. The maximum size of each variable, including both name and value, is 8192 bytes. Example: ‘"compartment-id-value"`
33 34 35 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 33 def variables @variables end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'config_source': :'configSource', 'variables': :'variables', 'terraform_version': :'terraformVersion', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 71 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'config_source': :'OCI::ResourceManager::Models::CreateConfigSourceDetails', 'variables': :'Hash<String, String>', 'terraform_version': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 154 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && config_source == other.config_source && variables == other.variables && terraform_version == other.terraform_version && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 191 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
171 172 173 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 171 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 180 def hash [compartment_id, display_name, description, config_source, variables, terraform_version, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/oci/resource_manager/models/create_stack_details.rb', line 218 def to_s to_hash.to_s end |