Class: OCI::ResourceManager::Models::DetectStackDriftDetails
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::DetectStackDriftDetails
- Defined in:
- lib/oci/resource_manager/models/detect_stack_drift_details.rb
Overview
The details for detecting drift in a stack
Instance Attribute Summary collapse
-
#resource_addresses ⇒ Array<String>
The list of resources in the specified stack to detect drift for.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DetectStackDriftDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DetectStackDriftDetails
Initializes the object
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/resource_manager/models/detect_stack_drift_details.rb', line 44 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.resource_addresses = attributes[:'resourceAddresses'] if attributes[:'resourceAddresses'] raise 'You cannot provide both :resourceAddresses and :resource_addresses' if attributes.key?(:'resourceAddresses') && attributes.key?(:'resource_addresses') self.resource_addresses = attributes[:'resource_addresses'] if attributes[:'resource_addresses'] end |
Instance Attribute Details
#resource_addresses ⇒ Array<String>
The list of resources in the specified stack to detect drift for. Each resource is identified by a resource address, which is a case-insensitive string derived from the resource type and name specified in the stack’s Terraform configuration plus an optional index. For example, the resource address for the fourth Compute instance with the name "test_instance" is oci_core_instance.test_instance. For more details and examples of resource addresses, see the Terraform documentation at [Resource spec](www.terraform.io/docs/internals/resource-addressing.html#examples).
17 18 19 |
# File 'lib/oci/resource_manager/models/detect_stack_drift_details.rb', line 17 def resource_addresses @resource_addresses end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 |
# File 'lib/oci/resource_manager/models/detect_stack_drift_details.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'resource_addresses': :'resourceAddresses' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
29 30 31 32 33 34 35 |
# File 'lib/oci/resource_manager/models/detect_stack_drift_details.rb', line 29 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'resource_addresses': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
64 65 66 67 68 69 |
# File 'lib/oci/resource_manager/models/detect_stack_drift_details.rb', line 64 def ==(other) return true if equal?(other) self.class == other.class && resource_addresses == other.resource_addresses end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/resource_manager/models/detect_stack_drift_details.rb', line 94 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
74 75 76 |
# File 'lib/oci/resource_manager/models/detect_stack_drift_details.rb', line 74 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
83 84 85 |
# File 'lib/oci/resource_manager/models/detect_stack_drift_details.rb', line 83 def hash [resource_addresses].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/resource_manager/models/detect_stack_drift_details.rb', line 127 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
121 122 123 |
# File 'lib/oci/resource_manager/models/detect_stack_drift_details.rb', line 121 def to_s to_hash.to_s end |