Class: OCI::ResourceManager::Models::FailureDetails
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::FailureDetails
- Defined in:
- lib/oci/resource_manager/models/failure_details.rb
Overview
FailureDetails model.
Constant Summary collapse
- CODE_ENUM =
[ CODE_INTERNAL_SERVICE_ERROR = 'INTERNAL_SERVICE_ERROR'.freeze, CODE_TERRAFORM_EXECUTION_ERROR = 'TERRAFORM_EXECUTION_ERROR'.freeze, CODE_TERRAFORM_CONFIG_UNZIP_FAILED = 'TERRAFORM_CONFIG_UNZIP_FAILED'.freeze, CODE_INVALID_WORKING_DIRECTORY = 'INVALID_WORKING_DIRECTORY'.freeze, CODE_JOB_TIMEOUT = 'JOB_TIMEOUT'.freeze, CODE_TERRAFORM_CONFIG_VIRUS_FOUND = 'TERRAFORM_CONFIG_VIRUS_FOUND'.freeze, CODE_TERRAFORM_GIT_CLONE_FAILURE = 'TERRAFORM_GIT_CLONE_FAILURE'.freeze, CODE_TERRAFORM_GIT_CHECKOUT_FAILURE = 'TERRAFORM_GIT_CHECKOUT_FAILURE'.freeze, CODE_TERRAFORM_OBJECT_STORAGE_CONFIG_SOURCE_EMPTY_BUCKET = 'TERRAFORM_OBJECT_STORAGE_CONFIG_SOURCE_EMPTY_BUCKET'.freeze, CODE_TERRAFORM_OBJECT_STORAGE_CONFIG_SOURCE_NO_TF_FILE_PRESENT = 'TERRAFORM_OBJECT_STORAGE_CONFIG_SOURCE_NO_TF_FILE_PRESENT'.freeze, CODE_TERRAFORM_OBJECT_STORAGE_CONFIG_SOURCE_UNSUPPORTED_OBJECT_SIZE = 'TERRAFORM_OBJECT_STORAGE_CONFIG_SOURCE_UNSUPPORTED_OBJECT_SIZE'.freeze, CODE_CUSTOM_TERRAFORM_PROVIDER_BUCKET_NOT_FOUND = 'CUSTOM_TERRAFORM_PROVIDER_BUCKET_NOT_FOUND'.freeze, CODE_CUSTOM_TERRAFORM_PROVIDER_UNSUPPORTED_OBJECT_SIZE = 'CUSTOM_TERRAFORM_PROVIDER_UNSUPPORTED_OBJECT_SIZE'.freeze, CODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#code ⇒ String
**[Required]** Job failure reason.
-
#message ⇒ String
**[Required]** A human-readable error string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FailureDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ FailureDetails
Initializes the object
64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 64 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.code = attributes[:'code'] if attributes[:'code'] self. = attributes[:'message'] if attributes[:'message'] end |
Instance Attribute Details
#code ⇒ String
**[Required]** Job failure reason.
30 31 32 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 30 def code @code end |
#message ⇒ String
**[Required]** A human-readable error string.
34 35 36 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 34 def @message end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'code': :'code', 'message': :'message' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'code': :'String', 'message': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
95 96 97 98 99 100 101 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 95 def ==(other) return true if equal?(other) self.class == other.class && code == other.code && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 126 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
106 107 108 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 106 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
115 116 117 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 115 def hash [code, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 159 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
153 154 155 |
# File 'lib/oci/resource_manager/models/failure_details.rb', line 153 def to_s to_hash.to_s end |