Class: OCI::ResourceManager::Models::PrivateEndpoint

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/resource_manager/models/private_endpoint.rb

Overview

A private endpoint. For more information about private endpoints, see [About Private Endpoints](docs.cloud.oracle.com/iaas/Content/Network/Concepts/privateaccess.htm#private-endpoints).

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PrivateEndpoint

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :vcn_id (String)

    The value to assign to the #vcn_id property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :source_ips (Array<String>)

    The value to assign to the #source_ips property

  • :nsg_id_list (Array<String>)

    The value to assign to the #nsg_id_list property

  • :is_used_with_configuration_source_provider (BOOLEAN)

    The value to assign to the #is_used_with_configuration_source_provider property

  • :dns_zones (Array<String>)

    The value to assign to the #dns_zones property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 152

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId']

  raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id')

  self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.source_ips = attributes[:'sourceIps'] if attributes[:'sourceIps']

  raise 'You cannot provide both :sourceIps and :source_ips' if attributes.key?(:'sourceIps') && attributes.key?(:'source_ips')

  self.source_ips = attributes[:'source_ips'] if attributes[:'source_ips']

  self.nsg_id_list = attributes[:'nsgIdList'] if attributes[:'nsgIdList']

  raise 'You cannot provide both :nsgIdList and :nsg_id_list' if attributes.key?(:'nsgIdList') && attributes.key?(:'nsg_id_list')

  self.nsg_id_list = attributes[:'nsg_id_list'] if attributes[:'nsg_id_list']

  self.is_used_with_configuration_source_provider = attributes[:'isUsedWithConfigurationSourceProvider'] unless attributes[:'isUsedWithConfigurationSourceProvider'].nil?

  raise 'You cannot provide both :isUsedWithConfigurationSourceProvider and :is_used_with_configuration_source_provider' if attributes.key?(:'isUsedWithConfigurationSourceProvider') && attributes.key?(:'is_used_with_configuration_source_provider')

  self.is_used_with_configuration_source_provider = attributes[:'is_used_with_configuration_source_provider'] unless attributes[:'is_used_with_configuration_source_provider'].nil?

  self.dns_zones = attributes[:'dnsZones'] if attributes[:'dnsZones']

  raise 'You cannot provide both :dnsZones and :dns_zones' if attributes.key?(:'dnsZones') && attributes.key?(:'dns_zones')

  self.dns_zones = attributes[:'dns_zones'] if attributes[:'dns_zones']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing this private endpoint details.

Returns:

  • (String)


27
28
29
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 27

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


86
87
88
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 86

def defined_tags
  @defined_tags
end

#descriptionString

Description of the private endpoint. Avoid entering confidential information.

Returns:

  • (String)


35
36
37
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 35

def description
  @description
end

#display_nameString

A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


31
32
33
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 31

def display_name
  @display_name
end

#dns_zonesArray<String>

DNS Proxy forwards any DNS FQDN queries over into the consumer DNS resolver if the DNS FQDN is included in the dns zones list otherwise it goes to service provider VCN resolver.

Returns:

  • (Array<String>)


60
61
62
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 60

def dns_zones
  @dns_zones
end

#freeform_tagsHash<String, String>

Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


79
80
81
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 79

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** Unique identifier ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the private endpoint details.

Returns:

  • (String)


23
24
25
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 23

def id
  @id
end

#is_used_with_configuration_source_providerBOOLEAN

When `true`, allows the private endpoint to be used with a configuration source provider.

Returns:

  • (BOOLEAN)


55
56
57
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 55

def is_used_with_configuration_source_provider
  @is_used_with_configuration_source_provider
end

#lifecycle_stateString

The current lifecycle state of the private endpoint.

Returns:

  • (String)


72
73
74
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 72

def lifecycle_state
  @lifecycle_state
end

#nsg_id_listArray<String>

An array of network security groups (NSG) that the customer can optionally provide.

Returns:

  • (Array<String>)


51
52
53
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 51

def nsg_id_list
  @nsg_id_list
end

#source_ipsArray<String>

The source IPs which resource manager service will use to connect to customer's network. Automatically assigned by Resource Manager Service.

Returns:

  • (Array<String>)


47
48
49
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 47

def source_ips
  @source_ips
end

#subnet_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet within the VCN for the private endpoint.

Returns:

  • (String)


43
44
45
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 43

def subnet_id
  @subnet_id
end

#time_createdDateTime

The date and time at which the private endpoint was created. Format is defined by RFC3339. Example: `2020-11-25T21:10:29.600Z`

Returns:

  • (DateTime)


67
68
69
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 67

def time_created
  @time_created
end

#vcn_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN for the private endpoint.

Returns:

  • (String)


39
40
41
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 39

def vcn_id
  @vcn_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 89

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'vcn_id': :'vcnId',
    'subnet_id': :'subnetId',
    'source_ips': :'sourceIps',
    'nsg_id_list': :'nsgIdList',
    'is_used_with_configuration_source_provider': :'isUsedWithConfigurationSourceProvider',
    'dns_zones': :'dnsZones',
    'time_created': :'timeCreated',
    'lifecycle_state': :'lifecycleState',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 111

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'vcn_id': :'String',
    'subnet_id': :'String',
    'source_ips': :'Array<String>',
    'nsg_id_list': :'Array<String>',
    'is_used_with_configuration_source_provider': :'BOOLEAN',
    'dns_zones': :'Array<String>',
    'time_created': :'DateTime',
    'lifecycle_state': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 255

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    vcn_id == other.vcn_id &&
    subnet_id == other.subnet_id &&
    source_ips == other.source_ips &&
    nsg_id_list == other.nsg_id_list &&
    is_used_with_configuration_source_provider == other.is_used_with_configuration_source_provider &&
    dns_zones == other.dns_zones &&
    time_created == other.time_created &&
    lifecycle_state == other.lifecycle_state &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 298

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


278
279
280
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 278

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



287
288
289
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 287

def hash
  [id, compartment_id, display_name, description, vcn_id, subnet_id, source_ips, nsg_id_list, is_used_with_configuration_source_provider, dns_zones, time_created, lifecycle_state, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
334
335
336
337
338
339
340
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 331

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



325
326
327
# File 'lib/oci/resource_manager/models/private_endpoint.rb', line 325

def to_s
  to_hash.to_s
end