Class: ResourceManager::Models::Stack

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/resource_manager/models/stack.rb

Overview

The stack object. Stacks represent definitions of groups of Oracle Cloud Infrastructure resources that you can act upon as a group. You take action on stacks by using jobs.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STACK_DRIFT_STATUS_ENUM =
[
  STACK_DRIFT_STATUS_NOT_CHECKED = 'NOT_CHECKED'.freeze,
  STACK_DRIFT_STATUS_IN_SYNC = 'IN_SYNC'.freeze,
  STACK_DRIFT_STATUS_DRIFTED = 'DRIFTED'.freeze,
  STACK_DRIFT_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Stack

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/oci/resource_manager/models/stack.rb', line 163

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.config_source = attributes[:'configSource'] if attributes[:'configSource']

  raise 'You cannot provide both :configSource and :config_source' if attributes.key?(:'configSource') && attributes.key?(:'config_source')

  self.config_source = attributes[:'config_source'] if attributes[:'config_source']

  self.variables = attributes[:'variables'] if attributes[:'variables']

  self.terraform_version = attributes[:'terraformVersion'] if attributes[:'terraformVersion']

  raise 'You cannot provide both :terraformVersion and :terraform_version' if attributes.key?(:'terraformVersion') && attributes.key?(:'terraform_version')

  self.terraform_version = attributes[:'terraform_version'] if attributes[:'terraform_version']

  self.stack_drift_status = attributes[:'stackDriftStatus'] if attributes[:'stackDriftStatus']

  raise 'You cannot provide both :stackDriftStatus and :stack_drift_status' if attributes.key?(:'stackDriftStatus') && attributes.key?(:'stack_drift_status')

  self.stack_drift_status = attributes[:'stack_drift_status'] if attributes[:'stack_drift_status']

  self.time_drift_last_checked = attributes[:'timeDriftLastChecked'] if attributes[:'timeDriftLastChecked']

  raise 'You cannot provide both :timeDriftLastChecked and :time_drift_last_checked' if attributes.key?(:'timeDriftLastChecked') && attributes.key?(:'time_drift_last_checked')

  self.time_drift_last_checked = attributes[:'time_drift_last_checked'] if attributes[:'time_drift_last_checked']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

Unique identifier ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) for the compartment where the stack is located.

Returns:

  • (String)


35
36
37
# File 'lib/oci/resource_manager/models/stack.rb', line 35

def compartment_id
  @compartment_id
end

#config_sourceOCI::ResourceManager::Models::ConfigSource



60
61
62
# File 'lib/oci/resource_manager/models/stack.rb', line 60

def config_source
  @config_source
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


100
101
102
# File 'lib/oci/resource_manager/models/stack.rb', line 100

def defined_tags
  @defined_tags
end

#descriptionString

Description of the stack.

Returns:

  • (String)


43
44
45
# File 'lib/oci/resource_manager/models/stack.rb', line 43

def description
  @description
end

#display_nameString

Human-readable name of the stack.

Returns:

  • (String)


39
40
41
# File 'lib/oci/resource_manager/models/stack.rb', line 39

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


93
94
95
# File 'lib/oci/resource_manager/models/stack.rb', line 93

def freeform_tags
  @freeform_tags
end

#idString

Unique identifier ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) for the stack.

Returns:

  • (String)


31
32
33
# File 'lib/oci/resource_manager/models/stack.rb', line 31

def id
  @id
end

#lifecycle_stateString

The current lifecycle state of the stack. For more information about stack lifecycle states in Resource Manager, see [Key Concepts](docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/resourcemanager.htm#concepts__StackStates).

Returns:

  • (String)


57
58
59
# File 'lib/oci/resource_manager/models/stack.rb', line 57

def lifecycle_state
  @lifecycle_state
end

#stack_drift_statusString

Drift status of the stack. Drift refers to differences between the actual (current) state of the stack and the expected (defined) state of the stack.

Returns:

  • (String)


79
80
81
# File 'lib/oci/resource_manager/models/stack.rb', line 79

def stack_drift_status
  @stack_drift_status
end

#terraform_versionString

The version of Terraform specified for the stack. Example: `0.12.x`

Returns:

  • (String)


73
74
75
# File 'lib/oci/resource_manager/models/stack.rb', line 73

def terraform_version
  @terraform_version
end

#time_createdDateTime

The date and time at which the stack was created. Format is defined by RFC3339. Example: `2020-01-25T21:10:29.600Z`

Returns:

  • (DateTime)


50
51
52
# File 'lib/oci/resource_manager/models/stack.rb', line 50

def time_created
  @time_created
end

#time_drift_last_checkedDateTime

The date and time when the drift detection was last executed. Format is defined by RFC3339. Example: `2020-01-25T21:10:29.600Z`

Returns:

  • (DateTime)


86
87
88
# File 'lib/oci/resource_manager/models/stack.rb', line 86

def time_drift_last_checked
  @time_drift_last_checked
end

#variablesHash<String, String>

Terraform variables associated with this resource. Maximum number of variables supported is 250. The maximum size of each variable, including both name and value, is 8192 bytes. Example: `"compartment-id-value"`

Returns:

  • (Hash<String, String>)


68
69
70
# File 'lib/oci/resource_manager/models/stack.rb', line 68

def variables
  @variables
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/resource_manager/models/stack.rb', line 103

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'time_created': :'timeCreated',
    'lifecycle_state': :'lifecycleState',
    'config_source': :'configSource',
    'variables': :'variables',
    'terraform_version': :'terraformVersion',
    'stack_drift_status': :'stackDriftStatus',
    'time_drift_last_checked': :'timeDriftLastChecked',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/resource_manager/models/stack.rb', line 124

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'time_created': :'DateTime',
    'lifecycle_state': :'String',
    'config_source': :'OCI::ResourceManager::Models::ConfigSource',
    'variables': :'Hash<String, String>',
    'terraform_version': :'String',
    'stack_drift_status': :'String',
    'time_drift_last_checked': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/oci/resource_manager/models/stack.rb', line 269

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    time_created == other.time_created &&
    lifecycle_state == other.lifecycle_state &&
    config_source == other.config_source &&
    variables == other.variables &&
    terraform_version == other.terraform_version &&
    stack_drift_status == other.stack_drift_status &&
    time_drift_last_checked == other.time_drift_last_checked &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/oci/resource_manager/models/stack.rb', line 311

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


291
292
293
# File 'lib/oci/resource_manager/models/stack.rb', line 291

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



300
301
302
# File 'lib/oci/resource_manager/models/stack.rb', line 300

def hash
  [id, compartment_id, display_name, description, time_created, lifecycle_state, config_source, variables, terraform_version, stack_drift_status, time_drift_last_checked, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



344
345
346
347
348
349
350
351
352
353
# File 'lib/oci/resource_manager/models/stack.rb', line 344

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



338
339
340
# File 'lib/oci/resource_manager/models/stack.rb', line 338

def to_s
  to_hash.to_s
end