Class: OCI::ResourceManager::Models::StackSummary
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::StackSummary
- Defined in:
- lib/oci/resource_manager/models/stack_summary.rb
Overview
Returns a list of properties and the defining property values for the specified stack.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
Unique identifier of the compartment in which the stack resides.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
General description of the stack.
-
#display_name ⇒ String
Human-readable display name for the stack.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with this resource.
-
#id ⇒ String
Unique identifier of the specified stack.
-
#lifecycle_state ⇒ String
The current lifecycle state of the stack.
-
#terraform_version ⇒ String
The version of Terraform specified for the stack.
-
#time_created ⇒ DateTime
The date and time when the stack was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StackSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ StackSummary
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.terraform_version = attributes[:'terraformVersion'] if attributes[:'terraformVersion'] raise 'You cannot provide both :terraformVersion and :terraform_version' if attributes.key?(:'terraformVersion') && attributes.key?(:'terraform_version') self.terraform_version = attributes[:'terraform_version'] if attributes[:'terraform_version'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
Unique identifier of the compartment in which the stack resides.
17 18 19 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 17 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
65 66 67 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 65 def @defined_tags end |
#description ⇒ String
General description of the stack.
25 26 27 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 25 def description @description end |
#display_name ⇒ String
Human-readable display name for the stack.
21 22 23 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 21 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with this resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
58 59 60 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 58 def @freeform_tags end |
#id ⇒ String
Unique identifier of the specified stack.
13 14 15 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 13 def id @id end |
#lifecycle_state ⇒ String
The current lifecycle state of the stack. For more information about stack lifecycle states in Resource Manager, see [Key Concepts](docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/resourcemanager.htm#concepts__StackStates).
Allowable values:
-
CREATING
-
ACTIVE
-
DELETING
-
DELETED
-
FAILED
46 47 48 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 46 def lifecycle_state @lifecycle_state end |
#terraform_version ⇒ String
The version of Terraform specified for the stack. Example: 0.12.x
51 52 53 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 51 def terraform_version @terraform_version end |
#time_created ⇒ DateTime
The date and time when the stack was created. Format is defined by RFC3339. Example: 2020-01-25T21:10:29.600Z
32 33 34 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 32 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 68 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'terraform_version': :'terraformVersion', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 85 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'terraform_version': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 176 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && time_created == other.time_created && lifecycle_state == other.lifecycle_state && terraform_version == other.terraform_version && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 214 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
194 195 196 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 194 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 203 def hash [id, compartment_id, display_name, description, time_created, lifecycle_state, terraform_version, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
241 242 243 |
# File 'lib/oci/resource_manager/models/stack_summary.rb', line 241 def to_s to_hash.to_s end |