Class: OCI::ResourceManager::Models::TemplateSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/resource_manager/models/template_summary.rb

Overview

Summary information for a template.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TemplateSummary

Initializes the object

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :is_free_tier (BOOLEAN)

    The value to assign to the #is_free_tier property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/oci/resource_manager/models/template_summary.rb', line 88

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.is_free_tier = attributes[:'isFreeTier'] unless attributes[:'isFreeTier'].nil?

  raise 'You cannot provide both :isFreeTier and :is_free_tier' if attributes.key?(:'isFreeTier') && attributes.key?(:'is_free_tier')

  self.is_free_tier = attributes[:'is_free_tier'] unless attributes[:'is_free_tier'].nil?

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']
end

Instance Attribute Details

#compartment_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing this template.



17
18
19
# File 'lib/oci/resource_manager/models/template_summary.rb', line 17

def compartment_id
  @compartment_id
end

#descriptionString

Brief description of the template.



25
26
27
# File 'lib/oci/resource_manager/models/template_summary.rb', line 25

def description
  @description
end

#display_nameString

Human-readable display name for the template.



21
22
23
# File 'lib/oci/resource_manager/models/template_summary.rb', line 21

def display_name
  @display_name
end

#idString

Unique identifier of the specified template.



13
14
15
# File 'lib/oci/resource_manager/models/template_summary.rb', line 13

def id
  @id
end

#is_free_tierBOOLEAN

whether the template will work for free tier tenancy.



29
30
31
# File 'lib/oci/resource_manager/models/template_summary.rb', line 29

def is_free_tier
  @is_free_tier
end

#lifecycle_stateString

The current lifecycle state of the template. Allowable values:

  • ACTIVE



43
44
45
# File 'lib/oci/resource_manager/models/template_summary.rb', line 43

def lifecycle_state
  @lifecycle_state
end

#time_createdDateTime

The date and time at which the template was created. Format is defined by RFC3339. Example: 2020-11-25T21:10:29.600Z



36
37
38
# File 'lib/oci/resource_manager/models/template_summary.rb', line 36

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/oci/resource_manager/models/template_summary.rb', line 46

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'description': :'description',
    'is_free_tier': :'isFreeTier',
    'time_created': :'timeCreated',
    'lifecycle_state': :'lifecycleState'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/resource_manager/models/template_summary.rb', line 61

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'description': :'String',
    'is_free_tier': :'BOOLEAN',
    'time_created': :'DateTime',
    'lifecycle_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/resource_manager/models/template_summary.rb', line 136

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    description == other.description &&
    is_free_tier == other.is_free_tier &&
    time_created == other.time_created &&
    lifecycle_state == other.lifecycle_state
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/resource_manager/models/template_summary.rb', line 172

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


152
153
154
# File 'lib/oci/resource_manager/models/template_summary.rb', line 152

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



161
162
163
# File 'lib/oci/resource_manager/models/template_summary.rb', line 161

def hash
  [id, compartment_id, display_name, description, is_free_tier, time_created, lifecycle_state].hash
end

#to_hashHash

Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
# File 'lib/oci/resource_manager/models/template_summary.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



199
200
201
# File 'lib/oci/resource_manager/models/template_summary.rb', line 199

def to_s
  to_hash.to_s
end