Class: OCI::ResourceManager::Models::UpdateConfigurationSourceProviderDetails
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::UpdateConfigurationSourceProviderDetails
- Defined in:
- lib/oci/resource_manager/models/update_configuration_source_provider_details.rb
Overview
The details for updating a configuration source provider.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
UpdateGithubAccessTokenConfigurationSourceProviderDetails, UpdateGitlabAccessTokenConfigurationSourceProviderDetails
Instance Attribute Summary collapse
-
#config_source_provider_type ⇒ String
The type of configuration source provider.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the configuration source provider.
-
#display_name ⇒ String
Human-readable name of the configuration source provider.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with the resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateConfigurationSourceProviderDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateConfigurationSourceProviderDetails
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.config_source_provider_type = attributes[:'configSourceProviderType'] if attributes[:'configSourceProviderType'] raise 'You cannot provide both :configSourceProviderType and :config_source_provider_type' if attributes.key?(:'configSourceProviderType') && attributes.key?(:'config_source_provider_type') self.config_source_provider_type = attributes[:'config_source_provider_type'] if attributes[:'config_source_provider_type'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#config_source_provider_type ⇒ String
The type of configuration source provider. The GITLAB_ACCESS_TOKEN type corresponds to GitLab. The GITHUB_ACCESS_TOKEN type corresponds to GitHub.
25 26 27 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 25 def config_source_provider_type @config_source_provider_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
39 40 41 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 39 def @defined_tags end |
#description ⇒ String
Description of the configuration source provider. Avoid entering confidential information.
18 19 20 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 18 def description @description end |
#display_name ⇒ String
Human-readable name of the configuration source provider. Avoid entering confidential information.
14 15 16 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 14 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
32 33 34 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 32 def @freeform_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'config_source_provider_type': :'configSourceProviderType', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 72 def self.get_subtype(object_hash) type = object_hash[:'configSourceProviderType'] # rubocop:disable Style/SymbolLiteral return 'OCI::ResourceManager::Models::UpdateGitlabAccessTokenConfigurationSourceProviderDetails' if type == 'GITLAB_ACCESS_TOKEN' return 'OCI::ResourceManager::Models::UpdateGithubAccessTokenConfigurationSourceProviderDetails' if type == 'GITHUB_ACCESS_TOKEN' # TODO: Log a warning when the subtype is not found. 'OCI::ResourceManager::Models::UpdateConfigurationSourceProviderDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'config_source_provider_type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 134 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && config_source_provider_type == other.config_source_provider_type && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 157 def hash [display_name, description, config_source_provider_type, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/resource_manager/models/update_configuration_source_provider_details.rb', line 195 def to_s to_hash.to_s end |