Class: OCI::ResourceManager::Models::UpdatePrivateEndpointDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/resource_manager/models/update_private_endpoint_details.rb

Overview

Update details for a private endpoint.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdatePrivateEndpointDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :vcn_id (String)

    The value to assign to the #vcn_id property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :dns_zones (Array<String>)

    The value to assign to the #dns_zones property

  • :nsg_id_list (Array<String>)

    The value to assign to the #nsg_id_list property

  • :is_used_with_configuration_source_provider (BOOLEAN)

    The value to assign to the #is_used_with_configuration_source_provider property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 103

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId']

  raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id')

  self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.dns_zones = attributes[:'dnsZones'] if attributes[:'dnsZones']

  raise 'You cannot provide both :dnsZones and :dns_zones' if attributes.key?(:'dnsZones') && attributes.key?(:'dns_zones')

  self.dns_zones = attributes[:'dns_zones'] if attributes[:'dns_zones']

  self.nsg_id_list = attributes[:'nsgIdList'] if attributes[:'nsgIdList']

  raise 'You cannot provide both :nsgIdList and :nsg_id_list' if attributes.key?(:'nsgIdList') && attributes.key?(:'nsg_id_list')

  self.nsg_id_list = attributes[:'nsg_id_list'] if attributes[:'nsg_id_list']

  self.is_used_with_configuration_source_provider = attributes[:'isUsedWithConfigurationSourceProvider'] unless attributes[:'isUsedWithConfigurationSourceProvider'].nil?

  raise 'You cannot provide both :isUsedWithConfigurationSourceProvider and :is_used_with_configuration_source_provider' if attributes.key?(:'isUsedWithConfigurationSourceProvider') && attributes.key?(:'is_used_with_configuration_source_provider')

  self.is_used_with_configuration_source_provider = attributes[:'is_used_with_configuration_source_provider'] unless attributes[:'is_used_with_configuration_source_provider'].nil?

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


52
53
54
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 52

def defined_tags
  @defined_tags
end

#descriptionString

Description of the private endpoint. Avoid entering confidential information.

Returns:

  • (String)


17
18
19
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 17

def description
  @description
end

#display_nameString

The private endpoint display name. Avoid entering confidential information.

Returns:

  • (String)


13
14
15
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 13

def display_name
  @display_name
end

#dns_zonesArray<String>

DNS Proxy forwards any DNS FQDN queries over into the consumer DNS resolver if the DNS FQDN is included in the dns zones list otherwise it goes to service provider VCN resolver.

Returns:

  • (Array<String>)


30
31
32
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 30

def dns_zones
  @dns_zones
end

#freeform_tagsHash<String, String>

Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


45
46
47
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 45

def freeform_tags
  @freeform_tags
end

#is_used_with_configuration_source_providerBOOLEAN

When `true`, allows the private endpoint to be used with a configuration source provider.

Returns:

  • (BOOLEAN)


38
39
40
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 38

def is_used_with_configuration_source_provider
  @is_used_with_configuration_source_provider
end

#nsg_id_listArray<String>

An array of network security group (NSG) [OCIDs](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the private endpoint.

Returns:

  • (Array<String>)


34
35
36
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 34

def nsg_id_list
  @nsg_id_list
end

#subnet_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet within the VCN for the private endpoint.

Returns:

  • (String)


25
26
27
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 25

def subnet_id
  @subnet_id
end

#vcn_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN for the private endpoint.

Returns:

  • (String)


21
22
23
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 21

def vcn_id
  @vcn_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 55

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'description': :'description',
    'vcn_id': :'vcnId',
    'subnet_id': :'subnetId',
    'dns_zones': :'dnsZones',
    'nsg_id_list': :'nsgIdList',
    'is_used_with_configuration_source_provider': :'isUsedWithConfigurationSourceProvider',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 72

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'description': :'String',
    'vcn_id': :'String',
    'subnet_id': :'String',
    'dns_zones': :'Array<String>',
    'nsg_id_list': :'Array<String>',
    'is_used_with_configuration_source_provider': :'BOOLEAN',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 167

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    description == other.description &&
    vcn_id == other.vcn_id &&
    subnet_id == other.subnet_id &&
    dns_zones == other.dns_zones &&
    nsg_id_list == other.nsg_id_list &&
    is_used_with_configuration_source_provider == other.is_used_with_configuration_source_provider &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 205

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 185

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



194
195
196
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 194

def hash
  [display_name, description, vcn_id, subnet_id, dns_zones, nsg_id_list, is_used_with_configuration_source_provider, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



232
233
234
# File 'lib/oci/resource_manager/models/update_private_endpoint_details.rb', line 232

def to_s
  to_hash.to_s
end