Class: OCI::ResourceManager::Models::UpdateTemplateDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/resource_manager/models/update_template_details.rb

Overview

Updates the specified template.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateTemplateDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 87

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.long_description = attributes[:'longDescription'] if attributes[:'longDescription']

  raise 'You cannot provide both :longDescription and :long_description' if attributes.key?(:'longDescription') && attributes.key?(:'long_description')

  self.long_description = attributes[:'long_description'] if attributes[:'long_description']

  self.logo_file_base64_encoded = attributes[:'logoFileBase64Encoded'] if attributes[:'logoFileBase64Encoded']

  raise 'You cannot provide both :logoFileBase64Encoded and :logo_file_base64_encoded' if attributes.key?(:'logoFileBase64Encoded') && attributes.key?(:'logo_file_base64_encoded')

  self.logo_file_base64_encoded = attributes[:'logo_file_base64_encoded'] if attributes[:'logo_file_base64_encoded']

  self.template_config_source = attributes[:'templateConfigSource'] if attributes[:'templateConfigSource']

  raise 'You cannot provide both :templateConfigSource and :template_config_source' if attributes.key?(:'templateConfigSource') && attributes.key?(:'template_config_source')

  self.template_config_source = attributes[:'template_config_source'] if attributes[:'template_config_source']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


42
43
44
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 42

def defined_tags
  @defined_tags
end

#descriptionString

Description of the template. Avoid entering confidential information.

Returns:

  • (String)


17
18
19
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 17

def description
  @description
end

#display_nameString

The template’s display name. Avoid entering confidential information.

Returns:

  • (String)


13
14
15
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 13

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


35
36
37
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 35

def freeform_tags
  @freeform_tags
end

#logo_file_base64_encodedString

Base64-encoded logo for the template.

Returns:

  • (String)


25
26
27
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 25

def logo_file_base64_encoded
  @logo_file_base64_encoded
end

#long_descriptionString

Detailed description of the template. This description is displayed in the Console page listing templates when the template is expanded. Avoid entering confidential information.

Returns:

  • (String)


21
22
23
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 21

def long_description
  @long_description
end

#template_config_sourceOCI::ResourceManager::Models::UpdateTemplateConfigSourceDetails



28
29
30
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 28

def template_config_source
  @template_config_source
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 45

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'description': :'description',
    'long_description': :'longDescription',
    'logo_file_base64_encoded': :'logoFileBase64Encoded',
    'template_config_source': :'templateConfigSource',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 60

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'description': :'String',
    'long_description': :'String',
    'logo_file_base64_encoded': :'String',
    'template_config_source': :'OCI::ResourceManager::Models::UpdateTemplateConfigSourceDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 139

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    description == other.description &&
    long_description == other.long_description &&
    logo_file_base64_encoded == other.logo_file_base64_encoded &&
    template_config_source == other.template_config_source &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 175

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 155

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



164
165
166
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 164

def hash
  [display_name, description, long_description, logo_file_base64_encoded, template_config_source, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



202
203
204
# File 'lib/oci/resource_manager/models/update_template_details.rb', line 202

def to_s
  to_hash.to_s
end