Class: OCI::ResourceSearch::Models::SearchDetails
- Inherits:
-
Object
- Object
- OCI::ResourceSearch::Models::SearchDetails
- Defined in:
- lib/oci/resource_search/models/search_details.rb
Overview
A base request type that contains common criteria for searching for resources. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- MATCHING_CONTEXT_TYPE_ENUM =
[ MATCHING_CONTEXT_TYPE_NONE = 'NONE'.freeze, MATCHING_CONTEXT_TYPE_HIGHLIGHTS = 'HIGHLIGHTS'.freeze ].freeze
Instance Attribute Summary collapse
-
#matching_context_type ⇒ String
The type of matching context returned in the response.
-
#type ⇒ String
[Required] The type of SearchDetails, whether
FreeTextorStructured.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SearchDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SearchDetails
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/resource_search/models/search_details.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.matching_context_type = attributes[:'matchingContextType'] if attributes[:'matchingContextType'] raise 'You cannot provide both :matchingContextType and :matching_context_type' if attributes.key?(:'matchingContextType') && attributes.key?(:'matching_context_type') self.matching_context_type = attributes[:'matching_context_type'] if attributes[:'matching_context_type'] end |
Instance Attribute Details
#matching_context_type ⇒ String
The type of matching context returned in the response. If you specify HIGHLIGHTS, then the service will highlight fragments in its response. (For more information, see ResourceSummary.searchContext and SearchContext.) The default setting is NONE.
23 24 25 |
# File 'lib/oci/resource_search/models/search_details.rb', line 23 def matching_context_type @matching_context_type end |
#type ⇒ String
[Required] The type of SearchDetails, whether FreeText or Structured.
18 19 20 |
# File 'lib/oci/resource_search/models/search_details.rb', line 18 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 |
# File 'lib/oci/resource_search/models/search_details.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'matching_context_type': :'matchingContextType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/resource_search/models/search_details.rb', line 50 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::ResourceSearch::Models::StructuredSearchDetails' if type == 'Structured' return 'OCI::ResourceSearch::Models::FreeTextSearchDetails' if type == 'FreeText' # TODO: Log a warning when the subtype is not found. 'OCI::ResourceSearch::Models::SearchDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 |
# File 'lib/oci/resource_search/models/search_details.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'matching_context_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
99 100 101 102 103 104 105 |
# File 'lib/oci/resource_search/models/search_details.rb', line 99 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && matching_context_type == other.matching_context_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/resource_search/models/search_details.rb', line 130 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
110 111 112 |
# File 'lib/oci/resource_search/models/search_details.rb', line 110 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
119 120 121 |
# File 'lib/oci/resource_search/models/search_details.rb', line 119 def hash [type, matching_context_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/resource_search/models/search_details.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
157 158 159 |
# File 'lib/oci/resource_search/models/search_details.rb', line 157 def to_s to_hash.to_s end |