Class: OCI::Rover::Models::CreateRoverClusterDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/rover/models/create_rover_cluster_details.rb

Overview

The information required to create a RoverCluster.

Constant Summary collapse

CLUSTER_TYPE_ENUM =
[
  CLUSTER_TYPE_STANDALONE = 'STANDALONE'.freeze,
  CLUSTER_TYPE_STATION = 'STATION'.freeze
].freeze
ENCLOSURE_TYPE_ENUM =
[
  ENCLOSURE_TYPE_RUGGADIZED = 'RUGGADIZED'.freeze,
  ENCLOSURE_TYPE_NON_RUGGADIZED = 'NON_RUGGADIZED'.freeze
].freeze
SHIPPING_PREFERENCE_ENUM =
[
  SHIPPING_PREFERENCE_ORACLE_SHIPPED = 'ORACLE_SHIPPED'.freeze,
  SHIPPING_PREFERENCE_CUSTOMER_PICKUP = 'CUSTOMER_PICKUP'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateRoverClusterDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 246

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.cluster_size = attributes[:'clusterSize'] if attributes[:'clusterSize']

  raise 'You cannot provide both :clusterSize and :cluster_size' if attributes.key?(:'clusterSize') && attributes.key?(:'cluster_size')

  self.cluster_size = attributes[:'cluster_size'] if attributes[:'cluster_size']

  self.customer_shipping_address = attributes[:'customerShippingAddress'] if attributes[:'customerShippingAddress']

  raise 'You cannot provide both :customerShippingAddress and :customer_shipping_address' if attributes.key?(:'customerShippingAddress') && attributes.key?(:'customer_shipping_address')

  self.customer_shipping_address = attributes[:'customer_shipping_address'] if attributes[:'customer_shipping_address']

  self.cluster_workloads = attributes[:'clusterWorkloads'] if attributes[:'clusterWorkloads']

  raise 'You cannot provide both :clusterWorkloads and :cluster_workloads' if attributes.key?(:'clusterWorkloads') && attributes.key?(:'cluster_workloads')

  self.cluster_workloads = attributes[:'cluster_workloads'] if attributes[:'cluster_workloads']

  self.cluster_type = attributes[:'clusterType'] if attributes[:'clusterType']

  raise 'You cannot provide both :clusterType and :cluster_type' if attributes.key?(:'clusterType') && attributes.key?(:'cluster_type')

  self.cluster_type = attributes[:'cluster_type'] if attributes[:'cluster_type']

  self.super_user_password = attributes[:'superUserPassword'] if attributes[:'superUserPassword']

  raise 'You cannot provide both :superUserPassword and :super_user_password' if attributes.key?(:'superUserPassword') && attributes.key?(:'super_user_password')

  self.super_user_password = attributes[:'super_user_password'] if attributes[:'super_user_password']

  self.enclosure_type = attributes[:'enclosureType'] if attributes[:'enclosureType']

  raise 'You cannot provide both :enclosureType and :enclosure_type' if attributes.key?(:'enclosureType') && attributes.key?(:'enclosure_type')

  self.enclosure_type = attributes[:'enclosure_type'] if attributes[:'enclosure_type']

  self.unlock_passphrase = attributes[:'unlockPassphrase'] if attributes[:'unlockPassphrase']

  raise 'You cannot provide both :unlockPassphrase and :unlock_passphrase' if attributes.key?(:'unlockPassphrase') && attributes.key?(:'unlock_passphrase')

  self.unlock_passphrase = attributes[:'unlock_passphrase'] if attributes[:'unlock_passphrase']

  self.point_of_contact = attributes[:'pointOfContact'] if attributes[:'pointOfContact']

  raise 'You cannot provide both :pointOfContact and :point_of_contact' if attributes.key?(:'pointOfContact') && attributes.key?(:'point_of_contact')

  self.point_of_contact = attributes[:'point_of_contact'] if attributes[:'point_of_contact']

  self.point_of_contact_phone_number = attributes[:'pointOfContactPhoneNumber'] if attributes[:'pointOfContactPhoneNumber']

  raise 'You cannot provide both :pointOfContactPhoneNumber and :point_of_contact_phone_number' if attributes.key?(:'pointOfContactPhoneNumber') && attributes.key?(:'point_of_contact_phone_number')

  self.point_of_contact_phone_number = attributes[:'point_of_contact_phone_number'] if attributes[:'point_of_contact_phone_number']

  self.shipping_preference = attributes[:'shippingPreference'] if attributes[:'shippingPreference']
  self.shipping_preference = "ORACLE_SHIPPED" if shipping_preference.nil? && !attributes.key?(:'shippingPreference') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :shippingPreference and :shipping_preference' if attributes.key?(:'shippingPreference') && attributes.key?(:'shipping_preference')

  self.shipping_preference = attributes[:'shipping_preference'] if attributes[:'shipping_preference']
  self.shipping_preference = "ORACLE_SHIPPED" if shipping_preference.nil? && !attributes.key?(:'shippingPreference') && !attributes.key?(:'shipping_preference') # rubocop:disable Style/StringLiterals

  self.shipping_vendor = attributes[:'shippingVendor'] if attributes[:'shippingVendor']

  raise 'You cannot provide both :shippingVendor and :shipping_vendor' if attributes.key?(:'shippingVendor') && attributes.key?(:'shipping_vendor')

  self.shipping_vendor = attributes[:'shipping_vendor'] if attributes[:'shipping_vendor']

  self.time_pickup_expected = attributes[:'timePickupExpected'] if attributes[:'timePickupExpected']

  raise 'You cannot provide both :timePickupExpected and :time_pickup_expected' if attributes.key?(:'timePickupExpected') && attributes.key?(:'time_pickup_expected')

  self.time_pickup_expected = attributes[:'time_pickup_expected'] if attributes[:'time_pickup_expected']

  self.oracle_shipping_tracking_url = attributes[:'oracleShippingTrackingUrl'] if attributes[:'oracleShippingTrackingUrl']

  raise 'You cannot provide both :oracleShippingTrackingUrl and :oracle_shipping_tracking_url' if attributes.key?(:'oracleShippingTrackingUrl') && attributes.key?(:'oracle_shipping_tracking_url')

  self.oracle_shipping_tracking_url = attributes[:'oracle_shipping_tracking_url'] if attributes[:'oracle_shipping_tracking_url']

  self.subscription_id = attributes[:'subscriptionId'] if attributes[:'subscriptionId']

  raise 'You cannot provide both :subscriptionId and :subscription_id' if attributes.key?(:'subscriptionId') && attributes.key?(:'subscription_id')

  self.subscription_id = attributes[:'subscription_id'] if attributes[:'subscription_id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_state_details = attributes[:'lifecycleStateDetails'] if attributes[:'lifecycleStateDetails']

  raise 'You cannot provide both :lifecycleStateDetails and :lifecycle_state_details' if attributes.key?(:'lifecycleStateDetails') && attributes.key?(:'lifecycle_state_details')

  self.lifecycle_state_details = attributes[:'lifecycle_state_details'] if attributes[:'lifecycle_state_details']

  self.is_import_requested = attributes[:'isImportRequested'] unless attributes[:'isImportRequested'].nil?

  raise 'You cannot provide both :isImportRequested and :is_import_requested' if attributes.key?(:'isImportRequested') && attributes.key?(:'is_import_requested')

  self.is_import_requested = attributes[:'is_import_requested'] unless attributes[:'is_import_requested'].nil?

  self.import_compartment_id = attributes[:'importCompartmentId'] if attributes[:'importCompartmentId']

  raise 'You cannot provide both :importCompartmentId and :import_compartment_id' if attributes.key?(:'importCompartmentId') && attributes.key?(:'import_compartment_id')

  self.import_compartment_id = attributes[:'import_compartment_id'] if attributes[:'import_compartment_id']

  self.import_file_bucket = attributes[:'importFileBucket'] if attributes[:'importFileBucket']

  raise 'You cannot provide both :importFileBucket and :import_file_bucket' if attributes.key?(:'importFileBucket') && attributes.key?(:'import_file_bucket')

  self.import_file_bucket = attributes[:'import_file_bucket'] if attributes[:'import_file_bucket']

  self.data_validation_code = attributes[:'dataValidationCode'] if attributes[:'dataValidationCode']

  raise 'You cannot provide both :dataValidationCode and :data_validation_code' if attributes.key?(:'dataValidationCode') && attributes.key?(:'data_validation_code')

  self.data_validation_code = attributes[:'data_validation_code'] if attributes[:'data_validation_code']

  self.master_key_id = attributes[:'masterKeyId'] if attributes[:'masterKeyId']

  raise 'You cannot provide both :masterKeyId and :master_key_id' if attributes.key?(:'masterKeyId') && attributes.key?(:'master_key_id')

  self.master_key_id = attributes[:'master_key_id'] if attributes[:'master_key_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#cluster_sizeInteger

**[Required]** Number of nodes desired in the cluster, in standalone clusters, between 5 and 15 inclusive. In station clusters, between 15 and 30 inclusive.

Returns:

  • (Integer)


44
45
46
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 44

def cluster_size
  @cluster_size
end

#cluster_typeString

Type of cluster.

Returns:

  • (String)


55
56
57
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 55

def cluster_type
  @cluster_type
end

#cluster_workloadsArray<OCI::Rover::Models::RoverWorkload>

List of existing workloads that should be provisioned on the nodes.



51
52
53
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 51

def cluster_workloads
  @cluster_workloads
end

#compartment_idString

**[Required]** The OCID of the compartment containing the RoverCluster.

Returns:

  • (String)


40
41
42
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 40

def compartment_id
  @compartment_id
end

#customer_shipping_addressOCI::Rover::Models::ShippingAddress



47
48
49
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 47

def customer_shipping_address
  @customer_shipping_address
end

#data_validation_codeString

Validation code returned by data validation tool. Required for return shipping label generation if data import was requested.

Returns:

  • (String)


119
120
121
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 119

def data_validation_code
  @data_validation_code
end

#defined_tagsHash<String, Hash<String, Object>>

The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


137
138
139
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 137

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


36
37
38
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 36

def display_name
  @display_name
end

#enclosure_typeString

The type of enclosure rover nodes in this cluster are shipped in.

Returns:

  • (String)


63
64
65
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 63

def enclosure_type
  @enclosure_type
end

#freeform_tagsHash<String, String>

The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


130
131
132
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 130

def freeform_tags
  @freeform_tags
end

#import_compartment_idString

An OCID of a compartment where data will be imported to upon Rover cluster return.

Returns:

  • (String)


111
112
113
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 111

def import_compartment_id
  @import_compartment_id
end

#import_file_bucketString

Name of a bucket where files from NFS share will be imported to upon Rover cluster return.

Returns:

  • (String)


115
116
117
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 115

def import_file_bucket
  @import_file_bucket
end

#is_import_requestedBOOLEAN

The flag indicating that customer requests data to be imported to OCI upon Rover cluster return.

Returns:

  • (BOOLEAN)


107
108
109
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 107

def is_import_requested
  @is_import_requested
end

#lifecycle_stateString

The current state of the RoverCluster.

Returns:

  • (String)


99
100
101
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 99

def lifecycle_state
  @lifecycle_state
end

#lifecycle_state_detailsString

A property that can contain details on the lifecycle.

Returns:

  • (String)


103
104
105
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 103

def lifecycle_state_details
  @lifecycle_state_details
end

#master_key_idString

Customer provided master key ID to encrypt secret information. If not provided, Rover's master key will be used for encryption.

Returns:

  • (String)


123
124
125
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 123

def master_key_id
  @master_key_id
end

#oracle_shipping_tracking_urlString

Tracking Url for the shipped Rover Cluster.

Returns:

  • (String)


91
92
93
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 91

def oracle_shipping_tracking_url
  @oracle_shipping_tracking_url
end

#point_of_contactString

Name of point of contact for this order if customer is picking up.

Returns:

  • (String)


71
72
73
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 71

def point_of_contact
  @point_of_contact
end

#point_of_contact_phone_numberString

Phone number of point of contact for this order if customer is picking up.

Returns:

  • (String)


75
76
77
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 75

def point_of_contact_phone_number
  @point_of_contact_phone_number
end

#shipping_preferenceString

Preference for device delivery.

Returns:

  • (String)


79
80
81
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 79

def shipping_preference
  @shipping_preference
end

#shipping_vendorString

Shipping vendor of choice for orace to customer shipping.

Returns:

  • (String)


83
84
85
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 83

def shipping_vendor
  @shipping_vendor
end

#subscription_idString

ID provided to customer after successful subscription to Rover Stations.

Returns:

  • (String)


95
96
97
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 95

def subscription_id
  @subscription_id
end

#super_user_passwordString

Root password for the rover cluster.

Returns:

  • (String)


59
60
61
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 59

def super_user_password
  @super_user_password
end

#system_tagsHash<String, Hash<String, Object>>

The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{free-tier-retain: true}`

Returns:

  • (Hash<String, Hash<String, Object>>)


144
145
146
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 144

def system_tags
  @system_tags
end

#time_pickup_expectedDateTime

Expected date when customer wants to pickup the cluster if they chose customer pickup.

Returns:

  • (DateTime)


87
88
89
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 87

def time_pickup_expected
  @time_pickup_expected
end

#unlock_passphraseString

Password to unlock the rover cluster.

Returns:

  • (String)


67
68
69
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 67

def unlock_passphrase
  @unlock_passphrase
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 147

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'cluster_size': :'clusterSize',
    'customer_shipping_address': :'customerShippingAddress',
    'cluster_workloads': :'clusterWorkloads',
    'cluster_type': :'clusterType',
    'super_user_password': :'superUserPassword',
    'enclosure_type': :'enclosureType',
    'unlock_passphrase': :'unlockPassphrase',
    'point_of_contact': :'pointOfContact',
    'point_of_contact_phone_number': :'pointOfContactPhoneNumber',
    'shipping_preference': :'shippingPreference',
    'shipping_vendor': :'shippingVendor',
    'time_pickup_expected': :'timePickupExpected',
    'oracle_shipping_tracking_url': :'oracleShippingTrackingUrl',
    'subscription_id': :'subscriptionId',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_state_details': :'lifecycleStateDetails',
    'is_import_requested': :'isImportRequested',
    'import_compartment_id': :'importCompartmentId',
    'import_file_bucket': :'importFileBucket',
    'data_validation_code': :'dataValidationCode',
    'master_key_id': :'masterKeyId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 181

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'compartment_id': :'String',
    'cluster_size': :'Integer',
    'customer_shipping_address': :'OCI::Rover::Models::ShippingAddress',
    'cluster_workloads': :'Array<OCI::Rover::Models::RoverWorkload>',
    'cluster_type': :'String',
    'super_user_password': :'String',
    'enclosure_type': :'String',
    'unlock_passphrase': :'String',
    'point_of_contact': :'String',
    'point_of_contact_phone_number': :'String',
    'shipping_preference': :'String',
    'shipping_vendor': :'String',
    'time_pickup_expected': :'DateTime',
    'oracle_shipping_tracking_url': :'String',
    'subscription_id': :'String',
    'lifecycle_state': :'String',
    'lifecycle_state_details': :'String',
    'is_import_requested': :'BOOLEAN',
    'import_compartment_id': :'String',
    'import_file_bucket': :'String',
    'data_validation_code': :'String',
    'master_key_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 450

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    cluster_size == other.cluster_size &&
    customer_shipping_address == other.customer_shipping_address &&
    cluster_workloads == other.cluster_workloads &&
    cluster_type == other.cluster_type &&
    super_user_password == other.super_user_password &&
    enclosure_type == other.enclosure_type &&
    unlock_passphrase == other.unlock_passphrase &&
    point_of_contact == other.point_of_contact &&
    point_of_contact_phone_number == other.point_of_contact_phone_number &&
    shipping_preference == other.shipping_preference &&
    shipping_vendor == other.shipping_vendor &&
    time_pickup_expected == other.time_pickup_expected &&
    oracle_shipping_tracking_url == other.oracle_shipping_tracking_url &&
    subscription_id == other.subscription_id &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_state_details == other.lifecycle_state_details &&
    is_import_requested == other.is_import_requested &&
    import_compartment_id == other.import_compartment_id &&
    import_file_bucket == other.import_file_bucket &&
    data_validation_code == other.data_validation_code &&
    master_key_id == other.master_key_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 505

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


485
486
487
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 485

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



494
495
496
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 494

def hash
  [display_name, compartment_id, cluster_size, customer_shipping_address, cluster_workloads, cluster_type, super_user_password, enclosure_type, unlock_passphrase, point_of_contact, point_of_contact_phone_number, shipping_preference, shipping_vendor, time_pickup_expected, oracle_shipping_tracking_url, subscription_id, lifecycle_state, lifecycle_state_details, is_import_requested, import_compartment_id, import_file_bucket, data_validation_code, master_key_id, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



538
539
540
541
542
543
544
545
546
547
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 538

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



532
533
534
# File 'lib/oci/rover/models/create_rover_cluster_details.rb', line 532

def to_s
  to_hash.to_s
end