Class: OCI::Rover::Models::RoverCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/rover/models/rover_cluster.rb

Overview

Description of RoverCluster.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
ENCLOSURE_TYPE_ENUM =
[
  ENCLOSURE_TYPE_RUGGADIZED = 'RUGGADIZED'.freeze,
  ENCLOSURE_TYPE_NON_RUGGADIZED = 'NON_RUGGADIZED'.freeze,
  ENCLOSURE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
CLUSTER_TYPE_ENUM =
[
  CLUSTER_TYPE_STANDALONE = 'STANDALONE'.freeze,
  CLUSTER_TYPE_STATION = 'STATION'.freeze,
  CLUSTER_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
SHIPPING_PREFERENCE_ENUM =
[
  SHIPPING_PREFERENCE_ORACLE_SHIPPED = 'ORACLE_SHIPPED'.freeze,
  SHIPPING_PREFERENCE_CUSTOMER_PICKUP = 'CUSTOMER_PICKUP'.freeze,
  SHIPPING_PREFERENCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RoverCluster

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
# File 'lib/oci/rover/models/rover_cluster.rb', line 343

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.cluster_size = attributes[:'clusterSize'] if attributes[:'clusterSize']

  raise 'You cannot provide both :clusterSize and :cluster_size' if attributes.key?(:'clusterSize') && attributes.key?(:'cluster_size')

  self.cluster_size = attributes[:'cluster_size'] if attributes[:'cluster_size']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_state_details = attributes[:'lifecycleStateDetails'] if attributes[:'lifecycleStateDetails']

  raise 'You cannot provide both :lifecycleStateDetails and :lifecycle_state_details' if attributes.key?(:'lifecycleStateDetails') && attributes.key?(:'lifecycle_state_details')

  self.lifecycle_state_details = attributes[:'lifecycle_state_details'] if attributes[:'lifecycle_state_details']

  self.customer_shipping_address = attributes[:'customerShippingAddress'] if attributes[:'customerShippingAddress']

  raise 'You cannot provide both :customerShippingAddress and :customer_shipping_address' if attributes.key?(:'customerShippingAddress') && attributes.key?(:'customer_shipping_address')

  self.customer_shipping_address = attributes[:'customer_shipping_address'] if attributes[:'customer_shipping_address']

  self.nodes = attributes[:'nodes'] if attributes[:'nodes']

  self.enclosure_type = attributes[:'enclosureType'] if attributes[:'enclosureType']

  raise 'You cannot provide both :enclosureType and :enclosure_type' if attributes.key?(:'enclosureType') && attributes.key?(:'enclosure_type')

  self.enclosure_type = attributes[:'enclosure_type'] if attributes[:'enclosure_type']

  self.time_customer_received = attributes[:'timeCustomerReceived'] if attributes[:'timeCustomerReceived']

  raise 'You cannot provide both :timeCustomerReceived and :time_customer_received' if attributes.key?(:'timeCustomerReceived') && attributes.key?(:'time_customer_received')

  self.time_customer_received = attributes[:'time_customer_received'] if attributes[:'time_customer_received']

  self.time_customer_returned = attributes[:'timeCustomerReturned'] if attributes[:'timeCustomerReturned']

  raise 'You cannot provide both :timeCustomerReturned and :time_customer_returned' if attributes.key?(:'timeCustomerReturned') && attributes.key?(:'time_customer_returned')

  self.time_customer_returned = attributes[:'time_customer_returned'] if attributes[:'time_customer_returned']

  self.delivery_tracking_info = attributes[:'deliveryTrackingInfo'] if attributes[:'deliveryTrackingInfo']

  raise 'You cannot provide both :deliveryTrackingInfo and :delivery_tracking_info' if attributes.key?(:'deliveryTrackingInfo') && attributes.key?(:'delivery_tracking_info')

  self.delivery_tracking_info = attributes[:'delivery_tracking_info'] if attributes[:'delivery_tracking_info']

  self.cluster_workloads = attributes[:'clusterWorkloads'] if attributes[:'clusterWorkloads']

  raise 'You cannot provide both :clusterWorkloads and :cluster_workloads' if attributes.key?(:'clusterWorkloads') && attributes.key?(:'cluster_workloads')

  self.cluster_workloads = attributes[:'cluster_workloads'] if attributes[:'cluster_workloads']

  self.cluster_type = attributes[:'clusterType'] if attributes[:'clusterType']
  self.cluster_type = "STANDALONE" if cluster_type.nil? && !attributes.key?(:'clusterType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :clusterType and :cluster_type' if attributes.key?(:'clusterType') && attributes.key?(:'cluster_type')

  self.cluster_type = attributes[:'cluster_type'] if attributes[:'cluster_type']
  self.cluster_type = "STANDALONE" if cluster_type.nil? && !attributes.key?(:'clusterType') && !attributes.key?(:'cluster_type') # rubocop:disable Style/StringLiterals

  self.subscription_id = attributes[:'subscriptionId'] if attributes[:'subscriptionId']

  raise 'You cannot provide both :subscriptionId and :subscription_id' if attributes.key?(:'subscriptionId') && attributes.key?(:'subscription_id')

  self.subscription_id = attributes[:'subscription_id'] if attributes[:'subscription_id']

  self.exterior_door_code = attributes[:'exteriorDoorCode'] if attributes[:'exteriorDoorCode']

  raise 'You cannot provide both :exteriorDoorCode and :exterior_door_code' if attributes.key?(:'exteriorDoorCode') && attributes.key?(:'exterior_door_code')

  self.exterior_door_code = attributes[:'exterior_door_code'] if attributes[:'exterior_door_code']

  self.interior_alarm_disarm_code = attributes[:'interiorAlarmDisarmCode'] if attributes[:'interiorAlarmDisarmCode']

  raise 'You cannot provide both :interiorAlarmDisarmCode and :interior_alarm_disarm_code' if attributes.key?(:'interiorAlarmDisarmCode') && attributes.key?(:'interior_alarm_disarm_code')

  self.interior_alarm_disarm_code = attributes[:'interior_alarm_disarm_code'] if attributes[:'interior_alarm_disarm_code']

  self.super_user_password = attributes[:'superUserPassword'] if attributes[:'superUserPassword']

  raise 'You cannot provide both :superUserPassword and :super_user_password' if attributes.key?(:'superUserPassword') && attributes.key?(:'super_user_password')

  self.super_user_password = attributes[:'super_user_password'] if attributes[:'super_user_password']

  self.unlock_passphrase = attributes[:'unlockPassphrase'] if attributes[:'unlockPassphrase']

  raise 'You cannot provide both :unlockPassphrase and :unlock_passphrase' if attributes.key?(:'unlockPassphrase') && attributes.key?(:'unlock_passphrase')

  self.unlock_passphrase = attributes[:'unlock_passphrase'] if attributes[:'unlock_passphrase']

  self.point_of_contact = attributes[:'pointOfContact'] if attributes[:'pointOfContact']

  raise 'You cannot provide both :pointOfContact and :point_of_contact' if attributes.key?(:'pointOfContact') && attributes.key?(:'point_of_contact')

  self.point_of_contact = attributes[:'point_of_contact'] if attributes[:'point_of_contact']

  self.point_of_contact_phone_number = attributes[:'pointOfContactPhoneNumber'] if attributes[:'pointOfContactPhoneNumber']

  raise 'You cannot provide both :pointOfContactPhoneNumber and :point_of_contact_phone_number' if attributes.key?(:'pointOfContactPhoneNumber') && attributes.key?(:'point_of_contact_phone_number')

  self.point_of_contact_phone_number = attributes[:'point_of_contact_phone_number'] if attributes[:'point_of_contact_phone_number']

  self.shipping_preference = attributes[:'shippingPreference'] if attributes[:'shippingPreference']
  self.shipping_preference = "ORACLE_SHIPPED" if shipping_preference.nil? && !attributes.key?(:'shippingPreference') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :shippingPreference and :shipping_preference' if attributes.key?(:'shippingPreference') && attributes.key?(:'shipping_preference')

  self.shipping_preference = attributes[:'shipping_preference'] if attributes[:'shipping_preference']
  self.shipping_preference = "ORACLE_SHIPPED" if shipping_preference.nil? && !attributes.key?(:'shippingPreference') && !attributes.key?(:'shipping_preference') # rubocop:disable Style/StringLiterals

  self.oracle_shipping_tracking_url = attributes[:'oracleShippingTrackingUrl'] if attributes[:'oracleShippingTrackingUrl']

  raise 'You cannot provide both :oracleShippingTrackingUrl and :oracle_shipping_tracking_url' if attributes.key?(:'oracleShippingTrackingUrl') && attributes.key?(:'oracle_shipping_tracking_url')

  self.oracle_shipping_tracking_url = attributes[:'oracle_shipping_tracking_url'] if attributes[:'oracle_shipping_tracking_url']

  self.shipping_vendor = attributes[:'shippingVendor'] if attributes[:'shippingVendor']

  raise 'You cannot provide both :shippingVendor and :shipping_vendor' if attributes.key?(:'shippingVendor') && attributes.key?(:'shipping_vendor')

  self.shipping_vendor = attributes[:'shipping_vendor'] if attributes[:'shipping_vendor']

  self.time_pickup_expected = attributes[:'timePickupExpected'] if attributes[:'timePickupExpected']

  raise 'You cannot provide both :timePickupExpected and :time_pickup_expected' if attributes.key?(:'timePickupExpected') && attributes.key?(:'time_pickup_expected')

  self.time_pickup_expected = attributes[:'time_pickup_expected'] if attributes[:'time_pickup_expected']

  self.time_return_window_starts = attributes[:'timeReturnWindowStarts'] if attributes[:'timeReturnWindowStarts']

  raise 'You cannot provide both :timeReturnWindowStarts and :time_return_window_starts' if attributes.key?(:'timeReturnWindowStarts') && attributes.key?(:'time_return_window_starts')

  self.time_return_window_starts = attributes[:'time_return_window_starts'] if attributes[:'time_return_window_starts']

  self.time_return_window_ends = attributes[:'timeReturnWindowEnds'] if attributes[:'timeReturnWindowEnds']

  raise 'You cannot provide both :timeReturnWindowEnds and :time_return_window_ends' if attributes.key?(:'timeReturnWindowEnds') && attributes.key?(:'time_return_window_ends')

  self.time_return_window_ends = attributes[:'time_return_window_ends'] if attributes[:'time_return_window_ends']

  self.return_shipping_label_uri = attributes[:'returnShippingLabelUri'] if attributes[:'returnShippingLabelUri']

  raise 'You cannot provide both :returnShippingLabelUri and :return_shipping_label_uri' if attributes.key?(:'returnShippingLabelUri') && attributes.key?(:'return_shipping_label_uri')

  self.return_shipping_label_uri = attributes[:'return_shipping_label_uri'] if attributes[:'return_shipping_label_uri']

  self.is_import_requested = attributes[:'isImportRequested'] unless attributes[:'isImportRequested'].nil?

  raise 'You cannot provide both :isImportRequested and :is_import_requested' if attributes.key?(:'isImportRequested') && attributes.key?(:'is_import_requested')

  self.is_import_requested = attributes[:'is_import_requested'] unless attributes[:'is_import_requested'].nil?

  self.import_compartment_id = attributes[:'importCompartmentId'] if attributes[:'importCompartmentId']

  raise 'You cannot provide both :importCompartmentId and :import_compartment_id' if attributes.key?(:'importCompartmentId') && attributes.key?(:'import_compartment_id')

  self.import_compartment_id = attributes[:'import_compartment_id'] if attributes[:'import_compartment_id']

  self.import_file_bucket = attributes[:'importFileBucket'] if attributes[:'importFileBucket']

  raise 'You cannot provide both :importFileBucket and :import_file_bucket' if attributes.key?(:'importFileBucket') && attributes.key?(:'import_file_bucket')

  self.import_file_bucket = attributes[:'import_file_bucket'] if attributes[:'import_file_bucket']

  self.data_validation_code = attributes[:'dataValidationCode'] if attributes[:'dataValidationCode']

  raise 'You cannot provide both :dataValidationCode and :data_validation_code' if attributes.key?(:'dataValidationCode') && attributes.key?(:'data_validation_code')

  self.data_validation_code = attributes[:'data_validation_code'] if attributes[:'data_validation_code']

  self.image_export_par = attributes[:'imageExportPar'] if attributes[:'imageExportPar']

  raise 'You cannot provide both :imageExportPar and :image_export_par' if attributes.key?(:'imageExportPar') && attributes.key?(:'image_export_par')

  self.image_export_par = attributes[:'image_export_par'] if attributes[:'image_export_par']

  self.master_key_id = attributes[:'masterKeyId'] if attributes[:'masterKeyId']

  raise 'You cannot provide both :masterKeyId and :master_key_id' if attributes.key?(:'masterKeyId') && attributes.key?(:'master_key_id')

  self.master_key_id = attributes[:'master_key_id'] if attributes[:'master_key_id']

  self.tags = attributes[:'tags'] if attributes[:'tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#cluster_sizeInteger

**[Required]** Size of the cluster.

Returns:

  • (Integer)


53
54
55
# File 'lib/oci/rover/models/rover_cluster.rb', line 53

def cluster_size
  @cluster_size
end

#cluster_typeString

Type of cluster.

Returns:

  • (String)


96
97
98
# File 'lib/oci/rover/models/rover_cluster.rb', line 96

def cluster_type
  @cluster_type
end

#cluster_workloadsArray<OCI::Rover::Models::RoverWorkload>

List of existing workloads that should be provisioned on the nodes.



92
93
94
# File 'lib/oci/rover/models/rover_cluster.rb', line 92

def cluster_workloads
  @cluster_workloads
end

#compartment_idString

**[Required]** The OCID of the compartment containing the RoverCluster.

Returns:

  • (String)


45
46
47
# File 'lib/oci/rover/models/rover_cluster.rb', line 45

def compartment_id
  @compartment_id
end

#customer_shipping_addressOCI::Rover::Models::ShippingAddress



68
69
70
# File 'lib/oci/rover/models/rover_cluster.rb', line 68

def customer_shipping_address
  @customer_shipping_address
end

#data_validation_codeString

Validation code returned by data validation tool. Required for return shipping label generation if data import was requested.

Returns:

  • (String)


168
169
170
# File 'lib/oci/rover/models/rover_cluster.rb', line 168

def data_validation_code
  @data_validation_code
end

#defined_tagsHash<String, Hash<String, Object>>

The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


195
196
197
# File 'lib/oci/rover/models/rover_cluster.rb', line 195

def defined_tags
  @defined_tags
end

#delivery_tracking_infoString

Tracking information for device shipping.

Returns:

  • (String)


88
89
90
# File 'lib/oci/rover/models/rover_cluster.rb', line 88

def delivery_tracking_info
  @delivery_tracking_info
end

#display_nameString

**[Required]** A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


49
50
51
# File 'lib/oci/rover/models/rover_cluster.rb', line 49

def display_name
  @display_name
end

#enclosure_typeString

The type of enclosure rover nodes in this cluster are shipped in.

Returns:

  • (String)


76
77
78
# File 'lib/oci/rover/models/rover_cluster.rb', line 76

def enclosure_type
  @enclosure_type
end

#exterior_door_codeString

Service generated code for the exterior trailer door of the trailer.

Returns:

  • (String)


104
105
106
# File 'lib/oci/rover/models/rover_cluster.rb', line 104

def exterior_door_code
  @exterior_door_code
end

#freeform_tagsHash<String, String>

The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`

Returns:

  • (Hash<String, String>)


188
189
190
# File 'lib/oci/rover/models/rover_cluster.rb', line 188

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The OCID of RoverCluster.

Returns:

  • (String)


41
42
43
# File 'lib/oci/rover/models/rover_cluster.rb', line 41

def id
  @id
end

#image_export_parString

The link to pre-authenticated request for a bucket where image workloads are moved.

Returns:

  • (String)


172
173
174
# File 'lib/oci/rover/models/rover_cluster.rb', line 172

def image_export_par
  @image_export_par
end

#import_compartment_idString

An OCID of a compartment where data will be imported to upon Rover cluster return.

Returns:

  • (String)


160
161
162
# File 'lib/oci/rover/models/rover_cluster.rb', line 160

def import_compartment_id
  @import_compartment_id
end

#import_file_bucketString

Name of a bucket where files from NFS share will be imported to upon Rover cluster return.

Returns:

  • (String)


164
165
166
# File 'lib/oci/rover/models/rover_cluster.rb', line 164

def import_file_bucket
  @import_file_bucket
end

#interior_alarm_disarm_codeString

Service generated code to disarm the interior alarm of the trailer.

Returns:

  • (String)


108
109
110
# File 'lib/oci/rover/models/rover_cluster.rb', line 108

def interior_alarm_disarm_code
  @interior_alarm_disarm_code
end

#is_import_requestedBOOLEAN

The flag indicating that customer requests data to be imported to OCI upon Rover cluster return.

Returns:

  • (BOOLEAN)


156
157
158
# File 'lib/oci/rover/models/rover_cluster.rb', line 156

def is_import_requested
  @is_import_requested
end

#lifecycle_stateString

**[Required]** The current state of the RoverCluster.

Returns:

  • (String)


61
62
63
# File 'lib/oci/rover/models/rover_cluster.rb', line 61

def lifecycle_state
  @lifecycle_state
end

#lifecycle_state_detailsString

A property that can contain details on the lifecycle.

Returns:

  • (String)


65
66
67
# File 'lib/oci/rover/models/rover_cluster.rb', line 65

def lifecycle_state_details
  @lifecycle_state_details
end

#master_key_idString

Customer provided master key ID to encrypt secret information. If not provided, Rover's master key will be used for encryption.

Returns:

  • (String)


176
177
178
# File 'lib/oci/rover/models/rover_cluster.rb', line 176

def master_key_id
  @master_key_id
end

#nodesArray<OCI::Rover::Models::RoverNodeSummary>

The summary of nodes that are part of this cluster.



72
73
74
# File 'lib/oci/rover/models/rover_cluster.rb', line 72

def nodes
  @nodes
end

#oracle_shipping_tracking_urlString

Tracking Url for the shipped Rover Cluster.

Returns:

  • (String)


132
133
134
# File 'lib/oci/rover/models/rover_cluster.rb', line 132

def oracle_shipping_tracking_url
  @oracle_shipping_tracking_url
end

#point_of_contactString

Name of point of contact for this order if customer is picking up.

Returns:

  • (String)


120
121
122
# File 'lib/oci/rover/models/rover_cluster.rb', line 120

def point_of_contact
  @point_of_contact
end

#point_of_contact_phone_numberString

Phone number of point of contact for this order if customer is picking up.

Returns:

  • (String)


124
125
126
# File 'lib/oci/rover/models/rover_cluster.rb', line 124

def point_of_contact_phone_number
  @point_of_contact_phone_number
end

#return_shipping_label_uriString

Uri to download return shipping label.

Returns:

  • (String)


152
153
154
# File 'lib/oci/rover/models/rover_cluster.rb', line 152

def return_shipping_label_uri
  @return_shipping_label_uri
end

#shipping_preferenceString

Preference for device delivery.

Returns:

  • (String)


128
129
130
# File 'lib/oci/rover/models/rover_cluster.rb', line 128

def shipping_preference
  @shipping_preference
end

#shipping_vendorString

Shipping vendor of choice for orace to customer shipping.

Returns:

  • (String)


136
137
138
# File 'lib/oci/rover/models/rover_cluster.rb', line 136

def shipping_vendor
  @shipping_vendor
end

#subscription_idString

ID provided to customer after successful subscription to Rover Stations.

Returns:

  • (String)


100
101
102
# File 'lib/oci/rover/models/rover_cluster.rb', line 100

def subscription_id
  @subscription_id
end

#super_user_passwordString

Root password for the rover cluster.

Returns:

  • (String)


112
113
114
# File 'lib/oci/rover/models/rover_cluster.rb', line 112

def super_user_password
  @super_user_password
end

#system_tagsHash<String, Hash<String, Object>>

The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{free-tier-retain: true}`

Returns:

  • (Hash<String, Hash<String, Object>>)


202
203
204
# File 'lib/oci/rover/models/rover_cluster.rb', line 202

def system_tags
  @system_tags
end

#tagsString

The tags associated with tagSlug.

Returns:

  • (String)


181
182
183
# File 'lib/oci/rover/models/rover_cluster.rb', line 181

def tags
  @tags
end

#time_createdDateTime

The time the the RoverCluster was created. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


57
58
59
# File 'lib/oci/rover/models/rover_cluster.rb', line 57

def time_created
  @time_created
end

#time_customer_receivedDateTime

Time when customer received the cluster.

Returns:

  • (DateTime)


80
81
82
# File 'lib/oci/rover/models/rover_cluster.rb', line 80

def time_customer_received
  @time_customer_received
end

#time_customer_returnedDateTime

Time when customer returned the cluster.

Returns:

  • (DateTime)


84
85
86
# File 'lib/oci/rover/models/rover_cluster.rb', line 84

def time_customer_returned
  @time_customer_returned
end

#time_pickup_expectedDateTime

Expected date when customer wants to pickup the device if they chose customer pickup.

Returns:

  • (DateTime)


140
141
142
# File 'lib/oci/rover/models/rover_cluster.rb', line 140

def time_pickup_expected
  @time_pickup_expected
end

#time_return_window_endsDateTime

End time for the window to pickup the device from customer.

Returns:

  • (DateTime)


148
149
150
# File 'lib/oci/rover/models/rover_cluster.rb', line 148

def time_return_window_ends
  @time_return_window_ends
end

#time_return_window_startsDateTime

Start time for the window to pickup the device from customer.

Returns:

  • (DateTime)


144
145
146
# File 'lib/oci/rover/models/rover_cluster.rb', line 144

def time_return_window_starts
  @time_return_window_starts
end

#unlock_passphraseString

Password to unlock the rover cluster.

Returns:

  • (String)


116
117
118
# File 'lib/oci/rover/models/rover_cluster.rb', line 116

def unlock_passphrase
  @unlock_passphrase
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/oci/rover/models/rover_cluster.rb', line 205

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'cluster_size': :'clusterSize',
    'time_created': :'timeCreated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_state_details': :'lifecycleStateDetails',
    'customer_shipping_address': :'customerShippingAddress',
    'nodes': :'nodes',
    'enclosure_type': :'enclosureType',
    'time_customer_received': :'timeCustomerReceived',
    'time_customer_returned': :'timeCustomerReturned',
    'delivery_tracking_info': :'deliveryTrackingInfo',
    'cluster_workloads': :'clusterWorkloads',
    'cluster_type': :'clusterType',
    'subscription_id': :'subscriptionId',
    'exterior_door_code': :'exteriorDoorCode',
    'interior_alarm_disarm_code': :'interiorAlarmDisarmCode',
    'super_user_password': :'superUserPassword',
    'unlock_passphrase': :'unlockPassphrase',
    'point_of_contact': :'pointOfContact',
    'point_of_contact_phone_number': :'pointOfContactPhoneNumber',
    'shipping_preference': :'shippingPreference',
    'oracle_shipping_tracking_url': :'oracleShippingTrackingUrl',
    'shipping_vendor': :'shippingVendor',
    'time_pickup_expected': :'timePickupExpected',
    'time_return_window_starts': :'timeReturnWindowStarts',
    'time_return_window_ends': :'timeReturnWindowEnds',
    'return_shipping_label_uri': :'returnShippingLabelUri',
    'is_import_requested': :'isImportRequested',
    'import_compartment_id': :'importCompartmentId',
    'import_file_bucket': :'importFileBucket',
    'data_validation_code': :'dataValidationCode',
    'image_export_par': :'imageExportPar',
    'master_key_id': :'masterKeyId',
    'tags': :'tags',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/oci/rover/models/rover_cluster.rb', line 252

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'cluster_size': :'Integer',
    'time_created': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_state_details': :'String',
    'customer_shipping_address': :'OCI::Rover::Models::ShippingAddress',
    'nodes': :'Array<OCI::Rover::Models::RoverNodeSummary>',
    'enclosure_type': :'String',
    'time_customer_received': :'DateTime',
    'time_customer_returned': :'DateTime',
    'delivery_tracking_info': :'String',
    'cluster_workloads': :'Array<OCI::Rover::Models::RoverWorkload>',
    'cluster_type': :'String',
    'subscription_id': :'String',
    'exterior_door_code': :'String',
    'interior_alarm_disarm_code': :'String',
    'super_user_password': :'String',
    'unlock_passphrase': :'String',
    'point_of_contact': :'String',
    'point_of_contact_phone_number': :'String',
    'shipping_preference': :'String',
    'oracle_shipping_tracking_url': :'String',
    'shipping_vendor': :'String',
    'time_pickup_expected': :'DateTime',
    'time_return_window_starts': :'DateTime',
    'time_return_window_ends': :'DateTime',
    'return_shipping_label_uri': :'String',
    'is_import_requested': :'BOOLEAN',
    'import_compartment_id': :'String',
    'import_file_bucket': :'String',
    'data_validation_code': :'String',
    'image_export_par': :'String',
    'master_key_id': :'String',
    'tags': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/oci/rover/models/rover_cluster.rb', line 635

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    cluster_size == other.cluster_size &&
    time_created == other.time_created &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_state_details == other.lifecycle_state_details &&
    customer_shipping_address == other.customer_shipping_address &&
    nodes == other.nodes &&
    enclosure_type == other.enclosure_type &&
    time_customer_received == other.time_customer_received &&
    time_customer_returned == other.time_customer_returned &&
    delivery_tracking_info == other.delivery_tracking_info &&
    cluster_workloads == other.cluster_workloads &&
    cluster_type == other.cluster_type &&
    subscription_id == other.subscription_id &&
    exterior_door_code == other.exterior_door_code &&
    interior_alarm_disarm_code == other.interior_alarm_disarm_code &&
    super_user_password == other.super_user_password &&
    unlock_passphrase == other.unlock_passphrase &&
    point_of_contact == other.point_of_contact &&
    point_of_contact_phone_number == other.point_of_contact_phone_number &&
    shipping_preference == other.shipping_preference &&
    oracle_shipping_tracking_url == other.oracle_shipping_tracking_url &&
    shipping_vendor == other.shipping_vendor &&
    time_pickup_expected == other.time_pickup_expected &&
    time_return_window_starts == other.time_return_window_starts &&
    time_return_window_ends == other.time_return_window_ends &&
    return_shipping_label_uri == other.return_shipping_label_uri &&
    is_import_requested == other.is_import_requested &&
    import_compartment_id == other.import_compartment_id &&
    import_file_bucket == other.import_file_bucket &&
    data_validation_code == other.data_validation_code &&
    image_export_par == other.image_export_par &&
    master_key_id == other.master_key_id &&
    tags == other.tags &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
# File 'lib/oci/rover/models/rover_cluster.rb', line 703

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


683
684
685
# File 'lib/oci/rover/models/rover_cluster.rb', line 683

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



692
693
694
# File 'lib/oci/rover/models/rover_cluster.rb', line 692

def hash
  [id, compartment_id, display_name, cluster_size, time_created, lifecycle_state, lifecycle_state_details, customer_shipping_address, nodes, enclosure_type, time_customer_received, time_customer_returned, delivery_tracking_info, cluster_workloads, cluster_type, subscription_id, exterior_door_code, interior_alarm_disarm_code, super_user_password, unlock_passphrase, point_of_contact, point_of_contact_phone_number, shipping_preference, oracle_shipping_tracking_url, shipping_vendor, time_pickup_expected, time_return_window_starts, time_return_window_ends, return_shipping_label_uri, is_import_requested, import_compartment_id, import_file_bucket, data_validation_code, image_export_par, master_key_id, tags, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



736
737
738
739
740
741
742
743
744
745
# File 'lib/oci/rover/models/rover_cluster.rb', line 736

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



730
731
732
# File 'lib/oci/rover/models/rover_cluster.rb', line 730

def to_s
  to_hash.to_s
end