Class: OCI::Rover::Models::RoverEntitlement
- Inherits:
-
Object
- Object
- OCI::Rover::Models::RoverEntitlement
- Defined in:
- lib/oci/rover/models/rover_entitlement.rb
Overview
Information about a RoverEntitlement.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The compartment Id for the entitlement.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any.
-
#display_name ⇒ String
A user-friendly name.
-
#entitlement_details ⇒ String
Details about the entitlement.
-
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any.
-
#id ⇒ String
**[Required]** A property that can uniquely identify the rover entitlement.
-
#lifecycle_state ⇒ String
**[Required]** Lifecyclestate for the entitlement.
-
#lifecycle_state_details ⇒ String
A property that can contain details on the lifecycle.
-
#requestor_email ⇒ String
**[Required]** Requestor email for the entitlement.
-
#requestor_name ⇒ String
**[Required]** Requestor name for the entitlement.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
-
#tenant_id ⇒ String
tenant Id.
-
#time_created ⇒ DateTime
Time of creation for the entitlement.
-
#time_updated ⇒ DateTime
Time when the entitlement was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RoverEntitlement
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RoverEntitlement
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 148 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.tenant_id = attributes[:'tenantId'] if attributes[:'tenantId'] raise 'You cannot provide both :tenantId and :tenant_id' if attributes.key?(:'tenantId') && attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] if attributes[:'tenant_id'] self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.requestor_name = attributes[:'requestorName'] if attributes[:'requestorName'] raise 'You cannot provide both :requestorName and :requestor_name' if attributes.key?(:'requestorName') && attributes.key?(:'requestor_name') self.requestor_name = attributes[:'requestor_name'] if attributes[:'requestor_name'] self.requestor_email = attributes[:'requestorEmail'] if attributes[:'requestorEmail'] raise 'You cannot provide both :requestorEmail and :requestor_email' if attributes.key?(:'requestorEmail') && attributes.key?(:'requestor_email') self.requestor_email = attributes[:'requestor_email'] if attributes[:'requestor_email'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.entitlement_details = attributes[:'entitlementDetails'] if attributes[:'entitlementDetails'] raise 'You cannot provide both :entitlementDetails and :entitlement_details' if attributes.key?(:'entitlementDetails') && attributes.key?(:'entitlement_details') self.entitlement_details = attributes[:'entitlement_details'] if attributes[:'entitlement_details'] self.lifecycle_state_details = attributes[:'lifecycleStateDetails'] if attributes[:'lifecycleStateDetails'] raise 'You cannot provide both :lifecycleStateDetails and :lifecycle_state_details' if attributes.key?(:'lifecycleStateDetails') && attributes.key?(:'lifecycle_state_details') self.lifecycle_state_details = attributes[:'lifecycle_state_details'] if attributes[:'lifecycle_state_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The compartment Id for the entitlement.
29 30 31 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 29 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
75 76 77 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 75 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
33 34 35 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 33 def display_name @display_name end |
#entitlement_details ⇒ String
Details about the entitlement.
49 50 51 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 49 def entitlement_details @entitlement_details end |
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
68 69 70 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 68 def @freeform_tags end |
#id ⇒ String
**[Required]** A property that can uniquely identify the rover entitlement.
25 26 27 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 25 def id @id end |
#lifecycle_state ⇒ String
**[Required]** Lifecyclestate for the entitlement.
45 46 47 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 45 def lifecycle_state @lifecycle_state end |
#lifecycle_state_details ⇒ String
A property that can contain details on the lifecycle.
53 54 55 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 53 def lifecycle_state_details @lifecycle_state_details end |
#requestor_email ⇒ String
**[Required]** Requestor email for the entitlement.
41 42 43 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 41 def requestor_email @requestor_email end |
#requestor_name ⇒ String
**[Required]** Requestor name for the entitlement.
37 38 39 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 37 def requestor_name @requestor_name end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{free-tier-retain: true}`
82 83 84 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 82 def @system_tags end |
#tenant_id ⇒ String
tenant Id.
21 22 23 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 21 def tenant_id @tenant_id end |
#time_created ⇒ DateTime
Time of creation for the entitlement.
57 58 59 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 57 def time_created @time_created end |
#time_updated ⇒ DateTime
Time when the entitlement was last updated.
61 62 63 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 61 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 85 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'tenant_id': :'tenantId', 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'requestor_name': :'requestorName', 'requestor_email': :'requestorEmail', 'lifecycle_state': :'lifecycleState', 'entitlement_details': :'entitlementDetails', 'lifecycle_state_details': :'lifecycleStateDetails', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 107 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'tenant_id': :'String', 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'requestor_name': :'String', 'requestor_email': :'String', 'lifecycle_state': :'String', 'entitlement_details': :'String', 'lifecycle_state_details': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 255 def ==(other) return true if equal?(other) self.class == other.class && tenant_id == other.tenant_id && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && requestor_name == other.requestor_name && requestor_email == other.requestor_email && lifecycle_state == other.lifecycle_state && entitlement_details == other.entitlement_details && lifecycle_state_details == other.lifecycle_state_details && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 298 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
278 279 280 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 278 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
287 288 289 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 287 def hash [tenant_id, id, compartment_id, display_name, requestor_name, requestor_email, lifecycle_state, entitlement_details, lifecycle_state_details, time_created, time_updated, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
325 326 327 |
# File 'lib/oci/rover/models/rover_entitlement.rb', line 325 def to_s to_hash.to_s end |