Class: OCI::Rover::Models::ShippingAddress

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/rover/models/shipping_address.rb

Overview

Shipping address for rover devices.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ShippingAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :addressee (String)

    The value to assign to the #addressee property

  • :care_of (String)

    The value to assign to the #care_of property

  • :address1 (String)

    The value to assign to the #address1 property

  • :address2 (String)

    The value to assign to the #address2 property

  • :address3 (String)

    The value to assign to the #address3 property

  • :address4 (String)

    The value to assign to the #address4 property

  • :city_or_locality (String)

    The value to assign to the #city_or_locality property

  • :state_or_region (String)

    The value to assign to the #state_or_region property

  • :zipcode (String)

    The value to assign to the #zipcode property

  • :country (String)

    The value to assign to the #country property

  • :phone_number (String)

    The value to assign to the #phone_number property

  • :email (String)

    The value to assign to the #email property



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/rover/models/shipping_address.rb', line 116

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.addressee = attributes[:'addressee'] if attributes[:'addressee']

  self.care_of = attributes[:'careOf'] if attributes[:'careOf']

  raise 'You cannot provide both :careOf and :care_of' if attributes.key?(:'careOf') && attributes.key?(:'care_of')

  self.care_of = attributes[:'care_of'] if attributes[:'care_of']

  self.address1 = attributes[:'address1'] if attributes[:'address1']

  self.address2 = attributes[:'address2'] if attributes[:'address2']

  self.address3 = attributes[:'address3'] if attributes[:'address3']

  self.address4 = attributes[:'address4'] if attributes[:'address4']

  self.city_or_locality = attributes[:'cityOrLocality'] if attributes[:'cityOrLocality']

  raise 'You cannot provide both :cityOrLocality and :city_or_locality' if attributes.key?(:'cityOrLocality') && attributes.key?(:'city_or_locality')

  self.city_or_locality = attributes[:'city_or_locality'] if attributes[:'city_or_locality']

  self.state_or_region = attributes[:'stateOrRegion'] if attributes[:'stateOrRegion']

  raise 'You cannot provide both :stateOrRegion and :state_or_region' if attributes.key?(:'stateOrRegion') && attributes.key?(:'state_or_region')

  self.state_or_region = attributes[:'state_or_region'] if attributes[:'state_or_region']

  self.zipcode = attributes[:'zipcode'] if attributes[:'zipcode']

  self.country = attributes[:'country'] if attributes[:'country']

  self.phone_number = attributes[:'phoneNumber'] if attributes[:'phoneNumber']

  raise 'You cannot provide both :phoneNumber and :phone_number' if attributes.key?(:'phoneNumber') && attributes.key?(:'phone_number')

  self.phone_number = attributes[:'phone_number'] if attributes[:'phone_number']

  self.email = attributes[:'email'] if attributes[:'email']
end

Instance Attribute Details

#address1String

[Required] Address line 1.

Returns:

  • (String)


20
21
22
# File 'lib/oci/rover/models/shipping_address.rb', line 20

def address1
  @address1
end

#address2String

Address line 2.

Returns:

  • (String)


24
25
26
# File 'lib/oci/rover/models/shipping_address.rb', line 24

def address2
  @address2
end

#address3String

Address line 3.

Returns:

  • (String)


28
29
30
# File 'lib/oci/rover/models/shipping_address.rb', line 28

def address3
  @address3
end

#address4String

Address line 4.

Returns:

  • (String)


32
33
34
# File 'lib/oci/rover/models/shipping_address.rb', line 32

def address4
  @address4
end

#addresseeString

[Required] Addressee in shipping address.

Returns:

  • (String)


12
13
14
# File 'lib/oci/rover/models/shipping_address.rb', line 12

def addressee
  @addressee
end

#care_ofString

CareOf for shipping address.

Returns:

  • (String)


16
17
18
# File 'lib/oci/rover/models/shipping_address.rb', line 16

def care_of
  @care_of
end

#city_or_localityString

[Required] city or locality for shipping address.

Returns:

  • (String)


36
37
38
# File 'lib/oci/rover/models/shipping_address.rb', line 36

def city_or_locality
  @city_or_locality
end

#countryString

[Required] country for shipping address.

Returns:

  • (String)


48
49
50
# File 'lib/oci/rover/models/shipping_address.rb', line 48

def country
  @country
end

#emailString

recepient email address.

Returns:

  • (String)


56
57
58
# File 'lib/oci/rover/models/shipping_address.rb', line 56

def email
  @email
end

#phone_numberString

[Required] recepient phone number.

Returns:

  • (String)


52
53
54
# File 'lib/oci/rover/models/shipping_address.rb', line 52

def phone_number
  @phone_number
end

#state_or_regionString

[Required] state or region for shipping address.

Returns:

  • (String)


40
41
42
# File 'lib/oci/rover/models/shipping_address.rb', line 40

def state_or_region
  @state_or_region
end

#zipcodeString

[Required] zipcode for shipping address.

Returns:

  • (String)


44
45
46
# File 'lib/oci/rover/models/shipping_address.rb', line 44

def zipcode
  @zipcode
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/rover/models/shipping_address.rb', line 59

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'addressee': :'addressee',
    'care_of': :'careOf',
    'address1': :'address1',
    'address2': :'address2',
    'address3': :'address3',
    'address4': :'address4',
    'city_or_locality': :'cityOrLocality',
    'state_or_region': :'stateOrRegion',
    'zipcode': :'zipcode',
    'country': :'country',
    'phone_number': :'phoneNumber',
    'email': :'email'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/rover/models/shipping_address.rb', line 79

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'addressee': :'String',
    'care_of': :'String',
    'address1': :'String',
    'address2': :'String',
    'address3': :'String',
    'address4': :'String',
    'city_or_locality': :'String',
    'state_or_region': :'String',
    'zipcode': :'String',
    'country': :'String',
    'phone_number': :'String',
    'email': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/oci/rover/models/shipping_address.rb', line 170

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    addressee == other.addressee &&
    care_of == other.care_of &&
    address1 == other.address1 &&
    address2 == other.address2 &&
    address3 == other.address3 &&
    address4 == other.address4 &&
    city_or_locality == other.city_or_locality &&
    state_or_region == other.state_or_region &&
    zipcode == other.zipcode &&
    country == other.country &&
    phone_number == other.phone_number &&
    email == other.email
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/oci/rover/models/shipping_address.rb', line 211

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/oci/rover/models/shipping_address.rb', line 191

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



200
201
202
# File 'lib/oci/rover/models/shipping_address.rb', line 200

def hash
  [addressee, care_of, address1, address2, address3, address4, city_or_locality, state_or_region, zipcode, country, phone_number, email].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
# File 'lib/oci/rover/models/shipping_address.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



238
239
240
# File 'lib/oci/rover/models/shipping_address.rb', line 238

def to_s
  to_hash.to_s
end