Class: OCI::Rover::RoverNodeClient

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/rover/rover_node_client.rb

Overview

A description of the RoverCloudService API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ RoverNodeClient

Creates a new RoverNodeClient. Notes:

If a config is not specified, then the global OCI.config will be used.

This client is not thread-safe

Either a region or an endpoint must be specified.  If an endpoint is specified, it will be used instead of the
  region. A region may be specified in the config or via or the region parameter. If specified in both, then the
  region parameter will be used.

Parameters:

  • config (Config) (defaults to: nil)

    A Config object.

  • region (String) (defaults to: nil)

    A region used to determine the service endpoint. This will usually correspond to a value in OCI::Regions::REGION_ENUM, but may be an arbitrary string.

  • endpoint (String) (defaults to: nil)

    The fully qualified endpoint URL

  • signer (OCI::BaseSigner) (defaults to: nil)

    A signer implementation which can be used by this client. If this is not provided then a signer will be constructed via the provided config. One use case of this parameter is instance principals authentication, so that the instance principals signer can be provided to the client

  • proxy_settings (OCI::ApiClientProxySettings) (defaults to: nil)

    If your environment requires you to use a proxy server for outgoing HTTP requests the details for the proxy can be provided in this parameter

  • retry_config (OCI::Retry::RetryConfig) (defaults to: nil)

    The retry configuration for this service client. This represents the default retry configuration to apply across all operations. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/rover/rover_node_client.rb', line 53

def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil)
  # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers)
  # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals
  # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then
  # pass it to this constructor.
  #
  # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid
  # so try and load the config from the default file.
  config = OCI::Config.validate_and_build_config_with_signer(config, signer)

  signer = OCI::Signer.config_file_auth_builder(config) if signer.nil?

  @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings)
  @retry_config = retry_config

  if endpoint
    @endpoint = endpoint + '/20201210'
  else
    region ||= config.region
    region ||= signer.region if signer.respond_to?(:region)
    self.region = region
  end
  logger.info "RoverNodeClient endpoint set to '#{@endpoint}'." if logger
end

Instance Attribute Details

#api_clientOCI::ApiClient (readonly)

Client used to make HTTP requests.

Returns:



13
14
15
# File 'lib/oci/rover/rover_node_client.rb', line 13

def api_client
  @api_client
end

#endpointString (readonly)

Fully qualified endpoint URL

Returns:

  • (String)


17
18
19
# File 'lib/oci/rover/rover_node_client.rb', line 17

def endpoint
  @endpoint
end

#regionString

The region, which will usually correspond to a value in OCI::Regions::REGION_ENUM.

Returns:

  • (String)


27
28
29
# File 'lib/oci/rover/rover_node_client.rb', line 27

def region
  @region
end

#retry_configOCI::Retry::RetryConfig (readonly)

The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries



23
24
25
# File 'lib/oci/rover/rover_node_client.rb', line 23

def retry_config
  @retry_config
end

Instance Method Details

#change_rover_node_compartment(rover_node_id, change_rover_node_compartment_details, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/rover/change_rover_node_compartment.rb.html) to see an example of how to use change_rover_node_compartment API.

Moves a rover node into a different compartment.

Parameters:

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :if_match (String)

    For optimistic concurrency control. In the PUT or DELETE call for a resource, set the if-match parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

  • :opc_request_id (String)

    The client request ID for tracing.

  • :opc_retry_token (String)

    A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations. For example, if a resource has been deleted and purged from the system, then a retry of the original creation request might be rejected.

Returns:

  • (Response)

    A Response object with data of type nil



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/rover/rover_node_client.rb', line 122

def change_rover_node_compartment(rover_node_id, change_rover_node_compartment_details, opts = {})
  logger.debug 'Calling operation RoverNodeClient#change_rover_node_compartment.' if logger

  raise "Missing the required parameter 'rover_node_id' when calling change_rover_node_compartment." if rover_node_id.nil?
  raise "Missing the required parameter 'change_rover_node_compartment_details' when calling change_rover_node_compartment." if change_rover_node_compartment_details.nil?
  raise "Parameter value for 'rover_node_id' must not be blank" if OCI::Internal::Util.blank_string?(rover_node_id)

  path = '/roverNodes/{roverNodeId}/actions/changeCompartment'.sub('{roverNodeId}', rover_node_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token]
  # rubocop:enable Style/NegatedIf
  header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token

  post_body = @api_client.object_to_http_body(change_rover_node_compartment_details)

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'RoverNodeClient#change_rover_node_compartment') do
    @api_client.call_api(
      :POST,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#create_rover_node(create_rover_node_details, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/rover/create_rover_node.rb.html) to see an example of how to use create_rover_node API.

Creates a new RoverNode.

Parameters:

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_retry_token (String)

    A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations. For example, if a resource has been deleted and purged from the system, then a retry of the original creation request might be rejected.

  • :opc_request_id (String)

    The client request ID for tracing.

Returns:



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/oci/rover/rover_node_client.rb', line 186

def create_rover_node(create_rover_node_details, opts = {})
  logger.debug 'Calling operation RoverNodeClient#create_rover_node.' if logger

  raise "Missing the required parameter 'create_rover_node_details' when calling create_rover_node." if create_rover_node_details.nil?

  path = '/roverNodes'
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token]
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf
  header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token

  post_body = @api_client.object_to_http_body(create_rover_node_details)

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'RoverNodeClient#create_rover_node') do
    @api_client.call_api(
      :POST,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::Rover::Models::RoverNode'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#delete_rover_node(rover_node_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/rover/delete_rover_node.rb.html) to see an example of how to use delete_rover_node API.

Deletes a RoverNode resource by identifier

Parameters:

  • rover_node_id (String)

    Unique RoverNode identifier

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :if_match (String)

    For optimistic concurrency control. In the PUT or DELETE call for a resource, set the if-match parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

  • :opc_request_id (String)

    The client request ID for tracing.

Returns:

  • (Response)

    A Response object with data of type nil



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/rover/rover_node_client.rb', line 247

def delete_rover_node(rover_node_id, opts = {})
  logger.debug 'Calling operation RoverNodeClient#delete_rover_node.' if logger

  raise "Missing the required parameter 'rover_node_id' when calling delete_rover_node." if rover_node_id.nil?
  raise "Parameter value for 'rover_node_id' must not be blank" if OCI::Internal::Util.blank_string?(rover_node_id)

  path = '/roverNodes/{roverNodeId}'.sub('{roverNodeId}', rover_node_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'RoverNodeClient#delete_rover_node') do
    @api_client.call_api(
      :DELETE,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#get_rover_node(rover_node_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/rover/get_rover_node.rb.html) to see an example of how to use get_rover_node API.

Gets a RoverNode by identifier.

Parameters:

  • rover_node_id (String)

    Unique RoverNode identifier

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    The client request ID for tracing.

Returns:



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/oci/rover/rover_node_client.rb', line 301

def get_rover_node(rover_node_id, opts = {})
  logger.debug 'Calling operation RoverNodeClient#get_rover_node.' if logger

  raise "Missing the required parameter 'rover_node_id' when calling get_rover_node." if rover_node_id.nil?
  raise "Parameter value for 'rover_node_id' must not be blank" if OCI::Internal::Util.blank_string?(rover_node_id)

  path = '/roverNodes/{roverNodeId}'.sub('{roverNodeId}', rover_node_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'RoverNodeClient#get_rover_node') do
    @api_client.call_api(
      :GET,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::Rover::Models::RoverNode'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#get_rover_node_certificate(rover_node_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/rover/get_rover_node_certificate.rb.html) to see an example of how to use get_rover_node_certificate API.

Get the certificate for a rover node

Parameters:

  • rover_node_id (String)

    Unique RoverNode identifier

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    The client request ID for tracing.

Returns:



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/oci/rover/rover_node_client.rb', line 355

def get_rover_node_certificate(rover_node_id, opts = {})
  logger.debug 'Calling operation RoverNodeClient#get_rover_node_certificate.' if logger

  raise "Missing the required parameter 'rover_node_id' when calling get_rover_node_certificate." if rover_node_id.nil?
  raise "Parameter value for 'rover_node_id' must not be blank" if OCI::Internal::Util.blank_string?(rover_node_id)

  path = '/roverNodes/{roverNodeId}/certificate'.sub('{roverNodeId}', rover_node_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'RoverNodeClient#get_rover_node_certificate') do
    @api_client.call_api(
      :GET,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::Rover::Models::RoverNodeCertificate'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#get_rover_node_encryption_key(rover_node_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/rover/get_rover_node_encryption_key.rb.html) to see an example of how to use get_rover_node_encryption_key API.

Get the data encryption key for a rover node.

Parameters:

  • rover_node_id (String)

    Serial number of the rover node.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    The client request ID for tracing.

Returns:



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/oci/rover/rover_node_client.rb', line 409

def get_rover_node_encryption_key(rover_node_id, opts = {})
  logger.debug 'Calling operation RoverNodeClient#get_rover_node_encryption_key.' if logger

  raise "Missing the required parameter 'rover_node_id' when calling get_rover_node_encryption_key." if rover_node_id.nil?
  raise "Parameter value for 'rover_node_id' must not be blank" if OCI::Internal::Util.blank_string?(rover_node_id)

  path = '/roverNodes/{roverNodeId}/encryptionKey'.sub('{roverNodeId}', rover_node_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'RoverNodeClient#get_rover_node_encryption_key') do
    @api_client.call_api(
      :GET,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::Rover::Models::RoverNodeEncryptionKey'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#get_rover_node_get_rpt(rover_node_id, jwt, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/rover/get_rover_node_get_rpt.rb.html) to see an example of how to use get_rover_node_get_rpt API.

Get the resource principal token for a rover node

Parameters:

  • rover_node_id (String)

    Unique RoverNode identifier

  • jwt (String)

    The Java Web Token which is a signature of the request that is signed with the resource’s private key This is meant solely in the context of getRpt

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    The client request ID for tracing.

Returns:



466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/oci/rover/rover_node_client.rb', line 466

def get_rover_node_get_rpt(rover_node_id, jwt, opts = {})
  logger.debug 'Calling operation RoverNodeClient#get_rover_node_get_rpt.' if logger

  raise "Missing the required parameter 'rover_node_id' when calling get_rover_node_get_rpt." if rover_node_id.nil?
  raise "Missing the required parameter 'jwt' when calling get_rover_node_get_rpt." if jwt.nil?
  raise "Parameter value for 'rover_node_id' must not be blank" if OCI::Internal::Util.blank_string?(rover_node_id)

  path = '/roverNodes/{roverNodeId}/getRpt'.sub('{roverNodeId}', rover_node_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:jwt] = jwt
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'RoverNodeClient#get_rover_node_get_rpt') do
    @api_client.call_api(
      :GET,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::Rover::Models::RoverNodeGetRpt'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#list_rover_nodes(compartment_id, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/rover/list_rover_nodes.rb.html) to see an example of how to use list_rover_nodes API.

Returns a list of RoverNodes.

Allowed values are: timeCreated, displayName

Parameters:

  • compartment_id (String)

    The OCID of the compartment in which to list resources.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :display_name (String)

    A filter to return only resources that match the entire display name given.

  • :limit (Integer)

    The maximum number of items to return. (default to 10)

  • :page (String)

    The page token representing the page at which to start retrieving results. This is usually retrieved from a previous list call.

  • :lifecycle_state (String)

    A filter to return only resources their lifecycleState matches the given lifecycleState.

  • :sort_order (String)

    The sort order to use, either ‘asc’ or ‘desc’. (default to ASC)

  • :sort_by (String)

    The field to sort by. Only one sort order may be provided. Default order for timeCreated is descending. Default order for displayName is ascending. If no value is specified timeCreated is default. (default to timeCreated)

  • :opc_request_id (String)

    The client request ID for tracing.

Returns:



531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
# File 'lib/oci/rover/rover_node_client.rb', line 531

def list_rover_nodes(compartment_id, opts = {})
  logger.debug 'Calling operation RoverNodeClient#list_rover_nodes.' if logger

  raise "Missing the required parameter 'compartment_id' when calling list_rover_nodes." if compartment_id.nil?

  if opts[:lifecycle_state] && !OCI::Rover::Models::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state])
    raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::Rover::Models::LIFECYCLE_STATE_ENUM.'
  end

  if opts[:sort_order] && !OCI::Rover::Models::SORT_ORDERS_ENUM.include?(opts[:sort_order])
    raise 'Invalid value for "sort_order", must be one of the values in OCI::Rover::Models::SORT_ORDERS_ENUM.'
  end

  if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by])
    raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.'
  end

  path = '/roverNodes'
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}
  query_params[:compartmentId] = compartment_id
  query_params[:displayName] = opts[:display_name] if opts[:display_name]
  query_params[:limit] = opts[:limit] if opts[:limit]
  query_params[:page] = opts[:page] if opts[:page]
  query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state]
  query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
  query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = nil

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'RoverNodeClient#list_rover_nodes') do
    @api_client.call_api(
      :GET,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::Rover::Models::RoverNodeCollection'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#loggerLogger

Returns The logger for this client. May be nil.

Returns:

  • (Logger)

    The logger for this client. May be nil.



92
93
94
# File 'lib/oci/rover/rover_node_client.rb', line 92

def logger
  @api_client.config.logger
end

#rover_node_action_set_key(rover_node_id, jwt, rover_node_action_set_key_details, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/rover/rover_node_action_set_key.rb.html) to see an example of how to use rover_node_action_set_key API.

Get the resource principal public key for a rover node

Parameters:

  • rover_node_id (String)

    Unique RoverNode identifier

  • jwt (String)

    The Java Web Token which is a signature of the request that is signed with the resource’s private key This is meant solely in the context of getRpt

  • rover_node_action_set_key_details (OCI::Rover::Models::RoverNodeActionSetKeyDetails)

    The information to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :if_match (String)

    For optimistic concurrency control. In the PUT or DELETE call for a resource, set the if-match parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

  • :opc_request_id (String)

    The client request ID for tracing.

  • :opc_retry_token (String)

    A token that uniquely identifies a request so it can be retried in case of a timeout or server error without risk of executing that same action again. Retry tokens expire after 24 hours, but can be invalidated before then due to conflicting operations. For example, if a resource has been deleted and purged from the system, then a retry of the original creation request might be rejected.

Returns:



619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/oci/rover/rover_node_client.rb', line 619

def rover_node_action_set_key(rover_node_id, jwt, rover_node_action_set_key_details, opts = {})
  logger.debug 'Calling operation RoverNodeClient#rover_node_action_set_key.' if logger

  raise "Missing the required parameter 'rover_node_id' when calling rover_node_action_set_key." if rover_node_id.nil?
  raise "Missing the required parameter 'jwt' when calling rover_node_action_set_key." if jwt.nil?
  raise "Missing the required parameter 'rover_node_action_set_key_details' when calling rover_node_action_set_key." if rover_node_action_set_key_details.nil?
  raise "Parameter value for 'rover_node_id' must not be blank" if OCI::Internal::Util.blank_string?(rover_node_id)

  path = '/roverNodes/{roverNodeId}/actions/setKey'.sub('{roverNodeId}', rover_node_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:jwt] = jwt
  header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token]
  # rubocop:enable Style/NegatedIf
  header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token

  post_body = @api_client.object_to_http_body(rover_node_action_set_key_details)

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'RoverNodeClient#rover_node_action_set_key') do
    @api_client.call_api(
      :POST,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::Rover::Models::RoverNodeSetKey'
    )
  end
  # rubocop:enable Metrics/BlockLength
end

#update_rover_node(rover_node_id, update_rover_node_details, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/rover/update_rover_node.rb.html) to see an example of how to use update_rover_node API.

Updates the RoverNode

Parameters:

  • rover_node_id (String)

    Unique RoverNode identifier

  • update_rover_node_details (OCI::Rover::Models::UpdateRoverNodeDetails)

    The information to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :if_match (String)

    For optimistic concurrency control. In the PUT or DELETE call for a resource, set the if-match parameter to the value of the etag from a previous GET or POST response for that resource. The resource will be updated or deleted only if the etag you provide matches the resource’s current etag value.

  • :opc_request_id (String)

    The client request ID for tracing.

Returns:



686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
# File 'lib/oci/rover/rover_node_client.rb', line 686

def update_rover_node(rover_node_id, update_rover_node_details, opts = {})
  logger.debug 'Calling operation RoverNodeClient#update_rover_node.' if logger

  raise "Missing the required parameter 'rover_node_id' when calling update_rover_node." if rover_node_id.nil?
  raise "Missing the required parameter 'update_rover_node_details' when calling update_rover_node." if update_rover_node_details.nil?
  raise "Parameter value for 'rover_node_id' must not be blank" if OCI::Internal::Util.blank_string?(rover_node_id)

  path = '/roverNodes/{roverNodeId}'.sub('{roverNodeId}', rover_node_id.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = @api_client.object_to_http_body(update_rover_node_details)

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'RoverNodeClient#update_rover_node') do
    @api_client.call_api(
      :PUT,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body,
      return_type: 'OCI::Rover::Models::RoverNode'
    )
  end
  # rubocop:enable Metrics/BlockLength
end