Class: OCI::Sch::Models::DimensionDetails
- Inherits:
-
Object
- Object
- OCI::Sch::Models::DimensionDetails
- Defined in:
- lib/oci/sch/models/dimension_details.rb
Overview
A dimension name and value.
Instance Attribute Summary collapse
-
#dimension_value ⇒ OCI::Sch::Models::DimensionValueDetails
This attribute is required.
-
#name ⇒ String
**[Required]** Dimension key.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DimensionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DimensionDetails
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/sch/models/dimension_details.rb', line 52 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.dimension_value = attributes[:'dimensionValue'] if attributes[:'dimensionValue'] raise 'You cannot provide both :dimensionValue and :dimension_value' if attributes.key?(:'dimensionValue') && attributes.key?(:'dimension_value') self.dimension_value = attributes[:'dimension_value'] if attributes[:'dimension_value'] end |
Instance Attribute Details
#dimension_value ⇒ OCI::Sch::Models::DimensionValueDetails
This attribute is required.
22 23 24 |
# File 'lib/oci/sch/models/dimension_details.rb', line 22 def dimension_value @dimension_value end |
#name ⇒ String
**[Required]** Dimension key. A valid dimension key includes only printable ASCII, excluding periods (.) and spaces. Custom dimension keys are acceptable. Avoid entering confidential information. Due to use by Service Connector Hub, the following dimension names are reserved: `connectorId`, `connectorName`, `connectorSourceType`. For information on valid dimension keys and values, see metric_data_details. Example: `type`
18 19 20 |
# File 'lib/oci/sch/models/dimension_details.rb', line 18 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 |
# File 'lib/oci/sch/models/dimension_details.rb', line 25 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'dimension_value': :'dimensionValue' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
35 36 37 38 39 40 41 42 |
# File 'lib/oci/sch/models/dimension_details.rb', line 35 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'dimension_value': :'OCI::Sch::Models::DimensionValueDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
74 75 76 77 78 79 80 |
# File 'lib/oci/sch/models/dimension_details.rb', line 74 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && dimension_value == other.dimension_value end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/sch/models/dimension_details.rb', line 105 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
85 86 87 |
# File 'lib/oci/sch/models/dimension_details.rb', line 85 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
94 95 96 |
# File 'lib/oci/sch/models/dimension_details.rb', line 94 def hash [name, dimension_value].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/sch/models/dimension_details.rb', line 138 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
132 133 134 |
# File 'lib/oci/sch/models/dimension_details.rb', line 132 def to_s to_hash.to_s end |