Class: OCI::Sch::Models::FunctionTaskDetails

Inherits:
TaskDetails
  • Object
show all
Defined in:
lib/oci/sch/models/function_task_details.rb

Overview

The Functions task. Batch input for a function can be limited by either size or time. The first limit reached determines the boundary of the batch. For configuration instructions, see [To create a service connector](docs.cloud.oracle.com/iaas/Content/service-connector-hub/managingconnectors.htm#create).

Constant Summary

Constants inherited from TaskDetails

TaskDetails::KIND_ENUM

Instance Attribute Summary collapse

Attributes inherited from TaskDetails

#kind

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from TaskDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ FunctionTaskDetails

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :function_id (String)

    The value to assign to the #function_id property

  • :batch_size_in_kbs (Integer)

    The value to assign to the #batch_size_in_kbs property

  • :batch_time_in_sec (Integer)

    The value to assign to the #batch_time_in_sec property



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/oci/sch/models/function_task_details.rb', line 63

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['kind'] = 'function'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.function_id = attributes[:'functionId'] if attributes[:'functionId']

  raise 'You cannot provide both :functionId and :function_id' if attributes.key?(:'functionId') && attributes.key?(:'function_id')

  self.function_id = attributes[:'function_id'] if attributes[:'function_id']

  self.batch_size_in_kbs = attributes[:'batchSizeInKbs'] if attributes[:'batchSizeInKbs']

  raise 'You cannot provide both :batchSizeInKbs and :batch_size_in_kbs' if attributes.key?(:'batchSizeInKbs') && attributes.key?(:'batch_size_in_kbs')

  self.batch_size_in_kbs = attributes[:'batch_size_in_kbs'] if attributes[:'batch_size_in_kbs']

  self.batch_time_in_sec = attributes[:'batchTimeInSec'] if attributes[:'batchTimeInSec']

  raise 'You cannot provide both :batchTimeInSec and :batch_time_in_sec' if attributes.key?(:'batchTimeInSec') && attributes.key?(:'batch_time_in_sec')

  self.batch_time_in_sec = attributes[:'batch_time_in_sec'] if attributes[:'batch_time_in_sec']
end

Instance Attribute Details

#batch_size_in_kbsInteger

Size limit (kilobytes) for batch sent to invoke the function.

Returns:



23
24
25
# File 'lib/oci/sch/models/function_task_details.rb', line 23

def batch_size_in_kbs
  @batch_size_in_kbs
end

#batch_time_in_secInteger

Time limit (seconds) for batch sent to invoke the function.

Returns:



28
29
30
# File 'lib/oci/sch/models/function_task_details.rb', line 28

def batch_time_in_sec
  @batch_time_in_sec
end

#function_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the function to be used as a task.

Returns:



18
19
20
# File 'lib/oci/sch/models/function_task_details.rb', line 18

def function_id
  @function_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/oci/sch/models/function_task_details.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'kind',
    'function_id': :'functionId',
    'batch_size_in_kbs': :'batchSizeInKbs',
    'batch_time_in_sec': :'batchTimeInSec'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/sch/models/function_task_details.rb', line 43

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'String',
    'function_id': :'String',
    'batch_size_in_kbs': :'Integer',
    'batch_time_in_sec': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



99
100
101
102
103
104
105
106
107
# File 'lib/oci/sch/models/function_task_details.rb', line 99

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    kind == other.kind &&
    function_id == other.function_id &&
    batch_size_in_kbs == other.batch_size_in_kbs &&
    batch_time_in_sec == other.batch_time_in_sec
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/oci/sch/models/function_task_details.rb', line 132

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


112
113
114
# File 'lib/oci/sch/models/function_task_details.rb', line 112

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



121
122
123
# File 'lib/oci/sch/models/function_task_details.rb', line 121

def hash
  [kind, function_id, batch_size_in_kbs, batch_time_in_sec].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/sch/models/function_task_details.rb', line 165

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



159
160
161
# File 'lib/oci/sch/models/function_task_details.rb', line 159

def to_s
  to_hash.to_s
end