Class: OCI::Sch::Models::JmesPathDimensionValue

Inherits:
DimensionValueDetails show all
Defined in:
lib/oci/sch/models/jmes_path_dimension_value.rb

Overview

Evaluated type of dimension value.

Constant Summary

Constants inherited from DimensionValueDetails

DimensionValueDetails::KIND_ENUM

Instance Attribute Summary collapse

Attributes inherited from DimensionValueDetails

#kind

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DimensionValueDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ JmesPathDimensionValue

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :path (String)

    The value to assign to the #path property



49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/oci/sch/models/jmes_path_dimension_value.rb', line 49

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['kind'] = 'jmesPath'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.path = attributes[:'path'] if attributes[:'path']
end

Instance Attribute Details

#pathString

**[Required]** The location to use for deriving the dimension value (evaluated). The path must start with `logContent` in an acceptable notation style with supported [JMESPath selectors](jmespath.org/specification.html): expression with dot and index operator (`.` and `metric_data_details. The returned value depends on the results of evaluation. If the evaluated value is valid, then the evaluated value is returned without double quotes. (Any front or trailing double quotes are trimmed before returning the value. For example, the evaluated value `"compartmentId"` is returned as `compartmentId`.) If the evaluated value is invalid, then the returned value is `SCH_EVAL_INVALID_VALUE`. If the evaluated value is empty, then the returned value is `SCH_EVAL_VALUE_EMPTY`.

Returns:

  • (String)


20
21
22
# File 'lib/oci/sch/models/jmes_path_dimension_value.rb', line 20

def path
  @path
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
# File 'lib/oci/sch/models/jmes_path_dimension_value.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'kind',
    'path': :'path'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



33
34
35
36
37
38
39
40
# File 'lib/oci/sch/models/jmes_path_dimension_value.rb', line 33

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'String',
    'path': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



69
70
71
72
73
74
75
# File 'lib/oci/sch/models/jmes_path_dimension_value.rb', line 69

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    kind == other.kind &&
    path == other.path
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/oci/sch/models/jmes_path_dimension_value.rb', line 100

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


80
81
82
# File 'lib/oci/sch/models/jmes_path_dimension_value.rb', line 80

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



89
90
91
# File 'lib/oci/sch/models/jmes_path_dimension_value.rb', line 89

def hash
  [kind, path].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/sch/models/jmes_path_dimension_value.rb', line 133

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



127
128
129
# File 'lib/oci/sch/models/jmes_path_dimension_value.rb', line 127

def to_s
  to_hash.to_s
end