Class: OCI::Sch::Models::MonitoringSourceDetails
- Inherits:
-
SourceDetails
- Object
- SourceDetails
- OCI::Sch::Models::MonitoringSourceDetails
- Defined in:
- lib/oci/sch/models/monitoring_source_details.rb
Overview
The Monitoring source. For configuration instructions, see [To create a service connector](docs.cloud.oracle.com/iaas/Content/service-connector-hub/managingconnectors.htm#create).
Constant Summary
Constants inherited from SourceDetails
Instance Attribute Summary collapse
-
#monitoring_sources ⇒ Array<OCI::Sch::Models::MonitoringSource>
**[Required]** The list of metric namespaces to retrieve data from.
Attributes inherited from SourceDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MonitoringSourceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from SourceDetails
Constructor Details
#initialize(attributes = {}) ⇒ MonitoringSourceDetails
Initializes the object
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/sch/models/monitoring_source_details.rb', line 46 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['kind'] = 'monitoring' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.monitoring_sources = attributes[:'monitoringSources'] if attributes[:'monitoringSources'] raise 'You cannot provide both :monitoringSources and :monitoring_sources' if attributes.key?(:'monitoringSources') && attributes.key?(:'monitoring_sources') self.monitoring_sources = attributes[:'monitoring_sources'] if attributes[:'monitoring_sources'] end |
Instance Attribute Details
#monitoring_sources ⇒ Array<OCI::Sch::Models::MonitoringSource>
**[Required]** The list of metric namespaces to retrieve data from.
17 18 19 |
# File 'lib/oci/sch/models/monitoring_source_details.rb', line 17 def monitoring_sources @monitoring_sources end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 27 |
# File 'lib/oci/sch/models/monitoring_source_details.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'kind': :'kind', 'monitoring_sources': :'monitoringSources' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
30 31 32 33 34 35 36 37 |
# File 'lib/oci/sch/models/monitoring_source_details.rb', line 30 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'kind': :'String', 'monitoring_sources': :'Array<OCI::Sch::Models::MonitoringSource>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
70 71 72 73 74 75 76 |
# File 'lib/oci/sch/models/monitoring_source_details.rb', line 70 def ==(other) return true if equal?(other) self.class == other.class && kind == other.kind && monitoring_sources == other.monitoring_sources end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/sch/models/monitoring_source_details.rb', line 101 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
81 82 83 |
# File 'lib/oci/sch/models/monitoring_source_details.rb', line 81 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
90 91 92 |
# File 'lib/oci/sch/models/monitoring_source_details.rb', line 90 def hash [kind, monitoring_sources].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/sch/models/monitoring_source_details.rb', line 134 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
128 129 130 |
# File 'lib/oci/sch/models/monitoring_source_details.rb', line 128 def to_s to_hash.to_s end |