Class: OCI::Sch::Models::ObjectStorageTargetDetails
- Inherits:
-
TargetDetails
- Object
- TargetDetails
- OCI::Sch::Models::ObjectStorageTargetDetails
- Defined in:
- lib/oci/sch/models/object_storage_target_details.rb
Overview
The bucket used for the Object Storage target. For configuration instructions, see [To create a service connector](docs.cloud.oracle.com/iaas/Content/service-connector-hub/managingconnectors.htm#create).
Constant Summary
Constants inherited from TargetDetails
Instance Attribute Summary collapse
-
#batch_rollover_size_in_mbs ⇒ Integer
The batch rollover size in megabytes.
-
#batch_rollover_time_in_ms ⇒ Integer
The batch rollover time in milliseconds.
-
#bucket_name ⇒ String
[Required] The name of the bucket.
-
#namespace ⇒ String
The namespace.
-
#object_name_prefix ⇒ String
The prefix of the objects.
Attributes inherited from TargetDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ObjectStorageTargetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from TargetDetails
Constructor Details
#initialize(attributes = {}) ⇒ ObjectStorageTargetDetails
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['kind'] = 'objectStorage' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.namespace = attributes[:'namespace'] if attributes[:'namespace'] self.bucket_name = attributes[:'bucketName'] if attributes[:'bucketName'] raise 'You cannot provide both :bucketName and :bucket_name' if attributes.key?(:'bucketName') && attributes.key?(:'bucket_name') self.bucket_name = attributes[:'bucket_name'] if attributes[:'bucket_name'] self.object_name_prefix = attributes[:'objectNamePrefix'] if attributes[:'objectNamePrefix'] raise 'You cannot provide both :objectNamePrefix and :object_name_prefix' if attributes.key?(:'objectNamePrefix') && attributes.key?(:'object_name_prefix') self.object_name_prefix = attributes[:'object_name_prefix'] if attributes[:'object_name_prefix'] self.batch_rollover_size_in_mbs = attributes[:'batchRolloverSizeInMBs'] if attributes[:'batchRolloverSizeInMBs'] raise 'You cannot provide both :batchRolloverSizeInMBs and :batch_rollover_size_in_mbs' if attributes.key?(:'batchRolloverSizeInMBs') && attributes.key?(:'batch_rollover_size_in_mbs') self.batch_rollover_size_in_mbs = attributes[:'batch_rollover_size_in_mbs'] if attributes[:'batch_rollover_size_in_mbs'] self.batch_rollover_time_in_ms = attributes[:'batchRolloverTimeInMs'] if attributes[:'batchRolloverTimeInMs'] raise 'You cannot provide both :batchRolloverTimeInMs and :batch_rollover_time_in_ms' if attributes.key?(:'batchRolloverTimeInMs') && attributes.key?(:'batch_rollover_time_in_ms') self.batch_rollover_time_in_ms = attributes[:'batch_rollover_time_in_ms'] if attributes[:'batch_rollover_time_in_ms'] end |
Instance Attribute Details
#batch_rollover_size_in_mbs ⇒ Integer
The batch rollover size in megabytes.
32 33 34 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 32 def batch_rollover_size_in_mbs @batch_rollover_size_in_mbs end |
#batch_rollover_time_in_ms ⇒ Integer
The batch rollover time in milliseconds.
37 38 39 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 37 def batch_rollover_time_in_ms @batch_rollover_time_in_ms end |
#bucket_name ⇒ String
[Required] The name of the bucket. Avoid entering confidential information.
22 23 24 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 22 def bucket_name @bucket_name end |
#namespace ⇒ String
The namespace.
17 18 19 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 17 def namespace @namespace end |
#object_name_prefix ⇒ String
The prefix of the objects. Avoid entering confidential information.
27 28 29 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 27 def object_name_prefix @object_name_prefix end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'kind': :'kind', 'namespace': :'namespace', 'bucket_name': :'bucketName', 'object_name_prefix': :'objectNamePrefix', 'batch_rollover_size_in_mbs': :'batchRolloverSizeInMBs', 'batch_rollover_time_in_ms': :'batchRolloverTimeInMs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'kind': :'String', 'namespace': :'String', 'bucket_name': :'String', 'object_name_prefix': :'String', 'batch_rollover_size_in_mbs': :'Integer', 'batch_rollover_time_in_ms': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && kind == other.kind && namespace == other.namespace && bucket_name == other.bucket_name && object_name_prefix == other.object_name_prefix && batch_rollover_size_in_mbs == other.batch_rollover_size_in_mbs && batch_rollover_time_in_ms == other.batch_rollover_time_in_ms end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 146 def hash [kind, namespace, bucket_name, object_name_prefix, batch_rollover_size_in_mbs, batch_rollover_time_in_ms].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 184 def to_s to_hash.to_s end |