Class: OCI::Sch::Models::UpdateServiceConnectorDetails
- Inherits:
-
Object
- Object
- OCI::Sch::Models::UpdateServiceConnectorDetails
- Defined in:
- lib/oci/sch/models/update_service_connector_details.rb
Overview
The configuration details for updating a service connector.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #source ⇒ OCI::Sch::Models::SourceDetails
- #target ⇒ OCI::Sch::Models::TargetDetails
-
#tasks ⇒ Array<OCI::Sch::Models::TaskDetails>
The list of the tasks.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateServiceConnectorDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateServiceConnectorDetails
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.source = attributes[:'source'] if attributes[:'source'] self.tasks = attributes[:'tasks'] if attributes[:'tasks'] self.target = attributes[:'target'] if attributes[:'target'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
43 44 45 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 43 def @defined_tags end |
#description ⇒ String
The description of the resource. Avoid entering confidential information.
20 21 22 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 20 def description @description end |
#display_name ⇒ String
A user-friendly name. It does not have to be unique, and it is changeable. Avoid entering confidential information.
15 16 17 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 15 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
37 38 39 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 37 def @freeform_tags end |
#source ⇒ OCI::Sch::Models::SourceDetails
23 24 25 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 23 def source @source end |
#target ⇒ OCI::Sch::Models::TargetDetails
31 32 33 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 31 def target @target end |
#tasks ⇒ Array<OCI::Sch::Models::TaskDetails>
The list of the tasks.
28 29 30 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 28 def tasks @tasks end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'source': :'source', 'tasks': :'tasks', 'target': :'target', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'source': :'OCI::Sch::Models::SourceDetails', 'tasks': :'Array<OCI::Sch::Models::TaskDetails>', 'target': :'OCI::Sch::Models::TargetDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 128 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && source == other.source && tasks == other.tasks && target == other.target && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 164 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
144 145 146 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 144 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 153 def hash [display_name, description, source, tasks, target, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 197 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
191 192 193 |
# File 'lib/oci/sch/models/update_service_connector_details.rb', line 191 def to_s to_hash.to_s end |