Class: OCI::ServiceCatalog::Models::CreatePrivateApplicationDetails
- Inherits:
-
Object
- Object
- OCI::ServiceCatalog::Models::CreatePrivateApplicationDetails
- Defined in:
- lib/oci/service_catalog/models/create_private_application_details.rb
Overview
The model for the parameters needed to create a private application.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the private application.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The name of the private application.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#logo_file_base64_encoded ⇒ String
Base64-encoded logo to use as the private application icon.
-
#long_description ⇒ String
A long description of the private application.
-
#package_details ⇒ OCI::ServiceCatalog::Models::CreatePrivateApplicationPackage
This attribute is required.
-
#short_description ⇒ String
[Required] A short description of the private application.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePrivateApplicationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreatePrivateApplicationDetails
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.short_description = attributes[:'shortDescription'] if attributes[:'shortDescription'] raise 'You cannot provide both :shortDescription and :short_description' if attributes.key?(:'shortDescription') && attributes.key?(:'short_description') self.short_description = attributes[:'short_description'] if attributes[:'short_description'] self.long_description = attributes[:'longDescription'] if attributes[:'longDescription'] raise 'You cannot provide both :longDescription and :long_description' if attributes.key?(:'longDescription') && attributes.key?(:'long_description') self.long_description = attributes[:'long_description'] if attributes[:'long_description'] self.logo_file_base64_encoded = attributes[:'logoFileBase64Encoded'] if attributes[:'logoFileBase64Encoded'] raise 'You cannot provide both :logoFileBase64Encoded and :logo_file_base64_encoded' if attributes.key?(:'logoFileBase64Encoded') && attributes.key?(:'logo_file_base64_encoded') self.logo_file_base64_encoded = attributes[:'logo_file_base64_encoded'] if attributes[:'logo_file_base64_encoded'] self.package_details = attributes[:'packageDetails'] if attributes[:'packageDetails'] raise 'You cannot provide both :packageDetails and :package_details' if attributes.key?(:'packageDetails') && attributes.key?(:'package_details') self.package_details = attributes[:'package_details'] if attributes[:'package_details'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the private application.
13 14 15 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 13 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
41 42 43 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 41 def end |
#display_name ⇒ String
[Required] The name of the private application.
17 18 19 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 17 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
47 48 49 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 47 def end |
#logo_file_base64_encoded ⇒ String
Base64-encoded logo to use as the private application icon. Template icon file requirements: PNG format, 50 KB maximum, 130 x 130 pixels.
31 32 33 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 31 def logo_file_base64_encoded @logo_file_base64_encoded end |
#long_description ⇒ String
A long description of the private application.
25 26 27 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 25 def long_description @long_description end |
#package_details ⇒ OCI::ServiceCatalog::Models::CreatePrivateApplicationPackage
This attribute is required.
35 36 37 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 35 def package_details @package_details end |
#short_description ⇒ String
[Required] A short description of the private application.
21 22 23 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 21 def short_description @short_description end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'short_description': :'shortDescription', 'long_description': :'longDescription', 'logo_file_base64_encoded': :'logoFileBase64Encoded', 'package_details': :'packageDetails', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'short_description': :'String', 'long_description': :'String', 'logo_file_base64_encoded': :'String', 'package_details': :'OCI::ServiceCatalog::Models::CreatePrivateApplicationPackage', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 157 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && short_description == other.short_description && long_description == other.long_description && logo_file_base64_encoded == other.logo_file_base64_encoded && package_details == other.package_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 194 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
174 175 176 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 174 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 183 def hash [compartment_id, display_name, short_description, long_description, logo_file_base64_encoded, package_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
221 222 223 |
# File 'lib/oci/service_catalog/models/create_private_application_details.rb', line 221 def to_s to_hash.to_s end |