Class: OCI::ServiceCatalog::Models::CreatePrivateApplicationPackage

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/service_catalog/models/create_private_application_package.rb

Overview

A base object for creating a private application package. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Direct Known Subclasses

CreatePrivateApplicationStackPackage

Constant Summary collapse

PACKAGE_TYPE_ENUM =
[
  PACKAGE_TYPE_STACK = 'STACK'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreatePrivateApplicationPackage

Initializes the object

Options Hash (attributes):

  • :package_type (String)

    The value to assign to the #package_type property

  • :version (String)

    The value to assign to the #version property



66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 66

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.package_type = attributes[:'packageType'] if attributes[:'packageType']

  raise 'You cannot provide both :packageType and :package_type' if attributes.key?(:'packageType') && attributes.key?(:'package_type')

  self.package_type = attributes[:'package_type'] if attributes[:'package_type']

  self.version = attributes[:'version'] if attributes[:'version']
end

Instance Attribute Details

#package_typeString

[Required] The package’s type.



17
18
19
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 17

def package_type
  @package_type
end

#versionString

[Required] The package version.



21
22
23
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 21

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



24
25
26
27
28
29
30
31
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 24

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'package_type': :'packageType',
    'version': :'version'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



48
49
50
51
52
53
54
55
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 48

def self.get_subtype(object_hash)
  type = object_hash[:'packageType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::ServiceCatalog::Models::CreatePrivateApplicationStackPackage' if type == 'STACK'

  # TODO: Log a warning when the subtype is not found.
  'OCI::ServiceCatalog::Models::CreatePrivateApplicationPackage'
end

.swagger_typesObject

Attribute type mapping.



34
35
36
37
38
39
40
41
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 34

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'package_type': :'String',
    'version': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



96
97
98
99
100
101
102
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 96

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    package_type == other.package_type &&
    version == other.version
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 127

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


107
108
109
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 107

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



116
117
118
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 116

def hash
  [package_type, version].hash
end

#to_hashHash

Returns the object in the form of hash



160
161
162
163
164
165
166
167
168
169
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 160

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



154
155
156
# File 'lib/oci/service_catalog/models/create_private_application_package.rb', line 154

def to_s
  to_hash.to_s
end