Class: OCI::ServiceCatalog::Models::PrivateApplication
- Inherits:
-
Object
- Object
- OCI::ServiceCatalog::Models::PrivateApplication
- Defined in:
- lib/oci/service_catalog/models/private_application.rb
Overview
Full details of an application or a solution, which lives inside the tenancy and may be included into service catalogs.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- PACKAGE_TYPE_ENUM =
[ PACKAGE_TYPE_STACK = 'STACK'.freeze, PACKAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the private application resides.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The name of the private application.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The unique identifier for the private application in Marketplace.
-
#lifecycle_state ⇒ String
[Required] The lifecycle state of the private application.
- #logo ⇒ OCI::ServiceCatalog::Models::UploadData
-
#long_description ⇒ String
A long description of the private application.
-
#package_type ⇒ String
[Required] Type of packages within this private application.
-
#short_description ⇒ String
A short description of the private application.
-
#time_created ⇒ DateTime
[Required] The date and time the private application was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_updated ⇒ DateTime
The date and time the private application was last modified, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PrivateApplication
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PrivateApplication
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 144 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.short_description = attributes[:'shortDescription'] if attributes[:'shortDescription'] raise 'You cannot provide both :shortDescription and :short_description' if attributes.key?(:'shortDescription') && attributes.key?(:'short_description') self.short_description = attributes[:'short_description'] if attributes[:'short_description'] self.long_description = attributes[:'longDescription'] if attributes[:'longDescription'] raise 'You cannot provide both :longDescription and :long_description' if attributes.key?(:'longDescription') && attributes.key?(:'long_description') self.long_description = attributes[:'long_description'] if attributes[:'long_description'] self.logo = attributes[:'logo'] if attributes[:'logo'] self.package_type = attributes[:'packageType'] if attributes[:'packageType'] raise 'You cannot provide both :packageType and :package_type' if attributes.key?(:'packageType') && attributes.key?(:'package_type') self.package_type = attributes[:'package_type'] if attributes[:'package_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the private application resides.
33 34 35 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 33 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
78 79 80 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 78 def @defined_tags end |
#display_name ⇒ String
[Required] The name of the private application.
41 42 43 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 41 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
84 85 86 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 84 def @freeform_tags end |
#id ⇒ String
[Required] The unique identifier for the private application in Marketplace.
37 38 39 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 37 def id @id end |
#lifecycle_state ⇒ String
[Required] The lifecycle state of the private application.
28 29 30 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 28 def lifecycle_state @lifecycle_state end |
#logo ⇒ OCI::ServiceCatalog::Models::UploadData
52 53 54 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 52 def logo @logo end |
#long_description ⇒ String
A long description of the private application.
49 50 51 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 49 def long_description @long_description end |
#package_type ⇒ String
[Required] Type of packages within this private application.
56 57 58 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 56 def package_type @package_type end |
#short_description ⇒ String
A short description of the private application.
45 46 47 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 45 def short_description @short_description end |
#time_created ⇒ DateTime
[Required] The date and time the private application was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Example: 2021-05-26T21:10:29.600Z
64 65 66 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 64 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the private application was last modified, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Example: 2021-12-10T05:10:29.721Z
72 73 74 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 72 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 87 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'lifecycle_state': :'lifecycleState', 'compartment_id': :'compartmentId', 'id': :'id', 'display_name': :'displayName', 'short_description': :'shortDescription', 'long_description': :'longDescription', 'logo': :'logo', 'package_type': :'packageType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 107 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'lifecycle_state': :'String', 'compartment_id': :'String', 'id': :'String', 'display_name': :'String', 'short_description': :'String', 'long_description': :'String', 'logo': :'OCI::ServiceCatalog::Models::UploadData', 'package_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 248 def ==(other) return true if equal?(other) self.class == other.class && lifecycle_state == other.lifecycle_state && compartment_id == other.compartment_id && id == other.id && display_name == other.display_name && short_description == other.short_description && long_description == other.long_description && logo == other.logo && package_type == other.package_type && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 289 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
269 270 271 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 269 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
278 279 280 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 278 def hash [lifecycle_state, compartment_id, id, display_name, short_description, long_description, logo, package_type, time_created, time_updated, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
322 323 324 325 326 327 328 329 330 331 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 322 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
316 317 318 |
# File 'lib/oci/service_catalog/models/private_application.rb', line 316 def to_s to_hash.to_s end |