Class: OCI::ServiceCatalog::Models::PrivateApplicationPackage
- Inherits:
-
Object
- Object
- OCI::ServiceCatalog::Models::PrivateApplicationPackage
- Defined in:
- lib/oci/service_catalog/models/private_application_package.rb
Overview
A base object for all types of private application packages. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- PACKAGE_TYPE_ENUM =
[ PACKAGE_TYPE_STACK = 'STACK'.freeze, PACKAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name of the package.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the private application package.
-
#package_type ⇒ String
[Required] The specified package’s type.
-
#private_application_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the private application where the package is hosted.
-
#time_created ⇒ DateTime
[Required] The date and time the private application package was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#version ⇒ String
[Required] The package version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PrivateApplicationPackage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PrivateApplicationPackage
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 102 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.private_application_id = attributes[:'privateApplicationId'] if attributes[:'privateApplicationId'] raise 'You cannot provide both :privateApplicationId and :private_application_id' if attributes.key?(:'privateApplicationId') && attributes.key?(:'private_application_id') self.private_application_id = attributes[:'private_application_id'] if attributes[:'private_application_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.version = attributes[:'version'] if attributes[:'version'] self.package_type = attributes[:'packageType'] if attributes[:'packageType'] raise 'You cannot provide both :packageType and :package_type' if attributes.key?(:'packageType') && attributes.key?(:'package_type') self.package_type = attributes[:'package_type'] if attributes[:'package_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#display_name ⇒ String
The display name of the package.
29 30 31 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 29 def display_name @display_name end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the private application package.
20 21 22 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 20 def id @id end |
#package_type ⇒ String
[Required] The specified package’s type.
37 38 39 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 37 def package_type @package_type end |
#private_application_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the private application where the package is hosted.
25 26 27 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 25 def private_application_id @private_application_id end |
#time_created ⇒ DateTime
[Required] The date and time the private application package was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Example: 2021-05-27T21:10:29.600Z
45 46 47 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 45 def time_created @time_created end |
#version ⇒ String
[Required] The package version.
33 34 35 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 33 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'private_application_id': :'privateApplicationId', 'display_name': :'displayName', 'version': :'version', 'package_type': :'packageType', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
80 81 82 83 84 85 86 87 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 80 def self.get_subtype(object_hash) type = object_hash[:'packageType'] # rubocop:disable Style/SymbolLiteral return 'OCI::ServiceCatalog::Models::PrivateApplicationStackPackage' if type == 'STACK' # TODO: Log a warning when the subtype is not found. 'OCI::ServiceCatalog::Models::PrivateApplicationPackage' end |
.swagger_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 62 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'private_application_id': :'String', 'display_name': :'String', 'version': :'String', 'package_type': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 157 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && private_application_id == other.private_application_id && display_name == other.display_name && version == other.version && package_type == other.package_type && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 192 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
172 173 174 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 172 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 181 def hash [id, private_application_id, display_name, version, package_type, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 225 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
219 220 221 |
# File 'lib/oci/service_catalog/models/private_application_package.rb', line 219 def to_s to_hash.to_s end |