Class: OCI::ServiceCatalog::Models::PrivateApplicationSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/service_catalog/models/private_application_summary.rb

Overview

Brief data about an application or a solution, which lives inside the tenancy and may be included into service catalogs.

Constant Summary collapse

PACKAGE_TYPE_ENUM =
[
  PACKAGE_TYPE_STACK = 'STACK'.freeze,
  PACKAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PrivateApplicationSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 99

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.short_description = attributes[:'shortDescription'] if attributes[:'shortDescription']

  raise 'You cannot provide both :shortDescription and :short_description' if attributes.key?(:'shortDescription') && attributes.key?(:'short_description')

  self.short_description = attributes[:'short_description'] if attributes[:'short_description']

  self. = attributes[:'logo'] if attributes[:'logo']

  self.package_type = attributes[:'packageType'] if attributes[:'packageType']

  raise 'You cannot provide both :packageType and :package_type' if attributes.key?(:'packageType') && attributes.key?(:'package_type')

  self.package_type = attributes[:'package_type'] if attributes[:'package_type']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the private application resides.

Returns:

  • (String)


24
25
26
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 24

def compartment_id
  @compartment_id
end

#display_nameString

**[Required]** The name of the private application.

Returns:

  • (String)


32
33
34
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 32

def display_name
  @display_name
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the private application.

Returns:

  • (String)


28
29
30
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 28

def id
  @id
end

#lifecycle_stateString

**[Required]** The lifecycle state of the private application.

Returns:

  • (String)


19
20
21
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 19

def lifecycle_state
  @lifecycle_state
end

#logoOCI::ServiceCatalog::Models::UploadData



39
40
41
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 39

def 
  @logo
end

#package_typeString

**[Required]** Type of the packages, which are hosted by the private application.

Returns:

  • (String)


43
44
45
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 43

def package_type
  @package_type
end

#short_descriptionString

A short description of the private application.

Returns:

  • (String)


36
37
38
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 36

def short_description
  @short_description
end

#time_createdDateTime

**[Required]** The date and time the private application was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.

Example: `2021-05-27T21:10:29.600Z`

Returns:

  • (DateTime)


51
52
53
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 51

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 54

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'lifecycle_state': :'lifecycleState',
    'compartment_id': :'compartmentId',
    'id': :'id',
    'display_name': :'displayName',
    'short_description': :'shortDescription',
    'logo': :'logo',
    'package_type': :'packageType',
    'time_created': :'timeCreated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 70

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'lifecycle_state': :'String',
    'compartment_id': :'String',
    'id': :'String',
    'display_name': :'String',
    'short_description': :'String',
    'logo': :'OCI::ServiceCatalog::Models::UploadData',
    'package_type': :'String',
    'time_created': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 166

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    lifecycle_state == other.lifecycle_state &&
    compartment_id == other.compartment_id &&
    id == other.id &&
    display_name == other.display_name &&
    short_description == other.short_description &&
     == other. &&
    package_type == other.package_type &&
    time_created == other.time_created
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 203

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 183

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



192
193
194
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 192

def hash
  [lifecycle_state, compartment_id, id, display_name, short_description, , package_type, time_created].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
245
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



230
231
232
# File 'lib/oci/service_catalog/models/private_application_summary.rb', line 230

def to_s
  to_hash.to_s
end