Class: OCI::ServiceCatalog::ServiceCatalogClientCompositeOperations
- Inherits:
-
Object
- Object
- OCI::ServiceCatalog::ServiceCatalogClientCompositeOperations
- Defined in:
- lib/oci/service_catalog/service_catalog_client_composite_operations.rb
Overview
This class provides a wrapper around ServiceCatalogClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality
Instance Attribute Summary collapse
-
#service_client ⇒ OCI::ServiceCatalog::ServiceCatalogClient
readonly
The ServiceCatalogClient used to communicate with the service_client.
Instance Method Summary collapse
-
#change_private_application_compartment_and_wait_for_state(private_application_id, change_private_application_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#change_private_application_compartment and then waits for the Models::WorkRequest to enter the given state(s).
-
#create_private_application_and_wait_for_state(create_private_application_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#create_private_application and then waits for the Models::WorkRequest to enter the given state(s).
-
#create_service_catalog_and_wait_for_state(create_service_catalog_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#create_service_catalog and then waits for the Models::ServiceCatalog acted upon to enter the given state(s).
-
#delete_private_application_and_wait_for_state(private_application_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#delete_private_application and then waits for the Models::WorkRequest to enter the given state(s).
-
#delete_service_catalog_and_wait_for_state(service_catalog_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#delete_service_catalog and then waits for the Models::ServiceCatalog acted upon to enter the given state(s).
-
#initialize(service_client = OCI::ServiceCatalog::ServiceCatalogClient.new) ⇒ ServiceCatalogClientCompositeOperations
constructor
Initializes a new ServiceCatalogClientCompositeOperations.
-
#update_private_application_and_wait_for_state(private_application_id, update_private_application_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#update_private_application and then waits for the Models::WorkRequest to enter the given state(s).
-
#update_service_catalog_and_wait_for_state(service_catalog_id, update_service_catalog_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#update_service_catalog and then waits for the Models::ServiceCatalog acted upon to enter the given state(s).
Constructor Details
#initialize(service_client = OCI::ServiceCatalog::ServiceCatalogClient.new) ⇒ ServiceCatalogClientCompositeOperations
Initializes a new ServiceCatalogClientCompositeOperations
20 21 22 |
# File 'lib/oci/service_catalog/service_catalog_client_composite_operations.rb', line 20 def initialize(service_client = OCI::ServiceCatalog::ServiceCatalogClient.new) @service_client = service_client end |
Instance Attribute Details
#service_client ⇒ OCI::ServiceCatalog::ServiceCatalogClient (readonly)
The OCI::ServiceCatalog::ServiceCatalogClient used to communicate with the service_client
14 15 16 |
# File 'lib/oci/service_catalog/service_catalog_client_composite_operations.rb', line 14 def service_client @service_client end |
Instance Method Details
#change_private_application_compartment_and_wait_for_state(private_application_id, change_private_application_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#change_private_application_compartment and then waits for the Models::WorkRequest to enter the given state(s).
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/service_catalog/service_catalog_client_composite_operations.rb', line 40 def change_private_application_compartment_and_wait_for_state(private_application_id, change_private_application_compartment_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.change_private_application_compartment(private_application_id, change_private_application_compartment_details, base_operation_opts) use_util = OCI::ServiceCatalog::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::ServiceCatalog::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#create_private_application_and_wait_for_state(create_private_application_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#create_private_application and then waits for the Models::WorkRequest to enter the given state(s).
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/service_catalog/service_catalog_client_composite_operations.rb', line 89 def create_private_application_and_wait_for_state(create_private_application_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.create_private_application(create_private_application_details, base_operation_opts) use_util = OCI::ServiceCatalog::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::ServiceCatalog::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#create_service_catalog_and_wait_for_state(create_service_catalog_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#create_service_catalog and then waits for the Models::ServiceCatalog acted upon to enter the given state(s).
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/service_catalog/service_catalog_client_composite_operations.rb', line 138 def create_service_catalog_and_wait_for_state(create_service_catalog_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.create_service_catalog(create_service_catalog_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_service_catalog(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#delete_private_application_and_wait_for_state(private_application_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#delete_private_application and then waits for the Models::WorkRequest to enter the given state(s).
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/service_catalog/service_catalog_client_composite_operations.rb', line 177 def delete_private_application_and_wait_for_state(private_application_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.delete_private_application(private_application_id, base_operation_opts) use_util = OCI::ServiceCatalog::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::ServiceCatalog::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#delete_service_catalog_and_wait_for_state(service_catalog_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#delete_service_catalog and then waits for the Models::ServiceCatalog acted upon to enter the given state(s).
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/service_catalog/service_catalog_client_composite_operations.rb', line 226 def delete_service_catalog_and_wait_for_state(service_catalog_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) initial_get_result = @service_client.get_service_catalog(service_catalog_id) operation_result = @service_client.delete_service_catalog(service_catalog_id, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) begin waiter_result = initial_get_result.wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200, succeed_on_not_found: true ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_private_application_and_wait_for_state(private_application_id, update_private_application_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#update_private_application and then waits for the Models::WorkRequest to enter the given state(s).
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/oci/service_catalog/service_catalog_client_composite_operations.rb', line 267 def update_private_application_and_wait_for_state(private_application_id, update_private_application_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_private_application(private_application_id, update_private_application_details, base_operation_opts) use_util = OCI::ServiceCatalog::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::ServiceCatalog::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_service_catalog_and_wait_for_state(service_catalog_id, update_service_catalog_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ServiceCatalog::ServiceCatalogClient#update_service_catalog and then waits for the Models::ServiceCatalog acted upon to enter the given state(s).
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/oci/service_catalog/service_catalog_client_composite_operations.rb', line 317 def update_service_catalog_and_wait_for_state(service_catalog_id, update_service_catalog_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_service_catalog(service_catalog_id, update_service_catalog_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_service_catalog(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |