Class: OCI::ServiceManagerProxy::Models::ServiceEnvironmentSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/service_manager_proxy/models/service_environment_summary.rb

Overview

Summary of service environment details.

Constant Summary collapse

STATUS_ENUM =
[
  STATUS_INITIALIZED = 'INITIALIZED'.freeze,
  STATUS_BEGIN_ACTIVATION = 'BEGIN_ACTIVATION'.freeze,
  STATUS_ACTIVE = 'ACTIVE'.freeze,
  STATUS_BEGIN_SOFT_TERMINATION = 'BEGIN_SOFT_TERMINATION'.freeze,
  STATUS_SOFT_TERMINATED = 'SOFT_TERMINATED'.freeze,
  STATUS_BEGIN_TERMINATION = 'BEGIN_TERMINATION'.freeze,
  STATUS_CANCELED = 'CANCELED'.freeze,
  STATUS_TERMINATED = 'TERMINATED'.freeze,
  STATUS_BEGIN_DISABLING = 'BEGIN_DISABLING'.freeze,
  STATUS_BEGIN_ENABLING = 'BEGIN_ENABLING'.freeze,
  STATUS_BEGIN_MIGRATION = 'BEGIN_MIGRATION'.freeze,
  STATUS_DISABLED = 'DISABLED'.freeze,
  STATUS_BEGIN_SUSPENSION = 'BEGIN_SUSPENSION'.freeze,
  STATUS_BEGIN_RESUMPTION = 'BEGIN_RESUMPTION'.freeze,
  STATUS_SUSPENDED = 'SUSPENDED'.freeze,
  STATUS_BEGIN_LOCK_RELOCATION = 'BEGIN_LOCK_RELOCATION'.freeze,
  STATUS_LOCKED_RELOCATION = 'LOCKED_RELOCATION'.freeze,
  STATUS_BEGIN_RELOCATION = 'BEGIN_RELOCATION'.freeze,
  STATUS_RELOCATED = 'RELOCATED'.freeze,
  STATUS_BEGIN_UNLOCK_RELOCATION = 'BEGIN_UNLOCK_RELOCATION'.freeze,
  STATUS_UNLOCKED_RELOCATION = 'UNLOCKED_RELOCATION'.freeze,
  STATUS_FAILED_LOCK_RELOCATION = 'FAILED_LOCK_RELOCATION'.freeze,
  STATUS_FAILED_ACTIVATION = 'FAILED_ACTIVATION'.freeze,
  STATUS_FAILED_MIGRATION = 'FAILED_MIGRATION'.freeze,
  STATUS_ACCESS_DISABLED = 'ACCESS_DISABLED'.freeze,
  STATUS_BEGIN_DISABLING_ACCESS = 'BEGIN_DISABLING_ACCESS'.freeze,
  STATUS_BEGIN_ENABLING_ACCESS = 'BEGIN_ENABLING_ACCESS'.freeze,
  STATUS_TRA_UNKNOWN = 'TRA_UNKNOWN'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ServiceEnvironmentSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 142

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.subscription_id = attributes[:'subscriptionId'] if attributes[:'subscriptionId']

  raise 'You cannot provide both :subscriptionId and :subscription_id' if attributes.key?(:'subscriptionId') && attributes.key?(:'subscription_id')

  self.subscription_id = attributes[:'subscription_id'] if attributes[:'subscription_id']

  self.status = attributes[:'status'] if attributes[:'status']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.service_definition = attributes[:'serviceDefinition'] if attributes[:'serviceDefinition']

  raise 'You cannot provide both :serviceDefinition and :service_definition' if attributes.key?(:'serviceDefinition') && attributes.key?(:'service_definition')

  self.service_definition = attributes[:'service_definition'] if attributes[:'service_definition']

  self.console_url = attributes[:'consoleUrl'] if attributes[:'consoleUrl']

  raise 'You cannot provide both :consoleUrl and :console_url' if attributes.key?(:'consoleUrl') && attributes.key?(:'console_url')

  self.console_url = attributes[:'console_url'] if attributes[:'console_url']

  self.service_environment_endpoints = attributes[:'serviceEnvironmentEndpoints'] if attributes[:'serviceEnvironmentEndpoints']

  raise 'You cannot provide both :serviceEnvironmentEndpoints and :service_environment_endpoints' if attributes.key?(:'serviceEnvironmentEndpoints') && attributes.key?(:'service_environment_endpoints')

  self.service_environment_endpoints = attributes[:'service_environment_endpoints'] if attributes[:'service_environment_endpoints']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) for the compartment.

Returns:

  • (String)


63
64
65
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 63

def compartment_id
  @compartment_id
end

#console_urlString

The URL for the console.

Returns:

  • (String)


71
72
73
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 71

def console_url
  @console_url
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


83
84
85
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 83

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"42"`

Returns:

  • (Hash<String, String>)


91
92
93
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 91

def freeform_tags
  @freeform_tags
end

#idString

[Required] Unqiue identifier for the entitlement related to the environment.

Note: Not an [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).

Returns:

  • (String)


48
49
50
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 48

def id
  @id
end

#service_definitionOCI::ServiceManagerProxy::Models::ServiceDefinition

This attribute is required.



67
68
69
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 67

def service_definition
  @service_definition
end

#service_environment_endpointsArray<OCI::ServiceManagerProxy::Models::ServiceEnvironmentEndPointOverview>

Array of service environment end points.



75
76
77
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 75

def service_environment_endpoints
  @service_environment_endpoints
end

#statusString

[Required] Status of the entitlement registration for the service.

Returns:

  • (String)


59
60
61
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 59

def status
  @status
end

#subscription_idString

[Required] The unique subscription ID associated with the service environment ID.

Note: Not an [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).

Returns:

  • (String)


55
56
57
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 55

def subscription_id
  @subscription_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 94

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'subscription_id': :'subscriptionId',
    'status': :'status',
    'compartment_id': :'compartmentId',
    'service_definition': :'serviceDefinition',
    'console_url': :'consoleUrl',
    'service_environment_endpoints': :'serviceEnvironmentEndpoints',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 111

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'subscription_id': :'String',
    'status': :'String',
    'compartment_id': :'String',
    'service_definition': :'OCI::ServiceManagerProxy::Models::ServiceDefinition',
    'console_url': :'String',
    'service_environment_endpoints': :'Array<OCI::ServiceManagerProxy::Models::ServiceEnvironmentEndPointOverview>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 215

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    subscription_id == other.subscription_id &&
    status == other.status &&
    compartment_id == other.compartment_id &&
    service_definition == other.service_definition &&
    console_url == other.console_url &&
    service_environment_endpoints == other.service_environment_endpoints &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 253

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


233
234
235
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 233

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



242
243
244
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 242

def hash
  [id, subscription_id, status, compartment_id, service_definition, console_url, service_environment_endpoints, defined_tags, freeform_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
295
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



280
281
282
# File 'lib/oci/service_manager_proxy/models/service_environment_summary.rb', line 280

def to_s
  to_hash.to_s
end