Class: OCI::ServiceMesh::Models::CreateAccessPolicyDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/service_mesh/models/create_access_policy_details.rb

Overview

The information about a new access policy.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateAccessPolicyDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :name (String)

    The value to assign to the #name property

  • :description (String)

    The value to assign to the #description property

  • :mesh_id (String)

    The value to assign to the #mesh_id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :rules (Array<OCI::ServiceMesh::Models::AccessPolicyRule>)

    The value to assign to the #rules property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 94

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.mesh_id = attributes[:'meshId'] if attributes[:'meshId']

  raise 'You cannot provide both :meshId and :mesh_id' if attributes.key?(:'meshId') && attributes.key?(:'mesh_id')

  self.mesh_id = attributes[:'mesh_id'] if attributes[:'mesh_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.rules = attributes[:'rules'] if attributes[:'rules']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


33
34
35
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 33

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


49
50
51
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 49

def defined_tags
  @defined_tags
end

#descriptionString

Description of the resource. It can be changed after creation. Avoid entering confidential information.

Example: `This is my new resource`

Returns:

  • (String)


24
25
26
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 24

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


43
44
45
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 43

def freeform_tags
  @freeform_tags
end

#mesh_idString

**[Required]** The OCID of the service mesh in which this access policy is created.

Returns:

  • (String)


28
29
30
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 28

def mesh_id
  @mesh_id
end

#nameString

**[Required]** A user-friendly name. The name has to be unique within the same service mesh and cannot be changed after creation. Avoid entering confidential information.

Example: `My unique resource name`

Returns:

  • (String)


16
17
18
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 16

def name
  @name
end

#rulesArray<OCI::ServiceMesh::Models::AccessPolicyRule>

List of applicable rules



37
38
39
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 37

def rules
  @rules
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 52

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'description': :'description',
    'mesh_id': :'meshId',
    'compartment_id': :'compartmentId',
    'rules': :'rules',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 67

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'description': :'String',
    'mesh_id': :'String',
    'compartment_id': :'String',
    'rules': :'Array<OCI::ServiceMesh::Models::AccessPolicyRule>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 138

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    description == other.description &&
    mesh_id == other.mesh_id &&
    compartment_id == other.compartment_id &&
    rules == other.rules &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 174

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 154

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



163
164
165
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 163

def hash
  [name, description, mesh_id, compartment_id, rules, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 207

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



201
202
203
# File 'lib/oci/service_mesh/models/create_access_policy_details.rb', line 201

def to_s
  to_hash.to_s
end