Class: OCI::ServiceMesh::Models::CreateIngressGatewayMutualTransportLayerSecurityDetails
- Inherits:
-
Object
- Object
- OCI::ServiceMesh::Models::CreateIngressGatewayMutualTransportLayerSecurityDetails
- Defined in:
- lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb
Overview
Mutual TLS settings used when sending requests to virtual services within the mesh.
Instance Attribute Summary collapse
-
#maximum_validity ⇒ Integer
The number of days the mTLS certificate is valid.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateIngressGatewayMutualTransportLayerSecurityDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateIngressGatewayMutualTransportLayerSecurityDetails
Initializes the object
44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb', line 44 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.maximum_validity = attributes[:'maximumValidity'] if attributes[:'maximumValidity'] self.maximum_validity = 45 if maximum_validity.nil? && !attributes.key?(:'maximumValidity') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :maximumValidity and :maximum_validity' if attributes.key?(:'maximumValidity') && attributes.key?(:'maximum_validity') self.maximum_validity = attributes[:'maximum_validity'] if attributes[:'maximum_validity'] self.maximum_validity = 45 if maximum_validity.nil? && !attributes.key?(:'maximumValidity') && !attributes.key?(:'maximum_validity') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#maximum_validity ⇒ Integer
The number of days the mTLS certificate is valid. This value should be less than the Maximum Validity Duration for Certificates (Days) setting on the Certificate Authority associated with this Mesh. The certificate will be automatically renewed after 2/3 of the validity period, so a certificate with a maximum validity of 45 days will be renewed every 30 days.
17 18 19 |
# File 'lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb', line 17 def maximum_validity @maximum_validity end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 |
# File 'lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'maximum_validity': :'maximumValidity' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
29 30 31 32 33 34 35 |
# File 'lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb', line 29 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'maximum_validity': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
66 67 68 69 70 71 |
# File 'lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb', line 66 def ==(other) return true if equal?(other) self.class == other.class && maximum_validity == other.maximum_validity end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb', line 96 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
76 77 78 |
# File 'lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb', line 76 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
85 86 87 |
# File 'lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb', line 85 def hash [maximum_validity].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb', line 129 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
123 124 125 |
# File 'lib/oci/service_mesh/models/create_ingress_gateway_mutual_transport_layer_security_details.rb', line 123 def to_s to_hash.to_s end |