Class: OCI::ServiceMesh::Models::CreateMutualTransportLayerSecurityDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb

Overview

The mTLS authentication mode to use when receiving requests from other virtual services or ingress gateways within the mesh.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateMutualTransportLayerSecurityDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :maximum_validity (Integer)

    The value to assign to the #maximum_validity property

  • :mode (String)

    The value to assign to the #mode property



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 54

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.maximum_validity = attributes[:'maximumValidity'] if attributes[:'maximumValidity']
  self.maximum_validity = 45 if maximum_validity.nil? && !attributes.key?(:'maximumValidity') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :maximumValidity and :maximum_validity' if attributes.key?(:'maximumValidity') && attributes.key?(:'maximum_validity')

  self.maximum_validity = attributes[:'maximum_validity'] if attributes[:'maximum_validity']
  self.maximum_validity = 45 if maximum_validity.nil? && !attributes.key?(:'maximumValidity') && !attributes.key?(:'maximum_validity') # rubocop:disable Style/StringLiterals

  self.mode = attributes[:'mode'] if attributes[:'mode']
end

Instance Attribute Details

#maximum_validityInteger

The number of days the mTLS certificate is valid. This value should be less than the Maximum Validity Duration for Certificates (Days) setting on the Certificate Authority associated with this Mesh. The certificate will be automatically renewed after 2/3 of the validity period, so a certificate with a maximum validity of 45 days will be renewed every 30 days.

Returns:

  • (Integer)


17
18
19
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 17

def maximum_validity
  @maximum_validity
end

#modeString

**[Required]** DISABLED: Connection is not tunneled. PERMISSIVE: Connection can be either plaintext or an mTLS tunnel. STRICT: Connection is an mTLS tunnel. Clients without a valid certificate will be rejected.

Returns:

  • (String)


24
25
26
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 24

def mode
  @mode
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 27

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'maximum_validity': :'maximumValidity',
    'mode': :'mode'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



37
38
39
40
41
42
43
44
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 37

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'maximum_validity': :'Integer',
    'mode': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



78
79
80
81
82
83
84
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 78

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    maximum_validity == other.maximum_validity &&
    mode == other.mode
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 109

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


89
90
91
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 89

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



98
99
100
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 98

def hash
  [maximum_validity, mode].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 142

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



136
137
138
# File 'lib/oci/service_mesh/models/create_mutual_transport_layer_security_details.rb', line 136

def to_s
  to_hash.to_s
end