Class: OCI::ServiceMesh::Models::CreateVirtualServiceDetails
- Inherits:
-
Object
- Object
- OCI::ServiceMesh::Models::CreateVirtualServiceDetails
- Defined in:
- lib/oci/service_mesh/models/create_virtual_service_details.rb
Overview
The information about the new VirtualService.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
- #default_routing_policy ⇒ OCI::ServiceMesh::Models::DefaultVirtualServiceRoutingPolicy
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#hosts ⇒ Array<String>
The DNS hostnames of the virtual service that is used by its callers.
-
#mesh_id ⇒ String
**[Required]** The OCID of the service mesh in which this virtual service is created.
- #mtls ⇒ OCI::ServiceMesh::Models::CreateMutualTransportLayerSecurityDetails
-
#name ⇒ String
**[Required]** A user-friendly name.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateVirtualServiceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateVirtualServiceDetails
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 110 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.mesh_id = attributes[:'meshId'] if attributes[:'meshId'] raise 'You cannot provide both :meshId and :mesh_id' if attributes.key?(:'meshId') && attributes.key?(:'mesh_id') self.mesh_id = attributes[:'mesh_id'] if attributes[:'mesh_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.default_routing_policy = attributes[:'defaultRoutingPolicy'] if attributes[:'defaultRoutingPolicy'] raise 'You cannot provide both :defaultRoutingPolicy and :default_routing_policy' if attributes.key?(:'defaultRoutingPolicy') && attributes.key?(:'default_routing_policy') self.default_routing_policy = attributes[:'default_routing_policy'] if attributes[:'default_routing_policy'] self.hosts = attributes[:'hosts'] if attributes[:'hosts'] self.mtls = attributes[:'mtls'] if attributes[:'mtls'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
47 48 49 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 47 def compartment_id @compartment_id end |
#default_routing_policy ⇒ OCI::ServiceMesh::Models::DefaultVirtualServiceRoutingPolicy
31 32 33 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 31 def default_routing_policy @default_routing_policy end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
59 60 61 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 59 def @defined_tags end |
#description ⇒ String
Description of the resource. It can be changed after creation. Avoid entering confidential information.
Example: `This is my new resource`
28 29 30 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 28 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
53 54 55 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 53 def @freeform_tags end |
#hosts ⇒ Array<String>
The DNS hostnames of the virtual service that is used by its callers. Wildcard hostnames are supported in the prefix form. Examples of valid hostnames are "www.example.com", "*.example.com", "*.com". Can be omitted if the virtual service will only have TCP virtual deployments.
39 40 41 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 39 def hosts @hosts end |
#mesh_id ⇒ String
**[Required]** The OCID of the service mesh in which this virtual service is created.
12 13 14 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 12 def mesh_id @mesh_id end |
#mtls ⇒ OCI::ServiceMesh::Models::CreateMutualTransportLayerSecurityDetails
42 43 44 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 42 def mtls @mtls end |
#name ⇒ String
**[Required]** A user-friendly name. The name has to be unique within the same service mesh and cannot be changed after creation. Avoid entering confidential information.
Example: `My unique resource name`
20 21 22 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 20 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 62 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'mesh_id': :'meshId', 'name': :'name', 'description': :'description', 'default_routing_policy': :'defaultRoutingPolicy', 'hosts': :'hosts', 'mtls': :'mtls', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 79 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'mesh_id': :'String', 'name': :'String', 'description': :'String', 'default_routing_policy': :'OCI::ServiceMesh::Models::DefaultVirtualServiceRoutingPolicy', 'hosts': :'Array<String>', 'mtls': :'OCI::ServiceMesh::Models::CreateMutualTransportLayerSecurityDetails', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 162 def ==(other) return true if equal?(other) self.class == other.class && mesh_id == other.mesh_id && name == other.name && description == other.description && default_routing_policy == other.default_routing_policy && hosts == other.hosts && mtls == other.mtls && compartment_id == other.compartment_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 200 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
180 181 182 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 180 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
189 190 191 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 189 def hash [mesh_id, name, description, default_routing_policy, hosts, mtls, compartment_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
227 228 229 |
# File 'lib/oci/service_mesh/models/create_virtual_service_details.rb', line 227 def to_s to_hash.to_s end |