Class: OCI::ServiceMesh::Models::ExternalServiceAccessPolicyTarget

Inherits:
AccessPolicyTarget show all
Defined in:
lib/oci/service_mesh/models/external_service_access_policy_target.rb

Overview

External service target that internal virtual services direct traffic to.

Constant Summary collapse

PROTOCOL_ENUM =
[
  PROTOCOL_HTTP = 'HTTP'.freeze,
  PROTOCOL_HTTPS = 'HTTPS'.freeze,
  PROTOCOL_TCP = 'TCP'.freeze,
  PROTOCOL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Constants inherited from AccessPolicyTarget

AccessPolicyTarget::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from AccessPolicyTarget

#type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from AccessPolicyTarget

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ ExternalServiceAccessPolicyTarget

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :hostnames (Array<String>)

    The value to assign to the #hostnames property

  • :ip_addresses (Array<String>)

    The value to assign to the #ip_addresses property

  • :ports (Array<Integer>)

    The value to assign to the #ports property

  • :protocol (String)

    The value to assign to the #protocol property



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 78

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'EXTERNAL_SERVICE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.hostnames = attributes[:'hostnames'] if attributes[:'hostnames']

  self.ip_addresses = attributes[:'ipAddresses'] if attributes[:'ipAddresses']

  raise 'You cannot provide both :ipAddresses and :ip_addresses' if attributes.key?(:'ipAddresses') && attributes.key?(:'ip_addresses')

  self.ip_addresses = attributes[:'ip_addresses'] if attributes[:'ip_addresses']

  self.ports = attributes[:'ports'] if attributes[:'ports']

  self.protocol = attributes[:'protocol'] if attributes[:'protocol']
end

Instance Attribute Details

#hostnamesArray<String>

The hostnames of the external service. Only applicable for HTTP and HTTPS protocols. Wildcard hostnames are supported in the prefix form. Examples of valid hostnames are "www.example.com", "*.example.com", "*.com", "*". Hostname "*" can be used to allow all hosts.

Returns:

  • (Array<String>)


25
26
27
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 25

def hostnames
  @hostnames
end

#ip_addressesArray<String>

The ipAddresses of the external service in CIDR notation. Only applicable for TCP protocol. All requests matching the given CIDR notation will pass through. In case a wildcard CIDR "0.0.0.0/0" is provided, the same port cannot be used for a virtual service communication.

Returns:

  • (Array<String>)


32
33
34
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 32

def ip_addresses
  @ip_addresses
end

#portsArray<Integer>

Ports exposed by an external service. If left empty all ports will be allowed.

Returns:

  • (Array<Integer>)


36
37
38
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 36

def ports
  @ports
end

#protocolString

Protocol of the external service

Returns:

  • (String)


40
41
42
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 40

def protocol
  @protocol
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'hostnames': :'hostnames',
    'ip_addresses': :'ipAddresses',
    'ports': :'ports',
    'protocol': :'protocol'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 56

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'hostnames': :'Array<String>',
    'ip_addresses': :'Array<String>',
    'ports': :'Array<Integer>',
    'protocol': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 121

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    hostnames == other.hostnames &&
    ip_addresses == other.ip_addresses &&
    ports == other.ports &&
    protocol == other.protocol
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 155

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


135
136
137
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 135

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



144
145
146
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 144

def hash
  [type, hostnames, ip_addresses, ports, protocol].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



188
189
190
191
192
193
194
195
196
197
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 188

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



182
183
184
# File 'lib/oci/service_mesh/models/external_service_access_policy_target.rb', line 182

def to_s
  to_hash.to_s
end