Class: OCI::ServiceMesh::Models::HttpVirtualServiceTrafficRouteRule
- Inherits:
-
VirtualServiceTrafficRouteRule
- Object
- VirtualServiceTrafficRouteRule
- OCI::ServiceMesh::Models::HttpVirtualServiceTrafficRouteRule
- Defined in:
- lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb
Overview
Rule for routing incoming Virtual Service traffic with HTTP protocol
Constant Summary collapse
- PATH_TYPE_ENUM =
[ PATH_TYPE_PREFIX = 'PREFIX'.freeze, PATH_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from VirtualServiceTrafficRouteRule
VirtualServiceTrafficRouteRule::TYPE_ENUM
Instance Attribute Summary collapse
-
#is_grpc ⇒ BOOLEAN
If true, the rule will check that the content-type header has a application/grpc or one of the various application/grpc+ values.
-
#path ⇒ String
Route to match.
-
#path_type ⇒ String
Match type for the route.
Attributes inherited from VirtualServiceTrafficRouteRule
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HttpVirtualServiceTrafficRouteRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from VirtualServiceTrafficRouteRule
Constructor Details
#initialize(attributes = {}) ⇒ HttpVirtualServiceTrafficRouteRule
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'HTTP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.path = attributes[:'path'] if attributes[:'path'] self.path = "/" if path.nil? && !attributes.key?(:'path') # rubocop:disable Style/StringLiterals self.path_type = attributes[:'pathType'] if attributes[:'pathType'] self.path_type = "PREFIX" if path_type.nil? && !attributes.key?(:'pathType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :pathType and :path_type' if attributes.key?(:'pathType') && attributes.key?(:'path_type') self.path_type = attributes[:'path_type'] if attributes[:'path_type'] self.path_type = "PREFIX" if path_type.nil? && !attributes.key?(:'pathType') && !attributes.key?(:'path_type') # rubocop:disable Style/StringLiterals self.is_grpc = attributes[:'isGrpc'] unless attributes[:'isGrpc'].nil? self.is_grpc = false if is_grpc.nil? && !attributes.key?(:'isGrpc') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isGrpc and :is_grpc' if attributes.key?(:'isGrpc') && attributes.key?(:'is_grpc') self.is_grpc = attributes[:'is_grpc'] unless attributes[:'is_grpc'].nil? self.is_grpc = false if is_grpc.nil? && !attributes.key?(:'isGrpc') && !attributes.key?(:'is_grpc') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#is_grpc ⇒ BOOLEAN
If true, the rule will check that the content-type header has a application/grpc or one of the various application/grpc+ values.
29 30 31 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 29 def is_grpc @is_grpc end |
#path ⇒ String
Route to match
19 20 21 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 19 def path @path end |
#path_type ⇒ String
Match type for the route
23 24 25 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 23 def path_type @path_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 32 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'destinations': :'destinations', 'path': :'path', 'path_type': :'pathType', 'is_grpc': :'isGrpc' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'destinations': :'Array<OCI::ServiceMesh::Models::VirtualDeploymentTrafficRuleTarget>', 'path': :'String', 'path_type': :'String', 'is_grpc': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 117 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && destinations == other.destinations && path == other.path && path_type == other.path_type && is_grpc == other.is_grpc end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 151 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
131 132 133 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 131 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
140 141 142 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 140 def hash [type, destinations, path, path_type, is_grpc].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 184 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
178 179 180 |
# File 'lib/oci/service_mesh/models/http_virtual_service_traffic_route_rule.rb', line 178 def to_s to_hash.to_s end |