Class: OCI::ServiceMesh::Models::IngressGatewayHost
- Inherits:
-
Object
- Object
- OCI::ServiceMesh::Models::IngressGatewayHost
- Defined in:
- lib/oci/service_mesh/models/ingress_gateway_host.rb
Overview
Host for the ingress listener.
Instance Attribute Summary collapse
-
#hostnames ⇒ Array<String>
Hostnames of the host.
-
#listeners ⇒ Array<OCI::ServiceMesh::Models::IngressGatewayListener>
**[Required]** The listeners for the ingress gateway.
-
#name ⇒ String
**[Required]** A user-friendly name for the host.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IngressGatewayHost
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IngressGatewayHost
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.hostnames = attributes[:'hostnames'] if attributes[:'hostnames'] self.listeners = attributes[:'listeners'] if attributes[:'listeners'] end |
Instance Attribute Details
#hostnames ⇒ Array<String>
Hostnames of the host. Applicable only for HTTP and TLS_PASSTHROUGH listeners. Wildcard hostnames are supported in the prefix form. Examples of valid hostnames are "www.example.com", "*.example.com", "*.com".
23 24 25 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 23 def hostnames @hostnames end |
#listeners ⇒ Array<OCI::ServiceMesh::Models::IngressGatewayListener>
**[Required]** The listeners for the ingress gateway.
27 28 29 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 27 def listeners @listeners end |
#name ⇒ String
**[Required]** A user-friendly name for the host. The name must be unique within the same ingress gateway. This name can be used in the ingress gateway route table resource to attach a route to this host.
Example: `MyExampleHost`
16 17 18 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 16 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'hostnames': :'hostnames', 'listeners': :'listeners' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'hostnames': :'Array<String>', 'listeners': :'Array<OCI::ServiceMesh::Models::IngressGatewayListener>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
80 81 82 83 84 85 86 87 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 80 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && hostnames == other.hostnames && listeners == other.listeners end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 112 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
92 93 94 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 92 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
101 102 103 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 101 def hash [name, hostnames, listeners].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 145 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
139 140 141 |
# File 'lib/oci/service_mesh/models/ingress_gateway_host.rb', line 139 def to_s to_hash.to_s end |