Class: OCI::ServiceMesh::Models::IngressGatewayRouteTableSummary
- Inherits:
-
Object
- Object
- OCI::ServiceMesh::Models::IngressGatewayRouteTableSummary
- Defined in:
- lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb
Overview
Summary of the IngressGatewayRouteTable.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#ingress_gateway_id ⇒ String
**[Required]** The OCID of the ingress gateway.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the ingress gateway.
-
#name ⇒ String
**[Required]** A user-friendly name.
-
#priority ⇒ Integer
The priority of the route table.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The time when this resource was created in an RFC3339 formatted datetime string.
-
#time_updated ⇒ DateTime
**[Required]** The time when this resource was updated in an RFC3339 formatted datetime string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IngressGatewayRouteTableSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IngressGatewayRouteTableSummary
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 138 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.ingress_gateway_id = attributes[:'ingressGatewayId'] if attributes[:'ingressGatewayId'] raise 'You cannot provide both :ingressGatewayId and :ingress_gateway_id' if attributes.key?(:'ingressGatewayId') && attributes.key?(:'ingress_gateway_id') self.ingress_gateway_id = attributes[:'ingress_gateway_id'] if attributes[:'ingress_gateway_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.priority = attributes[:'priority'] if attributes[:'priority'] self.priority = 500 if priority.nil? && !attributes.key?(:'priority') # rubocop:disable Style/StringLiterals self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
37 38 39 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 37 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
69 70 71 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 69 def @defined_tags end |
#description ⇒ String
Description of the resource. It can be changed after creation. Avoid entering confidential information.
Example: `This is my new resource`
28 29 30 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 28 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
63 64 65 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 63 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
12 13 14 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 12 def id @id end |
#ingress_gateway_id ⇒ String
**[Required]** The OCID of the ingress gateway.
32 33 34 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 32 def ingress_gateway_id @ingress_gateway_id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.
57 58 59 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 57 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the ingress gateway.
53 54 55 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 53 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** A user-friendly name. The name must be unique within the same ingress gateway and cannot be changed after creation. Avoid entering confidential information.
Example: `My unique resource name`
20 21 22 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 20 def name @name end |
#priority ⇒ Integer
The priority of the route table. Lower value means higher priority. The routes are declared based on the priority.
41 42 43 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 41 def priority @priority end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
75 76 77 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 75 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The time when this resource was created in an RFC3339 formatted datetime string.
45 46 47 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 45 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The time when this resource was updated in an RFC3339 formatted datetime string.
49 50 51 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 49 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 78 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'description': :'description', 'ingress_gateway_id': :'ingressGatewayId', 'compartment_id': :'compartmentId', 'priority': :'priority', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 99 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'description': :'String', 'ingress_gateway_id': :'String', 'compartment_id': :'String', 'priority': :'Integer', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 215 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && ingress_gateway_id == other.ingress_gateway_id && compartment_id == other.compartment_id && priority == other.priority && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 257 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
237 238 239 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 237 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 246 def hash [id, name, description, ingress_gateway_id, compartment_id, priority, time_created, time_updated, lifecycle_state, lifecycle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
284 285 286 |
# File 'lib/oci/service_mesh/models/ingress_gateway_route_table_summary.rb', line 284 def to_s to_hash.to_s end |