Class: OCI::ServiceMesh::Models::UpdateIngressGatewayDetails
- Inherits:
-
Object
- Object
- OCI::ServiceMesh::Models::UpdateIngressGatewayDetails
- Defined in:
- lib/oci/service_mesh/models/update_ingress_gateway_details.rb
Overview
The information to be updated.
Instance Attribute Summary collapse
- #access_logging ⇒ OCI::ServiceMesh::Models::AccessLoggingConfiguration
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#hosts ⇒ Array<OCI::ServiceMesh::Models::IngressGatewayHost>
An array of hostnames and their listener configuration that this gateway will bind to.
- #mtls ⇒ OCI::ServiceMesh::Models::CreateIngressGatewayMutualTransportLayerSecurityDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateIngressGatewayDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateIngressGatewayDetails
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.hosts = attributes[:'hosts'] if attributes[:'hosts'] self.access_logging = attributes[:'accessLogging'] if attributes[:'accessLogging'] raise 'You cannot provide both :accessLogging and :access_logging' if attributes.key?(:'accessLogging') && attributes.key?(:'access_logging') self.access_logging = attributes[:'access_logging'] if attributes[:'access_logging'] self.mtls = attributes[:'mtls'] if attributes[:'mtls'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#access_logging ⇒ OCI::ServiceMesh::Models::AccessLoggingConfiguration
23 24 25 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 23 def access_logging @access_logging end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
38 39 40 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 38 def @defined_tags end |
#description ⇒ String
Description of the resource. It can be changed after creation. Avoid entering confidential information.
Example: `This is my new resource`
16 17 18 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 16 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
32 33 34 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 32 def @freeform_tags end |
#hosts ⇒ Array<OCI::ServiceMesh::Models::IngressGatewayHost>
An array of hostnames and their listener configuration that this gateway will bind to.
20 21 22 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 20 def hosts @hosts end |
#mtls ⇒ OCI::ServiceMesh::Models::CreateIngressGatewayMutualTransportLayerSecurityDetails
26 27 28 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 26 def mtls @mtls end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'hosts': :'hosts', 'access_logging': :'accessLogging', 'mtls': :'mtls', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'hosts': :'Array<OCI::ServiceMesh::Models::IngressGatewayHost>', 'access_logging': :'OCI::ServiceMesh::Models::AccessLoggingConfiguration', 'mtls': :'OCI::ServiceMesh::Models::CreateIngressGatewayMutualTransportLayerSecurityDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 118 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && hosts == other.hosts && access_logging == other.access_logging && mtls == other.mtls && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 153 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
133 134 135 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 133 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 142 def hash [description, hosts, access_logging, mtls, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
180 181 182 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_details.rb', line 180 def to_s to_hash.to_s end |