Class: OCI::ServiceMesh::Models::UpdateIngressGatewayRouteTableDetails
- Inherits:
-
Object
- Object
- OCI::ServiceMesh::Models::UpdateIngressGatewayRouteTableDetails
- Defined in:
- lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb
Overview
The information to be updated.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#priority ⇒ Integer
The priority of the route table.
-
#route_rules ⇒ Array<OCI::ServiceMesh::Models::IngressGatewayTrafficRouteRule>
The route rules for the ingress gateway.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateIngressGatewayRouteTableDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateIngressGatewayRouteTableDetails
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 75 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.priority = attributes[:'priority'] if attributes[:'priority'] self.priority = 500 if priority.nil? && !attributes.key?(:'priority') # rubocop:disable Style/StringLiterals self.route_rules = attributes[:'routeRules'] if attributes[:'routeRules'] raise 'You cannot provide both :routeRules and :route_rules' if attributes.key?(:'routeRules') && attributes.key?(:'route_rules') self.route_rules = attributes[:'route_rules'] if attributes[:'route_rules'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
36 37 38 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 36 def @defined_tags end |
#description ⇒ String
Description of the resource. It can be changed after creation. Avoid entering confidential information.
Example: `This is my new resource`
16 17 18 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 16 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
30 31 32 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 30 def @freeform_tags end |
#priority ⇒ Integer
The priority of the route table. Lower value means higher priority. The routes are declared based on the priority.
20 21 22 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 20 def priority @priority end |
#route_rules ⇒ Array<OCI::ServiceMesh::Models::IngressGatewayTrafficRouteRule>
The route rules for the ingress gateway.
24 25 26 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 24 def route_rules @route_rules end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'priority': :'priority', 'route_rules': :'routeRules', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 52 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'priority': :'Integer', 'route_rules': :'Array<OCI::ServiceMesh::Models::IngressGatewayTrafficRouteRule>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && priority == other.priority && route_rules == other.route_rules && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 146 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
126 127 128 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 126 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
135 136 137 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 135 def hash [description, priority, route_rules, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 179 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
173 174 175 |
# File 'lib/oci/service_mesh/models/update_ingress_gateway_route_table_details.rb', line 173 def to_s to_hash.to_s end |