Class: OCI::ServiceMesh::Models::UpdateVirtualServiceDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/service_mesh/models/update_virtual_service_details.rb

Overview

The information to be updated.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateVirtualServiceDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 84

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.description = attributes[:'description'] if attributes[:'description']

  self.default_routing_policy = attributes[:'defaultRoutingPolicy'] if attributes[:'defaultRoutingPolicy']

  raise 'You cannot provide both :defaultRoutingPolicy and :default_routing_policy' if attributes.key?(:'defaultRoutingPolicy') && attributes.key?(:'default_routing_policy')

  self.default_routing_policy = attributes[:'default_routing_policy'] if attributes[:'default_routing_policy']

  self.hosts = attributes[:'hosts'] if attributes[:'hosts']

  self.mtls = attributes[:'mtls'] if attributes[:'mtls']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#default_routing_policyOCI::ServiceMesh::Models::DefaultVirtualServiceRoutingPolicy



19
20
21
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 19

def default_routing_policy
  @default_routing_policy
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


42
43
44
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 42

def defined_tags
  @defined_tags
end

#descriptionString

Description of the resource. It can be changed after creation. Avoid entering confidential information.

Example: `This is my new resource`

Returns:

  • (String)


16
17
18
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 16

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


36
37
38
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 36

def freeform_tags
  @freeform_tags
end

#hostsArray<String>

The DNS hostnames of the virtual service that is used by its callers. Wildcard hostnames are supported in the prefix form. Examples of valid hostnames are "www.example.com", "*.example.com", "*.com". Can be omitted if the virtual service will only have TCP virtual deployments.

Returns:

  • (Array<String>)


27
28
29
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 27

def hosts
  @hosts
end

#mtlsOCI::ServiceMesh::Models::CreateMutualTransportLayerSecurityDetails



30
31
32
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 30

def mtls
  @mtls
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 45

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'description',
    'default_routing_policy': :'defaultRoutingPolicy',
    'hosts': :'hosts',
    'mtls': :'mtls',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 59

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'description': :'String',
    'default_routing_policy': :'OCI::ServiceMesh::Models::DefaultVirtualServiceRoutingPolicy',
    'hosts': :'Array<String>',
    'mtls': :'OCI::ServiceMesh::Models::CreateMutualTransportLayerSecurityDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



122
123
124
125
126
127
128
129
130
131
132
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 122

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    description == other.description &&
    default_routing_policy == other.default_routing_policy &&
    hosts == other.hosts &&
    mtls == other.mtls &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 157

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


137
138
139
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 137

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



146
147
148
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 146

def hash
  [description, default_routing_policy, hosts, mtls, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



190
191
192
193
194
195
196
197
198
199
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 190

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



184
185
186
# File 'lib/oci/service_mesh/models/update_virtual_service_details.rb', line 184

def to_s
  to_hash.to_s
end