Class: OCI::ServiceMesh::Models::VirtualService

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/service_mesh/models/virtual_service.rb

Overview

This resource represents a customer-managed service in the Service Mesh. Each virtual service declares multiple running versions of the service and maps to a group of instances/pods running a specific version of the actual service.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VirtualService

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 165

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.mesh_id = attributes[:'meshId'] if attributes[:'meshId']

  raise 'You cannot provide both :meshId and :mesh_id' if attributes.key?(:'meshId') && attributes.key?(:'mesh_id')

  self.mesh_id = attributes[:'mesh_id'] if attributes[:'mesh_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.default_routing_policy = attributes[:'defaultRoutingPolicy'] if attributes[:'defaultRoutingPolicy']

  raise 'You cannot provide both :defaultRoutingPolicy and :default_routing_policy' if attributes.key?(:'defaultRoutingPolicy') && attributes.key?(:'default_routing_policy')

  self.default_routing_policy = attributes[:'default_routing_policy'] if attributes[:'default_routing_policy']

  self.hosts = attributes[:'hosts'] if attributes[:'hosts']

  self.mtls = attributes[:'mtls'] if attributes[:'mtls']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


28
29
30
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 28

def compartment_id
  @compartment_id
end

#default_routing_policyOCI::ServiceMesh::Models::DefaultVirtualServiceRoutingPolicy



51
52
53
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 51

def default_routing_policy
  @default_routing_policy
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


90
91
92
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 90

def defined_tags
  @defined_tags
end

#descriptionString

Description of the resource. It can be changed after creation. Avoid entering confidential information.

Example: `This is my new resource`

Returns:

  • (String)


48
49
50
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 48

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


84
85
86
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 84

def freeform_tags
  @freeform_tags
end

#hostsArray<String>

The DNS hostnames of the virtual service that is used by its callers. Wildcard hostnames are supported in the prefix form. Examples of valid hostnames are "www.example.com", "*.example.com", "*.com". Can be omitted if the virtual service will only have TCP virtual deployments.

Returns:

  • (Array<String>)


59
60
61
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 59

def hosts
  @hosts
end

#idString

**[Required]** Unique identifier that is immutable on creation.

Returns:

  • (String)


23
24
25
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 23

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.

Returns:

  • (String)


78
79
80
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 78

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the Resource.

Returns:

  • (String)


74
75
76
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 74

def lifecycle_state
  @lifecycle_state
end

#mesh_idString

**[Required]** The OCID of the service mesh in which this virtual service is created.

Returns:

  • (String)


32
33
34
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 32

def mesh_id
  @mesh_id
end

#mtlsOCI::ServiceMesh::Models::MutualTransportLayerSecurity



62
63
64
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 62

def mtls
  @mtls
end

#nameString

**[Required]** A user-friendly name. The name has to be unique within the same service mesh and cannot be changed after creation. Avoid entering confidential information.

Example: `My unique resource name`

Returns:

  • (String)


40
41
42
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 40

def name
  @name
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


96
97
98
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 96

def system_tags
  @system_tags
end

#time_createdDateTime

**[Required]** The time when this resource was created in an RFC3339 formatted datetime string.

Returns:

  • (DateTime)


66
67
68
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 66

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** The time when this resource was updated in an RFC3339 formatted datetime string.

Returns:

  • (DateTime)


70
71
72
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 70

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 99

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'mesh_id': :'meshId',
    'name': :'name',
    'description': :'description',
    'default_routing_policy': :'defaultRoutingPolicy',
    'hosts': :'hosts',
    'mtls': :'mtls',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 122

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'mesh_id': :'String',
    'name': :'String',
    'description': :'String',
    'default_routing_policy': :'OCI::ServiceMesh::Models::DefaultVirtualServiceRoutingPolicy',
    'hosts': :'Array<String>',
    'mtls': :'OCI::ServiceMesh::Models::MutualTransportLayerSecurity',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 262

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    mesh_id == other.mesh_id &&
    name == other.name &&
    description == other.description &&
    default_routing_policy == other.default_routing_policy &&
    hosts == other.hosts &&
    mtls == other.mtls &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 306

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


286
287
288
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 286

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



295
296
297
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 295

def hash
  [id, compartment_id, mesh_id, name, description, default_routing_policy, hosts, mtls, time_created, time_updated, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



339
340
341
342
343
344
345
346
347
348
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 339

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



333
334
335
# File 'lib/oci/service_mesh/models/virtual_service.rb', line 333

def to_s
  to_hash.to_s
end