Class: OCI::ServiceMesh::Models::VirtualServiceTrafficRouteRule
- Inherits:
-
Object
- Object
- OCI::ServiceMesh::Models::VirtualServiceTrafficRouteRule
- Defined in:
- lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb
Overview
Rule for routing incoming virtual service traffic to a version. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
HttpVirtualServiceTrafficRouteRule, TcpVirtualServiceTrafficRouteRule, TlsPassthroughVirtualServiceTrafficRouteRule
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_HTTP = 'HTTP'.freeze, TYPE_TLS_PASSTHROUGH = 'TLS_PASSTHROUGH'.freeze, TYPE_TCP = 'TCP'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#destinations ⇒ Array<OCI::ServiceMesh::Models::VirtualDeploymentTrafficRuleTarget>
**[Required]** The destination of the request.
-
#type ⇒ String
**[Required]** Type of protocol.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VirtualServiceTrafficRouteRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VirtualServiceTrafficRouteRule
Initializes the object
72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.destinations = attributes[:'destinations'] if attributes[:'destinations'] end |
Instance Attribute Details
#destinations ⇒ Array<OCI::ServiceMesh::Models::VirtualDeploymentTrafficRuleTarget>
**[Required]** The destination of the request.
25 26 27 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 25 def destinations @destinations end |
#type ⇒ String
**[Required]** Type of protocol.
21 22 23 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 21 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'destinations': :'destinations' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 52 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::ServiceMesh::Models::TcpVirtualServiceTrafficRouteRule' if type == 'TCP' return 'OCI::ServiceMesh::Models::TlsPassthroughVirtualServiceTrafficRouteRule' if type == 'TLS_PASSTHROUGH' return 'OCI::ServiceMesh::Models::HttpVirtualServiceTrafficRouteRule' if type == 'HTTP' # TODO: Log a warning when the subtype is not found. 'OCI::ServiceMesh::Models::VirtualServiceTrafficRouteRule' end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'destinations': :'Array<OCI::ServiceMesh::Models::VirtualDeploymentTrafficRuleTarget>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 109 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 103 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && destinations == other.destinations end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 134 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
114 115 116 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 114 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
123 124 125 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 123 def hash [type, destinations].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 167 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
161 162 163 |
# File 'lib/oci/service_mesh/models/virtual_service_traffic_route_rule.rb', line 161 def to_s to_hash.to_s end |