Class: OCI::StackMonitoring::Models::ConnectionDetails
- Inherits:
-
Object
- Object
- OCI::StackMonitoring::Models::ConnectionDetails
- Defined in:
- lib/oci/stack_monitoring/models/connection_details.rb
Overview
Connection details to connect to the database. HostName, protocol, and port should be specified.
Constant Summary collapse
- PROTOCOL_ENUM =
[ PROTOCOL_TCP = 'TCP'.freeze, PROTOCOL_TCPS = 'TCPS'.freeze, PROTOCOL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#connector_id ⇒ String
Database connector Identifier.
-
#db_id ⇒ String
dbId of the database.
-
#db_unique_name ⇒ String
UniqueName used for database connection requests.
-
#port ⇒ Integer
**[Required]** Listener Port number used for connection requests.
-
#protocol ⇒ String
**[Required]** Protocol used in DB connection string when connecting to external database service.
-
#service_name ⇒ String
**[Required]** Service name used for connection requests.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConnectionDetails
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.port = attributes[:'port'] if attributes[:'port'] self.connector_id = attributes[:'connectorId'] if attributes[:'connectorId'] raise 'You cannot provide both :connectorId and :connector_id' if attributes.key?(:'connectorId') && attributes.key?(:'connector_id') self.connector_id = attributes[:'connector_id'] if attributes[:'connector_id'] self.service_name = attributes[:'serviceName'] if attributes[:'serviceName'] raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] if attributes[:'service_name'] self.db_unique_name = attributes[:'dbUniqueName'] if attributes[:'dbUniqueName'] raise 'You cannot provide both :dbUniqueName and :db_unique_name' if attributes.key?(:'dbUniqueName') && attributes.key?(:'db_unique_name') self.db_unique_name = attributes[:'db_unique_name'] if attributes[:'db_unique_name'] self.db_id = attributes[:'dbId'] if attributes[:'dbId'] raise 'You cannot provide both :dbId and :db_id' if attributes.key?(:'dbId') && attributes.key?(:'db_id') self.db_id = attributes[:'db_id'] if attributes[:'db_id'] end |
Instance Attribute Details
#connector_id ⇒ String
Database connector Identifier
27 28 29 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 27 def connector_id @connector_id end |
#db_id ⇒ String
dbId of the database
39 40 41 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 39 def db_id @db_id end |
#db_unique_name ⇒ String
UniqueName used for database connection requests.
35 36 37 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 35 def db_unique_name @db_unique_name end |
#port ⇒ Integer
**[Required]** Listener Port number used for connection requests.
23 24 25 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 23 def port @port end |
#protocol ⇒ String
**[Required]** Protocol used in DB connection string when connecting to external database service.
19 20 21 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 19 def protocol @protocol end |
#service_name ⇒ String
**[Required]** Service name used for connection requests.
31 32 33 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 31 def service_name @service_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'protocol': :'protocol', 'port': :'port', 'connector_id': :'connectorId', 'service_name': :'serviceName', 'db_unique_name': :'dbUniqueName', 'db_id': :'dbId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'protocol': :'String', 'port': :'Integer', 'connector_id': :'String', 'service_name': :'String', 'db_unique_name': :'String', 'db_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 136 def ==(other) return true if equal?(other) self.class == other.class && protocol == other.protocol && port == other.port && connector_id == other.connector_id && service_name == other.service_name && db_unique_name == other.db_unique_name && db_id == other.db_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 171 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
151 152 153 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 151 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 160 def hash [protocol, port, connector_id, service_name, db_unique_name, db_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
198 199 200 |
# File 'lib/oci/stack_monitoring/models/connection_details.rb', line 198 def to_s to_hash.to_s end |