Class: OCI::StackMonitoring::Models::CreateDiscoveryJobDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/stack_monitoring/models/create_discovery_job_details.rb

Overview

The request of DiscoveryJob details.

Constant Summary collapse

DISCOVERY_TYPE_ENUM =
[
  DISCOVERY_TYPE_ADD = 'ADD'.freeze,
  DISCOVERY_TYPE_ADD_WITH_RETRY = 'ADD_WITH_RETRY'.freeze,
  DISCOVERY_TYPE_REFRESH = 'REFRESH'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDiscoveryJobDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 85

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.discovery_type = attributes[:'discoveryType'] if attributes[:'discoveryType']
  self.discovery_type = "ADD" if discovery_type.nil? && !attributes.key?(:'discoveryType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :discoveryType and :discovery_type' if attributes.key?(:'discoveryType') && attributes.key?(:'discovery_type')

  self.discovery_type = attributes[:'discovery_type'] if attributes[:'discovery_type']
  self.discovery_type = "ADD" if discovery_type.nil? && !attributes.key?(:'discoveryType') && !attributes.key?(:'discovery_type') # rubocop:disable Style/StringLiterals

  self.discovery_client = attributes[:'discoveryClient'] if attributes[:'discoveryClient']

  raise 'You cannot provide both :discoveryClient and :discovery_client' if attributes.key?(:'discoveryClient') && attributes.key?(:'discovery_client')

  self.discovery_client = attributes[:'discovery_client'] if attributes[:'discovery_client']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.discovery_details = attributes[:'discoveryDetails'] if attributes[:'discoveryDetails']

  raise 'You cannot provide both :discoveryDetails and :discovery_details' if attributes.key?(:'discoveryDetails') && attributes.key?(:'discovery_details')

  self.discovery_details = attributes[:'discovery_details'] if attributes[:'discovery_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The OCID of Compartment

Returns:

  • (String)


27
28
29
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 27

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


43
44
45
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 43

def defined_tags
  @defined_tags
end

#discovery_clientString

Client who submits discovery job.

Returns:

  • (String)


23
24
25
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 23

def discovery_client
  @discovery_client
end

#discovery_detailsOCI::StackMonitoring::Models::DiscoveryDetails

This attribute is required.



31
32
33
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 31

def discovery_details
  @discovery_details
end

#discovery_typeString

Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.

Returns:

  • (String)


19
20
21
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 19

def discovery_type
  @discovery_type
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


37
38
39
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 37

def freeform_tags
  @freeform_tags
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 46

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'discovery_type': :'discoveryType',
    'discovery_client': :'discoveryClient',
    'compartment_id': :'compartmentId',
    'discovery_details': :'discoveryDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 60

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'discovery_type': :'String',
    'discovery_client': :'String',
    'compartment_id': :'String',
    'discovery_details': :'OCI::StackMonitoring::Models::DiscoveryDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



145
146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 145

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    discovery_type == other.discovery_type &&
    discovery_client == other.discovery_client &&
    compartment_id == other.compartment_id &&
    discovery_details == other.discovery_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 180

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 160

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



169
170
171
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 169

def hash
  [discovery_type, discovery_client, compartment_id, discovery_details, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



207
208
209
# File 'lib/oci/stack_monitoring/models/create_discovery_job_details.rb', line 207

def to_s
  to_hash.to_s
end