Class: OCI::StackMonitoring::Models::DiscoveryJob

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/stack_monitoring/models/discovery_job.rb

Overview

The DiscoveryJob details.

Constant Summary collapse

DISCOVERY_TYPE_ENUM =
[
  DISCOVERY_TYPE_ADD = 'ADD'.freeze,
  DISCOVERY_TYPE_ADD_WITH_RETRY = 'ADD_WITH_RETRY'.freeze,
  DISCOVERY_TYPE_REFRESH = 'REFRESH'.freeze,
  DISCOVERY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_SUCCESS = 'SUCCESS'.freeze,
  STATUS_FAILURE = 'FAILURE'.freeze,
  STATUS_INPROGRESS = 'INPROGRESS'.freeze,
  STATUS_INACTIVE = 'INACTIVE'.freeze,
  STATUS_CREATED = 'CREATED'.freeze,
  STATUS_DELETED = 'DELETED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DiscoveryJob

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :discovery_type (String)

    The value to assign to the #discovery_type property

  • :status (String)

    The value to assign to the #status property

  • :status_message (String)

    The value to assign to the #status_message property

  • :tenant_id (String)

    The value to assign to the #tenant_id property

  • :user_id (String)

    The value to assign to the #user_id property

  • :discovery_client (String)

    The value to assign to the #discovery_client property

  • :discovery_details (OCI::StackMonitoring::Models::DiscoveryDetails)

    The value to assign to the #discovery_details property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 164

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.discovery_type = attributes[:'discoveryType'] if attributes[:'discoveryType']
  self.discovery_type = "ADD" if discovery_type.nil? && !attributes.key?(:'discoveryType') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :discoveryType and :discovery_type' if attributes.key?(:'discoveryType') && attributes.key?(:'discovery_type')

  self.discovery_type = attributes[:'discovery_type'] if attributes[:'discovery_type']
  self.discovery_type = "ADD" if discovery_type.nil? && !attributes.key?(:'discoveryType') && !attributes.key?(:'discovery_type') # rubocop:disable Style/StringLiterals

  self.status = attributes[:'status'] if attributes[:'status']

  self.status_message = attributes[:'statusMessage'] if attributes[:'statusMessage']

  raise 'You cannot provide both :statusMessage and :status_message' if attributes.key?(:'statusMessage') && attributes.key?(:'status_message')

  self.status_message = attributes[:'status_message'] if attributes[:'status_message']

  self.tenant_id = attributes[:'tenantId'] if attributes[:'tenantId']

  raise 'You cannot provide both :tenantId and :tenant_id' if attributes.key?(:'tenantId') && attributes.key?(:'tenant_id')

  self.tenant_id = attributes[:'tenant_id'] if attributes[:'tenant_id']

  self.user_id = attributes[:'userId'] if attributes[:'userId']

  raise 'You cannot provide both :userId and :user_id' if attributes.key?(:'userId') && attributes.key?(:'user_id')

  self.user_id = attributes[:'user_id'] if attributes[:'user_id']

  self.discovery_client = attributes[:'discoveryClient'] if attributes[:'discoveryClient']

  raise 'You cannot provide both :discoveryClient and :discovery_client' if attributes.key?(:'discoveryClient') && attributes.key?(:'discovery_client')

  self.discovery_client = attributes[:'discovery_client'] if attributes[:'discovery_client']

  self.discovery_details = attributes[:'discoveryDetails'] if attributes[:'discoveryDetails']

  raise 'You cannot provide both :discoveryDetails and :discovery_details' if attributes.key?(:'discoveryDetails') && attributes.key?(:'discovery_details')

  self.discovery_details = attributes[:'discovery_details'] if attributes[:'discovery_details']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

The OCID of the Compartment

Returns:

  • (String)


44
45
46
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 44

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


92
93
94
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 92

def defined_tags
  @defined_tags
end

#discovery_clientString

Client who submits discovery job.

Returns:

  • (String)


69
70
71
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 69

def discovery_client
  @discovery_client
end

#discovery_detailsOCI::StackMonitoring::Models::DiscoveryDetails



72
73
74
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 72

def discovery_details
  @discovery_details
end

#discovery_typeString

Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.

Returns:

  • (String)


49
50
51
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 49

def discovery_type
  @discovery_type
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


86
87
88
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 86

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The OCID of Discovery job

Returns:

  • (String)


40
41
42
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 40

def id
  @id
end

#lifecycle_stateString

The current state of the DiscoveryJob Resource.

Returns:

  • (String)


80
81
82
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 80

def lifecycle_state
  @lifecycle_state
end

#statusString

Specifies the status of the discovery job

Returns:

  • (String)


53
54
55
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 53

def status
  @status
end

#status_messageString

The short summary of the status of the discovery job

Returns:

  • (String)


57
58
59
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 57

def status_message
  @status_message
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


98
99
100
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 98

def system_tags
  @system_tags
end

#tenant_idString

The OCID of Tenant

Returns:

  • (String)


61
62
63
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 61

def tenant_id
  @tenant_id
end

#time_updatedDateTime

The time the discovery Job was updated.

Returns:

  • (DateTime)


76
77
78
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 76

def time_updated
  @time_updated
end

#user_idString

The OCID of user in which the job is submitted

Returns:

  • (String)


65
66
67
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 65

def user_id
  @user_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 101

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'discovery_type': :'discoveryType',
    'status': :'status',
    'status_message': :'statusMessage',
    'tenant_id': :'tenantId',
    'user_id': :'userId',
    'discovery_client': :'discoveryClient',
    'discovery_details': :'discoveryDetails',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 123

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'discovery_type': :'String',
    'status': :'String',
    'status_message': :'String',
    'tenant_id': :'String',
    'user_id': :'String',
    'discovery_client': :'String',
    'discovery_details': :'OCI::StackMonitoring::Models::DiscoveryDetails',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 295

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    discovery_type == other.discovery_type &&
    status == other.status &&
    status_message == other.status_message &&
    tenant_id == other.tenant_id &&
    user_id == other.user_id &&
    discovery_client == other.discovery_client &&
    discovery_details == other.discovery_details &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 338

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


318
319
320
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 318

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



327
328
329
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 327

def hash
  [id, compartment_id, discovery_type, status, status_message, tenant_id, user_id, discovery_client, discovery_details, time_updated, lifecycle_state, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



371
372
373
374
375
376
377
378
379
380
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 371

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



365
366
367
# File 'lib/oci/stack_monitoring/models/discovery_job.rb', line 365

def to_s
  to_hash.to_s
end