Class: OCI::StackMonitoring::Models::DiscoveryJobLogSummary
- Inherits:
-
Object
- Object
- OCI::StackMonitoring::Models::DiscoveryJobLogSummary
- Defined in:
- lib/oci/stack_monitoring/models/discovery_job_log_summary.rb
Overview
Log of a specific job
Constant Summary collapse
- LOG_TYPE_ENUM =
[ LOG_TYPE_INFO = 'INFO'.freeze, LOG_TYPE_WARNING = 'WARNING'.freeze, LOG_TYPE_ERROR = 'ERROR'.freeze, LOG_TYPE_SUCCESS = 'SUCCESS'.freeze, LOG_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#id ⇒ String
**[Required]** The OCID of Discovery job.
-
#log_message ⇒ String
**[Required]** Log message.
-
#log_type ⇒ String
**[Required]** Type of log (INFO, WARNING, ERROR or SUCCESS).
-
#time_created ⇒ DateTime
**[Required]** Time the Job log was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DiscoveryJobLogSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DiscoveryJobLogSummary
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.log_type = attributes[:'logType'] if attributes[:'logType'] raise 'You cannot provide both :logType and :log_type' if attributes.key?(:'logType') && attributes.key?(:'log_type') self.log_type = attributes[:'log_type'] if attributes[:'log_type'] self. = attributes[:'logMessage'] if attributes[:'logMessage'] raise 'You cannot provide both :logMessage and :log_message' if attributes.key?(:'logMessage') && attributes.key?(:'log_message') self. = attributes[:'log_message'] if attributes[:'log_message'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#id ⇒ String
**[Required]** The OCID of Discovery job
21 22 23 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 21 def id @id end |
#log_message ⇒ String
**[Required]** Log message
29 30 31 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 29 def @log_message end |
#log_type ⇒ String
**[Required]** Type of log (INFO, WARNING, ERROR or SUCCESS)
25 26 27 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 25 def log_type @log_type end |
#time_created ⇒ DateTime
**[Required]** Time the Job log was created
33 34 35 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 33 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'log_type': :'logType', 'log_message': :'logMessage', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'log_type': :'String', 'log_message': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 116 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && log_type == other.log_type && == other. && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 149 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
129 130 131 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 129 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
138 139 140 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 138 def hash [id, log_type, , time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
176 177 178 |
# File 'lib/oci/stack_monitoring/models/discovery_job_log_summary.rb', line 176 def to_s to_hash.to_s end |