Class: OCI::StackMonitoring::Models::EncryptedCredentials

Inherits:
MonitoredResourceCredential show all
Defined in:
lib/oci/stack_monitoring/models/encrypted_credentials.rb

Overview

Encypted credentials [indicated by the type property in CredentialStore].

Constant Summary

Constants inherited from MonitoredResourceCredential

MonitoredResourceCredential::CREDENTIAL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from MonitoredResourceCredential

#credential_type, #description, #name, #source, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from MonitoredResourceCredential

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ EncryptedCredentials

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 62

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['credentialType'] = 'ENCRYPTED'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key_id = attributes[:'keyId'] if attributes[:'keyId']

  raise 'You cannot provide both :keyId and :key_id' if attributes.key?(:'keyId') && attributes.key?(:'key_id')

  self.key_id = attributes[:'key_id'] if attributes[:'key_id']

  self.properties = attributes[:'properties'] if attributes[:'properties']
end

Instance Attribute Details

#key_idString

**[Required]** The master key OCID and applicable only for property value type ENCRYPTION. Key OCID is passed as input to Key management service decrypt API to retrieve the encrypted property value text.

Returns:

  • (String)


14
15
16
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 14

def key_id
  @key_id
end

#propertiesArray<OCI::StackMonitoring::Models::CredentialProperty>

**[Required]** The credential properties list. Credential property values will be encrypted format.



18
19
20
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 18

def properties
  @properties
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



21
22
23
24
25
26
27
28
29
30
31
32
33
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 21

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'source': :'source',
    'name': :'name',
    'type': :'type',
    'description': :'description',
    'credential_type': :'credentialType',
    'key_id': :'keyId',
    'properties': :'properties'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 36

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'source': :'String',
    'name': :'String',
    'type': :'String',
    'description': :'String',
    'credential_type': :'String',
    'key_id': :'String',
    'properties': :'Array<OCI::StackMonitoring::Models::CredentialProperty>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 88

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    source == other.source &&
    name == other.name &&
    type == other.type &&
    description == other.description &&
    credential_type == other.credential_type &&
    key_id == other.key_id &&
    properties == other.properties
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 124

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


104
105
106
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 104

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



113
114
115
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 113

def hash
  [source, name, type, description, credential_type, key_id, properties].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



157
158
159
160
161
162
163
164
165
166
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 157

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



151
152
153
# File 'lib/oci/stack_monitoring/models/encrypted_credentials.rb', line 151

def to_s
  to_hash.to_s
end