Class: OCI::StackMonitoring::Models::MonitoredResource
- Inherits:
-
Object
- Object
- OCI::StackMonitoring::Models::MonitoredResource
- Defined in:
- lib/oci/stack_monitoring/models/monitored_resource.rb
Overview
The information about monitored resource.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #aliases ⇒ OCI::StackMonitoring::Models::MonitoredResourceAliasCredential
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
- #credentials ⇒ OCI::StackMonitoring::Models::MonitoredResourceCredential
- #database_connection_details ⇒ OCI::StackMonitoring::Models::ConnectionDetails
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Monitored resource display name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#host_name ⇒ String
Monitored resource host name.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of monitored resource.
-
#lifecycle_state ⇒ String
Lifecycle state of the monitored resource.
-
#management_agent_id ⇒ String
Management Agent Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
-
#name ⇒ String
**[Required]** Monitored resource name.
-
#properties ⇒ Array<OCI::StackMonitoring::Models::MonitoredResourceProperty>
List of monitored resource properties.
-
#resource_time_zone ⇒ String
Time zone in the form of tz database canonical zone ID.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#tenant_id ⇒ String
**[Required]** Tenancy Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
-
#time_created ⇒ DateTime
The time the the resource was created.
-
#time_updated ⇒ DateTime
The time the the resource was updated.
-
#type ⇒ String
**[Required]** Monitored resource type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MonitoredResource
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MonitoredResource
Initializes the object
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 179 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.type = attributes[:'type'] if attributes[:'type'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.tenant_id = attributes[:'tenantId'] if attributes[:'tenantId'] raise 'You cannot provide both :tenantId and :tenant_id' if attributes.key?(:'tenantId') && attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] if attributes[:'tenant_id'] self.host_name = attributes[:'hostName'] if attributes[:'hostName'] raise 'You cannot provide both :hostName and :host_name' if attributes.key?(:'hostName') && attributes.key?(:'host_name') self.host_name = attributes[:'host_name'] if attributes[:'host_name'] self.management_agent_id = attributes[:'managementAgentId'] if attributes[:'managementAgentId'] raise 'You cannot provide both :managementAgentId and :management_agent_id' if attributes.key?(:'managementAgentId') && attributes.key?(:'management_agent_id') self.management_agent_id = attributes[:'management_agent_id'] if attributes[:'management_agent_id'] self.resource_time_zone = attributes[:'resourceTimeZone'] if attributes[:'resourceTimeZone'] self.resource_time_zone = "Etc/UTC" if resource_time_zone.nil? && !attributes.key?(:'resourceTimeZone') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :resourceTimeZone and :resource_time_zone' if attributes.key?(:'resourceTimeZone') && attributes.key?(:'resource_time_zone') self.resource_time_zone = attributes[:'resource_time_zone'] if attributes[:'resource_time_zone'] self.resource_time_zone = "Etc/UTC" if resource_time_zone.nil? && !attributes.key?(:'resourceTimeZone') && !attributes.key?(:'resource_time_zone') # rubocop:disable Style/StringLiterals self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.properties = attributes[:'properties'] if attributes[:'properties'] self.database_connection_details = attributes[:'databaseConnectionDetails'] if attributes[:'databaseConnectionDetails'] raise 'You cannot provide both :databaseConnectionDetails and :database_connection_details' if attributes.key?(:'databaseConnectionDetails') && attributes.key?(:'database_connection_details') self.database_connection_details = attributes[:'database_connection_details'] if attributes[:'database_connection_details'] self.credentials = attributes[:'credentials'] if attributes[:'credentials'] self.aliases = attributes[:'aliases'] if attributes[:'aliases'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#aliases ⇒ OCI::StackMonitoring::Models::MonitoredResourceAliasCredential
80 81 82 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 80 def aliases @aliases end |
#compartment_id ⇒ String
**[Required]** Compartment Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)
39 40 41 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 39 def compartment_id @compartment_id end |
#credentials ⇒ OCI::StackMonitoring::Models::MonitoredResourceCredential
77 78 79 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 77 def credentials @credentials end |
#database_connection_details ⇒ OCI::StackMonitoring::Models::ConnectionDetails
74 75 76 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 74 def database_connection_details @database_connection_details end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
92 93 94 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 92 def @defined_tags end |
#display_name ⇒ String
Monitored resource display name.
31 32 33 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 31 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
86 87 88 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 86 def @freeform_tags end |
#host_name ⇒ String
Monitored resource host name.
47 48 49 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 47 def host_name @host_name end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of monitored resource.
23 24 25 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 23 def id @id end |
#lifecycle_state ⇒ String
Lifecycle state of the monitored resource.
67 68 69 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 67 def lifecycle_state @lifecycle_state end |
#management_agent_id ⇒ String
Management Agent Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
51 52 53 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 51 def management_agent_id @management_agent_id end |
#name ⇒ String
**[Required]** Monitored resource name.
27 28 29 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 27 def name @name end |
#properties ⇒ Array<OCI::StackMonitoring::Models::MonitoredResourceProperty>
List of monitored resource properties
71 72 73 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 71 def properties @properties end |
#resource_time_zone ⇒ String
Time zone in the form of tz database canonical zone ID.
55 56 57 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 55 def resource_time_zone @resource_time_zone end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
98 99 100 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 98 def @system_tags end |
#tenant_id ⇒ String
**[Required]** Tenancy Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)
43 44 45 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 43 def tenant_id @tenant_id end |
#time_created ⇒ DateTime
The time the the resource was created. An RFC3339 formatted datetime string
59 60 61 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 59 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the the resource was updated. An RFC3339 formatted datetime string
63 64 65 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 63 def time_updated @time_updated end |
#type ⇒ String
**[Required]** Monitored resource type
35 36 37 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 35 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 101 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'display_name': :'displayName', 'type': :'type', 'compartment_id': :'compartmentId', 'tenant_id': :'tenantId', 'host_name': :'hostName', 'management_agent_id': :'managementAgentId', 'resource_time_zone': :'resourceTimeZone', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'properties': :'properties', 'database_connection_details': :'databaseConnectionDetails', 'credentials': :'credentials', 'aliases': :'aliases', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 128 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'display_name': :'String', 'type': :'String', 'compartment_id': :'String', 'tenant_id': :'String', 'host_name': :'String', 'management_agent_id': :'String', 'resource_time_zone': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'properties': :'Array<OCI::StackMonitoring::Models::MonitoredResourceProperty>', 'database_connection_details': :'OCI::StackMonitoring::Models::ConnectionDetails', 'credentials': :'OCI::StackMonitoring::Models::MonitoredResourceCredential', 'aliases': :'OCI::StackMonitoring::Models::MonitoredResourceAliasCredential', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 298 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && display_name == other.display_name && type == other.type && compartment_id == other.compartment_id && tenant_id == other.tenant_id && host_name == other.host_name && management_agent_id == other.management_agent_id && resource_time_zone == other.resource_time_zone && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && properties == other.properties && database_connection_details == other.database_connection_details && credentials == other.credentials && aliases == other.aliases && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 346 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
326 327 328 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 326 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
335 336 337 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 335 def hash [id, name, display_name, type, compartment_id, tenant_id, host_name, management_agent_id, resource_time_zone, time_created, time_updated, lifecycle_state, properties, database_connection_details, credentials, aliases, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
379 380 381 382 383 384 385 386 387 388 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 379 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
373 374 375 |
# File 'lib/oci/stack_monitoring/models/monitored_resource.rb', line 373 def to_s to_hash.to_s end |