Class: OCI::StackMonitoring::Models::MonitoredResourceAssociation

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/stack_monitoring/models/monitored_resource_association.rb

Overview

Association between two monitored resources.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MonitoredResourceAssociation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 113

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.association_type = attributes[:'associationType'] if attributes[:'associationType']

  raise 'You cannot provide both :associationType and :association_type' if attributes.key?(:'associationType') && attributes.key?(:'association_type')

  self.association_type = attributes[:'association_type'] if attributes[:'association_type']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.tenant_id = attributes[:'tenantId'] if attributes[:'tenantId']

  raise 'You cannot provide both :tenantId and :tenant_id' if attributes.key?(:'tenantId') && attributes.key?(:'tenant_id')

  self.tenant_id = attributes[:'tenant_id'] if attributes[:'tenant_id']

  self.source_resource_id = attributes[:'sourceResourceId'] if attributes[:'sourceResourceId']

  raise 'You cannot provide both :sourceResourceId and :source_resource_id' if attributes.key?(:'sourceResourceId') && attributes.key?(:'source_resource_id')

  self.source_resource_id = attributes[:'source_resource_id'] if attributes[:'source_resource_id']

  self.destination_resource_id = attributes[:'destinationResourceId'] if attributes[:'destinationResourceId']

  raise 'You cannot provide both :destinationResourceId and :destination_resource_id' if attributes.key?(:'destinationResourceId') && attributes.key?(:'destination_resource_id')

  self.destination_resource_id = attributes[:'destination_resource_id'] if attributes[:'destination_resource_id']

  self.source_resource_details = attributes[:'sourceResourceDetails'] if attributes[:'sourceResourceDetails']

  raise 'You cannot provide both :sourceResourceDetails and :source_resource_details' if attributes.key?(:'sourceResourceDetails') && attributes.key?(:'source_resource_details')

  self.source_resource_details = attributes[:'source_resource_details'] if attributes[:'source_resource_details']

  self.destination_resource_details = attributes[:'destinationResourceDetails'] if attributes[:'destinationResourceDetails']

  raise 'You cannot provide both :destinationResourceDetails and :destination_resource_details' if attributes.key?(:'destinationResourceDetails') && attributes.key?(:'destination_resource_details')

  self.destination_resource_details = attributes[:'destination_resource_details'] if attributes[:'destination_resource_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#association_typeString

**[Required]** Association Type

Returns:

  • (String)


12
13
14
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 12

def association_type
  @association_type
end

#compartment_idString

**[Required]** Compartment Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)

Returns:

  • (String)


16
17
18
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 16

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


50
51
52
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 50

def defined_tags
  @defined_tags
end

#destination_resource_detailsOCI::StackMonitoring::Models::AssociationResourceDetails



34
35
36
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 34

def destination_resource_details
  @destination_resource_details
end

#destination_resource_idString

**[Required]** Destination Monitored Resource Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)

Returns:

  • (String)


28
29
30
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 28

def destination_resource_id
  @destination_resource_id
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


44
45
46
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 44

def freeform_tags
  @freeform_tags
end

#source_resource_detailsOCI::StackMonitoring::Models::AssociationResourceDetails



31
32
33
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 31

def source_resource_details
  @source_resource_details
end

#source_resource_idString

**[Required]** Source Monitored Resource Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)

Returns:

  • (String)


24
25
26
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 24

def source_resource_id
  @source_resource_id
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


56
57
58
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 56

def system_tags
  @system_tags
end

#tenant_idString

**[Required]** Tenancy Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)

Returns:

  • (String)


20
21
22
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 20

def tenant_id
  @tenant_id
end

#time_createdDateTime

The time when the association was created. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


38
39
40
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 38

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 59

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'association_type': :'associationType',
    'compartment_id': :'compartmentId',
    'tenant_id': :'tenantId',
    'source_resource_id': :'sourceResourceId',
    'destination_resource_id': :'destinationResourceId',
    'source_resource_details': :'sourceResourceDetails',
    'destination_resource_details': :'destinationResourceDetails',
    'time_created': :'timeCreated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 78

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'association_type': :'String',
    'compartment_id': :'String',
    'tenant_id': :'String',
    'source_resource_id': :'String',
    'destination_resource_id': :'String',
    'source_resource_details': :'OCI::StackMonitoring::Models::AssociationResourceDetails',
    'destination_resource_details': :'OCI::StackMonitoring::Models::AssociationResourceDetails',
    'time_created': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 193

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    association_type == other.association_type &&
    compartment_id == other.compartment_id &&
    tenant_id == other.tenant_id &&
    source_resource_id == other.source_resource_id &&
    destination_resource_id == other.destination_resource_id &&
    source_resource_details == other.source_resource_details &&
    destination_resource_details == other.destination_resource_details &&
    time_created == other.time_created &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 233

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


213
214
215
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 213

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



222
223
224
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 222

def hash
  [association_type, compartment_id, tenant_id, source_resource_id, destination_resource_id, source_resource_details, destination_resource_details, time_created, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
275
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



260
261
262
# File 'lib/oci/stack_monitoring/models/monitored_resource_association.rb', line 260

def to_s
  to_hash.to_s
end