Class: OCI::StackMonitoring::Models::MonitoredResourceAssociationSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb

Overview

Summary of the monitored resource association.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MonitoredResourceAssociationSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 99

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.association_type = attributes[:'associationType'] if attributes[:'associationType']

  raise 'You cannot provide both :associationType and :association_type' if attributes.key?(:'associationType') && attributes.key?(:'association_type')

  self.association_type = attributes[:'association_type'] if attributes[:'association_type']

  self.source_resource_id = attributes[:'sourceResourceId'] if attributes[:'sourceResourceId']

  raise 'You cannot provide both :sourceResourceId and :source_resource_id' if attributes.key?(:'sourceResourceId') && attributes.key?(:'source_resource_id')

  self.source_resource_id = attributes[:'source_resource_id'] if attributes[:'source_resource_id']

  self.destination_resource_id = attributes[:'destinationResourceId'] if attributes[:'destinationResourceId']

  raise 'You cannot provide both :destinationResourceId and :destination_resource_id' if attributes.key?(:'destinationResourceId') && attributes.key?(:'destination_resource_id')

  self.destination_resource_id = attributes[:'destination_resource_id'] if attributes[:'destination_resource_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.source_resource_details = attributes[:'sourceResourceDetails'] if attributes[:'sourceResourceDetails']

  raise 'You cannot provide both :sourceResourceDetails and :source_resource_details' if attributes.key?(:'sourceResourceDetails') && attributes.key?(:'source_resource_details')

  self.source_resource_details = attributes[:'source_resource_details'] if attributes[:'source_resource_details']

  self.destination_resource_details = attributes[:'destinationResourceDetails'] if attributes[:'destinationResourceDetails']

  raise 'You cannot provide both :destinationResourceDetails and :destination_resource_details' if attributes.key?(:'destinationResourceDetails') && attributes.key?(:'destination_resource_details')

  self.destination_resource_details = attributes[:'destination_resource_details'] if attributes[:'destination_resource_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#association_typeString

**[Required]** Association type to be created between source and destination resources

Returns:

  • (String)


12
13
14
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 12

def association_type
  @association_type
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


42
43
44
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 42

def defined_tags
  @defined_tags
end

#destination_resource_detailsOCI::StackMonitoring::Models::AssociationResourceDetails



30
31
32
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 30

def destination_resource_details
  @destination_resource_details
end

#destination_resource_idString

**[Required]** Destination Monitored Resource Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)

Returns:

  • (String)


20
21
22
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 20

def destination_resource_id
  @destination_resource_id
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


36
37
38
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 36

def freeform_tags
  @freeform_tags
end

#source_resource_detailsOCI::StackMonitoring::Models::AssociationResourceDetails



27
28
29
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 27

def source_resource_details
  @source_resource_details
end

#source_resource_idString

**[Required]** Source Monitored Resource Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)

Returns:

  • (String)


16
17
18
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 16

def source_resource_id
  @source_resource_id
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


48
49
50
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 48

def system_tags
  @system_tags
end

#time_createdDateTime

The time the the association was created. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


24
25
26
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 24

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 51

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'association_type': :'associationType',
    'source_resource_id': :'sourceResourceId',
    'destination_resource_id': :'destinationResourceId',
    'time_created': :'timeCreated',
    'source_resource_details': :'sourceResourceDetails',
    'destination_resource_details': :'destinationResourceDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 68

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'association_type': :'String',
    'source_resource_id': :'String',
    'destination_resource_id': :'String',
    'time_created': :'DateTime',
    'source_resource_details': :'OCI::StackMonitoring::Models::AssociationResourceDetails',
    'destination_resource_details': :'OCI::StackMonitoring::Models::AssociationResourceDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 167

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    association_type == other.association_type &&
    source_resource_id == other.source_resource_id &&
    destination_resource_id == other.destination_resource_id &&
    time_created == other.time_created &&
    source_resource_details == other.source_resource_details &&
    destination_resource_details == other.destination_resource_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 205

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 185

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



194
195
196
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 194

def hash
  [association_type, source_resource_id, destination_resource_id, time_created, source_resource_details, destination_resource_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



232
233
234
# File 'lib/oci/stack_monitoring/models/monitored_resource_association_summary.rb', line 232

def to_s
  to_hash.to_s
end