Class: OCI::StackMonitoring::Models::MonitoredResourceCredential
- Inherits:
-
Object
- Object
- OCI::StackMonitoring::Models::MonitoredResourceCredential
- Defined in:
- lib/oci/stack_monitoring/models/monitored_resource_credential.rb
Overview
Monitored Resource Credential Details This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
EncryptedCredentials, PlainTextCredentials, PreExistingCredentials
Constant Summary collapse
- CREDENTIAL_TYPE_ENUM =
[ CREDENTIAL_TYPE_EXISTING = 'EXISTING'.freeze, CREDENTIAL_TYPE_PLAINTEXT = 'PLAINTEXT'.freeze, CREDENTIAL_TYPE_ENCRYPTED = 'ENCRYPTED'.freeze, CREDENTIAL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#credential_type ⇒ String
Type of credentials specified in the credentials element.
-
#description ⇒ String
The user-specified textual description of the credential.
-
#name ⇒ String
The name of the credential, within the context of the source.
-
#source ⇒ String
The source type and source name combination,delimited with (.) separator.
-
#type ⇒ String
The type of the credential ( ex. JMXCreds,DBCreds).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MonitoredResourceCredential
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MonitoredResourceCredential
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 93 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.source = attributes[:'source'] if attributes[:'source'] self.name = attributes[:'name'] if attributes[:'name'] self.type = attributes[:'type'] if attributes[:'type'] self.description = attributes[:'description'] if attributes[:'description'] self.credential_type = attributes[:'credentialType'] if attributes[:'credentialType'] raise 'You cannot provide both :credentialType and :credential_type' if attributes.key?(:'credentialType') && attributes.key?(:'credential_type') self.credential_type = attributes[:'credential_type'] if attributes[:'credential_type'] end |
Instance Attribute Details
#credential_type ⇒ String
Type of credentials specified in the credentials element. Three possible values - EXISTING, PLAINTEXT and ENCRYPTED. * EXISTING - Credential is already stored in agent and only credential name need to be passed for existing credential. * PLAINTEXT - The credential properties will have credentials in plain text format. * ENCRYPTED - The credential properties will have credentials stored in vault in encrypted format using KMS client which uses master key for encryption. The same master key will be used to decrypt the credentials before passing on to the management agent.
37 38 39 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 37 def credential_type @credential_type end |
#description ⇒ String
The user-specified textual description of the credential.
33 34 35 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 33 def description @description end |
#name ⇒ String
The name of the credential, within the context of the source.
25 26 27 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 25 def name @name end |
#source ⇒ String
21 22 23 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 21 def source @source end |
#type ⇒ String
The type of the credential ( ex. JMXCreds,DBCreds).
29 30 31 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 29 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'source': :'source', 'name': :'name', 'type': :'type', 'description': :'description', 'credential_type': :'credentialType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 70 def self.get_subtype(object_hash) type = object_hash[:'credentialType'] # rubocop:disable Style/SymbolLiteral return 'OCI::StackMonitoring::Models::PreExistingCredentials' if type == 'EXISTING' return 'OCI::StackMonitoring::Models::EncryptedCredentials' if type == 'ENCRYPTED' return 'OCI::StackMonitoring::Models::PlainTextCredentials' if type == 'PLAINTEXT' # TODO: Log a warning when the subtype is not found. 'OCI::StackMonitoring::Models::MonitoredResourceCredential' end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'source': :'String', 'name': :'String', 'type': :'String', 'description': :'String', 'credential_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 134 def ==(other) return true if equal?(other) self.class == other.class && source == other.source && name == other.name && type == other.type && description == other.description && credential_type == other.credential_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 157 def hash [source, name, type, description, credential_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_credential.rb', line 195 def to_s to_hash.to_s end |