Class: OCI::StackMonitoring::Models::MonitoredResourceMemberSummary
- Inherits:
-
Object
- Object
- OCI::StackMonitoring::Models::MonitoredResourceMemberSummary
- Defined in:
- lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb
Overview
Monitored resource member
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#host_name ⇒ String
Monitored Resource Host.
-
#lifecycle_state ⇒ String
The current state of the Resource.
-
#parent_id ⇒ String
Parent monitored resource identifier.
-
#resource_display_name ⇒ String
Monitored resource display name.
-
#resource_id ⇒ String
Monitored resource identifier.
-
#resource_name ⇒ String
Monitored resource name.
-
#resource_type ⇒ String
Monitored resource type.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MonitoredResourceMemberSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MonitoredResourceMemberSummary
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 119 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.resource_display_name = attributes[:'resourceDisplayName'] if attributes[:'resourceDisplayName'] raise 'You cannot provide both :resourceDisplayName and :resource_display_name' if attributes.key?(:'resourceDisplayName') && attributes.key?(:'resource_display_name') self.resource_display_name = attributes[:'resource_display_name'] if attributes[:'resource_display_name'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.host_name = attributes[:'hostName'] if attributes[:'hostName'] raise 'You cannot provide both :hostName and :host_name' if attributes.key?(:'hostName') && attributes.key?(:'host_name') self.host_name = attributes[:'host_name'] if attributes[:'host_name'] self.parent_id = attributes[:'parentId'] if attributes[:'parentId'] raise 'You cannot provide both :parentId and :parent_id' if attributes.key?(:'parentId') && attributes.key?(:'parent_id') self.parent_id = attributes[:'parent_id'] if attributes[:'parent_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
59 60 61 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 59 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
53 54 55 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 53 def @freeform_tags end |
#host_name ⇒ String
Monitored Resource Host
39 40 41 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 39 def host_name @host_name end |
#lifecycle_state ⇒ String
The current state of the Resource.
47 48 49 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 47 def lifecycle_state @lifecycle_state end |
#parent_id ⇒ String
Parent monitored resource identifier
43 44 45 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 43 def parent_id @parent_id end |
#resource_display_name ⇒ String
Monitored resource display name.
31 32 33 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 31 def resource_display_name @resource_display_name end |
#resource_id ⇒ String
Monitored resource identifier
23 24 25 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 23 def resource_id @resource_id end |
#resource_name ⇒ String
Monitored resource name
27 28 29 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 27 def resource_name @resource_name end |
#resource_type ⇒ String
Monitored resource type
35 36 37 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 35 def resource_type @resource_type end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
65 66 67 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 65 def @system_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 68 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'resource_id': :'resourceId', 'resource_name': :'resourceName', 'resource_display_name': :'resourceDisplayName', 'resource_type': :'resourceType', 'host_name': :'hostName', 'parent_id': :'parentId', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 86 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'resource_id': :'String', 'resource_name': :'String', 'resource_display_name': :'String', 'resource_type': :'String', 'host_name': :'String', 'parent_id': :'String', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 206 def ==(other) return true if equal?(other) self.class == other.class && resource_id == other.resource_id && resource_name == other.resource_name && resource_display_name == other.resource_display_name && resource_type == other.resource_type && host_name == other.host_name && parent_id == other.parent_id && lifecycle_state == other.lifecycle_state && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 245 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
225 226 227 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 225 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
234 235 236 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 234 def hash [resource_id, resource_name, resource_display_name, resource_type, host_name, parent_id, lifecycle_state, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
278 279 280 281 282 283 284 285 286 287 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 278 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
272 273 274 |
# File 'lib/oci/stack_monitoring/models/monitored_resource_member_summary.rb', line 272 def to_s to_hash.to_s end |