Method: OCI::Streaming::StreamClient#update_group

Defined in:
lib/oci/streaming/stream_client.rb

#update_group(stream_id, group_name, update_group_details, opts = {}) ⇒ Response

Note:

Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/streaming/update_group.rb.html) to see an example of how to use update_group API.

Forcefully changes the current location of a group as a whole; reseting processing location of all consumers to a particular location in the stream.

Parameters:

  • stream_id (String)

    The OCID of the stream.

  • group_name (String)

    The name of the consumer group.

  • update_group_details (OCI::Streaming::Models::UpdateGroupDetails)

    The information used to modify the group.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :retry_config (OCI::Retry::RetryConfig)

    The retry configuration to apply to this operation. If no key is provided then the service-level retry configuration defined by #retry_config will be used. If an explicit nil value is provided then the operation will not retry

  • :opc_request_id (String)

    The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.

Returns:

  • (Response)

    A Response object with data of type nil



530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
# File 'lib/oci/streaming/stream_client.rb', line 530

def update_group(stream_id, group_name, update_group_details, opts = {})
  logger.debug 'Calling operation StreamClient#update_group.' if logger

  raise "Missing the required parameter 'stream_id' when calling update_group." if stream_id.nil?
  raise "Missing the required parameter 'group_name' when calling update_group." if group_name.nil?
  raise "Missing the required parameter 'update_group_details' when calling update_group." if update_group_details.nil?
  raise "Parameter value for 'stream_id' must not be blank" if OCI::Internal::Util.blank_string?(stream_id)
  raise "Parameter value for 'group_name' must not be blank" if OCI::Internal::Util.blank_string?(group_name)

  path = '/streams/{streamId}/groups/{groupName}'.sub('{streamId}', stream_id.to_s).sub('{groupName}', group_name.to_s)
  operation_signing_strategy = :standard

  # rubocop:disable Style/NegatedIf
  # Query Params
  query_params = {}

  # Header Params
  header_params = {}
  header_params[:accept] = 'application/json'
  header_params[:'content-type'] = 'application/json'
  header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
  # rubocop:enable Style/NegatedIf

  post_body = @api_client.object_to_http_body(update_group_details)

  # rubocop:disable Metrics/BlockLength
  OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'StreamClient#update_group') do
    @api_client.call_api(
      :PUT,
      path,
      endpoint,
      header_params: header_params,
      query_params: query_params,
      operation_signing_strategy: operation_signing_strategy,
      body: post_body
    )
  end
  # rubocop:enable Metrics/BlockLength
end