Class: OCI::TenantManagerControlPlane::LinkClientCompositeOperations

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/tenant_manager_control_plane/link_client_composite_operations.rb

Overview

This class provides a wrapper around LinkClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(service_client = OCI::TenantManagerControlPlane::LinkClient.new) ⇒ LinkClientCompositeOperations

Initializes a new LinkClientCompositeOperations

Parameters:

  • service_client (OCI::TenantManagerControlPlane::LinkClient) (defaults to: OCI::TenantManagerControlPlane::LinkClient.new)

    The client used to communicate with the service. Defaults to a new service client created via OCI::TenantManagerControlPlane::LinkClient#initialize with no arguments



20
21
22
# File 'lib/oci/tenant_manager_control_plane/link_client_composite_operations.rb', line 20

def initialize(service_client = OCI::TenantManagerControlPlane::LinkClient.new)
  @service_client = service_client
end

Instance Attribute Details

#service_clientOCI::TenantManagerControlPlane::LinkClient (readonly)

The OCI::TenantManagerControlPlane::LinkClient used to communicate with the service_client

Returns:

  • (OCI::TenantManagerControlPlane::LinkClient)


14
15
16
# File 'lib/oci/tenant_manager_control_plane/link_client_composite_operations.rb', line 14

def service_client
  @service_client
end

Instance Method Details

Calls OCI::TenantManagerControlPlane::LinkClient#delete_link and then waits for the Models::Link acted upon to enter the given state(s).

Parameters:

  • link_id (String)

    OCID of the link to terminate.

  • wait_for_states (Array<String>) (defaults to: [])

    An array of states to wait on. These should be valid values for Models::Link#lifecycle_state

  • base_operation_opts (Hash) (defaults to: {})

    Any optional arguments accepted by OCI::TenantManagerControlPlane::LinkClient#delete_link

  • waiter_opts (Hash) (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/oci/tenant_manager_control_plane/link_client_composite_operations.rb', line 39

def delete_link_and_wait_for_state(link_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  initial_get_result = @service_client.get_link(link_id)
  operation_result = @service_client.delete_link(link_id, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)

  begin
    waiter_result = initial_get_result.wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200,
      succeed_on_not_found: true
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end