Class: OCI::TenantManagerControlPlane::Models::CreateDomainGovernanceDetails
- Inherits:
-
Object
- Object
- OCI::TenantManagerControlPlane::Models::CreateDomainGovernanceDetails
- Defined in:
- lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb
Overview
The parameters for creating a domain governance entity.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] OCID of the tenancy.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#domain_id ⇒ String
[Required] OCID of the domain.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#ons_subscription_id ⇒ String
[Required] The ONS subscription associated with this domain governance entity.
-
#ons_topic_id ⇒ String
[Required] The ONS topic associated with this domain governance entity.
-
#subscription_email ⇒ String
[Required] The email to notify the user, and that the ONS subscription will be created with.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDomainGovernanceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDomainGovernanceDetails
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 85 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.domain_id = attributes[:'domainId'] if attributes[:'domainId'] raise 'You cannot provide both :domainId and :domain_id' if attributes.key?(:'domainId') && attributes.key?(:'domain_id') self.domain_id = attributes[:'domain_id'] if attributes[:'domain_id'] self.subscription_email = attributes[:'subscriptionEmail'] if attributes[:'subscriptionEmail'] raise 'You cannot provide both :subscriptionEmail and :subscription_email' if attributes.key?(:'subscriptionEmail') && attributes.key?(:'subscription_email') self.subscription_email = attributes[:'subscription_email'] if attributes[:'subscription_email'] self.ons_topic_id = attributes[:'onsTopicId'] if attributes[:'onsTopicId'] raise 'You cannot provide both :onsTopicId and :ons_topic_id' if attributes.key?(:'onsTopicId') && attributes.key?(:'ons_topic_id') self.ons_topic_id = attributes[:'ons_topic_id'] if attributes[:'ons_topic_id'] self.ons_subscription_id = attributes[:'onsSubscriptionId'] if attributes[:'onsSubscriptionId'] raise 'You cannot provide both :onsSubscriptionId and :ons_subscription_id' if attributes.key?(:'onsSubscriptionId') && attributes.key?(:'ons_subscription_id') self.ons_subscription_id = attributes[:'ons_subscription_id'] if attributes[:'ons_subscription_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] OCID of the tenancy.
12 13 14 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 12 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
40 41 42 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 40 def end |
#domain_id ⇒ String
[Required] OCID of the domain.
16 17 18 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 16 def domain_id @domain_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
34 35 36 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 34 def end |
#ons_subscription_id ⇒ String
[Required] The ONS subscription associated with this domain governance entity.
28 29 30 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 28 def ons_subscription_id @ons_subscription_id end |
#ons_topic_id ⇒ String
[Required] The ONS topic associated with this domain governance entity.
24 25 26 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 24 def ons_topic_id @ons_topic_id end |
#subscription_email ⇒ String
[Required] The email to notify the user, and that the ONS subscription will be created with.
20 21 22 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 20 def subscription_email @subscription_email end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'domain_id': :'domainId', 'subscription_email': :'subscriptionEmail', 'ons_topic_id': :'onsTopicId', 'ons_subscription_id': :'onsSubscriptionId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'domain_id': :'String', 'subscription_email': :'String', 'ons_topic_id': :'String', 'ons_subscription_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 141 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && domain_id == other.domain_id && subscription_email == other.subscription_email && ons_topic_id == other.ons_topic_id && ons_subscription_id == other.ons_subscription_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 177 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
157 158 159 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 157 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 166 def hash [compartment_id, domain_id, subscription_email, ons_topic_id, ons_subscription_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
204 205 206 |
# File 'lib/oci/tenant_manager_control_plane/models/create_domain_governance_details.rb', line 204 def to_s to_hash.to_s end |