Class: OCI::TenantManagerControlPlane::Models::DomainGovernanceSummary
- Inherits:
-
Object
- Object
- OCI::TenantManagerControlPlane::Models::DomainGovernanceSummary
- Defined in:
- lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb
Overview
The summary of a domain govenance entity owned by a tenancy.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#domain_id ⇒ String
[Required] The OCID of the domain associated with this domain governance entity.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The OCID of the domain governance entity.
-
#is_governance_enabled ⇒ BOOLEAN
[Required] Indicates whether governance is enabled for this domain.
-
#lifecycle_state ⇒ String
[Required] The lifecycle state of the domain governance entity.
-
#ons_subscription_id ⇒ String
[Required] The ONS subscription associated with this domain governance entity.
-
#ons_topic_id ⇒ String
[Required] The ONS topic associated with this domain governance entity.
-
#owner_id ⇒ String
[Required] The OCID of the tenancy that owns this domain governance entity.
-
#subscription_email ⇒ String
The email to notify the user, and that the ONS subscription will be created with.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
Date-time when this domain governance was created.
-
#time_updated ⇒ DateTime
Date-time when this domain governance was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainGovernanceSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DomainGovernanceSummary
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 129 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.owner_id = attributes[:'ownerId'] if attributes[:'ownerId'] raise 'You cannot provide both :ownerId and :owner_id' if attributes.key?(:'ownerId') && attributes.key?(:'owner_id') self.owner_id = attributes[:'owner_id'] if attributes[:'owner_id'] self.domain_id = attributes[:'domainId'] if attributes[:'domainId'] raise 'You cannot provide both :domainId and :domain_id' if attributes.key?(:'domainId') && attributes.key?(:'domain_id') self.domain_id = attributes[:'domain_id'] if attributes[:'domain_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.is_governance_enabled = attributes[:'isGovernanceEnabled'] unless attributes[:'isGovernanceEnabled'].nil? raise 'You cannot provide both :isGovernanceEnabled and :is_governance_enabled' if attributes.key?(:'isGovernanceEnabled') && attributes.key?(:'is_governance_enabled') self.is_governance_enabled = attributes[:'is_governance_enabled'] unless attributes[:'is_governance_enabled'].nil? self.subscription_email = attributes[:'subscriptionEmail'] if attributes[:'subscriptionEmail'] raise 'You cannot provide both :subscriptionEmail and :subscription_email' if attributes.key?(:'subscriptionEmail') && attributes.key?(:'subscription_email') self.subscription_email = attributes[:'subscription_email'] if attributes[:'subscription_email'] self.ons_topic_id = attributes[:'onsTopicId'] if attributes[:'onsTopicId'] raise 'You cannot provide both :onsTopicId and :ons_topic_id' if attributes.key?(:'onsTopicId') && attributes.key?(:'ons_topic_id') self.ons_topic_id = attributes[:'ons_topic_id'] if attributes[:'ons_topic_id'] self.ons_subscription_id = attributes[:'onsSubscriptionId'] if attributes[:'onsSubscriptionId'] raise 'You cannot provide both :onsSubscriptionId and :ons_subscription_id' if attributes.key?(:'onsSubscriptionId') && attributes.key?(:'ons_subscription_id') self.ons_subscription_id = attributes[:'ons_subscription_id'] if attributes[:'ons_subscription_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
60 61 62 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 60 def end |
#domain_id ⇒ String
[Required] The OCID of the domain associated with this domain governance entity.
20 21 22 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 20 def domain_id @domain_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
54 55 56 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 54 def end |
#id ⇒ String
[Required] The OCID of the domain governance entity.
12 13 14 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 12 def id @id end |
#is_governance_enabled ⇒ BOOLEAN
[Required] Indicates whether governance is enabled for this domain.
28 29 30 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 28 def is_governance_enabled @is_governance_enabled end |
#lifecycle_state ⇒ String
[Required] The lifecycle state of the domain governance entity.
24 25 26 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 24 def lifecycle_state @lifecycle_state end |
#ons_subscription_id ⇒ String
[Required] The ONS subscription associated with this domain governance entity.
40 41 42 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 40 def ons_subscription_id @ons_subscription_id end |
#ons_topic_id ⇒ String
[Required] The ONS topic associated with this domain governance entity.
36 37 38 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 36 def ons_topic_id @ons_topic_id end |
#owner_id ⇒ String
[Required] The OCID of the tenancy that owns this domain governance entity.
16 17 18 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 16 def owner_id @owner_id end |
#subscription_email ⇒ String
The email to notify the user, and that the ONS subscription will be created with.
32 33 34 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 32 def subscription_email @subscription_email end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`
66 67 68 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 66 def end |
#time_created ⇒ DateTime
Date-time when this domain governance was created. An RFC3339-formatted date and time string.
44 45 46 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 44 def time_created @time_created end |
#time_updated ⇒ DateTime
Date-time when this domain governance was last updated. An RFC3339-formatted date and time string.
48 49 50 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 48 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'owner_id': :'ownerId', 'domain_id': :'domainId', 'lifecycle_state': :'lifecycleState', 'is_governance_enabled': :'isGovernanceEnabled', 'subscription_email': :'subscriptionEmail', 'ons_topic_id': :'onsTopicId', 'ons_subscription_id': :'onsSubscriptionId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 90 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'owner_id': :'String', 'domain_id': :'String', 'lifecycle_state': :'String', 'is_governance_enabled': :'BOOLEAN', 'subscription_email': :'String', 'ons_topic_id': :'String', 'ons_subscription_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 217 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && owner_id == other.owner_id && domain_id == other.domain_id && lifecycle_state == other.lifecycle_state && is_governance_enabled == other.is_governance_enabled && subscription_email == other.subscription_email && ons_topic_id == other.ons_topic_id && ons_subscription_id == other.ons_subscription_id && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 259 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
239 240 241 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 239 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 248 def hash [id, owner_id, domain_id, lifecycle_state, is_governance_enabled, subscription_email, ons_topic_id, ons_subscription_id, time_created, time_updated, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
286 287 288 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_governance_summary.rb', line 286 def to_s to_hash.to_s end |