Class: TenantManagerControlPlane::Models::DomainSummary
- Inherits:
-
Object
- Object
- TenantManagerControlPlane::Models::DomainSummary
- Defined in:
- lib/oci/tenant_manager_control_plane/models/domain_summary.rb
Overview
The summary of a domain owned by a tenancy.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#domain_name ⇒ String
**[Required]** The domain name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** OCID of the domain.
-
#lifecycle_state ⇒ String
**[Required]** The lifecycle state of the domain.
-
#owner_id ⇒ String
**[Required]** The OCID of the tenancy that has started the registration process for this domain.
-
#status ⇒ String
**[Required]** Status of the domain.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
Date-time when this domain was created.
-
#time_updated ⇒ DateTime
Date-time when this domain was last updated.
-
#txt_record ⇒ String
**[Required]** The code that the owner of the domain will need to add as a TXT record to their domain.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DomainSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DomainSummary
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.domain_name = attributes[:'domainName'] if attributes[:'domainName'] raise 'You cannot provide both :domainName and :domain_name' if attributes.key?(:'domainName') && attributes.key?(:'domain_name') self.domain_name = attributes[:'domain_name'] if attributes[:'domain_name'] self.owner_id = attributes[:'ownerId'] if attributes[:'ownerId'] raise 'You cannot provide both :ownerId and :owner_id' if attributes.key?(:'ownerId') && attributes.key?(:'owner_id') self.owner_id = attributes[:'owner_id'] if attributes[:'owner_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.status = attributes[:'status'] if attributes[:'status'] self.txt_record = attributes[:'txtRecord'] if attributes[:'txtRecord'] raise 'You cannot provide both :txtRecord and :txt_record' if attributes.key?(:'txtRecord') && attributes.key?(:'txt_record') self.txt_record = attributes[:'txt_record'] if attributes[:'txt_record'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
53 54 55 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 53 def @defined_tags end |
#domain_name ⇒ String
**[Required]** The domain name.
17 18 19 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 17 def domain_name @domain_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
47 48 49 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 47 def @freeform_tags end |
#id ⇒ String
**[Required]** OCID of the domain.
13 14 15 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 13 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The lifecycle state of the domain.
25 26 27 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 25 def lifecycle_state @lifecycle_state end |
#owner_id ⇒ String
**[Required]** The OCID of the tenancy that has started the registration process for this domain.
21 22 23 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 21 def owner_id @owner_id end |
#status ⇒ String
**[Required]** Status of the domain.
29 30 31 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 29 def status @status end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
59 60 61 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 59 def @system_tags end |
#time_created ⇒ DateTime
Date-time when this domain was created. An RFC 3339-formatted date and time string.
37 38 39 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 37 def time_created @time_created end |
#time_updated ⇒ DateTime
Date-time when this domain was last updated. An RFC 3339-formatted date and time string.
41 42 43 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 41 def time_updated @time_updated end |
#txt_record ⇒ String
**[Required]** The code that the owner of the domain will need to add as a TXT record to their domain.
33 34 35 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 33 def txt_record @txt_record end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 62 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'domain_name': :'domainName', 'owner_id': :'ownerId', 'lifecycle_state': :'lifecycleState', 'status': :'status', 'txt_record': :'txtRecord', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'domain_name': :'String', 'owner_id': :'String', 'lifecycle_state': :'String', 'status': :'String', 'txt_record': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 188 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && domain_name == other.domain_name && owner_id == other.owner_id && lifecycle_state == other.lifecycle_state && status == other.status && txt_record == other.txt_record && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 228 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
208 209 210 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 208 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 217 def hash [id, domain_name, owner_id, lifecycle_state, status, txt_record, time_created, time_updated, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 270 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
255 256 257 |
# File 'lib/oci/tenant_manager_control_plane/models/domain_summary.rb', line 255 def to_s to_hash.to_s end |