Class: TenantManagerControlPlane::Models::Order
- Inherits:
-
Object
- Object
- TenantManagerControlPlane::Models::Order
- Defined in:
- lib/oci/tenant_manager_control_plane/models/order.rb
Overview
Order details.
Instance Attribute Summary collapse
-
#admin_email ⇒ String
**[Required]** Administrator email owning the subscription.
-
#data_center_region ⇒ String
Order's data center region.
-
#order_number ⇒ String
**[Required]** Immutable and unique order number holding customer subscription information.
-
#order_state ⇒ String
**[Required]** State of the order.
-
#subscriptions ⇒ Array<OCI::TenantManagerControlPlane::Models::SubscriptionInfo>
**[Required]** Array of subscriptions associated with the order.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Order
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Order
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.order_number = attributes[:'orderNumber'] if attributes[:'orderNumber'] raise 'You cannot provide both :orderNumber and :order_number' if attributes.key?(:'orderNumber') && attributes.key?(:'order_number') self.order_number = attributes[:'order_number'] if attributes[:'order_number'] self.data_center_region = attributes[:'dataCenterRegion'] if attributes[:'dataCenterRegion'] raise 'You cannot provide both :dataCenterRegion and :data_center_region' if attributes.key?(:'dataCenterRegion') && attributes.key?(:'data_center_region') self.data_center_region = attributes[:'data_center_region'] if attributes[:'data_center_region'] self.admin_email = attributes[:'adminEmail'] if attributes[:'adminEmail'] raise 'You cannot provide both :adminEmail and :admin_email' if attributes.key?(:'adminEmail') && attributes.key?(:'admin_email') self.admin_email = attributes[:'admin_email'] if attributes[:'admin_email'] self.order_state = attributes[:'orderState'] if attributes[:'orderState'] raise 'You cannot provide both :orderState and :order_state' if attributes.key?(:'orderState') && attributes.key?(:'order_state') self.order_state = attributes[:'order_state'] if attributes[:'order_state'] self.subscriptions = attributes[:'subscriptions'] if attributes[:'subscriptions'] end |
Instance Attribute Details
#admin_email ⇒ String
**[Required]** Administrator email owning the subscription.
20 21 22 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 20 def admin_email @admin_email end |
#data_center_region ⇒ String
Order's data center region.
16 17 18 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 16 def data_center_region @data_center_region end |
#order_number ⇒ String
**[Required]** Immutable and unique order number holding customer subscription information.
12 13 14 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 12 def order_number @order_number end |
#order_state ⇒ String
**[Required]** State of the order.
24 25 26 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 24 def order_state @order_state end |
#subscriptions ⇒ Array<OCI::TenantManagerControlPlane::Models::SubscriptionInfo>
**[Required]** Array of subscriptions associated with the order.
28 29 30 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 28 def subscriptions @subscriptions end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'order_number': :'orderNumber', 'data_center_region': :'dataCenterRegion', 'admin_email': :'adminEmail', 'order_state': :'orderState', 'subscriptions': :'subscriptions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'order_number': :'String', 'data_center_region': :'String', 'admin_email': :'String', 'order_state': :'String', 'subscriptions': :'Array<OCI::TenantManagerControlPlane::Models::SubscriptionInfo>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 107 def ==(other) return true if equal?(other) self.class == other.class && order_number == other.order_number && data_center_region == other.data_center_region && admin_email == other.admin_email && order_state == other.order_state && subscriptions == other.subscriptions end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 141 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
121 122 123 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 121 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 130 def hash [order_number, data_center_region, admin_email, order_state, subscriptions].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/oci/tenant_manager_control_plane/models/order.rb', line 168 def to_s to_hash.to_s end |