Class: TenantManagerControlPlane::Models::Organization
- Inherits:
-
Object
- Object
- TenantManagerControlPlane::Models::Organization
- Defined in:
- lib/oci/tenant_manager_control_plane/models/organization.rb
Overview
An organization entity.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** OCID of the compartment containing the organization.
-
#default_ucm_subscription_id ⇒ String
**[Required]** OCID of the default Universal Credits Model subscription.
-
#display_name ⇒ String
A display name for the organization.
-
#id ⇒ String
**[Required]** OCID of the organization.
-
#lifecycle_state ⇒ String
**[Required]** Lifecycle state of the organization.
-
#parent_name ⇒ String
The name of the tenancy that is the organization parent.
-
#time_created ⇒ DateTime
**[Required]** Date-time when this organization was created.
-
#time_updated ⇒ DateTime
Date-time when this organization was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Organization
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Organization
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 99 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.parent_name = attributes[:'parentName'] if attributes[:'parentName'] raise 'You cannot provide both :parentName and :parent_name' if attributes.key?(:'parentName') && attributes.key?(:'parent_name') self.parent_name = attributes[:'parent_name'] if attributes[:'parent_name'] self.default_ucm_subscription_id = attributes[:'defaultUcmSubscriptionId'] if attributes[:'defaultUcmSubscriptionId'] raise 'You cannot provide both :defaultUcmSubscriptionId and :default_ucm_subscription_id' if attributes.key?(:'defaultUcmSubscriptionId') && attributes.key?(:'default_ucm_subscription_id') self.default_ucm_subscription_id = attributes[:'default_ucm_subscription_id'] if attributes[:'default_ucm_subscription_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** OCID of the compartment containing the organization. Always a tenancy OCID.
31 32 33 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 31 def compartment_id @compartment_id end |
#default_ucm_subscription_id ⇒ String
**[Required]** OCID of the default Universal Credits Model subscription. Any tenancy joining the organization will automatically get assigned this subscription if a subscription is not explictly assigned.
39 40 41 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 39 def default_ucm_subscription_id @default_ucm_subscription_id end |
#display_name ⇒ String
A display name for the organization. Avoid entering confidential information.
27 28 29 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 27 def display_name @display_name end |
#id ⇒ String
**[Required]** OCID of the organization.
23 24 25 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 23 def id @id end |
#lifecycle_state ⇒ String
**[Required]** Lifecycle state of the organization.
43 44 45 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 43 def lifecycle_state @lifecycle_state end |
#parent_name ⇒ String
The name of the tenancy that is the organization parent.
35 36 37 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 35 def parent_name @parent_name end |
#time_created ⇒ DateTime
**[Required]** Date-time when this organization was created.
47 48 49 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 47 def time_created @time_created end |
#time_updated ⇒ DateTime
Date-time when this organization was last updated.
51 52 53 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 51 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 54 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'parent_name': :'parentName', 'default_ucm_subscription_id': :'defaultUcmSubscriptionId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 70 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'parent_name': :'String', 'default_ucm_subscription_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 170 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && parent_name == other.parent_name && default_ucm_subscription_id == other.default_ucm_subscription_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 207 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
187 188 189 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 187 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 196 def hash [id, display_name, compartment_id, parent_name, default_ucm_subscription_id, lifecycle_state, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 240 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
234 235 236 |
# File 'lib/oci/tenant_manager_control_plane/models/organization.rb', line 234 def to_s to_hash.to_s end |