Class: OCI::TenantManagerControlPlane::Models::RecipientInvitationSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb

Overview

The summary of the invitation model that the recipient owns.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_PENDING = 'PENDING'.freeze,
  STATUS_CANCELED = 'CANCELED'.freeze,
  STATUS_ACCEPTED = 'ACCEPTED'.freeze,
  STATUS_IGNORED = 'IGNORED'.freeze,
  STATUS_EXPIRED = 'EXPIRED'.freeze,
  STATUS_FAILED = 'FAILED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RecipientInvitationSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :sender_invitation_id (String)

    The value to assign to the #sender_invitation_id property

  • :sender_tenancy_id (String)

    The value to assign to the #sender_tenancy_id property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :status (String)

    The value to assign to the #status property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :recipient_email_address (String)

    The value to assign to the #recipient_email_address property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 150

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.sender_invitation_id = attributes[:'senderInvitationId'] if attributes[:'senderInvitationId']

  raise 'You cannot provide both :senderInvitationId and :sender_invitation_id' if attributes.key?(:'senderInvitationId') && attributes.key?(:'sender_invitation_id')

  self.sender_invitation_id = attributes[:'sender_invitation_id'] if attributes[:'sender_invitation_id']

  self.sender_tenancy_id = attributes[:'senderTenancyId'] if attributes[:'senderTenancyId']

  raise 'You cannot provide both :senderTenancyId and :sender_tenancy_id' if attributes.key?(:'senderTenancyId') && attributes.key?(:'sender_tenancy_id')

  self.sender_tenancy_id = attributes[:'sender_tenancy_id'] if attributes[:'sender_tenancy_id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.status = attributes[:'status'] if attributes[:'status']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.recipient_email_address = attributes[:'recipientEmailAddress'] if attributes[:'recipientEmailAddress']

  raise 'You cannot provide both :recipientEmailAddress and :recipient_email_address' if attributes.key?(:'recipientEmailAddress') && attributes.key?(:'recipient_email_address')

  self.recipient_email_address = attributes[:'recipient_email_address'] if attributes[:'recipient_email_address']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

[Required] OCID of the recipient tenancy.

Returns:

  • (String)


37
38
39
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 37

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


81
82
83
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 81

def defined_tags
  @defined_tags
end

#display_nameString

[Required] A user-created name to describe the invitation. Avoid entering confidential information.

Returns:

  • (String)


41
42
43
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 41

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


75
76
77
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 75

def freeform_tags
  @freeform_tags
end

#idString

[Required] OCID of the recipient invitation.

Returns:

  • (String)


33
34
35
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 33

def id
  @id
end

#lifecycle_stateString

[Required] Lifecycle state of the recipient invitation.

Returns:

  • (String)


53
54
55
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 53

def lifecycle_state
  @lifecycle_state
end

#recipient_email_addressString

Email address of the recipient.

Returns:

  • (String)


69
70
71
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 69

def recipient_email_address
  @recipient_email_address
end

#sender_invitation_idString

[Required] OCID of the corresponding sender invitation.

Returns:

  • (String)


45
46
47
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 45

def sender_invitation_id
  @sender_invitation_id
end

#sender_tenancy_idString

[Required] OCID of the sender tenancy.

Returns:

  • (String)


49
50
51
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 49

def sender_tenancy_id
  @sender_tenancy_id
end

#statusString

[Required] Status of the recipient invitation.

Returns:

  • (String)


57
58
59
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 57

def status
  @status
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


87
88
89
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 87

def system_tags
  @system_tags
end

#time_createdDateTime

[Required] Date-time when this recipient invitation was created.

Returns:

  • (DateTime)


61
62
63
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 61

def time_created
  @time_created
end

#time_updatedDateTime

Date-time when this recipient invitation was last updated.

Returns:

  • (DateTime)


65
66
67
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 65

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 90

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'sender_invitation_id': :'senderInvitationId',
    'sender_tenancy_id': :'senderTenancyId',
    'lifecycle_state': :'lifecycleState',
    'status': :'status',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'recipient_email_address': :'recipientEmailAddress',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 111

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'sender_invitation_id': :'String',
    'sender_tenancy_id': :'String',
    'lifecycle_state': :'String',
    'status': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'recipient_email_address': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 260

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    sender_invitation_id == other.sender_invitation_id &&
    sender_tenancy_id == other.sender_tenancy_id &&
    lifecycle_state == other.lifecycle_state &&
    status == other.status &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    recipient_email_address == other.recipient_email_address &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 302

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


282
283
284
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 282

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



291
292
293
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 291

def hash
  [id, compartment_id, display_name, sender_invitation_id, sender_tenancy_id, lifecycle_state, status, time_created, time_updated, recipient_email_address, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



335
336
337
338
339
340
341
342
343
344
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 335

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



329
330
331
# File 'lib/oci/tenant_manager_control_plane/models/recipient_invitation_summary.rb', line 329

def to_s
  to_hash.to_s
end