Class: TenantManagerControlPlane::Models::SubscriptionInfo
- Inherits:
-
Object
- Object
- TenantManagerControlPlane::Models::SubscriptionInfo
- Defined in:
- lib/oci/tenant_manager_control_plane/models/subscription_info.rb
Overview
A single subscription's details.
Instance Attribute Summary collapse
-
#end_date ⇒ DateTime
**[Required]** Subscription end date.
-
#service ⇒ String
**[Required]** Service name for subscription.
-
#skus ⇒ Array<OCI::TenantManagerControlPlane::Models::Sku>
**[Required]** List of SKUs the subscription contains.
-
#spm_subscription_id ⇒ String
**[Required]** Subscription ID.
-
#start_date ⇒ DateTime
**[Required]** Subscription start date.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubscriptionInfo
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SubscriptionInfo
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.spm_subscription_id = attributes[:'spmSubscriptionId'] if attributes[:'spmSubscriptionId'] raise 'You cannot provide both :spmSubscriptionId and :spm_subscription_id' if attributes.key?(:'spmSubscriptionId') && attributes.key?(:'spm_subscription_id') self.spm_subscription_id = attributes[:'spm_subscription_id'] if attributes[:'spm_subscription_id'] self.service = attributes[:'service'] if attributes[:'service'] self.start_date = attributes[:'startDate'] if attributes[:'startDate'] raise 'You cannot provide both :startDate and :start_date' if attributes.key?(:'startDate') && attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] if attributes[:'start_date'] self.end_date = attributes[:'endDate'] if attributes[:'endDate'] raise 'You cannot provide both :endDate and :end_date' if attributes.key?(:'endDate') && attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] if attributes[:'end_date'] self.skus = attributes[:'skus'] if attributes[:'skus'] end |
Instance Attribute Details
#end_date ⇒ DateTime
**[Required]** Subscription end date. An RFC 3339-formatted date and time string.
24 25 26 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 24 def end_date @end_date end |
#service ⇒ String
**[Required]** Service name for subscription.
16 17 18 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 16 def service @service end |
#skus ⇒ Array<OCI::TenantManagerControlPlane::Models::Sku>
**[Required]** List of SKUs the subscription contains.
28 29 30 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 28 def skus @skus end |
#spm_subscription_id ⇒ String
**[Required]** Subscription ID.
12 13 14 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 12 def spm_subscription_id @spm_subscription_id end |
#start_date ⇒ DateTime
**[Required]** Subscription start date. An RFC 3339-formatted date and time string.
20 21 22 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 20 def start_date @start_date end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'spm_subscription_id': :'spmSubscriptionId', 'service': :'service', 'start_date': :'startDate', 'end_date': :'endDate', 'skus': :'skus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'spm_subscription_id': :'String', 'service': :'String', 'start_date': :'DateTime', 'end_date': :'DateTime', 'skus': :'Array<OCI::TenantManagerControlPlane::Models::Sku>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 103 def ==(other) return true if equal?(other) self.class == other.class && spm_subscription_id == other.spm_subscription_id && service == other.service && start_date == other.start_date && end_date == other.end_date && skus == other.skus end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 137 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
117 118 119 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 117 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 126 def hash [spm_subscription_id, service, start_date, end_date, skus].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
164 165 166 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_info.rb', line 164 def to_s to_hash.to_s end |