Class: TenantManagerControlPlane::Models::SubscriptionMapping

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb

Overview

Subscription mapping information.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionMapping

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :subscription_id (String)

    The value to assign to the #subscription_id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :is_explicitly_assigned (BOOLEAN)

    The value to assign to the #is_explicitly_assigned property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_terminated (DateTime)

    The value to assign to the #time_terminated property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 100

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.subscription_id = attributes[:'subscriptionId'] if attributes[:'subscriptionId']

  raise 'You cannot provide both :subscriptionId and :subscription_id' if attributes.key?(:'subscriptionId') && attributes.key?(:'subscription_id')

  self.subscription_id = attributes[:'subscription_id'] if attributes[:'subscription_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.is_explicitly_assigned = attributes[:'isExplicitlyAssigned'] unless attributes[:'isExplicitlyAssigned'].nil?
  self.is_explicitly_assigned = false if is_explicitly_assigned.nil? && !attributes.key?(:'isExplicitlyAssigned') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isExplicitlyAssigned and :is_explicitly_assigned' if attributes.key?(:'isExplicitlyAssigned') && attributes.key?(:'is_explicitly_assigned')

  self.is_explicitly_assigned = attributes[:'is_explicitly_assigned'] unless attributes[:'is_explicitly_assigned'].nil?
  self.is_explicitly_assigned = false if is_explicitly_assigned.nil? && !attributes.key?(:'isExplicitlyAssigned') && !attributes.key?(:'is_explicitly_assigned') # rubocop:disable Style/StringLiterals

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_terminated = attributes[:'timeTerminated'] if attributes[:'timeTerminated']

  raise 'You cannot provide both :timeTerminated and :time_terminated' if attributes.key?(:'timeTerminated') && attributes.key?(:'time_terminated')

  self.time_terminated = attributes[:'time_terminated'] if attributes[:'time_terminated']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']
end

Instance Attribute Details

#compartment_idString

**[Required]** OCID of the compartment. Always a tenancy OCID.

Returns:

  • (String)


32
33
34
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 32

def compartment_id
  @compartment_id
end

#idString

**[Required]** OCID of the mapping between subscription and compartment identified by the tenancy.

Returns:

  • (String)


24
25
26
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 24

def id
  @id
end

#is_explicitly_assignedBOOLEAN

**[Required]** Denotes if the subscription is explicity assigned to the root compartment or tenancy.

Returns:

  • (BOOLEAN)


36
37
38
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 36

def is_explicitly_assigned
  @is_explicitly_assigned
end

#lifecycle_stateString

**[Required]** Lifecycle state of the subscriptionMapping.

Returns:

  • (String)


40
41
42
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 40

def lifecycle_state
  @lifecycle_state
end

#subscription_idString

**[Required]** OCID of the subscription.

Returns:

  • (String)


28
29
30
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 28

def subscription_id
  @subscription_id
end

#time_createdDateTime

**[Required]** Date-time when subscription mapping was created.

Returns:

  • (DateTime)


48
49
50
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 48

def time_created
  @time_created
end

#time_terminatedDateTime

Date-time when subscription mapping was terminated.

Returns:

  • (DateTime)


44
45
46
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 44

def time_terminated
  @time_terminated
end

#time_updatedDateTime

**[Required]** Date-time when subscription mapping was updated.

Returns:

  • (DateTime)


52
53
54
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 52

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 55

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'subscription_id': :'subscriptionId',
    'compartment_id': :'compartmentId',
    'is_explicitly_assigned': :'isExplicitlyAssigned',
    'lifecycle_state': :'lifecycleState',
    'time_terminated': :'timeTerminated',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 71

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'subscription_id': :'String',
    'compartment_id': :'String',
    'is_explicitly_assigned': :'BOOLEAN',
    'lifecycle_state': :'String',
    'time_terminated': :'DateTime',
    'time_created': :'DateTime',
    'time_updated': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 173

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    subscription_id == other.subscription_id &&
    compartment_id == other.compartment_id &&
    is_explicitly_assigned == other.is_explicitly_assigned &&
    lifecycle_state == other.lifecycle_state &&
    time_terminated == other.time_terminated &&
    time_created == other.time_created &&
    time_updated == other.time_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 210

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


190
191
192
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 190

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



199
200
201
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 199

def hash
  [id, subscription_id, compartment_id, is_explicitly_assigned, lifecycle_state, time_terminated, time_created, time_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



237
238
239
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping.rb', line 237

def to_s
  to_hash.to_s
end