Class: OCI::TenantManagerControlPlane::Models::SubscriptionMappingSummary
- Inherits:
-
Object
- Object
- OCI::TenantManagerControlPlane::Models::SubscriptionMappingSummary
- Defined in:
- lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb
Overview
Subscription mapping information.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] OCID of the compartment.
-
#id ⇒ String
[Required] OCID of the mapping between subscription and compartment identified by the tenancy.
-
#is_explicitly_assigned ⇒ BOOLEAN
[Required] Denotes if the subscription is explicity assigned to the root compartment or tenancy.
-
#lifecycle_state ⇒ String
[Required] Lifecycle state of the subscription mapping.
-
#subscription_id ⇒ String
[Required] OCID of the subscription.
-
#time_created ⇒ DateTime
[Required] Date-time when subscription mapping was created.
-
#time_terminated ⇒ DateTime
Date-time when subscription mapping was terminated.
-
#time_updated ⇒ DateTime
[Required] Date-time when subscription mapping was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubscriptionMappingSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SubscriptionMappingSummary
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.subscription_id = attributes[:'subscriptionId'] if attributes[:'subscriptionId'] raise 'You cannot provide both :subscriptionId and :subscription_id' if attributes.key?(:'subscriptionId') && attributes.key?(:'subscription_id') self.subscription_id = attributes[:'subscription_id'] if attributes[:'subscription_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_explicitly_assigned = attributes[:'isExplicitlyAssigned'] unless attributes[:'isExplicitlyAssigned'].nil? self.is_explicitly_assigned = false if is_explicitly_assigned.nil? && !attributes.key?(:'isExplicitlyAssigned') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isExplicitlyAssigned and :is_explicitly_assigned' if attributes.key?(:'isExplicitlyAssigned') && attributes.key?(:'is_explicitly_assigned') self.is_explicitly_assigned = attributes[:'is_explicitly_assigned'] unless attributes[:'is_explicitly_assigned'].nil? self.is_explicitly_assigned = false if is_explicitly_assigned.nil? && !attributes.key?(:'isExplicitlyAssigned') && !attributes.key?(:'is_explicitly_assigned') # rubocop:disable Style/StringLiterals self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_terminated = attributes[:'timeTerminated'] if attributes[:'timeTerminated'] raise 'You cannot provide both :timeTerminated and :time_terminated' if attributes.key?(:'timeTerminated') && attributes.key?(:'time_terminated') self.time_terminated = attributes[:'time_terminated'] if attributes[:'time_terminated'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] OCID of the compartment. Always a tenancy OCID.
20 21 22 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 20 def compartment_id @compartment_id end |
#id ⇒ String
[Required] OCID of the mapping between subscription and compartment identified by the tenancy.
12 13 14 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 12 def id @id end |
#is_explicitly_assigned ⇒ BOOLEAN
[Required] Denotes if the subscription is explicity assigned to the root compartment or tenancy.
24 25 26 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 24 def is_explicitly_assigned @is_explicitly_assigned end |
#lifecycle_state ⇒ String
[Required] Lifecycle state of the subscription mapping.
28 29 30 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 28 def lifecycle_state @lifecycle_state end |
#subscription_id ⇒ String
[Required] OCID of the subscription.
16 17 18 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 16 def subscription_id @subscription_id end |
#time_created ⇒ DateTime
[Required] Date-time when subscription mapping was created.
36 37 38 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 36 def time_created @time_created end |
#time_terminated ⇒ DateTime
Date-time when subscription mapping was terminated.
32 33 34 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 32 def time_terminated @time_terminated end |
#time_updated ⇒ DateTime
[Required] Date-time when subscription mapping was updated.
40 41 42 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 40 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'subscription_id': :'subscriptionId', 'compartment_id': :'compartmentId', 'is_explicitly_assigned': :'isExplicitlyAssigned', 'lifecycle_state': :'lifecycleState', 'time_terminated': :'timeTerminated', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'subscription_id': :'String', 'compartment_id': :'String', 'is_explicitly_assigned': :'BOOLEAN', 'lifecycle_state': :'String', 'time_terminated': :'DateTime', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 148 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && subscription_id == other.subscription_id && compartment_id == other.compartment_id && is_explicitly_assigned == other.is_explicitly_assigned && lifecycle_state == other.lifecycle_state && time_terminated == other.time_terminated && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 174 def hash [id, subscription_id, compartment_id, is_explicitly_assigned, lifecycle_state, time_terminated, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/tenant_manager_control_plane/models/subscription_mapping_summary.rb', line 212 def to_s to_hash.to_s end |