Class: OCI::TenantManagerControlPlane::OrdersClientCompositeOperations

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/tenant_manager_control_plane/orders_client_composite_operations.rb

Overview

This class provides a wrapper around OrdersClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(service_client = OCI::TenantManagerControlPlane::OrdersClient.new) ⇒ OrdersClientCompositeOperations

Initializes a new OrdersClientCompositeOperations

Parameters:

  • (defaults to: OCI::TenantManagerControlPlane::OrdersClient.new)

    The client used to communicate with the service. Defaults to a new service client created via OCI::TenantManagerControlPlane::OrdersClient#initialize with no arguments



20
21
22
# File 'lib/oci/tenant_manager_control_plane/orders_client_composite_operations.rb', line 20

def initialize(service_client = OCI::TenantManagerControlPlane::OrdersClient.new)
  @service_client = service_client
end

Instance Attribute Details

#service_clientOCI::TenantManagerControlPlane::OrdersClient (readonly)

The OCI::TenantManagerControlPlane::OrdersClient used to communicate with the service_client

Returns:



14
15
16
# File 'lib/oci/tenant_manager_control_plane/orders_client_composite_operations.rb', line 14

def service_client
  @service_client
end

Instance Method Details

#activate_order_and_wait_for_state(activate_order_details, activation_token, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::TenantManagerControlPlane::OrdersClient#activate_order and then waits for the Models::WorkRequest to enter the given state(s).

Parameters:

  • The information needed to activate an order in a tenancy.

  • Activation Token containing an order id. JWT RFC 7519 formatted string.

  • (defaults to: [])

    An array of states to wait on. These should be valid values for Models::WorkRequest#status

  • (defaults to: {})

    Any optional arguments accepted by OCI::TenantManagerControlPlane::OrdersClient#activate_order

  • (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:

  • A Response object containing the completed Models::WorkRequest



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/tenant_manager_control_plane/orders_client_composite_operations.rb', line 41

def activate_order_and_wait_for_state(activate_order_details, activation_token, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.activate_order(activate_order_details, activation_token, base_operation_opts)
  use_util = OCI::TenantManagerControlPlane::Util.respond_to?(:wait_on_work_request)

  return operation_result if wait_for_states.empty? && !use_util

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.headers['opc-work-request-id']

  begin
    if use_util
      waiter_result = OCI::TenantManagerControlPlane::Util.wait_on_work_request(
        @service_client,
        wait_for_resource_id,
        max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
        max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
      )
    else
      waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until(
        eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) },
        max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
        max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
      )
    end
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end