Class: TenantManagerControlPlane::RecipientInvitationClient
- Inherits:
-
Object
- Object
- TenantManagerControlPlane::RecipientInvitationClient
- Defined in:
- lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb
Overview
The Organizations API allows you to consolidate multiple OCI tenancies into an organization, and centrally manage your tenancies and its resources.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in OCI::Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#accept_recipient_invitation(recipient_invitation_id, opts = {}) ⇒ Response
Accepts a recipient invitation.
-
#get_recipient_invitation(recipient_invitation_id, opts = {}) ⇒ Response
Gets information about the recipient invitation.
-
#ignore_recipient_invitation(recipient_invitation_id, opts = {}) ⇒ Response
Ignores a recipient invitation.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ RecipientInvitationClient
constructor
Creates a new RecipientInvitationClient.
-
#list_recipient_invitations(compartment_id, opts = {}) ⇒ Response
Return a (paginated) list of recipient invitations.
-
#logger ⇒ Logger
The logger for this client.
-
#update_recipient_invitation(recipient_invitation_id, update_recipient_invitation_details, opts = {}) ⇒ Response
Updates the RecipientInvitation.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ RecipientInvitationClient
Creates a new RecipientInvitationClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20200801' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "RecipientInvitationClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in OCI::Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is `nil`, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#accept_recipient_invitation(recipient_invitation_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/tenantmanagercontrolplane/accept_recipient_invitation.rb.html) to see an example of how to use accept_recipient_invitation API.
Accepts a recipient invitation.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 121 def accept_recipient_invitation(recipient_invitation_id, opts = {}) logger.debug 'Calling operation RecipientInvitationClient#accept_recipient_invitation.' if logger raise "Missing the required parameter 'recipient_invitation_id' when calling accept_recipient_invitation." if recipient_invitation_id.nil? raise "Parameter value for 'recipient_invitation_id' must not be blank" if OCI::Internal::Util.blank_string?(recipient_invitation_id) path = '/recipientInvitations/{recipientInvitationId}/actions/accept'.sub('{recipientInvitationId}', recipient_invitation_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'RecipientInvitationClient#accept_recipient_invitation') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_recipient_invitation(recipient_invitation_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/tenantmanagercontrolplane/get_recipient_invitation.rb.html) to see an example of how to use get_recipient_invitation API.
Gets information about the recipient invitation.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 177 def get_recipient_invitation(recipient_invitation_id, opts = {}) logger.debug 'Calling operation RecipientInvitationClient#get_recipient_invitation.' if logger raise "Missing the required parameter 'recipient_invitation_id' when calling get_recipient_invitation." if recipient_invitation_id.nil? raise "Parameter value for 'recipient_invitation_id' must not be blank" if OCI::Internal::Util.blank_string?(recipient_invitation_id) path = '/recipientInvitations/{recipientInvitationId}'.sub('{recipientInvitationId}', recipient_invitation_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'RecipientInvitationClient#get_recipient_invitation') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::TenantManagerControlPlane::Models::RecipientInvitation' ) end # rubocop:enable Metrics/BlockLength end |
#ignore_recipient_invitation(recipient_invitation_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/tenantmanagercontrolplane/ignore_recipient_invitation.rb.html) to see an example of how to use ignore_recipient_invitation API.
Ignores a recipient invitation.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 243 def ignore_recipient_invitation(recipient_invitation_id, opts = {}) logger.debug 'Calling operation RecipientInvitationClient#ignore_recipient_invitation.' if logger raise "Missing the required parameter 'recipient_invitation_id' when calling ignore_recipient_invitation." if recipient_invitation_id.nil? raise "Parameter value for 'recipient_invitation_id' must not be blank" if OCI::Internal::Util.blank_string?(recipient_invitation_id) path = '/recipientInvitations/{recipientInvitationId}/actions/ignore'.sub('{recipientInvitationId}', recipient_invitation_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'RecipientInvitationClient#ignore_recipient_invitation') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::TenantManagerControlPlane::Models::RecipientInvitation' ) end # rubocop:enable Metrics/BlockLength end |
#list_recipient_invitations(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/tenantmanagercontrolplane/list_recipient_invitations.rb.html) to see an example of how to use list_recipient_invitations API.
Return a (paginated) list of recipient invitations.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 305 def list_recipient_invitations(compartment_id, opts = {}) logger.debug 'Calling operation RecipientInvitationClient#list_recipient_invitations.' if logger raise "Missing the required parameter 'compartment_id' when calling list_recipient_invitations." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::TenantManagerControlPlane::Models::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::TenantManagerControlPlane::Models::LIFECYCLE_STATE_ENUM.' end if opts[:status] && !OCI::TenantManagerControlPlane::Models::RECIPIENT_INVITATION_STATUS_ENUM.include?(opts[:status]) raise 'Invalid value for "status", must be one of the values in OCI::TenantManagerControlPlane::Models::RECIPIENT_INVITATION_STATUS_ENUM.' end path = '/recipientInvitations' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:senderTenancyId] = opts[:sender_tenancy_id] if opts[:sender_tenancy_id] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:status] = opts[:status] if opts[:status] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'RecipientInvitationClient#list_recipient_invitations') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::TenantManagerControlPlane::Models::RecipientInvitationCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 92 def logger @api_client.config.logger end |
#update_recipient_invitation(recipient_invitation_id, update_recipient_invitation_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/tenantmanagercontrolplane/update_recipient_invitation.rb.html) to see an example of how to use update_recipient_invitation API.
Updates the RecipientInvitation.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client.rb', line 378 def update_recipient_invitation(recipient_invitation_id, update_recipient_invitation_details, opts = {}) logger.debug 'Calling operation RecipientInvitationClient#update_recipient_invitation.' if logger raise "Missing the required parameter 'recipient_invitation_id' when calling update_recipient_invitation." if recipient_invitation_id.nil? raise "Missing the required parameter 'update_recipient_invitation_details' when calling update_recipient_invitation." if update_recipient_invitation_details.nil? raise "Parameter value for 'recipient_invitation_id' must not be blank" if OCI::Internal::Util.blank_string?(recipient_invitation_id) path = '/recipientInvitations/{recipientInvitationId}'.sub('{recipientInvitationId}', recipient_invitation_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_recipient_invitation_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'RecipientInvitationClient#update_recipient_invitation') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::TenantManagerControlPlane::Models::RecipientInvitation' ) end # rubocop:enable Metrics/BlockLength end |