Class: OCI::TenantManagerControlPlane::RecipientInvitationClientCompositeOperations

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/tenant_manager_control_plane/recipient_invitation_client_composite_operations.rb

Overview

This class provides a wrapper around RecipientInvitationClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(service_client = OCI::TenantManagerControlPlane::RecipientInvitationClient.new) ⇒ RecipientInvitationClientCompositeOperations

Initializes a new RecipientInvitationClientCompositeOperations

Parameters:

  • (defaults to: OCI::TenantManagerControlPlane::RecipientInvitationClient.new)

    The client used to communicate with the service. Defaults to a new service client created via OCI::TenantManagerControlPlane::RecipientInvitationClient#initialize with no arguments



20
21
22
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client_composite_operations.rb', line 20

def initialize(service_client = OCI::TenantManagerControlPlane::RecipientInvitationClient.new)
  @service_client = service_client
end

Instance Attribute Details

#service_clientOCI::TenantManagerControlPlane::RecipientInvitationClient (readonly)

The OCI::TenantManagerControlPlane::RecipientInvitationClient used to communicate with the service_client

Returns:



14
15
16
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client_composite_operations.rb', line 14

def service_client
  @service_client
end

Instance Method Details

#accept_recipient_invitation_and_wait_for_state(recipient_invitation_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::TenantManagerControlPlane::RecipientInvitationClient#accept_recipient_invitation and then waits for the Models::WorkRequest to enter the given state(s).

Parameters:

  • OCID of recipient invitation to accept.

  • (defaults to: [])

    An array of states to wait on. These should be valid values for Models::WorkRequest#status

  • (defaults to: {})

    Any optional arguments accepted by OCI::TenantManagerControlPlane::RecipientInvitationClient#accept_recipient_invitation

  • (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:

  • A Response object containing the completed Models::WorkRequest



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client_composite_operations.rb', line 39

def accept_recipient_invitation_and_wait_for_state(recipient_invitation_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.accept_recipient_invitation(recipient_invitation_id, base_operation_opts)
  use_util = OCI::TenantManagerControlPlane::Util.respond_to?(:wait_on_work_request)

  return operation_result if wait_for_states.empty? && !use_util

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.headers['opc-work-request-id']

  begin
    if use_util
      waiter_result = OCI::TenantManagerControlPlane::Util.wait_on_work_request(
        @service_client,
        wait_for_resource_id,
        max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
        max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
      )
    else
      waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until(
        eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) },
        max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
        max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
      )
    end
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#ignore_recipient_invitation_and_wait_for_state(recipient_invitation_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::TenantManagerControlPlane::RecipientInvitationClient#ignore_recipient_invitation and then waits for the Models::RecipientInvitation acted upon to enter the given state(s).

Parameters:

  • OCID of recipient invitation to ignore.

  • (defaults to: [])

    An array of states to wait on. These should be valid values for Models::RecipientInvitation#lifecycle_state

  • (defaults to: {})

    Any optional arguments accepted by OCI::TenantManagerControlPlane::RecipientInvitationClient#ignore_recipient_invitation

  • (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:

  • A Response object with data of type Models::RecipientInvitation



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client_composite_operations.rb', line 88

def ignore_recipient_invitation_and_wait_for_state(recipient_invitation_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.ignore_recipient_invitation(recipient_invitation_id, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_recipient_invitation(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end

#update_recipient_invitation_and_wait_for_state(recipient_invitation_id, update_recipient_invitation_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response

Calls OCI::TenantManagerControlPlane::RecipientInvitationClient#update_recipient_invitation and then waits for the Models::RecipientInvitation acted upon to enter the given state(s).

Parameters:

  • OCID of the recipient invitation to update.

  • The information to be updated.

  • (defaults to: [])

    An array of states to wait on. These should be valid values for Models::RecipientInvitation#lifecycle_state

  • (defaults to: {})

    Any optional arguments accepted by OCI::TenantManagerControlPlane::RecipientInvitationClient#update_recipient_invitation

  • (defaults to: {})

    Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:

    • max_interval_seconds: The maximum interval between queries, in seconds.

    • max_wait_seconds The maximum time to wait, in seconds

Returns:

  • A Response object with data of type Models::RecipientInvitation



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/tenant_manager_control_plane/recipient_invitation_client_composite_operations.rb', line 128

def update_recipient_invitation_and_wait_for_state(recipient_invitation_id, update_recipient_invitation_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
  operation_result = @service_client.update_recipient_invitation(recipient_invitation_id, update_recipient_invitation_details, base_operation_opts)

  return operation_result if wait_for_states.empty?

  lowered_wait_for_states = wait_for_states.map(&:downcase)
  wait_for_resource_id = operation_result.data.id

  begin
    waiter_result = @service_client.get_recipient_invitation(wait_for_resource_id).wait_until(
      eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
      max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
      max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
    )
    result_to_return = waiter_result

    return result_to_return
  rescue StandardError
    raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
  end
end