Class: TenantManagerControlPlane::SenderInvitationClient
- Inherits:
-
Object
- Object
- TenantManagerControlPlane::SenderInvitationClient
- Defined in:
- lib/oci/tenant_manager_control_plane/sender_invitation_client.rb
Overview
The Organizations API allows you to consolidate multiple OCI tenancies into an organization, and centrally manage your tenancies and its resources.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in OCI::Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#cancel_sender_invitation(sender_invitation_id, opts = {}) ⇒ Response
Cancels a sender invitation.
-
#create_sender_invitation(create_sender_invitation_details, opts = {}) ⇒ Response
Creates a sender invitation and asynchronously sends the invitation to the recipient.
-
#get_sender_invitation(sender_invitation_id, opts = {}) ⇒ Response
Gets information about the sender invitation.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ SenderInvitationClient
constructor
Creates a new SenderInvitationClient.
-
#list_sender_invitations(compartment_id, opts = {}) ⇒ Response
Return a (paginated) list of sender invitations.
-
#logger ⇒ Logger
The logger for this client.
-
#update_sender_invitation(sender_invitation_id, update_sender_invitation_details, opts = {}) ⇒ Response
Updates the SenderInvitation.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ SenderInvitationClient
Creates a new SenderInvitationClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20200801' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "SenderInvitationClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in OCI::Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is `nil`, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#cancel_sender_invitation(sender_invitation_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/tenantmanagercontrolplane/cancel_sender_invitation.rb.html) to see an example of how to use cancel_sender_invitation API.
Cancels a sender invitation.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 121 def cancel_sender_invitation(sender_invitation_id, opts = {}) logger.debug 'Calling operation SenderInvitationClient#cancel_sender_invitation.' if logger raise "Missing the required parameter 'sender_invitation_id' when calling cancel_sender_invitation." if sender_invitation_id.nil? raise "Parameter value for 'sender_invitation_id' must not be blank" if OCI::Internal::Util.blank_string?(sender_invitation_id) path = '/senderInvitations/{senderInvitationId}/actions/cancel'.sub('{senderInvitationId}', sender_invitation_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'SenderInvitationClient#cancel_sender_invitation') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_sender_invitation(create_sender_invitation_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/tenantmanagercontrolplane/create_sender_invitation.rb.html) to see an example of how to use create_sender_invitation API.
Creates a sender invitation and asynchronously sends the invitation to the recipient.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 183 def create_sender_invitation(create_sender_invitation_details, opts = {}) logger.debug 'Calling operation SenderInvitationClient#create_sender_invitation.' if logger raise "Missing the required parameter 'create_sender_invitation_details' when calling create_sender_invitation." if create_sender_invitation_details.nil? path = '/senderInvitations' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_sender_invitation_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'SenderInvitationClient#create_sender_invitation') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::TenantManagerControlPlane::Models::SenderInvitation' ) end # rubocop:enable Metrics/BlockLength end |
#get_sender_invitation(sender_invitation_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/tenantmanagercontrolplane/get_sender_invitation.rb.html) to see an example of how to use get_sender_invitation API.
Gets information about the sender invitation.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 238 def get_sender_invitation(sender_invitation_id, opts = {}) logger.debug 'Calling operation SenderInvitationClient#get_sender_invitation.' if logger raise "Missing the required parameter 'sender_invitation_id' when calling get_sender_invitation." if sender_invitation_id.nil? raise "Parameter value for 'sender_invitation_id' must not be blank" if OCI::Internal::Util.blank_string?(sender_invitation_id) path = '/senderInvitations/{senderInvitationId}'.sub('{senderInvitationId}', sender_invitation_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'SenderInvitationClient#get_sender_invitation') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::TenantManagerControlPlane::Models::SenderInvitation' ) end # rubocop:enable Metrics/BlockLength end |
#list_sender_invitations(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/tenantmanagercontrolplane/list_sender_invitations.rb.html) to see an example of how to use list_sender_invitations API.
Return a (paginated) list of sender invitations.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 306 def list_sender_invitations(compartment_id, opts = {}) logger.debug 'Calling operation SenderInvitationClient#list_sender_invitations.' if logger raise "Missing the required parameter 'compartment_id' when calling list_sender_invitations." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::TenantManagerControlPlane::Models::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::TenantManagerControlPlane::Models::LIFECYCLE_STATE_ENUM.' end if opts[:status] && !OCI::TenantManagerControlPlane::Models::SENDER_INVITATION_STATUS_ENUM.include?(opts[:status]) raise 'Invalid value for "status", must be one of the values in OCI::TenantManagerControlPlane::Models::SENDER_INVITATION_STATUS_ENUM.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end if opts[:sort_order] && !OCI::TenantManagerControlPlane::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::TenantManagerControlPlane::Models::SORT_ORDER_ENUM.' end path = '/senderInvitations' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:recipientTenancyId] = opts[:recipient_tenancy_id] if opts[:recipient_tenancy_id] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:status] = opts[:status] if opts[:status] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'SenderInvitationClient#list_sender_invitations') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::TenantManagerControlPlane::Models::SenderInvitationCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 92 def logger @api_client.config.logger end |
#update_sender_invitation(sender_invitation_id, update_sender_invitation_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/tenantmanagercontrolplane/update_sender_invitation.rb.html) to see an example of how to use update_sender_invitation API.
Updates the SenderInvitation.
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/oci/tenant_manager_control_plane/sender_invitation_client.rb', line 391 def update_sender_invitation(sender_invitation_id, update_sender_invitation_details, opts = {}) logger.debug 'Calling operation SenderInvitationClient#update_sender_invitation.' if logger raise "Missing the required parameter 'sender_invitation_id' when calling update_sender_invitation." if sender_invitation_id.nil? raise "Missing the required parameter 'update_sender_invitation_details' when calling update_sender_invitation." if update_sender_invitation_details.nil? raise "Parameter value for 'sender_invitation_id' must not be blank" if OCI::Internal::Util.blank_string?(sender_invitation_id) path = '/senderInvitations/{senderInvitationId}'.sub('{senderInvitationId}', sender_invitation_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_sender_invitation_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'SenderInvitationClient#update_sender_invitation') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::TenantManagerControlPlane::Models::SenderInvitation' ) end # rubocop:enable Metrics/BlockLength end |