Class: OCI::ThreatIntelligence::Models::DataAttribution
- Inherits:
-
Object
- Object
- OCI::ThreatIntelligence::Models::DataAttribution
- Defined in:
- lib/oci/threat_intelligence/models/data_attribution.rb
Overview
The confidence, source information, and visibility for a particular sighting or observation of some data associated with an indicator such as threat type, attribute or relationship.
Instance Attribute Summary collapse
-
#confidence ⇒ Integer
**[Required]** Confidence is an integer from 0 to 100 that provides a measure of our certainty in the maliciousness of data attributed to an indicator.
-
#source ⇒ OCI::ThreatIntelligence::Models::IndicatorSourceSummary
This attribute is required.
-
#time_first_seen ⇒ DateTime
The time the data was first seen for this entity.
-
#time_last_seen ⇒ DateTime
**[Required]** The last time this data was seen for this entity.
-
#visibility ⇒ OCI::ThreatIntelligence::Models::DataVisibility
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataAttribution
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataAttribution
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.confidence = attributes[:'confidence'] if attributes[:'confidence'] self.source = attributes[:'source'] if attributes[:'source'] self.visibility = attributes[:'visibility'] if attributes[:'visibility'] self.time_first_seen = attributes[:'timeFirstSeen'] if attributes[:'timeFirstSeen'] raise 'You cannot provide both :timeFirstSeen and :time_first_seen' if attributes.key?(:'timeFirstSeen') && attributes.key?(:'time_first_seen') self.time_first_seen = attributes[:'time_first_seen'] if attributes[:'time_first_seen'] self.time_last_seen = attributes[:'timeLastSeen'] if attributes[:'timeLastSeen'] raise 'You cannot provide both :timeLastSeen and :time_last_seen' if attributes.key?(:'timeLastSeen') && attributes.key?(:'time_last_seen') self.time_last_seen = attributes[:'time_last_seen'] if attributes[:'time_last_seen'] end |
Instance Attribute Details
#confidence ⇒ Integer
**[Required]** Confidence is an integer from 0 to 100 that provides a measure of our certainty in the maliciousness of data attributed to an indicator. For example, if the source of the data being attributed is the Tor Project, our confidence that the associated indicator is a tor exit node would be 100.
12 13 14 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 12 def confidence @confidence end |
#source ⇒ OCI::ThreatIntelligence::Models::IndicatorSourceSummary
This attribute is required.
16 17 18 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 16 def source @source end |
#time_first_seen ⇒ DateTime
The time the data was first seen for this entity. Defaults to time last seen if no time first seen is provided from the data source. An RFC3339 formatted datetime string
24 25 26 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 24 def time_first_seen @time_first_seen end |
#time_last_seen ⇒ DateTime
**[Required]** The last time this data was seen for this entity. An RFC3339 formatted datetime string
28 29 30 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 28 def time_last_seen @time_last_seen end |
#visibility ⇒ OCI::ThreatIntelligence::Models::DataVisibility
This attribute is required.
20 21 22 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 20 def visibility @visibility end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'confidence': :'confidence', 'source': :'source', 'visibility': :'visibility', 'time_first_seen': :'timeFirstSeen', 'time_last_seen': :'timeLastSeen' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'confidence': :'Integer', 'source': :'OCI::ThreatIntelligence::Models::IndicatorSourceSummary', 'visibility': :'OCI::ThreatIntelligence::Models::DataVisibility', 'time_first_seen': :'DateTime', 'time_last_seen': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 99 def ==(other) return true if equal?(other) self.class == other.class && confidence == other.confidence && source == other.source && visibility == other.visibility && time_first_seen == other.time_first_seen && time_last_seen == other.time_last_seen end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 133 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
113 114 115 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 113 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
122 123 124 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 122 def hash [confidence, source, visibility, time_first_seen, time_last_seen].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 166 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
160 161 162 |
# File 'lib/oci/threat_intelligence/models/data_attribution.rb', line 160 def to_s to_hash.to_s end |