Class: OCI::ThreatIntelligence::Models::IndicatorSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/threat_intelligence/models/indicator_summary.rb

Overview

Summary of a data signature observed on a network or host that indicates a potential security threat.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_DOMAIN_NAME = 'DOMAIN_NAME'.freeze,
  TYPE_FILE_NAME = 'FILE_NAME'.freeze,
  TYPE_MD5_HASH = 'MD5_HASH'.freeze,
  TYPE_SHA1_HASH = 'SHA1_HASH'.freeze,
  TYPE_SHA256_HASH = 'SHA256_HASH'.freeze,
  TYPE_IP_ADDRESS = 'IP_ADDRESS'.freeze,
  TYPE_URL = 'URL'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IndicatorSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :type (String)

    The value to assign to the #type property

  • :value (String)

    The value to assign to the #value property

  • :confidence (Integer)

    The value to assign to the #confidence property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :threat_types (Array<OCI::ThreatIntelligence::Models::ThreatType>)

    The value to assign to the #threat_types property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 113

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.type = attributes[:'type'] if attributes[:'type']

  self.value = attributes[:'value'] if attributes[:'value']

  self.confidence = attributes[:'confidence'] if attributes[:'confidence']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.threat_types = attributes[:'threatTypes'] if attributes[:'threatTypes']

  raise 'You cannot provide both :threatTypes and :threat_types' if attributes.key?(:'threatTypes') && attributes.key?(:'threat_types')

  self.threat_types = attributes[:'threat_types'] if attributes[:'threat_types']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']
end

Instance Attribute Details

#compartment_idString

Compartment Identifier

Returns:

  • (String)


46
47
48
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 46

def compartment_id
  @compartment_id
end

#confidenceInteger

Confidence is an integer from 0 to 100 that provides a measure of our certainty in the maliciousness of the indicator. This confidence value is aggregated from the confidence in the threat types, attributes, and relationships to create an overall value for the indicator.

Returns:

  • (Integer)


42
43
44
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 42

def confidence
  @confidence
end

#idString

**[Required]** The OCID of the indicator.

Returns:

  • (String)


30
31
32
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 30

def id
  @id
end

#lifecycle_stateString

The state of the indicator. It will always be ACTIVE. This field is added for consistency.

Returns:

  • (String)


54
55
56
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 54

def lifecycle_state
  @lifecycle_state
end

#threat_typesArray<OCI::ThreatIntelligence::Models::ThreatType>

**[Required]** Characteristics of the threat indicator based on previous observations or behavior. May include related tactics, techniques, and procedures.

Returns:

  • (Array<OCI::ThreatIntelligence::Models::ThreatType>)


50
51
52
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 50

def threat_types
  @threat_types
end

#time_createdDateTime

**[Required]** The time the data was first seen for this indicator. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


58
59
60
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 58

def time_created
  @time_created
end

#time_updatedDateTime

**[Required]** The last time this indicator was updated. It starts with the same value as timeCreated and is never empty. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


62
63
64
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 62

def time_updated
  @time_updated
end

#typeString

**[Required]** Type of indicator

Returns:

  • (String)


34
35
36
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 34

def type
  @type
end

#valueString

**[Required]** The value of indicator.

Returns:

  • (String)


38
39
40
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 38

def value
  @value
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 65

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'type': :'type',
    'value': :'value',
    'confidence': :'confidence',
    'compartment_id': :'compartmentId',
    'threat_types': :'threatTypes',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 82

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'type': :'String',
    'value': :'String',
    'confidence': :'Integer',
    'compartment_id': :'String',
    'threat_types': :'Array<OCI::ThreatIntelligence::Models::ThreatType>',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 191

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    type == other.type &&
    value == other.value &&
    confidence == other.confidence &&
    compartment_id == other.compartment_id &&
    threat_types == other.threat_types &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 229

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 209

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



218
219
220
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 218

def hash
  [id, type, value, confidence, compartment_id, threat_types, lifecycle_state, time_created, time_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



256
257
258
# File 'lib/oci/threat_intelligence/models/indicator_summary.rb', line 256

def to_s
  to_hash.to_s
end