Class: OCI::Usage::Models::ProductSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/usage/models/product_summary.rb

Overview

Provides details about product rewards and the usage amount.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProductSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :product_number (String)

    The value to assign to the #product_number property

  • :product_name (String)

    The value to assign to the #product_name property

  • :usage_amount (Float)

    The value to assign to the #usage_amount property

  • :earned_rewards (Float)

    The value to assign to the #earned_rewards property

  • :is_eligible_to_earn_rewards (BOOLEAN)

    The value to assign to the #is_eligible_to_earn_rewards property



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/usage/models/product_summary.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.product_number = attributes[:'productNumber'] if attributes[:'productNumber']

  raise 'You cannot provide both :productNumber and :product_number' if attributes.key?(:'productNumber') && attributes.key?(:'product_number')

  self.product_number = attributes[:'product_number'] if attributes[:'product_number']

  self.product_name = attributes[:'productName'] if attributes[:'productName']

  raise 'You cannot provide both :productName and :product_name' if attributes.key?(:'productName') && attributes.key?(:'product_name')

  self.product_name = attributes[:'product_name'] if attributes[:'product_name']

  self.usage_amount = attributes[:'usageAmount'] if attributes[:'usageAmount']

  raise 'You cannot provide both :usageAmount and :usage_amount' if attributes.key?(:'usageAmount') && attributes.key?(:'usage_amount')

  self.usage_amount = attributes[:'usage_amount'] if attributes[:'usage_amount']

  self.earned_rewards = attributes[:'earnedRewards'] if attributes[:'earnedRewards']

  raise 'You cannot provide both :earnedRewards and :earned_rewards' if attributes.key?(:'earnedRewards') && attributes.key?(:'earned_rewards')

  self.earned_rewards = attributes[:'earned_rewards'] if attributes[:'earned_rewards']

  self.is_eligible_to_earn_rewards = attributes[:'isEligibleToEarnRewards'] unless attributes[:'isEligibleToEarnRewards'].nil?

  raise 'You cannot provide both :isEligibleToEarnRewards and :is_eligible_to_earn_rewards' if attributes.key?(:'isEligibleToEarnRewards') && attributes.key?(:'is_eligible_to_earn_rewards')

  self.is_eligible_to_earn_rewards = attributes[:'is_eligible_to_earn_rewards'] unless attributes[:'is_eligible_to_earn_rewards'].nil?
end

Instance Attribute Details

#earned_rewardsFloat

The earned rewards for the product.

Returns:

  • (Float)


24
25
26
# File 'lib/oci/usage/models/product_summary.rb', line 24

def earned_rewards
  @earned_rewards
end

#is_eligible_to_earn_rewardsBOOLEAN

The boolean parameter to indicate if the product is eligible to earn rewards.

Returns:

  • (BOOLEAN)


28
29
30
# File 'lib/oci/usage/models/product_summary.rb', line 28

def is_eligible_to_earn_rewards
  @is_eligible_to_earn_rewards
end

#product_nameString

The rate card product name.

Returns:

  • (String)


16
17
18
# File 'lib/oci/usage/models/product_summary.rb', line 16

def product_name
  @product_name
end

#product_numberString

The rate card product number.

Returns:

  • (String)


12
13
14
# File 'lib/oci/usage/models/product_summary.rb', line 12

def product_number
  @product_number
end

#usage_amountFloat

The rate card product usage amount.

Returns:

  • (Float)


20
21
22
# File 'lib/oci/usage/models/product_summary.rb', line 20

def usage_amount
  @usage_amount
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/usage/models/product_summary.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'product_number': :'productNumber',
    'product_name': :'productName',
    'usage_amount': :'usageAmount',
    'earned_rewards': :'earnedRewards',
    'is_eligible_to_earn_rewards': :'isEligibleToEarnRewards'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/usage/models/product_summary.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'product_number': :'String',
    'product_name': :'String',
    'usage_amount': :'Float',
    'earned_rewards': :'Float',
    'is_eligible_to_earn_rewards': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/usage/models/product_summary.rb', line 111

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    product_number == other.product_number &&
    product_name == other.product_name &&
    usage_amount == other.usage_amount &&
    earned_rewards == other.earned_rewards &&
    is_eligible_to_earn_rewards == other.is_eligible_to_earn_rewards
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/usage/models/product_summary.rb', line 145

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


125
126
127
# File 'lib/oci/usage/models/product_summary.rb', line 125

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



134
135
136
# File 'lib/oci/usage/models/product_summary.rb', line 134

def hash
  [product_number, product_name, usage_amount, earned_rewards, is_eligible_to_earn_rewards].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
# File 'lib/oci/usage/models/product_summary.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



172
173
174
# File 'lib/oci/usage/models/product_summary.rb', line 172

def to_s
  to_hash.to_s
end