Class: OCI::Usage::Models::RewardDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/usage/models/reward_details.rb

Overview

The overall monthly reward summary.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RewardDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :tenancy_id (String)

    The value to assign to the #tenancy_id property

  • :subscription_id (String)

    The value to assign to the #subscription_id property

  • :currency (String)

    The value to assign to the #currency property

  • :rewards_rate (Float)

    The value to assign to the #rewards_rate property

  • :total_rewards_available (Float)

    The value to assign to the #total_rewards_available property

  • :redemption_code (String)

    The value to assign to the #redemption_code property



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/oci/usage/models/reward_details.rb', line 74

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId']

  raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id')

  self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id']

  self.subscription_id = attributes[:'subscriptionId'] if attributes[:'subscriptionId']

  raise 'You cannot provide both :subscriptionId and :subscription_id' if attributes.key?(:'subscriptionId') && attributes.key?(:'subscription_id')

  self.subscription_id = attributes[:'subscription_id'] if attributes[:'subscription_id']

  self.currency = attributes[:'currency'] if attributes[:'currency']

  self.rewards_rate = attributes[:'rewardsRate'] if attributes[:'rewardsRate']

  raise 'You cannot provide both :rewardsRate and :rewards_rate' if attributes.key?(:'rewardsRate') && attributes.key?(:'rewards_rate')

  self.rewards_rate = attributes[:'rewards_rate'] if attributes[:'rewards_rate']

  self.total_rewards_available = attributes[:'totalRewardsAvailable'] if attributes[:'totalRewardsAvailable']

  raise 'You cannot provide both :totalRewardsAvailable and :total_rewards_available' if attributes.key?(:'totalRewardsAvailable') && attributes.key?(:'total_rewards_available')

  self.total_rewards_available = attributes[:'total_rewards_available'] if attributes[:'total_rewards_available']

  self.redemption_code = attributes[:'redemptionCode'] if attributes[:'redemptionCode']

  raise 'You cannot provide both :redemptionCode and :redemption_code' if attributes.key?(:'redemptionCode') && attributes.key?(:'redemption_code')

  self.redemption_code = attributes[:'redemption_code'] if attributes[:'redemption_code']
end

Instance Attribute Details

#currencyString

The currency unit for the reward amount.

Returns:

  • (String)


20
21
22
# File 'lib/oci/usage/models/reward_details.rb', line 20

def currency
  @currency
end

#redemption_codeString

The redemption code used in the billing center during the reward redemption process

Returns:

  • (String)


32
33
34
# File 'lib/oci/usage/models/reward_details.rb', line 32

def redemption_code
  @redemption_code
end

#rewards_rateFloat

The current Rewards percentage in decimal format.

Returns:

  • (Float)


24
25
26
# File 'lib/oci/usage/models/reward_details.rb', line 24

def rewards_rate
  @rewards_rate
end

#subscription_idString

The entitlement ID from MQS, which is the same as the subcription ID.

Returns:

  • (String)


16
17
18
# File 'lib/oci/usage/models/reward_details.rb', line 16

def subscription_id
  @subscription_id
end

#tenancy_idString

The OCID of the target tenancy.

Returns:

  • (String)


12
13
14
# File 'lib/oci/usage/models/reward_details.rb', line 12

def tenancy_id
  @tenancy_id
end

#total_rewards_availableFloat

The total number of available rewards for a given subscription ID.

Returns:

  • (Float)


28
29
30
# File 'lib/oci/usage/models/reward_details.rb', line 28

def total_rewards_available
  @total_rewards_available
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/oci/usage/models/reward_details.rb', line 35

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'tenancy_id': :'tenancyId',
    'subscription_id': :'subscriptionId',
    'currency': :'currency',
    'rewards_rate': :'rewardsRate',
    'total_rewards_available': :'totalRewardsAvailable',
    'redemption_code': :'redemptionCode'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/oci/usage/models/reward_details.rb', line 49

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'tenancy_id': :'String',
    'subscription_id': :'String',
    'currency': :'String',
    'rewards_rate': :'Float',
    'total_rewards_available': :'Float',
    'redemption_code': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/usage/models/reward_details.rb', line 120

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    tenancy_id == other.tenancy_id &&
    subscription_id == other.subscription_id &&
    currency == other.currency &&
    rewards_rate == other.rewards_rate &&
    total_rewards_available == other.total_rewards_available &&
    redemption_code == other.redemption_code
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/oci/usage/models/reward_details.rb', line 155

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


135
136
137
# File 'lib/oci/usage/models/reward_details.rb', line 135

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



144
145
146
# File 'lib/oci/usage/models/reward_details.rb', line 144

def hash
  [tenancy_id, subscription_id, currency, rewards_rate, total_rewards_available, redemption_code].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



188
189
190
191
192
193
194
195
196
197
# File 'lib/oci/usage/models/reward_details.rb', line 188

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



182
183
184
# File 'lib/oci/usage/models/reward_details.rb', line 182

def to_s
  to_hash.to_s
end