Class: OCI::UsageApi::Models::CostAnalysisUI
- Inherits:
-
Object
- Object
- OCI::UsageApi::Models::CostAnalysisUI
- Defined in:
- lib/oci/usage_api/models/cost_analysis_ui.rb
Overview
The common fields for Cost Analysis UI rendering.
Constant Summary collapse
- GRAPH_ENUM =
[ GRAPH_BARS = 'BARS'.freeze, GRAPH_LINES = 'LINES'.freeze, GRAPH_STACKED_LINES = 'STACKED_LINES'.freeze, GRAPH_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#graph ⇒ String
The graph type.
-
#is_cumulative_graph ⇒ BOOLEAN
A cumulative graph.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CostAnalysisUI
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CostAnalysisUI
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 54 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.graph = attributes[:'graph'] if attributes[:'graph'] self.is_cumulative_graph = attributes[:'isCumulativeGraph'] unless attributes[:'isCumulativeGraph'].nil? raise 'You cannot provide both :isCumulativeGraph and :is_cumulative_graph' if attributes.key?(:'isCumulativeGraph') && attributes.key?(:'is_cumulative_graph') self.is_cumulative_graph = attributes[:'is_cumulative_graph'] unless attributes[:'is_cumulative_graph'].nil? end |
Instance Attribute Details
#graph ⇒ String
The graph type.
20 21 22 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 20 def graph @graph end |
#is_cumulative_graph ⇒ BOOLEAN
A cumulative graph.
24 25 26 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 24 def is_cumulative_graph @is_cumulative_graph end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'graph': :'graph', 'is_cumulative_graph': :'isCumulativeGraph' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 37 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'graph': :'String', 'is_cumulative_graph': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
89 90 91 92 93 94 95 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 89 def ==(other) return true if equal?(other) self.class == other.class && graph == other.graph && is_cumulative_graph == other.is_cumulative_graph end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 120 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
100 101 102 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 100 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
109 110 111 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 109 def hash [graph, is_cumulative_graph].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 153 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
147 148 149 |
# File 'lib/oci/usage_api/models/cost_analysis_ui.rb', line 147 def to_s to_hash.to_s end |