Class: OCI::UsageApi::Models::CreateScheduleDetails
- Inherits:
-
Object
- Object
- OCI::UsageApi::Models::CreateScheduleDetails
- Defined in:
- lib/oci/usage_api/models/create_schedule_details.rb
Overview
The saved schedule.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The tenancy of the customer.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#name ⇒ String
**[Required]** The unique name of the schedule created by the user.
-
#query_properties ⇒ OCI::UsageApi::Models::QueryProperties
This attribute is required.
-
#result_location ⇒ OCI::UsageApi::Models::ResultLocation
This attribute is required.
-
#schedule_recurrences ⇒ String
**[Required]** In x-obmcs-recurring-time format shown here: datatracker.ietf.org/doc/html/rfc5545#section-3.3.10 Describes the frequency of when the schedule will be run.
-
#time_scheduled ⇒ DateTime
**[Required]** The date and time of the first time job execution.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateScheduleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateScheduleDetails
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 93 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.result_location = attributes[:'resultLocation'] if attributes[:'resultLocation'] raise 'You cannot provide both :resultLocation and :result_location' if attributes.key?(:'resultLocation') && attributes.key?(:'result_location') self.result_location = attributes[:'result_location'] if attributes[:'result_location'] self.schedule_recurrences = attributes[:'scheduleRecurrences'] if attributes[:'scheduleRecurrences'] raise 'You cannot provide both :scheduleRecurrences and :schedule_recurrences' if attributes.key?(:'scheduleRecurrences') && attributes.key?(:'schedule_recurrences') self.schedule_recurrences = attributes[:'schedule_recurrences'] if attributes[:'schedule_recurrences'] self.time_scheduled = attributes[:'timeScheduled'] if attributes[:'timeScheduled'] raise 'You cannot provide both :timeScheduled and :time_scheduled' if attributes.key?(:'timeScheduled') && attributes.key?(:'time_scheduled') self.time_scheduled = attributes[:'time_scheduled'] if attributes[:'time_scheduled'] self.query_properties = attributes[:'queryProperties'] if attributes[:'queryProperties'] raise 'You cannot provide both :queryProperties and :query_properties' if attributes.key?(:'queryProperties') && attributes.key?(:'query_properties') self.query_properties = attributes[:'query_properties'] if attributes[:'query_properties'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The tenancy of the customer
16 17 18 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 16 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`
45 46 47 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 45 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"value"`
40 41 42 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 40 def @freeform_tags end |
#name ⇒ String
**[Required]** The unique name of the schedule created by the user
12 13 14 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 12 def name @name end |
#query_properties ⇒ OCI::UsageApi::Models::QueryProperties
This attribute is required.
34 35 36 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 34 def query_properties @query_properties end |
#result_location ⇒ OCI::UsageApi::Models::ResultLocation
This attribute is required.
20 21 22 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 20 def result_location @result_location end |
#schedule_recurrences ⇒ String
**[Required]** In x-obmcs-recurring-time format shown here: datatracker.ietf.org/doc/html/rfc5545#section-3.3.10 Describes the frequency of when the schedule will be run
26 27 28 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 26 def schedule_recurrences @schedule_recurrences end |
#time_scheduled ⇒ DateTime
**[Required]** The date and time of the first time job execution
30 31 32 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 30 def time_scheduled @time_scheduled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'compartment_id': :'compartmentId', 'result_location': :'resultLocation', 'schedule_recurrences': :'scheduleRecurrences', 'time_scheduled': :'timeScheduled', 'query_properties': :'queryProperties', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 64 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'compartment_id': :'String', 'result_location': :'OCI::UsageApi::Models::ResultLocation', 'schedule_recurrences': :'String', 'time_scheduled': :'DateTime', 'query_properties': :'OCI::UsageApi::Models::QueryProperties', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 151 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && compartment_id == other.compartment_id && result_location == other.result_location && schedule_recurrences == other.schedule_recurrences && time_scheduled == other.time_scheduled && query_properties == other.query_properties && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 188 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
168 169 170 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 168 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 177 def hash [name, compartment_id, result_location, schedule_recurrences, time_scheduled, query_properties, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
215 216 217 |
# File 'lib/oci/usage_api/models/create_schedule_details.rb', line 215 def to_s to_hash.to_s end |