Class: OCI::UsageApi::Models::CreateScheduleReportDetails
- Inherits:
-
Object
- Object
- OCI::UsageApi::Models::CreateScheduleReportDetails
- Defined in:
- lib/oci/usage_api/models/create_schedule_report_details.rb
Overview
New custom table detail.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The compartment OCID.
-
#query_id ⇒ String
[Required] The query OCID.
- #saved_schedule_report ⇒ OCI::UsageApi::Models::SavedScheduleReport
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateScheduleReportDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateScheduleReportDetails
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 52 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.query_id = attributes[:'queryId'] if attributes[:'queryId'] raise 'You cannot provide both :queryId and :query_id' if attributes.key?(:'queryId') && attributes.key?(:'query_id') self.query_id = attributes[:'query_id'] if attributes[:'query_id'] self.saved_schedule_report = attributes[:'savedScheduleReport'] if attributes[:'savedScheduleReport'] raise 'You cannot provide both :savedScheduleReport and :saved_schedule_report' if attributes.key?(:'savedScheduleReport') && attributes.key?(:'saved_schedule_report') self.saved_schedule_report = attributes[:'saved_schedule_report'] if attributes[:'saved_schedule_report'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The compartment OCID.
12 13 14 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 12 def compartment_id @compartment_id end |
#query_id ⇒ String
[Required] The query OCID.
16 17 18 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 16 def query_id @query_id end |
#saved_schedule_report ⇒ OCI::UsageApi::Models::SavedScheduleReport
19 20 21 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 19 def saved_schedule_report @saved_schedule_report end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 27 28 29 30 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 22 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'query_id': :'queryId', 'saved_schedule_report': :'savedScheduleReport' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 33 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'query_id': :'String', 'saved_schedule_report': :'OCI::UsageApi::Models::SavedScheduleReport' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
84 85 86 87 88 89 90 91 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 84 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && query_id == other.query_id && saved_schedule_report == other.saved_schedule_report end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 116 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
96 97 98 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 96 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
105 106 107 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 105 def hash [compartment_id, query_id, saved_schedule_report].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 149 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
143 144 145 |
# File 'lib/oci/usage_api/models/create_schedule_report_details.rb', line 143 def to_s to_hash.to_s end |