Class: OCI::UsageApi::Models::DynamicDateRange
- Defined in:
- lib/oci/usage_api/models/dynamic_date_range.rb
Overview
The saved dynamic date range (Required when staticDateRange is missing).
Constant Summary collapse
- DYNAMIC_DATE_RANGE_TYPE_ENUM =
[ DYNAMIC_DATE_RANGE_TYPE_LAST_7_DAYS = 'LAST_7_DAYS'.freeze, DYNAMIC_DATE_RANGE_TYPE_LAST_CALENDAR_WEEK = 'LAST_CALENDAR_WEEK'.freeze, DYNAMIC_DATE_RANGE_TYPE_LAST_CALENDAR_MONTH = 'LAST_CALENDAR_MONTH'.freeze, DYNAMIC_DATE_RANGE_TYPE_LAST_30_DAYS = 'LAST_30_DAYS'.freeze, DYNAMIC_DATE_RANGE_TYPE_MONTH_TO_DATE = 'MONTH_TO_DATE'.freeze, DYNAMIC_DATE_RANGE_TYPE_LAST_YEAR = 'LAST_YEAR'.freeze, DYNAMIC_DATE_RANGE_TYPE_YEAR_TODATE = 'YEAR_TODATE'.freeze, DYNAMIC_DATE_RANGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from DateRange
OCI::UsageApi::Models::DateRange::DATE_RANGE_TYPE_ENUM
Instance Attribute Summary collapse
-
#dynamic_date_range_type ⇒ String
This attribute is required.
Attributes inherited from DateRange
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DynamicDateRange
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DateRange
Constructor Details
#initialize(attributes = {}) ⇒ DynamicDateRange
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/usage_api/models/dynamic_date_range.rb', line 54 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['dateRangeType'] = 'DYNAMIC' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.dynamic_date_range_type = attributes[:'dynamicDateRangeType'] if attributes[:'dynamicDateRangeType'] raise 'You cannot provide both :dynamicDateRangeType and :dynamic_date_range_type' if attributes.key?(:'dynamicDateRangeType') && attributes.key?(:'dynamic_date_range_type') self.dynamic_date_range_type = attributes[:'dynamic_date_range_type'] if attributes[:'dynamic_date_range_type'] end |
Instance Attribute Details
#dynamic_date_range_type ⇒ String
This attribute is required.
25 26 27 |
# File 'lib/oci/usage_api/models/dynamic_date_range.rb', line 25 def dynamic_date_range_type @dynamic_date_range_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 |
# File 'lib/oci/usage_api/models/dynamic_date_range.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'date_range_type': :'dateRangeType', 'dynamic_date_range_type': :'dynamicDateRangeType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 |
# File 'lib/oci/usage_api/models/dynamic_date_range.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'date_range_type': :'String', 'dynamic_date_range_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
91 92 93 94 95 96 97 |
# File 'lib/oci/usage_api/models/dynamic_date_range.rb', line 91 def ==(other) return true if equal?(other) self.class == other.class && date_range_type == other.date_range_type && dynamic_date_range_type == other.dynamic_date_range_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/usage_api/models/dynamic_date_range.rb', line 122 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
102 103 104 |
# File 'lib/oci/usage_api/models/dynamic_date_range.rb', line 102 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
111 112 113 |
# File 'lib/oci/usage_api/models/dynamic_date_range.rb', line 111 def hash [date_range_type, dynamic_date_range_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/usage_api/models/dynamic_date_range.rb', line 155 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
149 150 151 |
# File 'lib/oci/usage_api/models/dynamic_date_range.rb', line 149 def to_s to_hash.to_s end |