Class: OCI::UsageApi::Models::Filter
- Inherits:
-
Object
- Object
- OCI::UsageApi::Models::Filter
- Defined in:
- lib/oci/usage_api/models/filter.rb
Overview
The filter object for query usage.
Constant Summary collapse
- OPERATOR_ENUM =
[ OPERATOR_AND = 'AND'.freeze, OPERATOR_NOT = 'NOT'.freeze, OPERATOR_OR = 'OR'.freeze, OPERATOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<OCI::UsageApi::Models::Dimension>
The dimensions to filter on.
-
#filters ⇒ Array<OCI::UsageApi::Models::Filter>
The nested filter object.
-
#operator ⇒ String
The filter operator.
-
#tags ⇒ Array<OCI::UsageApi::Models::Tag>
The tags to filter on.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Filter
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Filter
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/usage_api/models/filter.rb', line 68 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operator = attributes[:'operator'] if attributes[:'operator'] self.dimensions = attributes[:'dimensions'] if attributes[:'dimensions'] self. = attributes[:'tags'] if attributes[:'tags'] self.filters = attributes[:'filters'] if attributes[:'filters'] end |
Instance Attribute Details
#dimensions ⇒ Array<OCI::UsageApi::Models::Dimension>
The dimensions to filter on.
24 25 26 |
# File 'lib/oci/usage_api/models/filter.rb', line 24 def dimensions @dimensions end |
#filters ⇒ Array<OCI::UsageApi::Models::Filter>
The nested filter object.
32 33 34 |
# File 'lib/oci/usage_api/models/filter.rb', line 32 def filters @filters end |
#operator ⇒ String
The filter operator. Example: ‘AND’, ‘OR’, ‘NOT’.
20 21 22 |
# File 'lib/oci/usage_api/models/filter.rb', line 20 def operator @operator end |
#tags ⇒ Array<OCI::UsageApi::Models::Tag>
The tags to filter on.
28 29 30 |
# File 'lib/oci/usage_api/models/filter.rb', line 28 def @tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/usage_api/models/filter.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operator': :'operator', 'dimensions': :'dimensions', 'tags': :'tags', 'filters': :'filters' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/usage_api/models/filter.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operator': :'String', 'dimensions': :'Array<OCI::UsageApi::Models::Dimension>', 'tags': :'Array<OCI::UsageApi::Models::Tag>', 'filters': :'Array<OCI::UsageApi::Models::Filter>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/usage_api/models/filter.rb', line 103 def ==(other) return true if equal?(other) self.class == other.class && operator == other.operator && dimensions == other.dimensions && == other. && filters == other.filters end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/usage_api/models/filter.rb', line 136 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
116 117 118 |
# File 'lib/oci/usage_api/models/filter.rb', line 116 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
125 126 127 |
# File 'lib/oci/usage_api/models/filter.rb', line 125 def hash [operator, dimensions, , filters].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/usage_api/models/filter.rb', line 169 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
163 164 165 |
# File 'lib/oci/usage_api/models/filter.rb', line 163 def to_s to_hash.to_s end |