Class: OCI::UsageApi::Models::QuerySummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/usage_api/models/query_summary.rb

Overview

Query summery in the list request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ QuerySummary

Initializes the object

Options Hash (attributes):



46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/usage_api/models/query_summary.rb', line 46

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.query_definition = attributes[:'queryDefinition'] if attributes[:'queryDefinition']

  raise 'You cannot provide both :queryDefinition and :query_definition' if attributes.key?(:'queryDefinition') && attributes.key?(:'query_definition')

  self.query_definition = attributes[:'query_definition'] if attributes[:'query_definition']
end

Instance Attribute Details

#idString

[Required] The query OCID.



12
13
14
# File 'lib/oci/usage_api/models/query_summary.rb', line 12

def id
  @id
end

#query_definitionOCI::UsageApi::Models::QueryDefinition

This attribute is required.



16
17
18
# File 'lib/oci/usage_api/models/query_summary.rb', line 16

def query_definition
  @query_definition
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



19
20
21
22
23
24
25
26
# File 'lib/oci/usage_api/models/query_summary.rb', line 19

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'query_definition': :'queryDefinition'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



29
30
31
32
33
34
35
36
# File 'lib/oci/usage_api/models/query_summary.rb', line 29

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'query_definition': :'OCI::UsageApi::Models::QueryDefinition'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



68
69
70
71
72
73
74
# File 'lib/oci/usage_api/models/query_summary.rb', line 68

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    query_definition == other.query_definition
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/usage_api/models/query_summary.rb', line 99

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


79
80
81
# File 'lib/oci/usage_api/models/query_summary.rb', line 79

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



88
89
90
# File 'lib/oci/usage_api/models/query_summary.rb', line 88

def hash
  [id, query_definition].hash
end

#to_hashHash

Returns the object in the form of hash



132
133
134
135
136
137
138
139
140
141
# File 'lib/oci/usage_api/models/query_summary.rb', line 132

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



126
127
128
# File 'lib/oci/usage_api/models/query_summary.rb', line 126

def to_s
  to_hash.to_s
end