Class: OCI::UsageApi::Models::ReportQuery
- Inherits:
-
Object
- Object
- OCI::UsageApi::Models::ReportQuery
- Defined in:
- lib/oci/usage_api/models/report_query.rb
Overview
The request of the generated Cost Analysis report.
Constant Summary collapse
- GRANULARITY_ENUM =
[ GRANULARITY_HOURLY = 'HOURLY'.freeze, GRANULARITY_DAILY = 'DAILY'.freeze, GRANULARITY_MONTHLY = 'MONTHLY'.freeze, GRANULARITY_TOTAL = 'TOTAL'.freeze, GRANULARITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- QUERY_TYPE_ENUM =
[ QUERY_TYPE_USAGE = 'USAGE'.freeze, QUERY_TYPE_COST = 'COST'.freeze, QUERY_TYPE_CREDIT = 'CREDIT'.freeze, QUERY_TYPE_EXPIREDCREDIT = 'EXPIREDCREDIT'.freeze, QUERY_TYPE_ALLCREDIT = 'ALLCREDIT'.freeze, QUERY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DATE_RANGE_NAME_ENUM =
[ DATE_RANGE_NAME_LAST_SEVEN_DAYS = 'LAST_SEVEN_DAYS'.freeze, DATE_RANGE_NAME_LAST_TEN_DAYS = 'LAST_TEN_DAYS'.freeze, DATE_RANGE_NAME_MTD = 'MTD'.freeze, DATE_RANGE_NAME_LAST_TWO_MONTHS = 'LAST_TWO_MONTHS'.freeze, DATE_RANGE_NAME_LAST_THREE_MONTHS = 'LAST_THREE_MONTHS'.freeze, DATE_RANGE_NAME_ALL = 'ALL'.freeze, DATE_RANGE_NAME_LAST_SIX_MONTHS = 'LAST_SIX_MONTHS'.freeze, DATE_RANGE_NAME_LAST_ONE_YEAR = 'LAST_ONE_YEAR'.freeze, DATE_RANGE_NAME_YTD = 'YTD'.freeze, DATE_RANGE_NAME_CUSTOM = 'CUSTOM'.freeze, DATE_RANGE_NAME_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_depth ⇒ Float
The compartment depth level.
-
#date_range_name ⇒ String
The UI date range, for example, LAST_THREE_MONTHS.
- #filter ⇒ OCI::UsageApi::Models::Filter
- #forecast ⇒ OCI::UsageApi::Models::Forecast
-
#granularity ⇒ String
[Required] The usage granularity.
-
#group_by ⇒ Array<String>
Aggregate the result by.
-
#group_by_tag ⇒ Array<OCI::UsageApi::Models::Tag>
GroupBy a specific tagKey.
-
#is_aggregate_by_time ⇒ BOOLEAN
Whether aggregated by time.
-
#query_type ⇒ String
The query usage type.
-
#tenant_id ⇒ String
[Required] Tenant ID.
-
#time_usage_ended ⇒ DateTime
The usage end time.
-
#time_usage_started ⇒ DateTime
The usage start time.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReportQuery
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ReportQuery
Initializes the object
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/usage_api/models/report_query.rb', line 165 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.tenant_id = attributes[:'tenantId'] if attributes[:'tenantId'] raise 'You cannot provide both :tenantId and :tenant_id' if attributes.key?(:'tenantId') && attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] if attributes[:'tenant_id'] self.time_usage_started = attributes[:'timeUsageStarted'] if attributes[:'timeUsageStarted'] raise 'You cannot provide both :timeUsageStarted and :time_usage_started' if attributes.key?(:'timeUsageStarted') && attributes.key?(:'time_usage_started') self.time_usage_started = attributes[:'time_usage_started'] if attributes[:'time_usage_started'] self.time_usage_ended = attributes[:'timeUsageEnded'] if attributes[:'timeUsageEnded'] raise 'You cannot provide both :timeUsageEnded and :time_usage_ended' if attributes.key?(:'timeUsageEnded') && attributes.key?(:'time_usage_ended') self.time_usage_ended = attributes[:'time_usage_ended'] if attributes[:'time_usage_ended'] self.granularity = attributes[:'granularity'] if attributes[:'granularity'] self.is_aggregate_by_time = attributes[:'isAggregateByTime'] unless attributes[:'isAggregateByTime'].nil? self.is_aggregate_by_time = false if is_aggregate_by_time.nil? && !attributes.key?(:'isAggregateByTime') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isAggregateByTime and :is_aggregate_by_time' if attributes.key?(:'isAggregateByTime') && attributes.key?(:'is_aggregate_by_time') self.is_aggregate_by_time = attributes[:'is_aggregate_by_time'] unless attributes[:'is_aggregate_by_time'].nil? self.is_aggregate_by_time = false if is_aggregate_by_time.nil? && !attributes.key?(:'isAggregateByTime') && !attributes.key?(:'is_aggregate_by_time') # rubocop:disable Style/StringLiterals self.forecast = attributes[:'forecast'] if attributes[:'forecast'] self.query_type = attributes[:'queryType'] if attributes[:'queryType'] raise 'You cannot provide both :queryType and :query_type' if attributes.key?(:'queryType') && attributes.key?(:'query_type') self.query_type = attributes[:'query_type'] if attributes[:'query_type'] self.group_by = attributes[:'groupBy'] if attributes[:'groupBy'] raise 'You cannot provide both :groupBy and :group_by' if attributes.key?(:'groupBy') && attributes.key?(:'group_by') self.group_by = attributes[:'group_by'] if attributes[:'group_by'] self.group_by_tag = attributes[:'groupByTag'] if attributes[:'groupByTag'] raise 'You cannot provide both :groupByTag and :group_by_tag' if attributes.key?(:'groupByTag') && attributes.key?(:'group_by_tag') self.group_by_tag = attributes[:'group_by_tag'] if attributes[:'group_by_tag'] self.compartment_depth = attributes[:'compartmentDepth'] if attributes[:'compartmentDepth'] raise 'You cannot provide both :compartmentDepth and :compartment_depth' if attributes.key?(:'compartmentDepth') && attributes.key?(:'compartment_depth') self.compartment_depth = attributes[:'compartment_depth'] if attributes[:'compartment_depth'] self.filter = attributes[:'filter'] if attributes[:'filter'] self.date_range_name = attributes[:'dateRangeName'] if attributes[:'dateRangeName'] raise 'You cannot provide both :dateRangeName and :date_range_name' if attributes.key?(:'dateRangeName') && attributes.key?(:'date_range_name') self.date_range_name = attributes[:'date_range_name'] if attributes[:'date_range_name'] end |
Instance Attribute Details
#compartment_depth ⇒ Float
The compartment depth level.
98 99 100 |
# File 'lib/oci/usage_api/models/report_query.rb', line 98 def compartment_depth @compartment_depth end |
#date_range_name ⇒ String
The UI date range, for example, LAST_THREE_MONTHS. Conflicts with timeUsageStarted and timeUsageEnded.
105 106 107 |
# File 'lib/oci/usage_api/models/report_query.rb', line 105 def date_range_name @date_range_name end |
#filter ⇒ OCI::UsageApi::Models::Filter
101 102 103 |
# File 'lib/oci/usage_api/models/report_query.rb', line 101 def filter @filter end |
#forecast ⇒ OCI::UsageApi::Models::Forecast
68 69 70 |
# File 'lib/oci/usage_api/models/report_query.rb', line 68 def forecast @forecast end |
#granularity ⇒ String
[Required] The usage granularity. HOURLY - Hourly data aggregation. DAILY - Daily data aggregation. MONTHLY - Monthly data aggregation. TOTAL - Not yet supported.
61 62 63 |
# File 'lib/oci/usage_api/models/report_query.rb', line 61 def granularity @granularity end |
#group_by ⇒ Array<String>
Aggregate the result by. example:
`[\"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\",
\"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\",
\"resourceId\", \"tenantId\", \"tenantName\"]`
87 88 89 |
# File 'lib/oci/usage_api/models/report_query.rb', line 87 def group_by @group_by end |
#group_by_tag ⇒ Array<OCI::UsageApi::Models::Tag>
GroupBy a specific tagKey. Provide the tagNamespace and tagKey in the tag object. Only supports one tag in the list. For example:
`[{\"namespace\":\"oracle\", \"key\":\"createdBy\"]`
94 95 96 |
# File 'lib/oci/usage_api/models/report_query.rb', line 94 def group_by_tag @group_by_tag end |
#is_aggregate_by_time ⇒ BOOLEAN
Whether aggregated by time. If isAggregateByTime is true, all usage/cost over the query time period will be added up.
65 66 67 |
# File 'lib/oci/usage_api/models/report_query.rb', line 65 def is_aggregate_by_time @is_aggregate_by_time end |
#query_type ⇒ String
The query usage type. COST by default if it is missing. Usage - Query the usage data. Cost - Query the cost/billing data. Credit - Query the credit adjustments data. ExpiredCredit - Query the expired credits data AllCredit - Query the credit adjustments and expired credit
78 79 80 |
# File 'lib/oci/usage_api/models/report_query.rb', line 78 def query_type @query_type end |
#tenant_id ⇒ String
[Required] Tenant ID.
44 45 46 |
# File 'lib/oci/usage_api/models/report_query.rb', line 44 def tenant_id @tenant_id end |
#time_usage_ended ⇒ DateTime
The usage end time.
52 53 54 |
# File 'lib/oci/usage_api/models/report_query.rb', line 52 def time_usage_ended @time_usage_ended end |
#time_usage_started ⇒ DateTime
The usage start time.
48 49 50 |
# File 'lib/oci/usage_api/models/report_query.rb', line 48 def time_usage_started @time_usage_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/usage_api/models/report_query.rb', line 108 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'tenant_id': :'tenantId', 'time_usage_started': :'timeUsageStarted', 'time_usage_ended': :'timeUsageEnded', 'granularity': :'granularity', 'is_aggregate_by_time': :'isAggregateByTime', 'forecast': :'forecast', 'query_type': :'queryType', 'group_by': :'groupBy', 'group_by_tag': :'groupByTag', 'compartment_depth': :'compartmentDepth', 'filter': :'filter', 'date_range_name': :'dateRangeName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/usage_api/models/report_query.rb', line 128 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'tenant_id': :'String', 'time_usage_started': :'DateTime', 'time_usage_ended': :'DateTime', 'granularity': :'String', 'is_aggregate_by_time': :'BOOLEAN', 'forecast': :'OCI::UsageApi::Models::Forecast', 'query_type': :'String', 'group_by': :'Array<String>', 'group_by_tag': :'Array<OCI::UsageApi::Models::Tag>', 'compartment_depth': :'Float', 'filter': :'OCI::UsageApi::Models::Filter', 'date_range_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/oci/usage_api/models/report_query.rb', line 280 def ==(other) return true if equal?(other) self.class == other.class && tenant_id == other.tenant_id && time_usage_started == other.time_usage_started && time_usage_ended == other.time_usage_ended && granularity == other.granularity && is_aggregate_by_time == other.is_aggregate_by_time && forecast == other.forecast && query_type == other.query_type && group_by == other.group_by && group_by_tag == other.group_by_tag && compartment_depth == other.compartment_depth && filter == other.filter && date_range_name == other.date_range_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/oci/usage_api/models/report_query.rb', line 321 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
301 302 303 |
# File 'lib/oci/usage_api/models/report_query.rb', line 301 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
310 311 312 |
# File 'lib/oci/usage_api/models/report_query.rb', line 310 def hash [tenant_id, time_usage_started, time_usage_ended, granularity, is_aggregate_by_time, forecast, query_type, group_by, group_by_tag, compartment_depth, filter, date_range_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
354 355 356 357 358 359 360 361 362 363 |
# File 'lib/oci/usage_api/models/report_query.rb', line 354 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
348 349 350 |
# File 'lib/oci/usage_api/models/report_query.rb', line 348 def to_s to_hash.to_s end |