Class: OCI::UsageApi::Models::Schedule

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/usage_api/models/schedule.rb

Overview

The schedule.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Schedule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/oci/usage_api/models/schedule.rb', line 129

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.result_location = attributes[:'resultLocation'] if attributes[:'resultLocation']

  raise 'You cannot provide both :resultLocation and :result_location' if attributes.key?(:'resultLocation') && attributes.key?(:'result_location')

  self.result_location = attributes[:'result_location'] if attributes[:'result_location']

  self.schedule_recurrences = attributes[:'scheduleRecurrences'] if attributes[:'scheduleRecurrences']

  raise 'You cannot provide both :scheduleRecurrences and :schedule_recurrences' if attributes.key?(:'scheduleRecurrences') && attributes.key?(:'schedule_recurrences')

  self.schedule_recurrences = attributes[:'schedule_recurrences'] if attributes[:'schedule_recurrences']

  self.time_scheduled = attributes[:'timeScheduled'] if attributes[:'timeScheduled']

  raise 'You cannot provide both :timeScheduled and :time_scheduled' if attributes.key?(:'timeScheduled') && attributes.key?(:'time_scheduled')

  self.time_scheduled = attributes[:'time_scheduled'] if attributes[:'time_scheduled']

  self.query_properties = attributes[:'queryProperties'] if attributes[:'queryProperties']

  raise 'You cannot provide both :queryProperties and :query_properties' if attributes.key?(:'queryProperties') && attributes.key?(:'query_properties')

  self.query_properties = attributes[:'query_properties'] if attributes[:'query_properties']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The tenancy of the customer

Returns:

  • (String)


27
28
29
# File 'lib/oci/usage_api/models/schedule.rb', line 27

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


64
65
66
# File 'lib/oci/usage_api/models/schedule.rb', line 64

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"value"`

Returns:

  • (Hash<String, String>)


59
60
61
# File 'lib/oci/usage_api/models/schedule.rb', line 59

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The OCID representing unique shedule

Returns:

  • (String)


19
20
21
# File 'lib/oci/usage_api/models/schedule.rb', line 19

def id
  @id
end

#lifecycle_stateString

**[Required]** The lifecycle state of the schedule

Returns:

  • (String)


53
54
55
# File 'lib/oci/usage_api/models/schedule.rb', line 53

def lifecycle_state
  @lifecycle_state
end

#nameString

**[Required]** The unique name of the schedule created by the user

Returns:

  • (String)


23
24
25
# File 'lib/oci/usage_api/models/schedule.rb', line 23

def name
  @name
end

#query_propertiesOCI::UsageApi::Models::QueryProperties

This attribute is required.



45
46
47
# File 'lib/oci/usage_api/models/schedule.rb', line 45

def query_properties
  @query_properties
end

#result_locationOCI::UsageApi::Models::ResultLocation

This attribute is required.



31
32
33
# File 'lib/oci/usage_api/models/schedule.rb', line 31

def result_location
  @result_location
end

#schedule_recurrencesString

**[Required]** In x-obmcs-recurring-time format shown here: datatracker.ietf.org/doc/html/rfc5545#section-3.3.10 Describes the frequency of when the schedule will be run

Returns:

  • (String)


37
38
39
# File 'lib/oci/usage_api/models/schedule.rb', line 37

def schedule_recurrences
  @schedule_recurrences
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


69
70
71
# File 'lib/oci/usage_api/models/schedule.rb', line 69

def system_tags
  @system_tags
end

#time_createdDateTime

**[Required]** The date and time of when the schedule was created

Returns:

  • (DateTime)


49
50
51
# File 'lib/oci/usage_api/models/schedule.rb', line 49

def time_created
  @time_created
end

#time_scheduledDateTime

**[Required]** The date and time of the first time job execution

Returns:

  • (DateTime)


41
42
43
# File 'lib/oci/usage_api/models/schedule.rb', line 41

def time_scheduled
  @time_scheduled
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/usage_api/models/schedule.rb', line 72

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'result_location': :'resultLocation',
    'schedule_recurrences': :'scheduleRecurrences',
    'time_scheduled': :'timeScheduled',
    'query_properties': :'queryProperties',
    'time_created': :'timeCreated',
    'lifecycle_state': :'lifecycleState',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/oci/usage_api/models/schedule.rb', line 92

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'result_location': :'OCI::UsageApi::Models::ResultLocation',
    'schedule_recurrences': :'String',
    'time_scheduled': :'DateTime',
    'query_properties': :'OCI::UsageApi::Models::QueryProperties',
    'time_created': :'DateTime',
    'lifecycle_state': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/oci/usage_api/models/schedule.rb', line 220

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    result_location == other.result_location &&
    schedule_recurrences == other.schedule_recurrences &&
    time_scheduled == other.time_scheduled &&
    query_properties == other.query_properties &&
    time_created == other.time_created &&
    lifecycle_state == other.lifecycle_state &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/usage_api/models/schedule.rb', line 261

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


241
242
243
# File 'lib/oci/usage_api/models/schedule.rb', line 241

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



250
251
252
# File 'lib/oci/usage_api/models/schedule.rb', line 250

def hash
  [id, name, compartment_id, result_location, schedule_recurrences, time_scheduled, query_properties, time_created, lifecycle_state, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
303
# File 'lib/oci/usage_api/models/schedule.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



288
289
290
# File 'lib/oci/usage_api/models/schedule.rb', line 288

def to_s
  to_hash.to_s
end