Class: OCI::UsageApi::Models::ScheduleSummary
- Inherits:
-
Object
- Object
- OCI::UsageApi::Models::ScheduleSummary
- Defined in:
- lib/oci/usage_api/models/schedule_summary.rb
Overview
Schedule summary for listSchedule.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The schedule OCID.
-
#lifecycle_state ⇒ String
**[Required]** The lifecycle state of the schedule summary.
-
#name ⇒ String
**[Required]** The unique name of the schedule created by the user.
-
#schedule_recurrences ⇒ String
**[Required]** In x-obmcs-recurring-time format shown here: datatracker.ietf.org/doc/html/rfc5545#section-3.3.10 Describes the frequency of when the schedule will be run.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_scheduled ⇒ DateTime
**[Required]** The date and time of the first time job execution.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScheduleSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ScheduleSummary
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.schedule_recurrences = attributes[:'scheduleRecurrences'] if attributes[:'scheduleRecurrences'] raise 'You cannot provide both :scheduleRecurrences and :schedule_recurrences' if attributes.key?(:'scheduleRecurrences') && attributes.key?(:'schedule_recurrences') self.schedule_recurrences = attributes[:'schedule_recurrences'] if attributes[:'schedule_recurrences'] self.time_scheduled = attributes[:'timeScheduled'] if attributes[:'timeScheduled'] raise 'You cannot provide both :timeScheduled and :time_scheduled' if attributes.key?(:'timeScheduled') && attributes.key?(:'time_scheduled') self.time_scheduled = attributes[:'time_scheduled'] if attributes[:'time_scheduled'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`
37 38 39 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 37 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"value"`
32 33 34 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 32 def @freeform_tags end |
#id ⇒ String
**[Required]** The schedule OCID.
12 13 14 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 12 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The lifecycle state of the schedule summary
46 47 48 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 46 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** The unique name of the schedule created by the user
16 17 18 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 16 def name @name end |
#schedule_recurrences ⇒ String
**[Required]** In x-obmcs-recurring-time format shown here: datatracker.ietf.org/doc/html/rfc5545#section-3.3.10 Describes the frequency of when the schedule will be run
22 23 24 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 22 def schedule_recurrences @schedule_recurrences end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"free-tier-retained": "true"}`
42 43 44 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 42 def @system_tags end |
#time_scheduled ⇒ DateTime
**[Required]** The date and time of the first time job execution
26 27 28 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 26 def time_scheduled @time_scheduled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'schedule_recurrences': :'scheduleRecurrences', 'time_scheduled': :'timeScheduled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'schedule_recurrences': :'String', 'time_scheduled': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 148 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && schedule_recurrences == other.schedule_recurrences && time_scheduled == other.time_scheduled && == other. && == other. && == other. && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 174 def hash [id, name, schedule_recurrences, time_scheduled, , , , lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/usage_api/models/schedule_summary.rb', line 212 def to_s to_hash.to_s end |