Class: OCI::UsageApi::UsageapiClientCompositeOperations
- Inherits:
-
Object
- Object
- OCI::UsageApi::UsageapiClientCompositeOperations
- Defined in:
- lib/oci/usage_api/usageapi_client_composite_operations.rb
Overview
This class provides a wrapper around UsageapiClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality
Instance Attribute Summary collapse
-
#service_client ⇒ OCI::UsageApi::UsageapiClient
readonly
The UsageapiClient used to communicate with the service_client.
Instance Method Summary collapse
-
#initialize(service_client = OCI::UsageApi::UsageapiClient.new) ⇒ UsageapiClientCompositeOperations
constructor
Initializes a new UsageapiClientCompositeOperations.
Constructor Details
#initialize(service_client = OCI::UsageApi::UsageapiClient.new) ⇒ UsageapiClientCompositeOperations
Initializes a new UsageapiClientCompositeOperations
20 21 22 |
# File 'lib/oci/usage_api/usageapi_client_composite_operations.rb', line 20 def initialize(service_client = OCI::UsageApi::UsageapiClient.new) @service_client = service_client end |
Instance Attribute Details
#service_client ⇒ OCI::UsageApi::UsageapiClient (readonly)
The OCI::UsageApi::UsageapiClient used to communicate with the service_client
14 15 16 |
# File 'lib/oci/usage_api/usageapi_client_composite_operations.rb', line 14 def service_client @service_client end |