Class: OCI::VisualBuilder::Models::ApplicationSummary
- Inherits:
-
Object
- Object
- OCI::VisualBuilder::Models::ApplicationSummary
- Defined in:
- lib/oci/visual_builder/models/application_summary.rb
Overview
Summary of the Vb Instance’s applications.
Constant Summary collapse
- STATE_ENUM =
[ STATE_STAGE = 'STAGE'.freeze, STATE_LIVE = 'LIVE'.freeze, STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#id ⇒ String
[Required] Unique identifier of the application.
-
#project_id ⇒ String
[Required] Project identifier.
-
#state ⇒ String
[Required] Represents the deployment state of the application.
-
#version ⇒ String
[Required] Version of deployed application.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationSummary
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.version = attributes[:'version'] if attributes[:'version'] self.state = attributes[:'state'] if attributes[:'state'] end |
Instance Attribute Details
#id ⇒ String
[Required] Unique identifier of the application.
19 20 21 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 19 def id @id end |
#project_id ⇒ String
[Required] Project identifier.
23 24 25 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 23 def project_id @project_id end |
#state ⇒ String
[Required] Represents the deployment state of the application.
31 32 33 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 31 def state @state end |
#version ⇒ String
[Required] Version of deployed application.
27 28 29 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 27 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'project_id': :'projectId', 'version': :'version', 'state': :'state' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'project_id': :'String', 'version': :'String', 'state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 106 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && project_id == other.project_id && version == other.version && state == other.state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 139 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
119 120 121 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 119 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
128 129 130 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 128 def hash [id, project_id, version, state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
166 167 168 |
# File 'lib/oci/visual_builder/models/application_summary.rb', line 166 def to_s to_hash.to_s end |