Class: OCI::VisualBuilder::Models::CreateVbInstanceDetails
- Inherits:
-
Object
- Object
- OCI::VisualBuilder::Models::CreateVbInstanceDetails
- Defined in:
- lib/oci/visual_builder/models/create_vb_instance_details.rb
Overview
The information about new VbInstance.
Constant Summary collapse
- CONSUMPTION_MODEL_ENUM =
[ CONSUMPTION_MODEL_UCM = 'UCM'.freeze, CONSUMPTION_MODEL_GOV = 'GOV'.freeze, CONSUMPTION_MODEL_VB4_SAAS = 'VB4SAAS'.freeze ].freeze
Instance Attribute Summary collapse
-
#alternate_custom_endpoints ⇒ Array<OCI::VisualBuilder::Models::CreateCustomEndpointDetails>
A list of alternate custom endpoints to be used for the vb instance URL (contact Oracle for alternateCustomEndpoints availability for a specific instance).
-
#compartment_id ⇒ String
[Required] Compartment Identifier.
-
#consumption_model ⇒ String
Optional parameter specifying which entitlement to use for billing purposes.
- #custom_endpoint ⇒ OCI::VisualBuilder::Models::CreateCustomEndpointDetails
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#display_name ⇒ String
[Required] Vb Instance Identifier.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#idcs_open_id ⇒ String
Encrypted IDCS Open ID token.
-
#is_visual_builder_enabled ⇒ BOOLEAN
Visual Builder is enabled or not.
-
#node_count ⇒ Integer
[Required] The number of Nodes.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateVbInstanceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateVbInstanceDetails
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.idcs_open_id = attributes[:'idcsOpenId'] if attributes[:'idcsOpenId'] raise 'You cannot provide both :idcsOpenId and :idcs_open_id' if attributes.key?(:'idcsOpenId') && attributes.key?(:'idcs_open_id') self.idcs_open_id = attributes[:'idcs_open_id'] if attributes[:'idcs_open_id'] self.node_count = attributes[:'nodeCount'] if attributes[:'nodeCount'] raise 'You cannot provide both :nodeCount and :node_count' if attributes.key?(:'nodeCount') && attributes.key?(:'node_count') self.node_count = attributes[:'node_count'] if attributes[:'node_count'] self.is_visual_builder_enabled = attributes[:'isVisualBuilderEnabled'] unless attributes[:'isVisualBuilderEnabled'].nil? self.is_visual_builder_enabled = true if is_visual_builder_enabled.nil? && !attributes.key?(:'isVisualBuilderEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isVisualBuilderEnabled and :is_visual_builder_enabled' if attributes.key?(:'isVisualBuilderEnabled') && attributes.key?(:'is_visual_builder_enabled') self.is_visual_builder_enabled = attributes[:'is_visual_builder_enabled'] unless attributes[:'is_visual_builder_enabled'].nil? self.is_visual_builder_enabled = true if is_visual_builder_enabled.nil? && !attributes.key?(:'isVisualBuilderEnabled') && !attributes.key?(:'is_visual_builder_enabled') # rubocop:disable Style/StringLiterals self.custom_endpoint = attributes[:'customEndpoint'] if attributes[:'customEndpoint'] raise 'You cannot provide both :customEndpoint and :custom_endpoint' if attributes.key?(:'customEndpoint') && attributes.key?(:'custom_endpoint') self.custom_endpoint = attributes[:'custom_endpoint'] if attributes[:'custom_endpoint'] self.alternate_custom_endpoints = attributes[:'alternateCustomEndpoints'] if attributes[:'alternateCustomEndpoints'] raise 'You cannot provide both :alternateCustomEndpoints and :alternate_custom_endpoints' if attributes.key?(:'alternateCustomEndpoints') && attributes.key?(:'alternate_custom_endpoints') self.alternate_custom_endpoints = attributes[:'alternate_custom_endpoints'] if attributes[:'alternate_custom_endpoints'] self.consumption_model = attributes[:'consumptionModel'] if attributes[:'consumptionModel'] raise 'You cannot provide both :consumptionModel and :consumption_model' if attributes.key?(:'consumptionModel') && attributes.key?(:'consumption_model') self.consumption_model = attributes[:'consumption_model'] if attributes[:'consumption_model'] end |
Instance Attribute Details
#alternate_custom_endpoints ⇒ Array<OCI::VisualBuilder::Models::CreateCustomEndpointDetails>
A list of alternate custom endpoints to be used for the vb instance URL (contact Oracle for alternateCustomEndpoints availability for a specific instance).
57 58 59 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 57 def alternate_custom_endpoints @alternate_custom_endpoints end |
#compartment_id ⇒ String
[Required] Compartment Identifier.
22 23 24 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 22 def compartment_id @compartment_id end |
#consumption_model ⇒ String
Optional parameter specifying which entitlement to use for billing purposes. Only required if the account possesses more than one entitlement.
61 62 63 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 61 def consumption_model @consumption_model end |
#custom_endpoint ⇒ OCI::VisualBuilder::Models::CreateCustomEndpointDetails
51 52 53 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 51 def custom_endpoint @custom_endpoint end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: ‘{"bar-key": "value"}`
36 37 38 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 36 def end |
#display_name ⇒ String
[Required] Vb Instance Identifier.
18 19 20 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 18 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
29 30 31 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 29 def end |
#idcs_open_id ⇒ String
Encrypted IDCS Open ID token. This is required for pre-UCPIS cloud accounts, but not UCPIS, hence not a required parameter
40 41 42 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 40 def idcs_open_id @idcs_open_id end |
#is_visual_builder_enabled ⇒ BOOLEAN
Visual Builder is enabled or not.
48 49 50 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 48 def is_visual_builder_enabled @is_visual_builder_enabled end |
#node_count ⇒ Integer
[Required] The number of Nodes
44 45 46 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 44 def node_count @node_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 64 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'idcs_open_id': :'idcsOpenId', 'node_count': :'nodeCount', 'is_visual_builder_enabled': :'isVisualBuilderEnabled', 'custom_endpoint': :'customEndpoint', 'alternate_custom_endpoints': :'alternateCustomEndpoints', 'consumption_model': :'consumptionModel' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 82 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'idcs_open_id': :'String', 'node_count': :'Integer', 'is_visual_builder_enabled': :'BOOLEAN', 'custom_endpoint': :'OCI::VisualBuilder::Models::CreateCustomEndpointDetails', 'alternate_custom_endpoints': :'Array<OCI::VisualBuilder::Models::CreateCustomEndpointDetails>', 'consumption_model': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 199 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && == other. && == other. && idcs_open_id == other.idcs_open_id && node_count == other.node_count && is_visual_builder_enabled == other.is_visual_builder_enabled && custom_endpoint == other.custom_endpoint && alternate_custom_endpoints == other.alternate_custom_endpoints && consumption_model == other.consumption_model end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 238 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
218 219 220 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 218 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 227 def hash [display_name, compartment_id, , , idcs_open_id, node_count, is_visual_builder_enabled, custom_endpoint, alternate_custom_endpoints, consumption_model].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
265 266 267 |
# File 'lib/oci/visual_builder/models/create_vb_instance_details.rb', line 265 def to_s to_hash.to_s end |