Class: OCI::VisualBuilder::Models::IdcsInfoDetails
- Inherits:
-
Object
- Object
- OCI::VisualBuilder::Models::IdcsInfoDetails
- Defined in:
- lib/oci/visual_builder/models/idcs_info_details.rb
Overview
Information for IDCS access
Instance Attribute Summary collapse
-
#idcs_app_display_name ⇒ String
**[Required]** The IDCS application display name associated with the instance.
-
#idcs_app_id ⇒ String
**[Required]** The IDCS application ID associated with the instance.
-
#idcs_app_location_url ⇒ String
**[Required]** URL for the location of the IDCS Application (used by IDCS APIs).
-
#idcs_app_name ⇒ String
**[Required]** The IDCS application name associated with the instance.
-
#instance_primary_audience_url ⇒ String
**[Required]** The URL used as the primary audience for visual builder flows in this instance type: string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdcsInfoDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IdcsInfoDetails
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.idcs_app_location_url = attributes[:'idcsAppLocationUrl'] if attributes[:'idcsAppLocationUrl'] raise 'You cannot provide both :idcsAppLocationUrl and :idcs_app_location_url' if attributes.key?(:'idcsAppLocationUrl') && attributes.key?(:'idcs_app_location_url') self.idcs_app_location_url = attributes[:'idcs_app_location_url'] if attributes[:'idcs_app_location_url'] self.idcs_app_display_name = attributes[:'idcsAppDisplayName'] if attributes[:'idcsAppDisplayName'] raise 'You cannot provide both :idcsAppDisplayName and :idcs_app_display_name' if attributes.key?(:'idcsAppDisplayName') && attributes.key?(:'idcs_app_display_name') self.idcs_app_display_name = attributes[:'idcs_app_display_name'] if attributes[:'idcs_app_display_name'] self.idcs_app_id = attributes[:'idcsAppId'] if attributes[:'idcsAppId'] raise 'You cannot provide both :idcsAppId and :idcs_app_id' if attributes.key?(:'idcsAppId') && attributes.key?(:'idcs_app_id') self.idcs_app_id = attributes[:'idcs_app_id'] if attributes[:'idcs_app_id'] self.idcs_app_name = attributes[:'idcsAppName'] if attributes[:'idcsAppName'] raise 'You cannot provide both :idcsAppName and :idcs_app_name' if attributes.key?(:'idcsAppName') && attributes.key?(:'idcs_app_name') self.idcs_app_name = attributes[:'idcs_app_name'] if attributes[:'idcs_app_name'] self.instance_primary_audience_url = attributes[:'instancePrimaryAudienceUrl'] if attributes[:'instancePrimaryAudienceUrl'] raise 'You cannot provide both :instancePrimaryAudienceUrl and :instance_primary_audience_url' if attributes.key?(:'instancePrimaryAudienceUrl') && attributes.key?(:'instance_primary_audience_url') self.instance_primary_audience_url = attributes[:'instance_primary_audience_url'] if attributes[:'instance_primary_audience_url'] end |
Instance Attribute Details
#idcs_app_display_name ⇒ String
**[Required]** The IDCS application display name associated with the instance
16 17 18 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 16 def idcs_app_display_name @idcs_app_display_name end |
#idcs_app_id ⇒ String
**[Required]** The IDCS application ID associated with the instance
20 21 22 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 20 def idcs_app_id @idcs_app_id end |
#idcs_app_location_url ⇒ String
**[Required]** URL for the location of the IDCS Application (used by IDCS APIs)
12 13 14 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 12 def idcs_app_location_url @idcs_app_location_url end |
#idcs_app_name ⇒ String
**[Required]** The IDCS application name associated with the instance
24 25 26 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 24 def idcs_app_name @idcs_app_name end |
#instance_primary_audience_url ⇒ String
**[Required]** The URL used as the primary audience for visual builder flows in this instance type: string
30 31 32 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 30 def instance_primary_audience_url @instance_primary_audience_url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'idcs_app_location_url': :'idcsAppLocationUrl', 'idcs_app_display_name': :'idcsAppDisplayName', 'idcs_app_id': :'idcsAppId', 'idcs_app_name': :'idcsAppName', 'instance_primary_audience_url': :'instancePrimaryAudienceUrl' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'idcs_app_location_url': :'String', 'idcs_app_display_name': :'String', 'idcs_app_id': :'String', 'idcs_app_name': :'String', 'instance_primary_audience_url': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 113 def ==(other) return true if equal?(other) self.class == other.class && idcs_app_location_url == other.idcs_app_location_url && idcs_app_display_name == other.idcs_app_display_name && idcs_app_id == other.idcs_app_id && idcs_app_name == other.idcs_app_name && instance_primary_audience_url == other.instance_primary_audience_url end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 147 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
127 128 129 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 127 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 136 def hash [idcs_app_location_url, idcs_app_display_name, idcs_app_id, idcs_app_name, instance_primary_audience_url].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
174 175 176 |
# File 'lib/oci/visual_builder/models/idcs_info_details.rb', line 174 def to_s to_hash.to_s end |