Class: OCI::VisualBuilder::Models::VbInstance
- Inherits:
-
Object
- Object
- OCI::VisualBuilder::Models::VbInstance
- Defined in:
- lib/oci/visual_builder/models/vb_instance.rb
Overview
Description of Vb Instance.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CONSUMPTION_MODEL_ENUM =
[ CONSUMPTION_MODEL_UCM = 'UCM'.freeze, CONSUMPTION_MODEL_GOV = 'GOV'.freeze, CONSUMPTION_MODEL_VB4_SAAS = 'VB4SAAS'.freeze, CONSUMPTION_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#alternate_custom_endpoints ⇒ Array<OCI::VisualBuilder::Models::CustomEndpointDetails>
A list of alternate custom endpoints used for the vb instance URL.
-
#attachments ⇒ Array<OCI::VisualBuilder::Models::AttachmentDetails>
A list of associated attachments to other services.
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#consumption_model ⇒ String
The entitlement used for billing purposes.
- #custom_endpoint ⇒ OCI::VisualBuilder::Models::CustomEndpointDetails
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** Vb Instance Identifier, can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
- #idcs_info ⇒ OCI::VisualBuilder::Models::IdcsInfoDetails
-
#instance_url ⇒ String
**[Required]** The Vb Instance URL.
-
#is_visual_builder_enabled ⇒ BOOLEAN
Visual Builder is enabled or not.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the vb instance.
-
#node_count ⇒ Integer
**[Required]** The number of Nodes.
-
#state_message ⇒ String
An message describing the current state in more detail.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
The time the the VbInstance was created.
-
#time_updated ⇒ DateTime
The time the VbInstance was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VbInstance
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VbInstance
Initializes the object
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 183 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'stateMessage'] if attributes[:'stateMessage'] raise 'You cannot provide both :stateMessage and :state_message' if attributes.key?(:'stateMessage') && attributes.key?(:'state_message') self. = attributes[:'state_message'] if attributes[:'state_message'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.instance_url = attributes[:'instanceUrl'] if attributes[:'instanceUrl'] raise 'You cannot provide both :instanceUrl and :instance_url' if attributes.key?(:'instanceUrl') && attributes.key?(:'instance_url') self.instance_url = attributes[:'instance_url'] if attributes[:'instance_url'] self.node_count = attributes[:'nodeCount'] if attributes[:'nodeCount'] raise 'You cannot provide both :nodeCount and :node_count' if attributes.key?(:'nodeCount') && attributes.key?(:'node_count') self.node_count = attributes[:'node_count'] if attributes[:'node_count'] self.is_visual_builder_enabled = attributes[:'isVisualBuilderEnabled'] unless attributes[:'isVisualBuilderEnabled'].nil? raise 'You cannot provide both :isVisualBuilderEnabled and :is_visual_builder_enabled' if attributes.key?(:'isVisualBuilderEnabled') && attributes.key?(:'is_visual_builder_enabled') self.is_visual_builder_enabled = attributes[:'is_visual_builder_enabled'] unless attributes[:'is_visual_builder_enabled'].nil? self.custom_endpoint = attributes[:'customEndpoint'] if attributes[:'customEndpoint'] raise 'You cannot provide both :customEndpoint and :custom_endpoint' if attributes.key?(:'customEndpoint') && attributes.key?(:'custom_endpoint') self.custom_endpoint = attributes[:'custom_endpoint'] if attributes[:'custom_endpoint'] self.alternate_custom_endpoints = attributes[:'alternateCustomEndpoints'] if attributes[:'alternateCustomEndpoints'] raise 'You cannot provide both :alternateCustomEndpoints and :alternate_custom_endpoints' if attributes.key?(:'alternateCustomEndpoints') && attributes.key?(:'alternate_custom_endpoints') self.alternate_custom_endpoints = attributes[:'alternate_custom_endpoints'] if attributes[:'alternate_custom_endpoints'] self.consumption_model = attributes[:'consumptionModel'] if attributes[:'consumptionModel'] raise 'You cannot provide both :consumptionModel and :consumption_model' if attributes.key?(:'consumptionModel') && attributes.key?(:'consumption_model') self.consumption_model = attributes[:'consumption_model'] if attributes[:'consumption_model'] self.idcs_info = attributes[:'idcsInfo'] if attributes[:'idcsInfo'] raise 'You cannot provide both :idcsInfo and :idcs_info' if attributes.key?(:'idcsInfo') && attributes.key?(:'idcs_info') self.idcs_info = attributes[:'idcs_info'] if attributes[:'idcs_info'] self. = attributes[:'attachments'] if attributes[:'attachments'] end |
Instance Attribute Details
#alternate_custom_endpoints ⇒ Array<OCI::VisualBuilder::Models::CustomEndpointDetails>
A list of alternate custom endpoints used for the vb instance URL.
93 94 95 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 93 def alternate_custom_endpoints @alternate_custom_endpoints end |
#attachments ⇒ Array<OCI::VisualBuilder::Models::AttachmentDetails>
A list of associated attachments to other services
105 106 107 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 105 def @attachments end |
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
39 40 41 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 39 def compartment_id @compartment_id end |
#consumption_model ⇒ String
The entitlement used for billing purposes.
97 98 99 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 97 def consumption_model @consumption_model end |
#custom_endpoint ⇒ OCI::VisualBuilder::Models::CustomEndpointDetails
88 89 90 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 88 def custom_endpoint @custom_endpoint end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
67 68 69 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 67 def @defined_tags end |
#display_name ⇒ String
**[Required]** Vb Instance Identifier, can be renamed.
35 36 37 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 35 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
61 62 63 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 61 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
31 32 33 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 31 def id @id end |
#idcs_info ⇒ OCI::VisualBuilder::Models::IdcsInfoDetails
100 101 102 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 100 def idcs_info @idcs_info end |
#instance_url ⇒ String
**[Required]** The Vb Instance URL.
77 78 79 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 77 def instance_url @instance_url end |
#is_visual_builder_enabled ⇒ BOOLEAN
Visual Builder is enabled or not.
85 86 87 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 85 def is_visual_builder_enabled @is_visual_builder_enabled end |
#lifecycle_state ⇒ String
**[Required]** The current state of the vb instance.
51 52 53 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 51 def lifecycle_state @lifecycle_state end |
#node_count ⇒ Integer
**[Required]** The number of Nodes
81 82 83 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 81 def node_count @node_count end |
#state_message ⇒ String
An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
55 56 57 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 55 def @state_message end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
73 74 75 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 73 def @system_tags end |
#time_created ⇒ DateTime
The time the the VbInstance was created. An RFC3339 formatted datetime string.
43 44 45 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 43 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the VbInstance was updated. An RFC3339 formatted datetime string.
47 48 49 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 47 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 108 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'state_message': :'stateMessage', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'instance_url': :'instanceUrl', 'node_count': :'nodeCount', 'is_visual_builder_enabled': :'isVisualBuilderEnabled', 'custom_endpoint': :'customEndpoint', 'alternate_custom_endpoints': :'alternateCustomEndpoints', 'consumption_model': :'consumptionModel', 'idcs_info': :'idcsInfo', 'attachments': :'attachments' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 134 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'state_message': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'instance_url': :'String', 'node_count': :'Integer', 'is_visual_builder_enabled': :'BOOLEAN', 'custom_endpoint': :'OCI::VisualBuilder::Models::CustomEndpointDetails', 'alternate_custom_endpoints': :'Array<OCI::VisualBuilder::Models::CustomEndpointDetails>', 'consumption_model': :'String', 'idcs_info': :'OCI::VisualBuilder::Models::IdcsInfoDetails', 'attachments': :'Array<OCI::VisualBuilder::Models::AttachmentDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 323 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && == other. && == other. && == other. && == other. && instance_url == other.instance_url && node_count == other.node_count && is_visual_builder_enabled == other.is_visual_builder_enabled && custom_endpoint == other.custom_endpoint && alternate_custom_endpoints == other.alternate_custom_endpoints && consumption_model == other.consumption_model && idcs_info == other.idcs_info && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 370 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
350 351 352 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 350 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
359 360 361 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 359 def hash [id, display_name, compartment_id, time_created, time_updated, lifecycle_state, , , , , instance_url, node_count, is_visual_builder_enabled, custom_endpoint, alternate_custom_endpoints, consumption_model, idcs_info, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
403 404 405 406 407 408 409 410 411 412 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 403 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
397 398 399 |
# File 'lib/oci/visual_builder/models/vb_instance.rb', line 397 def to_s to_hash.to_s end |