Class: OCI::VnMonitoring::Models::CreateDrgRouteDistributionDetails
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::CreateDrgRouteDistributionDetails
- Defined in:
- lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb
Overview
Details used to create a route distribution.
Constant Summary collapse
- DISTRIBUTION_TYPE_ENUM =
[ DISTRIBUTION_TYPE_IMPORT = 'IMPORT'.freeze ].freeze
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#distribution_type ⇒ String
**[Required]** Whether this distribution defines how routes get imported into route tables or exported through DRG Attachments.
-
#drg_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG the DRG route table belongs to.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDrgRouteDistributionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDrgRouteDistributionDetails
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.drg_id = attributes[:'drgId'] if attributes[:'drgId'] raise 'You cannot provide both :drgId and :drg_id' if attributes.key?(:'drgId') && attributes.key?(:'drg_id') self.drg_id = attributes[:'drg_id'] if attributes[:'drg_id'] self.distribution_type = attributes[:'distributionType'] if attributes[:'distributionType'] raise 'You cannot provide both :distributionType and :distribution_type' if attributes.key?(:'distributionType') && attributes.key?(:'distribution_type') self.distribution_type = attributes[:'distribution_type'] if attributes[:'distribution_type'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
19 20 21 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 19 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
25 26 27 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 25 def display_name @display_name end |
#distribution_type ⇒ String
**[Required]** Whether this distribution defines how routes get imported into route tables or exported through DRG Attachments
41 42 43 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 41 def distribution_type @distribution_type end |
#drg_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG the DRG route table belongs to.
36 37 38 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 36 def drg_id @drg_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
31 32 33 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 31 def @freeform_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'drg_id': :'drgId', 'distribution_type': :'distributionType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'drg_id': :'String', 'distribution_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 132 def ==(other) return true if equal?(other) self.class == other.class && == other. && display_name == other.display_name && == other. && drg_id == other.drg_id && distribution_type == other.distribution_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 166 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
146 147 148 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 146 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 155 def hash [, display_name, , drg_id, distribution_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
193 194 195 |
# File 'lib/oci/vn_monitoring/models/create_drg_route_distribution_details.rb', line 193 def to_s to_hash.to_s end |