Class: OCI::VnMonitoring::Models::CreatePrivateIpDetails
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::CreatePrivateIpDetails
- Defined in:
- lib/oci/vn_monitoring/models/create_private_ip_details.rb
Overview
CreatePrivateIpDetails model.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#hostname_label ⇒ String
The hostname for the private IP.
-
#ip_address ⇒ String
A private IP address of your choice.
-
#vnic_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VNIC to assign the private IP to.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePrivateIpDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreatePrivateIpDetails
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 98 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel'] raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label') self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label'] self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress'] raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address'] self.vnic_id = attributes[:'vnicId'] if attributes[:'vnicId'] raise 'You cannot provide both :vnicId and :vnic_id' if attributes.key?(:'vnicId') && attributes.key?(:'vnic_id') self.vnic_id = attributes[:'vnic_id'] if attributes[:'vnic_id'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
14 15 16 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 14 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
20 21 22 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 20 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
26 27 28 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 26 def @freeform_tags end |
#hostname_label ⇒ String
The hostname for the private IP. Used for DNS. The value is the hostname portion of the private IP's fully qualified domain name (FQDN) (for example, `bminstance-1` in FQDN `bminstance-1.subnet123.vcn1.oraclevcn.com`). Must be unique across all VNICs in the subnet and comply with [RFC 952](tools.ietf.org/html/rfc952) and [RFC 1123](tools.ietf.org/html/rfc1123).
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
Example: `bminstance-1`
41 42 43 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 41 def hostname_label @hostname_label end |
#ip_address ⇒ String
A private IP address of your choice. Must be an available IP address within the subnet's CIDR. If you don't specify a value, Oracle automatically assigns a private IP address from the subnet.
Example: `10.0.3.3`
50 51 52 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 50 def ip_address @ip_address end |
#vnic_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VNIC to assign the private IP to. The VNIC and private IP must be in the same subnet.
56 57 58 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 56 def vnic_id @vnic_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 59 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'hostname_label': :'hostnameLabel', 'ip_address': :'ipAddress', 'vnic_id': :'vnicId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 73 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'hostname_label': :'String', 'ip_address': :'String', 'vnic_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 148 def ==(other) return true if equal?(other) self.class == other.class && == other. && display_name == other.display_name && == other. && hostname_label == other.hostname_label && ip_address == other.ip_address && vnic_id == other.vnic_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 172 def hash [, display_name, , hostname_label, ip_address, vnic_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/vn_monitoring/models/create_private_ip_details.rb', line 210 def to_s to_hash.to_s end |