Class: OCI::VnMonitoring::Models::CreateSubnetDetails
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::CreateSubnetDetails
- Defined in:
- lib/oci/vn_monitoring/models/create_subnet_details.rb
Overview
CreateSubnetDetails model.
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
**[Required]** The availability domain to contain the subnet.
-
#cidr_block ⇒ String
**[Required]** The CIDR IP address range of the subnet.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to contain the subnet.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#dhcp_options_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the set of DHCP options the subnet will use.
-
#display_name ⇒ String
A user-friendly name.
-
#dns_label ⇒ String
A DNS label for the subnet, used in conjunction with the VNIC's hostname and VCN's DNS label to form a fully qualified domain name (FQDN) for each VNIC within this subnet (for example, `bminstance-1.subnet123.vcn1.oraclevcn.com`).
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#ipv6_cidr_block ⇒ String
Use this to enable IPv6 addressing for this subnet.
-
#prohibit_public_ip_on_vnic ⇒ BOOLEAN
Whether VNICs within this subnet can have public IP addresses.
-
#route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the subnet will use.
-
#security_list_ids ⇒ Array<String>
The OCIDs of the security list or lists the subnet will use.
-
#vcn_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN to contain the subnet.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSubnetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSubnetDetails
Initializes the object
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 180 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock'] raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block') self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'dhcpOptionsId'] if attributes[:'dhcpOptionsId'] raise 'You cannot provide both :dhcpOptionsId and :dhcp_options_id' if attributes.key?(:'dhcpOptionsId') && attributes.key?(:'dhcp_options_id') self. = attributes[:'dhcp_options_id'] if attributes[:'dhcp_options_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.dns_label = attributes[:'dnsLabel'] if attributes[:'dnsLabel'] raise 'You cannot provide both :dnsLabel and :dns_label' if attributes.key?(:'dnsLabel') && attributes.key?(:'dns_label') self.dns_label = attributes[:'dns_label'] if attributes[:'dns_label'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.ipv6_cidr_block = attributes[:'ipv6CidrBlock'] if attributes[:'ipv6CidrBlock'] raise 'You cannot provide both :ipv6CidrBlock and :ipv6_cidr_block' if attributes.key?(:'ipv6CidrBlock') && attributes.key?(:'ipv6_cidr_block') self.ipv6_cidr_block = attributes[:'ipv6_cidr_block'] if attributes[:'ipv6_cidr_block'] self.prohibit_public_ip_on_vnic = attributes[:'prohibitPublicIpOnVnic'] unless attributes[:'prohibitPublicIpOnVnic'].nil? raise 'You cannot provide both :prohibitPublicIpOnVnic and :prohibit_public_ip_on_vnic' if attributes.key?(:'prohibitPublicIpOnVnic') && attributes.key?(:'prohibit_public_ip_on_vnic') self.prohibit_public_ip_on_vnic = attributes[:'prohibit_public_ip_on_vnic'] unless attributes[:'prohibit_public_ip_on_vnic'].nil? self.route_table_id = attributes[:'routeTableId'] if attributes[:'routeTableId'] raise 'You cannot provide both :routeTableId and :route_table_id' if attributes.key?(:'routeTableId') && attributes.key?(:'route_table_id') self.route_table_id = attributes[:'route_table_id'] if attributes[:'route_table_id'] self.security_list_ids = attributes[:'securityListIds'] if attributes[:'securityListIds'] raise 'You cannot provide both :securityListIds and :security_list_ids' if attributes.key?(:'securityListIds') && attributes.key?(:'security_list_ids') self.security_list_ids = attributes[:'security_list_ids'] if attributes[:'security_list_ids'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] end |
Instance Attribute Details
#availability_domain ⇒ String
**[Required]** The availability domain to contain the subnet.
Example: `Uocm:PHX-AD-1`
15 16 17 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 15 def availability_domain @availability_domain end |
#cidr_block ⇒ String
**[Required]** The CIDR IP address range of the subnet. The CIDR must maintain the following rules -
-
The CIDR block is valid and correctly formatted.
-
The new range is within one of the parent VCN ranges.
Example: `10.0.1.0/24`
25 26 27 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 25 def cidr_block @cidr_block end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to contain the subnet.
29 30 31 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 29 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
35 36 37 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 35 def @defined_tags end |
#dhcp_options_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the set of DHCP options the subnet will use. If you don't provide a value, the subnet uses the VCN's default set of DHCP options.
41 42 43 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 41 def @dhcp_options_id end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
47 48 49 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 47 def display_name @display_name end |
#dns_label ⇒ String
A DNS label for the subnet, used in conjunction with the VNIC's hostname and VCN's DNS label to form a fully qualified domain name (FQDN) for each VNIC within this subnet (for example, `bminstance-1.subnet123.vcn1.oraclevcn.com`). Must be an alphanumeric string that begins with a letter and is unique within the VCN. The value cannot be changed.
This value must be set if you want to use the Internet and VCN Resolver to resolve the hostnames of instances in the subnet. It can only be set if the VCN itself was created with a DNS label.
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
Example: `subnet123`
65 66 67 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 65 def dns_label @dns_label end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
71 72 73 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 71 def @freeform_tags end |
#ipv6_cidr_block ⇒ String
Use this to enable IPv6 addressing for this subnet. The VCN must be enabled for IPv6. You can't change this subnet characteristic later. All subnets are /64 in size. The subnet portion of the IPv6 address is the fourth hextet from the left (1111 in the following example).
For important details about IPv6 addressing in a VCN, see [IPv6 Addresses](docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
Example: `2001:0db8:0123:1111::/64`
82 83 84 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 82 def ipv6_cidr_block @ipv6_cidr_block end |
#prohibit_public_ip_on_vnic ⇒ BOOLEAN
Whether VNICs within this subnet can have public IP addresses. Defaults to false, which means VNICs created in this subnet will automatically be assigned public IP addresses unless specified otherwise during instance launch or VNIC creation (with the `assignPublicIp` flag in OCI::VnMonitoring::Models::CreateVnicDetails). If `prohibitPublicIpOnVnic` is set to true, VNICs created in this subnet cannot have public IP addresses (that is, it's a private subnet).
For IPv6, if `prohibitPublicIpOnVnic` is set to `true`, internet access is not allowed for any IPv6s assigned to VNICs in the subnet.
Example: `true`
99 100 101 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 99 def prohibit_public_ip_on_vnic @prohibit_public_ip_on_vnic end |
#route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the subnet will use. If you don't provide a value, the subnet uses the VCN's default route table.
105 106 107 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 105 def route_table_id @route_table_id end |
#security_list_ids ⇒ Array<String>
The OCIDs of the security list or lists the subnet will use. If you don't provide a value, the subnet uses the VCN's default security list. Remember that security lists are associated *with the subnet*, but the rules are applied to the individual VNICs in the subnet.
113 114 115 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 113 def security_list_ids @security_list_ids end |
#vcn_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN to contain the subnet.
117 118 119 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 117 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 120 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'cidr_block': :'cidrBlock', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'dhcp_options_id': :'dhcpOptionsId', 'display_name': :'displayName', 'dns_label': :'dnsLabel', 'freeform_tags': :'freeformTags', 'ipv6_cidr_block': :'ipv6CidrBlock', 'prohibit_public_ip_on_vnic': :'prohibitPublicIpOnVnic', 'route_table_id': :'routeTableId', 'security_list_ids': :'securityListIds', 'vcn_id': :'vcnId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 141 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'cidr_block': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'dhcp_options_id': :'String', 'display_name': :'String', 'dns_label': :'String', 'freeform_tags': :'Hash<String, String>', 'ipv6_cidr_block': :'String', 'prohibit_public_ip_on_vnic': :'BOOLEAN', 'route_table_id': :'String', 'security_list_ids': :'Array<String>', 'vcn_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 272 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && cidr_block == other.cidr_block && compartment_id == other.compartment_id && == other. && == other. && display_name == other.display_name && dns_label == other.dns_label && == other. && ipv6_cidr_block == other.ipv6_cidr_block && prohibit_public_ip_on_vnic == other.prohibit_public_ip_on_vnic && route_table_id == other.route_table_id && security_list_ids == other.security_list_ids && vcn_id == other.vcn_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 314 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
294 295 296 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 294 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
303 304 305 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 303 def hash [availability_domain, cidr_block, compartment_id, , , display_name, dns_label, , ipv6_cidr_block, prohibit_public_ip_on_vnic, route_table_id, security_list_ids, vcn_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
347 348 349 350 351 352 353 354 355 356 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 347 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
341 342 343 |
# File 'lib/oci/vn_monitoring/models/create_subnet_details.rb', line 341 def to_s to_hash.to_s end |