Class: OCI::VnMonitoring::Models::DrgRouteDistribution
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::DrgRouteDistribution
- Defined in:
- lib/oci/vn_monitoring/models/drg_route_distribution.rb
Overview
A route distribution establishes how routes get imported into DRG route tables and exported through the DRG attachments.
A route distribution is a list of statements. Each statement consists of a set of matches, all of which must be `True` in order for the statement's action to take place. Each statement determines which routes are propagated.
You can assign a route distribution as a route table's import distribution. The statements in an import route distribution specify how how incoming route advertisements through a referenced attachment or all attachments of a certain type are inserted into the route table.
You can assign a route distribution as a DRG attachment's export distribution. Export route distribution statements specify how routes in a DRG attachment's assigned table are advertised out through the attachment. When a DRG attachment is created, a route distribution is created with a single ACCEPT statement with match criteria MATCH_ALL. Exporting routes through VCN attachments is unsupported, so no VCN attachments are assigned an export distribution.
The two auto-generated DRG route tables (one as the default for VCN attachments, and the other for all other types of attachments) are each assigned an auto generated import route distribution. The default VCN table's import distribution has a single statement with match criteria MATCH_ALL to import routes from each DRG attachment type. The other table's import distribution has a statement to import routes from attachments with the VCN type.
The route distribution is always in the same compartment as the DRG.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DISTRIBUTION_TYPE_ENUM =
[ DISTRIBUTION_TYPE_IMPORT = 'IMPORT'.freeze, DISTRIBUTION_TYPE_EXPORT = 'EXPORT'.freeze, DISTRIBUTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the route distribution.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#distribution_type ⇒ String
**[Required]** Whether this distribution defines how routes get imported into route tables or exported through DRG attachments.
-
#drg_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG that contains this route distribution.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The route distribution's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
-
#lifecycle_state ⇒ String
**[Required]** The route distribution's current state.
-
#time_created ⇒ DateTime
**[Required]** The date and time the route distribution was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DrgRouteDistribution
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DrgRouteDistribution
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 139 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.drg_id = attributes[:'drgId'] if attributes[:'drgId'] raise 'You cannot provide both :drgId and :drg_id' if attributes.key?(:'drgId') && attributes.key?(:'drg_id') self.drg_id = attributes[:'drg_id'] if attributes[:'drg_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.distribution_type = attributes[:'distributionType'] if attributes[:'distributionType'] raise 'You cannot provide both :distributionType and :distribution_type' if attributes.key?(:'distributionType') && attributes.key?(:'distribution_type') self.distribution_type = attributes[:'distribution_type'] if attributes[:'distribution_type'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the route distribution.
50 51 52 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 50 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
56 57 58 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 56 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
62 63 64 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 62 def display_name @display_name end |
#distribution_type ⇒ String
**[Required]** Whether this distribution defines how routes get imported into route tables or exported through DRG attachments.
88 89 90 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 88 def distribution_type @distribution_type end |
#drg_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG that contains this route distribution.
46 47 48 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 46 def drg_id @drg_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
68 69 70 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 68 def @freeform_tags end |
#id ⇒ String
**[Required]** The route distribution's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
72 73 74 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 72 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The route distribution's current state.
76 77 78 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 76 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
**[Required]** The date and time the route distribution was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
83 84 85 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 83 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 91 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'drg_id': :'drgId', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'distribution_type': :'distributionType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 108 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'drg_id': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'distribution_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 229 def ==(other) return true if equal?(other) self.class == other.class && drg_id == other.drg_id && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && distribution_type == other.distribution_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 267 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
247 248 249 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 247 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
256 257 258 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 256 def hash [drg_id, compartment_id, , display_name, , id, lifecycle_state, time_created, distribution_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
300 301 302 303 304 305 306 307 308 309 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 300 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
294 295 296 |
# File 'lib/oci/vn_monitoring/models/drg_route_distribution.rb', line 294 def to_s to_hash.to_s end |