Class: OCI::VnMonitoring::Models::EgressSecurityRule
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::EgressSecurityRule
- Defined in:
- lib/oci/vn_monitoring/models/egress_security_rule.rb
Overview
A rule for allowing outbound IP packets.
Constant Summary collapse
- DESTINATION_TYPE_ENUM =
[ DESTINATION_TYPE_CIDR_BLOCK = 'CIDR_BLOCK'.freeze, DESTINATION_TYPE_SERVICE_CIDR_BLOCK = 'SERVICE_CIDR_BLOCK'.freeze, DESTINATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#destination ⇒ String
**[Required]** Conceptually, this is the range of IP addresses that a packet originating from the instance can go to.
-
#destination_type ⇒ String
Type of destination for the rule.
- #icmp_options ⇒ OCI::VnMonitoring::Models::IcmpOptions
-
#is_stateless ⇒ BOOLEAN
A stateless rule allows traffic in one direction.
-
#protocol ⇒ String
**[Required]** The transport protocol.
- #tcp_options ⇒ OCI::VnMonitoring::Models::TcpOptions
- #udp_options ⇒ OCI::VnMonitoring::Models::UdpOptions
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EgressSecurityRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EgressSecurityRule
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.destination = attributes[:'destination'] if attributes[:'destination'] self.destination_type = attributes[:'destinationType'] if attributes[:'destinationType'] self.destination_type = "CIDR_BLOCK" if destination_type.nil? && !attributes.key?(:'destinationType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :destinationType and :destination_type' if attributes.key?(:'destinationType') && attributes.key?(:'destination_type') self.destination_type = attributes[:'destination_type'] if attributes[:'destination_type'] self.destination_type = "CIDR_BLOCK" if destination_type.nil? && !attributes.key?(:'destinationType') && !attributes.key?(:'destination_type') # rubocop:disable Style/StringLiterals self. = attributes[:'icmpOptions'] if attributes[:'icmpOptions'] raise 'You cannot provide both :icmpOptions and :icmp_options' if attributes.key?(:'icmpOptions') && attributes.key?(:'icmp_options') self. = attributes[:'icmp_options'] if attributes[:'icmp_options'] self.is_stateless = attributes[:'isStateless'] unless attributes[:'isStateless'].nil? raise 'You cannot provide both :isStateless and :is_stateless' if attributes.key?(:'isStateless') && attributes.key?(:'is_stateless') self.is_stateless = attributes[:'is_stateless'] unless attributes[:'is_stateless'].nil? self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self. = attributes[:'tcpOptions'] if attributes[:'tcpOptions'] raise 'You cannot provide both :tcpOptions and :tcp_options' if attributes.key?(:'tcpOptions') && attributes.key?(:'tcp_options') self. = attributes[:'tcp_options'] if attributes[:'tcp_options'] self. = attributes[:'udpOptions'] if attributes[:'udpOptions'] raise 'You cannot provide both :udpOptions and :udp_options' if attributes.key?(:'udpOptions') && attributes.key?(:'udp_options') self. = attributes[:'udp_options'] if attributes[:'udp_options'] end |
Instance Attribute Details
#destination ⇒ String
**[Required]** Conceptually, this is the range of IP addresses that a packet originating from the instance can go to.
Allowed values:
* IP address range in CIDR notation. For example: `192.168.1.0/24` or `2001:0db8:0123:45::/56`
Note that IPv6 addressing is currently supported only in certain regions. See
[IPv6 Addresses](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
* The `cidrBlock` value for a {Service}, if you're
setting up a security list rule for traffic destined for a particular `Service` through
a service gateway. For example: `oci-phx-objectstorage`.
31 32 33 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 31 def destination @destination end |
#destination_type ⇒ String
Type of destination for the rule. The default is `CIDR_BLOCK`.
Allowed values:
* `CIDR_BLOCK`: If the rule's `destination` is an IP address range in CIDR notation.
* `SERVICE_CIDR_BLOCK`: If the rule's `destination` is the `cidrBlock` value for a
{Service} (the rule is for traffic destined for a
particular `Service` through a service gateway).
44 45 46 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 44 def destination_type @destination_type end |
#icmp_options ⇒ OCI::VnMonitoring::Models::IcmpOptions
47 48 49 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 47 def @icmp_options end |
#is_stateless ⇒ BOOLEAN
A stateless rule allows traffic in one direction. Remember to add a corresponding stateless rule in the other direction if you need to support bidirectional traffic. For example, if egress traffic allows TCP destination port 80, there should be an ingress rule to allow TCP source port 80. Defaults to false, which means the rule is stateful and a corresponding rule is not necessary for bidirectional traffic.
56 57 58 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 56 def is_stateless @is_stateless end |
#protocol ⇒ String
**[Required]** The transport protocol. Specify either `all` or an IPv4 protocol number as defined in [Protocol Numbers](www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml). Options are supported only for ICMP ("1"), TCP ("6"), UDP ("17"), and ICMPv6 ("58").
64 65 66 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 64 def protocol @protocol end |
#tcp_options ⇒ OCI::VnMonitoring::Models::TcpOptions
67 68 69 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 67 def @tcp_options end |
#udp_options ⇒ OCI::VnMonitoring::Models::UdpOptions
70 71 72 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 70 def @udp_options end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 73 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'destination': :'destination', 'destination_type': :'destinationType', 'icmp_options': :'icmpOptions', 'is_stateless': :'isStateless', 'protocol': :'protocol', 'tcp_options': :'tcpOptions', 'udp_options': :'udpOptions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 88 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'destination': :'String', 'destination_type': :'String', 'icmp_options': :'OCI::VnMonitoring::Models::IcmpOptions', 'is_stateless': :'BOOLEAN', 'protocol': :'String', 'tcp_options': :'OCI::VnMonitoring::Models::TcpOptions', 'udp_options': :'OCI::VnMonitoring::Models::UdpOptions' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 178 def ==(other) return true if equal?(other) self.class == other.class && destination == other.destination && destination_type == other.destination_type && == other. && is_stateless == other.is_stateless && protocol == other.protocol && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 214 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
194 195 196 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 194 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 203 def hash [destination, destination_type, , is_stateless, protocol, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
241 242 243 |
# File 'lib/oci/vn_monitoring/models/egress_security_rule.rb', line 241 def to_s to_hash.to_s end |