Class: OCI::VnMonitoring::Models::PathAnalyzerTest
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::PathAnalyzerTest
- Defined in:
- lib/oci/vn_monitoring/models/path_analyzer_test.rb
Overview
Defines the details saved in a `PathAnalyzerTest` resource. These configuration details are used to run a [Network Path Analyzer](docs.cloud.oracle.com/iaas/Content/Network/Concepts/path_analyzer.htm) analysis.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the `PathAnalyzerTest` resource's compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#destination_endpoint ⇒ OCI::VnMonitoring::Models::Endpoint
This attribute is required.
-
#display_name ⇒ String
**[Required]** A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** A unique identifier established when the resource is created.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the `PathAnalyzerTest` resource.
-
#protocol ⇒ Integer
**[Required]** The IP protocol to use for the `PathAnalyzerTest` resource.
- #protocol_parameters ⇒ OCI::VnMonitoring::Models::ProtocolParameters
-
#query_options ⇒ OCI::VnMonitoring::Models::QueryOptions
This attribute is required.
-
#source_endpoint ⇒ OCI::VnMonitoring::Models::Endpoint
This attribute is required.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The date and time the `PathAnalyzerTest` resource was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
**[Required]** The date and time the `PathAnalyzerTest` resource was last updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PathAnalyzerTest
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PathAnalyzerTest
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 149 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.source_endpoint = attributes[:'sourceEndpoint'] if attributes[:'sourceEndpoint'] raise 'You cannot provide both :sourceEndpoint and :source_endpoint' if attributes.key?(:'sourceEndpoint') && attributes.key?(:'source_endpoint') self.source_endpoint = attributes[:'source_endpoint'] if attributes[:'source_endpoint'] self.destination_endpoint = attributes[:'destinationEndpoint'] if attributes[:'destinationEndpoint'] raise 'You cannot provide both :destinationEndpoint and :destination_endpoint' if attributes.key?(:'destinationEndpoint') && attributes.key?(:'destination_endpoint') self.destination_endpoint = attributes[:'destination_endpoint'] if attributes[:'destination_endpoint'] self.protocol_parameters = attributes[:'protocolParameters'] if attributes[:'protocolParameters'] raise 'You cannot provide both :protocolParameters and :protocol_parameters' if attributes.key?(:'protocolParameters') && attributes.key?(:'protocol_parameters') self.protocol_parameters = attributes[:'protocol_parameters'] if attributes[:'protocol_parameters'] self. = attributes[:'queryOptions'] if attributes[:'queryOptions'] raise 'You cannot provide both :queryOptions and :query_options' if attributes.key?(:'queryOptions') && attributes.key?(:'query_options') self. = attributes[:'query_options'] if attributes[:'query_options'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the `PathAnalyzerTest` resource's compartment.
32 33 34 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 32 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
77 78 79 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 77 def @defined_tags end |
#destination_endpoint ⇒ OCI::VnMonitoring::Models::Endpoint
This attribute is required.
44 45 46 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 44 def destination_endpoint @destination_endpoint end |
#display_name ⇒ String
**[Required]** A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
28 29 30 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 28 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
71 72 73 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 71 def @freeform_tags end |
#id ⇒ String
**[Required]** A unique identifier established when the resource is created. The identifier can't be changed later.
22 23 24 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 22 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the `PathAnalyzerTest` resource.
65 66 67 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 65 def lifecycle_state @lifecycle_state end |
#protocol ⇒ Integer
**[Required]** The IP protocol to use for the `PathAnalyzerTest` resource.
36 37 38 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 36 def protocol @protocol end |
#protocol_parameters ⇒ OCI::VnMonitoring::Models::ProtocolParameters
47 48 49 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 47 def protocol_parameters @protocol_parameters end |
#query_options ⇒ OCI::VnMonitoring::Models::QueryOptions
This attribute is required.
51 52 53 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 51 def @query_options end |
#source_endpoint ⇒ OCI::VnMonitoring::Models::Endpoint
This attribute is required.
40 41 42 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 40 def source_endpoint @source_endpoint end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
83 84 85 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 83 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The date and time the `PathAnalyzerTest` resource was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
56 57 58 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 56 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The date and time the `PathAnalyzerTest` resource was last updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
61 62 63 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 61 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 86 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'protocol': :'protocol', 'source_endpoint': :'sourceEndpoint', 'destination_endpoint': :'destinationEndpoint', 'protocol_parameters': :'protocolParameters', 'query_options': :'queryOptions', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 108 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'protocol': :'Integer', 'source_endpoint': :'OCI::VnMonitoring::Models::Endpoint', 'destination_endpoint': :'OCI::VnMonitoring::Models::Endpoint', 'protocol_parameters': :'OCI::VnMonitoring::Models::ProtocolParameters', 'query_options': :'OCI::VnMonitoring::Models::QueryOptions', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 252 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && protocol == other.protocol && source_endpoint == other.source_endpoint && destination_endpoint == other.destination_endpoint && protocol_parameters == other.protocol_parameters && == other. && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 295 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
275 276 277 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 275 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
284 285 286 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 284 def hash [id, display_name, compartment_id, protocol, source_endpoint, destination_endpoint, protocol_parameters, , time_created, time_updated, lifecycle_state, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 337 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
322 323 324 |
# File 'lib/oci/vn_monitoring/models/path_analyzer_test.rb', line 322 def to_s to_hash.to_s end |