Class: OCI::VnMonitoring::Models::PrivateIp

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vn_monitoring/models/private_ip.rb

Overview

A *private IP* is a conceptual term that refers to an IPv4 private IP address and related properties. The `privateIp` object is the API representation of a private IP.

*Note:* For information about IPv6 addresses, see Ipv6.

Each instance has a *primary private IP* that is automatically created and assigned to the primary VNIC during instance launch. If you add a secondary VNIC to the instance, it also automatically gets a primary private IP. You can't remove a primary private IP from its VNIC. The primary private IP is automatically deleted when the VNIC is terminated.

You can add *secondary private IPs* to a VNIC after it's created. For more information, see the `privateIp` operations and also [IP Addresses](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingIPaddresses.htm).

*Note:* Only list_private_ips and get_private_ip work with primary private IPs. To create and update primary private IPs, you instead work with instance and VNIC operations. For example, a primary private IP's properties come from the values you specify in CreateVnicDetails when calling either launch_instance or attach_vnic. To update the hostname for a primary private IP, you use update_vnic.

To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PrivateIp

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :availability_domain (String)

    The value to assign to the #availability_domain property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :hostname_label (String)

    The value to assign to the #hostname_label property

  • :id (String)

    The value to assign to the #id property

  • :ip_address (String)

    The value to assign to the #ip_address property

  • :is_primary (BOOLEAN)

    The value to assign to the #is_primary property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :vnic_id (String)

    The value to assign to the #vnic_id property



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 180

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel']

  raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label')

  self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label']

  self.id = attributes[:'id'] if attributes[:'id']

  self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress']

  raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address')

  self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address']

  self.is_primary = attributes[:'isPrimary'] unless attributes[:'isPrimary'].nil?

  raise 'You cannot provide both :isPrimary and :is_primary' if attributes.key?(:'isPrimary') && attributes.key?(:'is_primary')

  self.is_primary = attributes[:'is_primary'] unless attributes[:'is_primary'].nil?

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.vnic_id = attributes[:'vnicId'] if attributes[:'vnicId']

  raise 'You cannot provide both :vnicId and :vnic_id' if attributes.key?(:'vnicId') && attributes.key?(:'vnic_id')

  self.vnic_id = attributes[:'vnic_id'] if attributes[:'vnic_id']
end

Instance Attribute Details

#availability_domainString

The private IP's availability domain.

Example: `Uocm:PHX-AD-1`

Returns:

  • (String)


44
45
46
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 44

def availability_domain
  @availability_domain
end

#compartment_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the private IP.

Returns:

  • (String)


48
49
50
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 48

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


54
55
56
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 54

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


60
61
62
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 60

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


66
67
68
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 66

def freeform_tags
  @freeform_tags
end

#hostname_labelString

The hostname for the private IP. Used for DNS. The value is the hostname portion of the private IP's fully qualified domain name (FQDN) (for example, `bminstance-1` in FQDN `bminstance-1.subnet123.vcn1.oraclevcn.com`). Must be unique across all VNICs in the subnet and comply with [RFC 952](tools.ietf.org/html/rfc952) and [RFC 1123](tools.ietf.org/html/rfc1123).

For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).

Example: `bminstance-1`

Returns:

  • (String)


81
82
83
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 81

def hostname_label
  @hostname_label
end

#idString

Returns:

  • (String)


85
86
87
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 85

def id
  @id
end

#ip_addressString

The private IP address of the `privateIp` object. The address is within the CIDR of the VNIC's subnet.

Example: `10.0.3.3`

Returns:

  • (String)


94
95
96
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 94

def ip_address
  @ip_address
end

#is_primaryBOOLEAN

Whether this private IP is the primary one on the VNIC. Primary private IPs are unassigned and deleted automatically when the VNIC is terminated.

Example: `true`

Returns:

  • (BOOLEAN)


102
103
104
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 102

def is_primary
  @is_primary
end

#subnet_idString

Returns:

  • (String)


107
108
109
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 107

def subnet_id
  @subnet_id
end

#time_createdDateTime

The date and time the private IP was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Example: `2016-08-25T21:10:29.600Z`

Returns:

  • (DateTime)


114
115
116
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 114

def time_created
  @time_created
end

#vnic_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VNIC the private IP is assigned to. The VNIC and private IP must be in the same subnet.

Returns:

  • (String)


120
121
122
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 120

def vnic_id
  @vnic_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 123

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'availabilityDomain',
    'compartment_id': :'compartmentId',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'hostname_label': :'hostnameLabel',
    'id': :'id',
    'ip_address': :'ipAddress',
    'is_primary': :'isPrimary',
    'subnet_id': :'subnetId',
    'time_created': :'timeCreated',
    'vnic_id': :'vnicId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 143

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'String',
    'compartment_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'hostname_label': :'String',
    'id': :'String',
    'ip_address': :'String',
    'is_primary': :'BOOLEAN',
    'subnet_id': :'String',
    'time_created': :'DateTime',
    'vnic_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 262

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    availability_domain == other.availability_domain &&
    compartment_id == other.compartment_id &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    hostname_label == other.hostname_label &&
    id == other.id &&
    ip_address == other.ip_address &&
    is_primary == other.is_primary &&
    subnet_id == other.subnet_id &&
    time_created == other.time_created &&
    vnic_id == other.vnic_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 303

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 283

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



292
293
294
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 292

def hash
  [availability_domain, compartment_id, defined_tags, display_name, freeform_tags, hostname_label, id, ip_address, is_primary, subnet_id, time_created, vnic_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



330
331
332
# File 'lib/oci/vn_monitoring/models/private_ip.rb', line 330

def to_s
  to_hash.to_s
end