Class: OCI::VnMonitoring::Models::RouteRule
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::RouteRule
- Defined in:
- lib/oci/vn_monitoring/models/route_rule.rb
Overview
A mapping between a destination IP address range and a virtual device to route matching packets to (a target).
Constant Summary collapse
- DESTINATION_TYPE_ENUM =
[ DESTINATION_TYPE_CIDR_BLOCK = 'CIDR_BLOCK'.freeze, DESTINATION_TYPE_SERVICE_CIDR_BLOCK = 'SERVICE_CIDR_BLOCK'.freeze, DESTINATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cidr_block ⇒ String
Deprecated.
-
#destination ⇒ String
Conceptually, this is the range of IP addresses used for matching when routing traffic.
-
#destination_type ⇒ String
Type of destination for the rule.
-
#network_entity_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the route rule's target.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RouteRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RouteRule
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 102 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock'] raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block') self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block'] self.destination = attributes[:'destination'] if attributes[:'destination'] self.destination_type = attributes[:'destinationType'] if attributes[:'destinationType'] self.destination_type = "CIDR_BLOCK" if destination_type.nil? && !attributes.key?(:'destinationType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :destinationType and :destination_type' if attributes.key?(:'destinationType') && attributes.key?(:'destination_type') self.destination_type = attributes[:'destination_type'] if attributes[:'destination_type'] self.destination_type = "CIDR_BLOCK" if destination_type.nil? && !attributes.key?(:'destinationType') && !attributes.key?(:'destination_type') # rubocop:disable Style/StringLiterals self.network_entity_id = attributes[:'networkEntityId'] if attributes[:'networkEntityId'] raise 'You cannot provide both :networkEntityId and :network_entity_id' if attributes.key?(:'networkEntityId') && attributes.key?(:'network_entity_id') self.network_entity_id = attributes[:'network_entity_id'] if attributes[:'network_entity_id'] end |
Instance Attribute Details
#cidr_block ⇒ String
Deprecated. Instead use `destination` and `destinationType`. Requests that include both `cidrBlock` and `destination` will be rejected.
A destination IP address range in CIDR notation. Matching packets will be routed to the indicated network entity (the target).
Cannot be an IPv6 CIDR.
Example: `0.0.0.0/0`
30 31 32 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 30 def cidr_block @cidr_block end |
#destination ⇒ String
Conceptually, this is the range of IP addresses used for matching when routing traffic. Required if you provide a `destinationType`.
Allowed values:
* IP address range in CIDR notation. Can be an IPv4 or IPv6 CIDR. For example: `192.168.1.0/24`
or `2001:0db8:0123:45::/56`. If you set this to an IPv6 CIDR, the route rule's target
can only be a DRG or internet gateway.
IPv6 addressing is supported for all commercial and government regions.
See [IPv6 Addresses](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
* The `cidrBlock` value for a {Service}, if you're
setting up a route rule for traffic destined for a particular `Service` through
a service gateway. For example: `oci-phx-objectstorage`.
48 49 50 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 48 def destination @destination end |
#destination_type ⇒ String
Type of destination for the rule. Required if you provide a `destination`.
* `CIDR_BLOCK`: If the rule's `destination` is an IP address range in CIDR notation.
* `SERVICE_CIDR_BLOCK`: If the rule's `destination` is the `cidrBlock` value for a
{Service} (the rule is for traffic destined for a
particular `Service` through a service gateway).
59 60 61 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 59 def destination_type @destination_type end |
#network_entity_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the route rule's target. For information about the type of targets you can specify, see [Route Tables](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm).
66 67 68 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 66 def network_entity_id @network_entity_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cidr_block': :'cidrBlock', 'destination': :'destination', 'destination_type': :'destinationType', 'network_entity_id': :'networkEntityId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cidr_block': :'String', 'destination': :'String', 'destination_type': :'String', 'network_entity_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 151 def ==(other) return true if equal?(other) self.class == other.class && cidr_block == other.cidr_block && destination == other.destination && destination_type == other.destination_type && network_entity_id == other.network_entity_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 184 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
164 165 166 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 164 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 173 def hash [cidr_block, destination, destination_type, network_entity_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
211 212 213 |
# File 'lib/oci/vn_monitoring/models/route_rule.rb', line 211 def to_s to_hash.to_s end |