Class: VnMonitoring::Models::Subnet
- Inherits:
-
Object
- Object
- VnMonitoring::Models::Subnet
- Defined in:
- lib/oci/vn_monitoring/models/subnet.rb
Overview
A logical subdivision of a VCN. Each subnet consists of a contiguous range of IP addresses that do not overlap with other subnets in the VCN. Example: 172.16.1.0/24. For more information, see [Overview of the Networking Service](docs.cloud.oracle.com/iaas/Content/Network/Concepts/overview.htm) and [VCNs and Subnets](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVCNs.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
**[Required]** The subnet's availability domain.
-
#cidr_block ⇒ String
**[Required]** The subnet's CIDR block.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the subnet.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#dhcp_options_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the set of DHCP options that the subnet uses.
-
#display_name ⇒ String
A user-friendly name.
-
#dns_label ⇒ String
A DNS label for the subnet, used in conjunction with the VNIC's hostname and VCN's DNS label to form a fully qualified domain name (FQDN) for each VNIC within this subnet (for example, `bminstance-1.subnet123.vcn1.oraclevcn.com`).
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The subnet's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
-
#ipv6_cidr_block ⇒ String
For an IPv6-enabled subnet, this is the IPv6 CIDR block for the subnet's private IP address space.
-
#ipv6_public_cidr_block ⇒ String
For an IPv6-enabled subnet, this is the IPv6 CIDR block for the subnet's public IP address space.
-
#ipv6_virtual_router_ip ⇒ String
For an IPv6-enabled subnet, this is the IPv6 address of the virtual router.
-
#lifecycle_state ⇒ String
**[Required]** The subnet's current state.
-
#prohibit_public_ip_on_vnic ⇒ BOOLEAN
Whether VNICs within this subnet can have public IP addresses.
-
#route_table_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table that the subnet uses.
-
#security_list_ids ⇒ Array<String>
The OCIDs of the security list or lists that the subnet uses.
-
#subnet_domain_name ⇒ String
The subnet's domain name, which consists of the subnet's DNS label, the VCN's DNS label, and the `oraclevcn.com` domain.
-
#time_created ⇒ DateTime
The date and time the subnet was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcn_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN the subnet is in.
-
#virtual_router_ip ⇒ String
**[Required]** The IP address of the virtual router.
-
#virtual_router_mac ⇒ String
**[Required]** The MAC address of the virtual router.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Subnet
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Subnet
Initializes the object
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 267 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock'] raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block') self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'dhcpOptionsId'] if attributes[:'dhcpOptionsId'] raise 'You cannot provide both :dhcpOptionsId and :dhcp_options_id' if attributes.key?(:'dhcpOptionsId') && attributes.key?(:'dhcp_options_id') self. = attributes[:'dhcp_options_id'] if attributes[:'dhcp_options_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.dns_label = attributes[:'dnsLabel'] if attributes[:'dnsLabel'] raise 'You cannot provide both :dnsLabel and :dns_label' if attributes.key?(:'dnsLabel') && attributes.key?(:'dns_label') self.dns_label = attributes[:'dns_label'] if attributes[:'dns_label'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.ipv6_cidr_block = attributes[:'ipv6CidrBlock'] if attributes[:'ipv6CidrBlock'] raise 'You cannot provide both :ipv6CidrBlock and :ipv6_cidr_block' if attributes.key?(:'ipv6CidrBlock') && attributes.key?(:'ipv6_cidr_block') self.ipv6_cidr_block = attributes[:'ipv6_cidr_block'] if attributes[:'ipv6_cidr_block'] self.ipv6_public_cidr_block = attributes[:'ipv6PublicCidrBlock'] if attributes[:'ipv6PublicCidrBlock'] raise 'You cannot provide both :ipv6PublicCidrBlock and :ipv6_public_cidr_block' if attributes.key?(:'ipv6PublicCidrBlock') && attributes.key?(:'ipv6_public_cidr_block') self.ipv6_public_cidr_block = attributes[:'ipv6_public_cidr_block'] if attributes[:'ipv6_public_cidr_block'] self.ipv6_virtual_router_ip = attributes[:'ipv6VirtualRouterIp'] if attributes[:'ipv6VirtualRouterIp'] raise 'You cannot provide both :ipv6VirtualRouterIp and :ipv6_virtual_router_ip' if attributes.key?(:'ipv6VirtualRouterIp') && attributes.key?(:'ipv6_virtual_router_ip') self.ipv6_virtual_router_ip = attributes[:'ipv6_virtual_router_ip'] if attributes[:'ipv6_virtual_router_ip'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.prohibit_public_ip_on_vnic = attributes[:'prohibitPublicIpOnVnic'] unless attributes[:'prohibitPublicIpOnVnic'].nil? raise 'You cannot provide both :prohibitPublicIpOnVnic and :prohibit_public_ip_on_vnic' if attributes.key?(:'prohibitPublicIpOnVnic') && attributes.key?(:'prohibit_public_ip_on_vnic') self.prohibit_public_ip_on_vnic = attributes[:'prohibit_public_ip_on_vnic'] unless attributes[:'prohibit_public_ip_on_vnic'].nil? self.route_table_id = attributes[:'routeTableId'] if attributes[:'routeTableId'] raise 'You cannot provide both :routeTableId and :route_table_id' if attributes.key?(:'routeTableId') && attributes.key?(:'route_table_id') self.route_table_id = attributes[:'route_table_id'] if attributes[:'route_table_id'] self.security_list_ids = attributes[:'securityListIds'] if attributes[:'securityListIds'] raise 'You cannot provide both :securityListIds and :security_list_ids' if attributes.key?(:'securityListIds') && attributes.key?(:'security_list_ids') self.security_list_ids = attributes[:'security_list_ids'] if attributes[:'security_list_ids'] self.subnet_domain_name = attributes[:'subnetDomainName'] if attributes[:'subnetDomainName'] raise 'You cannot provide both :subnetDomainName and :subnet_domain_name' if attributes.key?(:'subnetDomainName') && attributes.key?(:'subnet_domain_name') self.subnet_domain_name = attributes[:'subnet_domain_name'] if attributes[:'subnet_domain_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.virtual_router_ip = attributes[:'virtualRouterIp'] if attributes[:'virtualRouterIp'] raise 'You cannot provide both :virtualRouterIp and :virtual_router_ip' if attributes.key?(:'virtualRouterIp') && attributes.key?(:'virtual_router_ip') self.virtual_router_ip = attributes[:'virtual_router_ip'] if attributes[:'virtual_router_ip'] self.virtual_router_mac = attributes[:'virtualRouterMac'] if attributes[:'virtualRouterMac'] raise 'You cannot provide both :virtualRouterMac and :virtual_router_mac' if attributes.key?(:'virtualRouterMac') && attributes.key?(:'virtual_router_mac') self.virtual_router_mac = attributes[:'virtual_router_mac'] if attributes[:'virtual_router_mac'] end |
Instance Attribute Details
#availability_domain ⇒ String
**[Required]** The subnet's availability domain.
Example: `Uocm:PHX-AD-1`
33 34 35 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 33 def availability_domain @availability_domain end |
#cidr_block ⇒ String
**[Required]** The subnet's CIDR block.
Example: `10.0.1.0/24`
40 41 42 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 40 def cidr_block @cidr_block end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the subnet.
44 45 46 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 44 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
50 51 52 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 50 def @defined_tags end |
#dhcp_options_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the set of DHCP options that the subnet uses.
55 56 57 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 55 def @dhcp_options_id end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
61 62 63 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 61 def display_name @display_name end |
#dns_label ⇒ String
A DNS label for the subnet, used in conjunction with the VNIC's hostname and VCN's DNS label to form a fully qualified domain name (FQDN) for each VNIC within this subnet (for example, `bminstance-1.subnet123.vcn1.oraclevcn.com`). Must be an alphanumeric string that begins with a letter and is unique within the VCN. The value cannot be changed.
The absence of this parameter means the Internet and VCN Resolver will not resolve hostnames of instances in this subnet.
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
Example: `subnet123`
78 79 80 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 78 def dns_label @dns_label end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
84 85 86 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 84 def @freeform_tags end |
#id ⇒ String
**[Required]** The subnet's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
88 89 90 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 88 def id @id end |
#ipv6_cidr_block ⇒ String
For an IPv6-enabled subnet, this is the IPv6 CIDR block for the subnet's private IP address space. The subnet size is always /64. IPv6 addressing is supported for all commercial and government regions. See [IPv6 Addresses](docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
Example: `2001:0db8:0123:1111::/64`
97 98 99 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 97 def ipv6_cidr_block @ipv6_cidr_block end |
#ipv6_public_cidr_block ⇒ String
For an IPv6-enabled subnet, this is the IPv6 CIDR block for the subnet's public IP address space. The subnet size is always /64. The left 48 bits are inherited from the `ipv6PublicCidrBlock` of the Vcn, and the remaining 16 bits are from the subnet's `ipv6CidrBlock`.
Example: `2001:0db8:0123:1111::/64`
107 108 109 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 107 def ipv6_public_cidr_block @ipv6_public_cidr_block end |
#ipv6_virtual_router_ip ⇒ String
For an IPv6-enabled subnet, this is the IPv6 address of the virtual router.
Example: `2001:0db8:0123:1111:89ab:cdef:1234:5678`
114 115 116 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 114 def ipv6_virtual_router_ip @ipv6_virtual_router_ip end |
#lifecycle_state ⇒ String
**[Required]** The subnet's current state.
118 119 120 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 118 def lifecycle_state @lifecycle_state end |
#prohibit_public_ip_on_vnic ⇒ BOOLEAN
Whether VNICs within this subnet can have public IP addresses. Defaults to false, which means VNICs created in this subnet will automatically be assigned public IP addresses unless specified otherwise during instance launch or VNIC creation (with the `assignPublicIp` flag in OCI::VnMonitoring::Models::CreateVnicDetails). If `prohibitPublicIpOnVnic` is set to true, VNICs created in this subnet cannot have public IP addresses (that is, it's a private subnet).
Example: `true`
133 134 135 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 133 def prohibit_public_ip_on_vnic @prohibit_public_ip_on_vnic end |
#route_table_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table that the subnet uses.
137 138 139 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 137 def route_table_id @route_table_id end |
#security_list_ids ⇒ Array<String>
The OCIDs of the security list or lists that the subnet uses. Remember that security lists are associated *with the subnet*, but the rules are applied to the individual VNICs in the subnet.
144 145 146 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 144 def security_list_ids @security_list_ids end |
#subnet_domain_name ⇒ String
The subnet's domain name, which consists of the subnet's DNS label, the VCN's DNS label, and the `oraclevcn.com` domain.
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
Example: `subnet123.vcn1.oraclevcn.com`
155 156 157 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 155 def subnet_domain_name @subnet_domain_name end |
#time_created ⇒ DateTime
The date and time the subnet was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
162 163 164 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 162 def time_created @time_created end |
#vcn_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN the subnet is in.
166 167 168 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 166 def vcn_id @vcn_id end |
#virtual_router_ip ⇒ String
**[Required]** The IP address of the virtual router.
Example: `10.0.14.1`
173 174 175 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 173 def virtual_router_ip @virtual_router_ip end |
#virtual_router_mac ⇒ String
**[Required]** The MAC address of the virtual router.
Example: `00:00:00:00:00:01`
180 181 182 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 180 def virtual_router_mac @virtual_router_mac end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 183 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'cidr_block': :'cidrBlock', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'dhcp_options_id': :'dhcpOptionsId', 'display_name': :'displayName', 'dns_label': :'dnsLabel', 'freeform_tags': :'freeformTags', 'id': :'id', 'ipv6_cidr_block': :'ipv6CidrBlock', 'ipv6_public_cidr_block': :'ipv6PublicCidrBlock', 'ipv6_virtual_router_ip': :'ipv6VirtualRouterIp', 'lifecycle_state': :'lifecycleState', 'prohibit_public_ip_on_vnic': :'prohibitPublicIpOnVnic', 'route_table_id': :'routeTableId', 'security_list_ids': :'securityListIds', 'subnet_domain_name': :'subnetDomainName', 'time_created': :'timeCreated', 'vcn_id': :'vcnId', 'virtual_router_ip': :'virtualRouterIp', 'virtual_router_mac': :'virtualRouterMac' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 212 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'cidr_block': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'dhcp_options_id': :'String', 'display_name': :'String', 'dns_label': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'ipv6_cidr_block': :'String', 'ipv6_public_cidr_block': :'String', 'ipv6_virtual_router_ip': :'String', 'lifecycle_state': :'String', 'prohibit_public_ip_on_vnic': :'BOOLEAN', 'route_table_id': :'String', 'security_list_ids': :'Array<String>', 'subnet_domain_name': :'String', 'time_created': :'DateTime', 'vcn_id': :'String', 'virtual_router_ip': :'String', 'virtual_router_mac': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 416 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && cidr_block == other.cidr_block && compartment_id == other.compartment_id && == other. && == other. && display_name == other.display_name && dns_label == other.dns_label && == other. && id == other.id && ipv6_cidr_block == other.ipv6_cidr_block && ipv6_public_cidr_block == other.ipv6_public_cidr_block && ipv6_virtual_router_ip == other.ipv6_virtual_router_ip && lifecycle_state == other.lifecycle_state && prohibit_public_ip_on_vnic == other.prohibit_public_ip_on_vnic && route_table_id == other.route_table_id && security_list_ids == other.security_list_ids && subnet_domain_name == other.subnet_domain_name && time_created == other.time_created && vcn_id == other.vcn_id && virtual_router_ip == other.virtual_router_ip && virtual_router_mac == other.virtual_router_mac end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 466 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
446 447 448 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 446 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
455 456 457 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 455 def hash [availability_domain, cidr_block, compartment_id, , , display_name, dns_label, , id, ipv6_cidr_block, ipv6_public_cidr_block, ipv6_virtual_router_ip, lifecycle_state, prohibit_public_ip_on_vnic, route_table_id, security_list_ids, subnet_domain_name, time_created, vcn_id, virtual_router_ip, virtual_router_mac].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
499 500 501 502 503 504 505 506 507 508 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 499 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
493 494 495 |
# File 'lib/oci/vn_monitoring/models/subnet.rb', line 493 def to_s to_hash.to_s end |