Class: OCI::VnMonitoring::Models::TopologyRoutesToRelationshipDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb

Overview

Defines route rule details for a `routesTo` relationship.

Constant Summary collapse

ROUTE_TYPE_ENUM =
[
  ROUTE_TYPE_STATIC = 'STATIC'.freeze,
  ROUTE_TYPE_DYNAMIC = 'DYNAMIC'.freeze,
  ROUTE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TopologyRoutesToRelationshipDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :destination_type (String)

    The value to assign to the #destination_type property

  • :destination (String)

    The value to assign to the #destination property

  • :route_table_id (String)

    The value to assign to the #route_table_id property

  • :route_type (String)

    The value to assign to the #route_type property



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 73

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.destination_type = attributes[:'destinationType'] if attributes[:'destinationType']

  raise 'You cannot provide both :destinationType and :destination_type' if attributes.key?(:'destinationType') && attributes.key?(:'destination_type')

  self.destination_type = attributes[:'destination_type'] if attributes[:'destination_type']

  self.destination = attributes[:'destination'] if attributes[:'destination']

  self.route_table_id = attributes[:'routeTableId'] if attributes[:'routeTableId']

  raise 'You cannot provide both :routeTableId and :route_table_id' if attributes.key?(:'routeTableId') && attributes.key?(:'route_table_id')

  self.route_table_id = attributes[:'route_table_id'] if attributes[:'route_table_id']

  self.route_type = attributes[:'routeType'] if attributes[:'routeType']

  raise 'You cannot provide both :routeType and :route_type' if attributes.key?(:'routeType') && attributes.key?(:'route_type')

  self.route_type = attributes[:'route_type'] if attributes[:'route_type']
end

Instance Attribute Details

#destinationString

**[Required]** An IP address range in CIDR notation or the `cidrBlock` value for a Service.

Returns:

  • (String)


28
29
30
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 28

def destination
  @destination
end

#destination_typeString

**[Required]** The destinationType can be set to one of two values:

  • Use `CIDR_BLOCK` if the rule's `destination` is an IP address range in CIDR notation.

  • Use `SERVICE_CIDR_BLOCK` if the rule's `destination` is the `cidrBlock` value for a Service.

Returns:

  • (String)


24
25
26
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 24

def destination_type
  @destination_type
end

#route_table_idString

**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the routing table that contains the route rule.

Returns:

  • (String)


32
33
34
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 32

def route_table_id
  @route_table_id
end

#route_typeString

A route rule can be `STATIC` if manually added to the route table or `DYNAMIC` if imported from another route table.

Returns:

  • (String)


37
38
39
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 37

def route_type
  @route_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 40

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'destination_type': :'destinationType',
    'destination': :'destination',
    'route_table_id': :'routeTableId',
    'route_type': :'routeType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
61
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 52

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'destination_type': :'String',
    'destination': :'String',
    'route_table_id': :'String',
    'route_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



120
121
122
123
124
125
126
127
128
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 120

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    destination_type == other.destination_type &&
    destination == other.destination &&
    route_table_id == other.route_table_id &&
    route_type == other.route_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 153

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


133
134
135
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 133

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



142
143
144
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 142

def hash
  [destination_type, destination, route_table_id, route_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



180
181
182
# File 'lib/oci/vn_monitoring/models/topology_routes_to_relationship_details.rb', line 180

def to_s
  to_hash.to_s
end