Class: OCI::VnMonitoring::Models::TrafficNode
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::TrafficNode
- Defined in:
- lib/oci/vn_monitoring/models/traffic_node.rb
Overview
Defines the configuration of the OCI entity that represents a traffic node in `PathAnalysisResult`.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_VISIBLE = 'VISIBLE'.freeze, TYPE_ACCESS_DENIED = 'ACCESS_DENIED'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #egress_security_action ⇒ OCI::VnMonitoring::Models::SecurityAction
- #egress_traffic ⇒ OCI::VnMonitoring::Models::EgressTrafficSpec
- #ingress_security_action ⇒ OCI::VnMonitoring::Models::SecurityAction
- #next_hop_routing_action ⇒ OCI::VnMonitoring::Models::RoutingAction
-
#type ⇒ String
**[Required]** Type of the `TrafficNode`.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TrafficNode
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TrafficNode
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.egress_traffic = attributes[:'egressTraffic'] if attributes[:'egressTraffic'] raise 'You cannot provide both :egressTraffic and :egress_traffic' if attributes.key?(:'egressTraffic') && attributes.key?(:'egress_traffic') self.egress_traffic = attributes[:'egress_traffic'] if attributes[:'egress_traffic'] self.next_hop_routing_action = attributes[:'nextHopRoutingAction'] if attributes[:'nextHopRoutingAction'] raise 'You cannot provide both :nextHopRoutingAction and :next_hop_routing_action' if attributes.key?(:'nextHopRoutingAction') && attributes.key?(:'next_hop_routing_action') self.next_hop_routing_action = attributes[:'next_hop_routing_action'] if attributes[:'next_hop_routing_action'] self.egress_security_action = attributes[:'egressSecurityAction'] if attributes[:'egressSecurityAction'] raise 'You cannot provide both :egressSecurityAction and :egress_security_action' if attributes.key?(:'egressSecurityAction') && attributes.key?(:'egress_security_action') self.egress_security_action = attributes[:'egress_security_action'] if attributes[:'egress_security_action'] self.ingress_security_action = attributes[:'ingressSecurityAction'] if attributes[:'ingressSecurityAction'] raise 'You cannot provide both :ingressSecurityAction and :ingress_security_action' if attributes.key?(:'ingressSecurityAction') && attributes.key?(:'ingress_security_action') self.ingress_security_action = attributes[:'ingress_security_action'] if attributes[:'ingress_security_action'] end |
Instance Attribute Details
#egress_security_action ⇒ OCI::VnMonitoring::Models::SecurityAction
30 31 32 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 30 def egress_security_action @egress_security_action end |
#egress_traffic ⇒ OCI::VnMonitoring::Models::EgressTrafficSpec
24 25 26 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 24 def egress_traffic @egress_traffic end |
#ingress_security_action ⇒ OCI::VnMonitoring::Models::SecurityAction
33 34 35 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 33 def ingress_security_action @ingress_security_action end |
#next_hop_routing_action ⇒ OCI::VnMonitoring::Models::RoutingAction
27 28 29 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 27 def next_hop_routing_action @next_hop_routing_action end |
#type ⇒ String
**[Required]** Type of the `TrafficNode`.
21 22 23 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 21 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'egress_traffic': :'egressTraffic', 'next_hop_routing_action': :'nextHopRoutingAction', 'egress_security_action': :'egressSecurityAction', 'ingress_security_action': :'ingressSecurityAction' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 66 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::VnMonitoring::Models::VisibleTrafficNode' if type == 'VISIBLE' return 'OCI::VnMonitoring::Models::AccessDeniedTrafficNode' if type == 'ACCESS_DENIED' # TODO: Log a warning when the subtype is not found. 'OCI::VnMonitoring::Models::TrafficNode' end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'egress_traffic': :'OCI::VnMonitoring::Models::EgressTrafficSpec', 'next_hop_routing_action': :'OCI::VnMonitoring::Models::RoutingAction', 'egress_security_action': :'OCI::VnMonitoring::Models::SecurityAction', 'ingress_security_action': :'OCI::VnMonitoring::Models::SecurityAction' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 141 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && egress_traffic == other.egress_traffic && next_hop_routing_action == other.next_hop_routing_action && egress_security_action == other.egress_security_action && ingress_security_action == other.ingress_security_action end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 175 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
155 156 157 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 155 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 164 def hash [type, egress_traffic, next_hop_routing_action, egress_security_action, ingress_security_action].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
202 203 204 |
# File 'lib/oci/vn_monitoring/models/traffic_node.rb', line 202 def to_s to_hash.to_s end |