Class: OCI::VnMonitoring::Models::UpdateDrgAttachmentDetails
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::UpdateDrgAttachmentDetails
- Defined in:
- lib/oci/vn_monitoring/models/update_drg_attachment_details.rb
Overview
UpdateDrgAttachmentDetails model.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#drg_route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table that is assigned to this attachment.
-
#export_drg_route_distribution_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the export route distribution used to specify how routes in the assigned DRG route table are advertised out through the attachment.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #network_details ⇒ OCI::VnMonitoring::Models::DrgAttachmentNetworkUpdateDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDrgAttachmentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDrgAttachmentDetails
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.drg_route_table_id = attributes[:'drgRouteTableId'] if attributes[:'drgRouteTableId'] raise 'You cannot provide both :drgRouteTableId and :drg_route_table_id' if attributes.key?(:'drgRouteTableId') && attributes.key?(:'drg_route_table_id') self.drg_route_table_id = attributes[:'drg_route_table_id'] if attributes[:'drg_route_table_id'] self.network_details = attributes[:'networkDetails'] if attributes[:'networkDetails'] raise 'You cannot provide both :networkDetails and :network_details' if attributes.key?(:'networkDetails') && attributes.key?(:'network_details') self.network_details = attributes[:'network_details'] if attributes[:'network_details'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.export_drg_route_distribution_id = attributes[:'exportDrgRouteDistributionId'] if attributes[:'exportDrgRouteDistributionId'] raise 'You cannot provide both :exportDrgRouteDistributionId and :export_drg_route_distribution_id' if attributes.key?(:'exportDrgRouteDistributionId') && attributes.key?(:'export_drg_route_distribution_id') self.export_drg_route_distribution_id = attributes[:'export_drg_route_distribution_id'] if attributes[:'export_drg_route_distribution_id'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
33 34 35 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 33 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
14 15 16 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 14 def display_name @display_name end |
#drg_route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table that is assigned to this attachment.
The DRG route table manages traffic inside the DRG.
You can't remove a DRG route table from a DRG attachment, but you can reassign which DRG route table it uses.
24 25 26 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 24 def drg_route_table_id @drg_route_table_id end |
#export_drg_route_distribution_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the export route distribution used to specify how routes in the assigned DRG route table are advertised out through the attachment. If this value is null, no routes are advertised through this attachment.
46 47 48 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 46 def export_drg_route_distribution_id @export_drg_route_distribution_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
39 40 41 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 39 def @freeform_tags end |
#network_details ⇒ OCI::VnMonitoring::Models::DrgAttachmentNetworkUpdateDetails
27 28 29 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 27 def network_details @network_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'drg_route_table_id': :'drgRouteTableId', 'network_details': :'networkDetails', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'export_drg_route_distribution_id': :'exportDrgRouteDistributionId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'drg_route_table_id': :'String', 'network_details': :'OCI::VnMonitoring::Models::DrgAttachmentNetworkUpdateDetails', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'export_drg_route_distribution_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 138 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && drg_route_table_id == other.drg_route_table_id && network_details == other.network_details && == other. && == other. && export_drg_route_distribution_id == other.export_drg_route_distribution_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
153 154 155 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 153 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 162 def hash [display_name, drg_route_table_id, network_details, , , export_drg_route_distribution_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
200 201 202 |
# File 'lib/oci/vn_monitoring/models/update_drg_attachment_details.rb', line 200 def to_s to_hash.to_s end |