Class: OCI::VnMonitoring::Models::UpdateDrgRouteTableDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vn_monitoring/models/update_drg_route_table_details.rb

Overview

Details used in a request to update a DRG route table.

You can't assign a table to a virtual circuit or IPSec tunnel attachment if there is a static route rule for an RPC attachment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateDrgRouteTableDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :import_drg_route_distribution_id (String)

    The value to assign to the #import_drg_route_distribution_id property

  • :is_ecmp_enabled (BOOLEAN)

    The value to assign to the #is_ecmp_enabled property



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 80

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.import_drg_route_distribution_id = attributes[:'importDrgRouteDistributionId'] if attributes[:'importDrgRouteDistributionId']

  raise 'You cannot provide both :importDrgRouteDistributionId and :import_drg_route_distribution_id' if attributes.key?(:'importDrgRouteDistributionId') && attributes.key?(:'import_drg_route_distribution_id')

  self.import_drg_route_distribution_id = attributes[:'import_drg_route_distribution_id'] if attributes[:'import_drg_route_distribution_id']

  self.is_ecmp_enabled = attributes[:'isEcmpEnabled'] unless attributes[:'isEcmpEnabled'].nil?

  raise 'You cannot provide both :isEcmpEnabled and :is_ecmp_enabled' if attributes.key?(:'isEcmpEnabled') && attributes.key?(:'is_ecmp_enabled')

  self.is_ecmp_enabled = attributes[:'is_ecmp_enabled'] unless attributes[:'is_ecmp_enabled'].nil?
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


17
18
19
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 17

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


23
24
25
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 23

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


29
30
31
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 29

def freeform_tags
  @freeform_tags
end

#import_drg_route_distribution_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the import route distribution used to specify how incoming route advertisements through referenced attachements are inserted into the DRG route table.

Returns:

  • (String)


35
36
37
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 35

def import_drg_route_distribution_id
  @import_drg_route_distribution_id
end

#is_ecmp_enabledBOOLEAN

If you want traffic to be routed using ECMP across your virtual circuits or IPSec tunnels to your on-prem networks, set this value to true on the route table.

Returns:

  • (BOOLEAN)


41
42
43
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 41

def is_ecmp_enabled
  @is_ecmp_enabled
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 44

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'import_drg_route_distribution_id': :'importDrgRouteDistributionId',
    'is_ecmp_enabled': :'isEcmpEnabled'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 57

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'import_drg_route_distribution_id': :'String',
    'is_ecmp_enabled': :'BOOLEAN'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



124
125
126
127
128
129
130
131
132
133
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 124

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    import_drg_route_distribution_id == other.import_drg_route_distribution_id &&
    is_ecmp_enabled == other.is_ecmp_enabled
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 158

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


138
139
140
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 138

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



147
148
149
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 147

def hash
  [defined_tags, display_name, freeform_tags, import_drg_route_distribution_id, is_ecmp_enabled].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



185
186
187
# File 'lib/oci/vn_monitoring/models/update_drg_route_table_details.rb', line 185

def to_s
  to_hash.to_s
end