Class: OCI::VnMonitoring::Models::UpdateIpv6Details

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vn_monitoring/models/update_ipv6_details.rb

Overview

UpdateIpv6Details model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateIpv6Details

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :display_name (String)

    The value to assign to the #display_name property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :is_internet_access_allowed (BOOLEAN)

    The value to assign to the #is_internet_access_allowed property

  • :vnic_id (String)

    The value to assign to the #vnic_id property



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 83

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.is_internet_access_allowed = attributes[:'isInternetAccessAllowed'] unless attributes[:'isInternetAccessAllowed'].nil?
  self.is_internet_access_allowed = true if is_internet_access_allowed.nil? && !attributes.key?(:'isInternetAccessAllowed') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isInternetAccessAllowed and :is_internet_access_allowed' if attributes.key?(:'isInternetAccessAllowed') && attributes.key?(:'is_internet_access_allowed')

  self.is_internet_access_allowed = attributes[:'is_internet_access_allowed'] unless attributes[:'is_internet_access_allowed'].nil?
  self.is_internet_access_allowed = true if is_internet_access_allowed.nil? && !attributes.key?(:'isInternetAccessAllowed') && !attributes.key?(:'is_internet_access_allowed') # rubocop:disable Style/StringLiterals

  self.vnic_id = attributes[:'vnicId'] if attributes[:'vnicId']

  raise 'You cannot provide both :vnicId and :vnic_id' if attributes.key?(:'vnicId') && attributes.key?(:'vnic_id')

  self.vnic_id = attributes[:'vnic_id'] if attributes[:'vnic_id']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


14
15
16
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 14

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.

Returns:

  • (String)


20
21
22
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 20

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


26
27
28
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 26

def freeform_tags
  @freeform_tags
end

#is_internet_access_allowedBOOLEAN

Whether the IPv6 can be used for internet communication. Allowed by default for an IPv6 in a public subnet. Never allowed for an IPv6 in a private subnet. If the value is `true`, the IPv6 uses its public IP address for internet communication.

If you switch this from `true` to `false`, the `publicIpAddress` attribute for the IPv6 becomes null.

Example: `false`

Returns:

  • (BOOLEAN)


38
39
40
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 38

def is_internet_access_allowed
  @is_internet_access_allowed
end

#vnic_idString

The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VNIC to reassign the IPv6 to. The VNIC must be in the same subnet as the current VNIC.

Returns:

  • (String)


44
45
46
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 44

def vnic_id
  @vnic_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 47

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'is_internet_access_allowed': :'isInternetAccessAllowed',
    'vnic_id': :'vnicId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 60

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'is_internet_access_allowed': :'BOOLEAN',
    'vnic_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 129

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    is_internet_access_allowed == other.is_internet_access_allowed &&
    vnic_id == other.vnic_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 163

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


143
144
145
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 143

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



152
153
154
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 152

def hash
  [defined_tags, display_name, freeform_tags, is_internet_access_allowed, vnic_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



196
197
198
199
200
201
202
203
204
205
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 196

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



190
191
192
# File 'lib/oci/vn_monitoring/models/update_ipv6_details.rb', line 190

def to_s
  to_hash.to_s
end