Class: OCI::VnMonitoring::Models::UpdatePathAnalyzerTestDetails
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::UpdatePathAnalyzerTestDetails
- Defined in:
- lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb
Overview
Details to update a `PathAnalyzerTest` resource.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
- #destination_endpoint ⇒ OCI::VnMonitoring::Models::Endpoint
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#protocol ⇒ Integer
The IP protocol to use in the `PathAnalyzerTest` resource.
- #protocol_parameters ⇒ OCI::VnMonitoring::Models::ProtocolParameters
- #query_options ⇒ OCI::VnMonitoring::Models::QueryOptions
- #source_endpoint ⇒ OCI::VnMonitoring::Models::Endpoint
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdatePathAnalyzerTestDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdatePathAnalyzerTestDetails
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.source_endpoint = attributes[:'sourceEndpoint'] if attributes[:'sourceEndpoint'] raise 'You cannot provide both :sourceEndpoint and :source_endpoint' if attributes.key?(:'sourceEndpoint') && attributes.key?(:'source_endpoint') self.source_endpoint = attributes[:'source_endpoint'] if attributes[:'source_endpoint'] self.destination_endpoint = attributes[:'destinationEndpoint'] if attributes[:'destinationEndpoint'] raise 'You cannot provide both :destinationEndpoint and :destination_endpoint' if attributes.key?(:'destinationEndpoint') && attributes.key?(:'destination_endpoint') self.destination_endpoint = attributes[:'destination_endpoint'] if attributes[:'destination_endpoint'] self.protocol_parameters = attributes[:'protocolParameters'] if attributes[:'protocolParameters'] raise 'You cannot provide both :protocolParameters and :protocol_parameters' if attributes.key?(:'protocolParameters') && attributes.key?(:'protocol_parameters') self.protocol_parameters = attributes[:'protocol_parameters'] if attributes[:'protocol_parameters'] self. = attributes[:'queryOptions'] if attributes[:'queryOptions'] raise 'You cannot provide both :queryOptions and :query_options' if attributes.key?(:'queryOptions') && attributes.key?(:'query_options') self. = attributes[:'query_options'] if attributes[:'query_options'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
42 43 44 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 42 def @defined_tags end |
#destination_endpoint ⇒ OCI::VnMonitoring::Models::Endpoint
24 25 26 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 24 def destination_endpoint @destination_endpoint end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
14 15 16 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 14 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
36 37 38 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 36 def @freeform_tags end |
#protocol ⇒ Integer
The IP protocol to use in the `PathAnalyzerTest` resource.
18 19 20 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 18 def protocol @protocol end |
#protocol_parameters ⇒ OCI::VnMonitoring::Models::ProtocolParameters
27 28 29 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 27 def protocol_parameters @protocol_parameters end |
#query_options ⇒ OCI::VnMonitoring::Models::QueryOptions
30 31 32 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 30 def @query_options end |
#source_endpoint ⇒ OCI::VnMonitoring::Models::Endpoint
21 22 23 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 21 def source_endpoint @source_endpoint end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'protocol': :'protocol', 'source_endpoint': :'sourceEndpoint', 'destination_endpoint': :'destinationEndpoint', 'protocol_parameters': :'protocolParameters', 'query_options': :'queryOptions', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'protocol': :'Integer', 'source_endpoint': :'OCI::VnMonitoring::Models::Endpoint', 'destination_endpoint': :'OCI::VnMonitoring::Models::Endpoint', 'protocol_parameters': :'OCI::VnMonitoring::Models::ProtocolParameters', 'query_options': :'OCI::VnMonitoring::Models::QueryOptions', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 148 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && protocol == other.protocol && source_endpoint == other.source_endpoint && destination_endpoint == other.destination_endpoint && protocol_parameters == other.protocol_parameters && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 174 def hash [display_name, protocol, source_endpoint, destination_endpoint, protocol_parameters, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/vn_monitoring/models/update_path_analyzer_test_details.rb', line 212 def to_s to_hash.to_s end |