Class: OCI::VnMonitoring::Models::UpdatePublicIpDetails
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::UpdatePublicIpDetails
- Defined in:
- lib/oci/vn_monitoring/models/update_public_ip_details.rb
Overview
UpdatePublicIpDetails model.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#private_ip_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private IP to assign the public IP to.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdatePublicIpDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdatePublicIpDetails
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 71 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.private_ip_id = attributes[:'privateIpId'] if attributes[:'privateIpId'] raise 'You cannot provide both :privateIpId and :private_ip_id' if attributes.key?(:'privateIpId') && attributes.key?(:'private_ip_id') self.private_ip_id = attributes[:'private_ip_id'] if attributes[:'private_ip_id'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
14 15 16 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 14 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
20 21 22 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 20 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
26 27 28 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 26 def @freeform_tags end |
#private_ip_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private IP to assign the public IP to.
-
If the public IP is already assigned to a different private IP, it will be unassigned
and then reassigned to the specified private IP.
-
If you set this field to an empty string, the public IP will be unassigned from the
private IP it is currently assigned to.
35 36 37 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 35 def private_ip_id @private_ip_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'private_ip_id': :'privateIpId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'private_ip_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 109 def ==(other) return true if equal?(other) self.class == other.class && == other. && display_name == other.display_name && == other. && private_ip_id == other.private_ip_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 142 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
122 123 124 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 122 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
131 132 133 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 131 def hash [, display_name, , private_ip_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 175 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
169 170 171 |
# File 'lib/oci/vn_monitoring/models/update_public_ip_details.rb', line 169 def to_s to_hash.to_s end |