Class: VnMonitoring::Models::Vcn
- Inherits:
-
Object
- Object
- VnMonitoring::Models::Vcn
- Defined in:
- lib/oci/vn_monitoring/models/vcn.rb
Overview
A virtual cloud network (VCN). For more information, see [Overview of the Networking Service](docs.cloud.oracle.com/iaas/Content/Network/Concepts/overview.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cidr_block ⇒ String
**[Required]** The CIDR block IP address of the VCN.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the VCN.
-
#default_dhcp_options_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN's default set of DHCP options.
-
#default_route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN's default route table.
-
#default_security_list_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN's default security list.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#dns_label ⇒ String
A DNS label for the VCN, used in conjunction with the VNIC's hostname and subnet's DNS label to form a fully qualified domain name (FQDN) for each VNIC within this subnet (for example, `bminstance-1.subnet123.vcn1.oraclevcn.com`).
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The VCN's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
-
#ipv6_cidr_block ⇒ String
For an IPv6-enabled VCN, this is the IPv6 CIDR block for the VCN's private IP address space.
-
#ipv6_public_cidr_block ⇒ String
For an IPv6-enabled VCN, this is the IPv6 CIDR block for the VCN's public IP address space.
-
#lifecycle_state ⇒ String
**[Required]** The VCN's current state.
-
#time_created ⇒ DateTime
The date and time the VCN was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcn_domain_name ⇒ String
The VCN's domain name, which consists of the VCN's DNS label, and the `oraclevcn.com` domain.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Vcn
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Vcn
Initializes the object
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 198 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cidr_block = attributes[:'cidrBlock'] if attributes[:'cidrBlock'] raise 'You cannot provide both :cidrBlock and :cidr_block' if attributes.key?(:'cidrBlock') && attributes.key?(:'cidr_block') self.cidr_block = attributes[:'cidr_block'] if attributes[:'cidr_block'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'defaultDhcpOptionsId'] if attributes[:'defaultDhcpOptionsId'] raise 'You cannot provide both :defaultDhcpOptionsId and :default_dhcp_options_id' if attributes.key?(:'defaultDhcpOptionsId') && attributes.key?(:'default_dhcp_options_id') self. = attributes[:'default_dhcp_options_id'] if attributes[:'default_dhcp_options_id'] self.default_route_table_id = attributes[:'defaultRouteTableId'] if attributes[:'defaultRouteTableId'] raise 'You cannot provide both :defaultRouteTableId and :default_route_table_id' if attributes.key?(:'defaultRouteTableId') && attributes.key?(:'default_route_table_id') self.default_route_table_id = attributes[:'default_route_table_id'] if attributes[:'default_route_table_id'] self.default_security_list_id = attributes[:'defaultSecurityListId'] if attributes[:'defaultSecurityListId'] raise 'You cannot provide both :defaultSecurityListId and :default_security_list_id' if attributes.key?(:'defaultSecurityListId') && attributes.key?(:'default_security_list_id') self.default_security_list_id = attributes[:'default_security_list_id'] if attributes[:'default_security_list_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.dns_label = attributes[:'dnsLabel'] if attributes[:'dnsLabel'] raise 'You cannot provide both :dnsLabel and :dns_label' if attributes.key?(:'dnsLabel') && attributes.key?(:'dns_label') self.dns_label = attributes[:'dns_label'] if attributes[:'dns_label'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.ipv6_cidr_block = attributes[:'ipv6CidrBlock'] if attributes[:'ipv6CidrBlock'] raise 'You cannot provide both :ipv6CidrBlock and :ipv6_cidr_block' if attributes.key?(:'ipv6CidrBlock') && attributes.key?(:'ipv6_cidr_block') self.ipv6_cidr_block = attributes[:'ipv6_cidr_block'] if attributes[:'ipv6_cidr_block'] self.ipv6_public_cidr_block = attributes[:'ipv6PublicCidrBlock'] if attributes[:'ipv6PublicCidrBlock'] raise 'You cannot provide both :ipv6PublicCidrBlock and :ipv6_public_cidr_block' if attributes.key?(:'ipv6PublicCidrBlock') && attributes.key?(:'ipv6_public_cidr_block') self.ipv6_public_cidr_block = attributes[:'ipv6_public_cidr_block'] if attributes[:'ipv6_public_cidr_block'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.vcn_domain_name = attributes[:'vcnDomainName'] if attributes[:'vcnDomainName'] raise 'You cannot provide both :vcnDomainName and :vcn_domain_name' if attributes.key?(:'vcnDomainName') && attributes.key?(:'vcn_domain_name') self.vcn_domain_name = attributes[:'vcn_domain_name'] if attributes[:'vcn_domain_name'] end |
Instance Attribute Details
#cidr_block ⇒ String
**[Required]** The CIDR block IP address of the VCN.
Example: `172.16.0.0/16`
30 31 32 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 30 def cidr_block @cidr_block end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the VCN.
34 35 36 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 34 def compartment_id @compartment_id end |
#default_dhcp_options_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN's default set of DHCP options.
39 40 41 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 39 def @default_dhcp_options_id end |
#default_route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN's default route table.
43 44 45 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 43 def default_route_table_id @default_route_table_id end |
#default_security_list_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the VCN's default security list.
47 48 49 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 47 def default_security_list_id @default_security_list_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
53 54 55 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 53 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
59 60 61 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 59 def display_name @display_name end |
#dns_label ⇒ String
A DNS label for the VCN, used in conjunction with the VNIC's hostname and subnet's DNS label to form a fully qualified domain name (FQDN) for each VNIC within this subnet (for example, `bminstance-1.subnet123.vcn1.oraclevcn.com`). Must be an alphanumeric string that begins with a letter. The value cannot be changed.
The absence of this parameter means the Internet and VCN Resolver will not work for this VCN.
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
Example: `vcn1`
76 77 78 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 76 def dns_label @dns_label end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
82 83 84 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 82 def @freeform_tags end |
#id ⇒ String
**[Required]** The VCN's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
86 87 88 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 86 def id @id end |
#ipv6_cidr_block ⇒ String
For an IPv6-enabled VCN, this is the IPv6 CIDR block for the VCN's private IP address space. The VCN size is always /56. Oracle provides the IPv6 CIDR block to use as the same CIDR for the `ipv6PublicCidrBlock`. When creating a subnet, specify the last 8 bits, 00 to FF. See [IPv6 Addresses](docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm). Example: `2001:0db8:0123::/56`
96 97 98 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 96 def ipv6_cidr_block @ipv6_cidr_block end |
#ipv6_public_cidr_block ⇒ String
For an IPv6-enabled VCN, this is the IPv6 CIDR block for the VCN's public IP address space. The VCN size is always /56. This CIDR is always provided by Oracle. If you don't provide a custom CIDR for the `ipv6CidrBlock` when creating the VCN, Oracle assigns that value and also uses it for `ipv6PublicCidrBlock`. Oracle uses addresses from this block for the `publicIpAddress` attribute of an Ipv6 that has internet access allowed.
Example: `2001:0db8:0123::/48`
107 108 109 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 107 def ipv6_public_cidr_block @ipv6_public_cidr_block end |
#lifecycle_state ⇒ String
**[Required]** The VCN's current state.
111 112 113 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 111 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The date and time the VCN was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
118 119 120 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 118 def time_created @time_created end |
#vcn_domain_name ⇒ String
The VCN's domain name, which consists of the VCN's DNS label, and the `oraclevcn.com` domain.
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
Example: `vcn1.oraclevcn.com`
129 130 131 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 129 def vcn_domain_name @vcn_domain_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 132 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cidr_block': :'cidrBlock', 'compartment_id': :'compartmentId', 'default_dhcp_options_id': :'defaultDhcpOptionsId', 'default_route_table_id': :'defaultRouteTableId', 'default_security_list_id': :'defaultSecurityListId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'dns_label': :'dnsLabel', 'freeform_tags': :'freeformTags', 'id': :'id', 'ipv6_cidr_block': :'ipv6CidrBlock', 'ipv6_public_cidr_block': :'ipv6PublicCidrBlock', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'vcn_domain_name': :'vcnDomainName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 155 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cidr_block': :'String', 'compartment_id': :'String', 'default_dhcp_options_id': :'String', 'default_route_table_id': :'String', 'default_security_list_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'dns_label': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'ipv6_cidr_block': :'String', 'ipv6_public_cidr_block': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'vcn_domain_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 311 def ==(other) return true if equal?(other) self.class == other.class && cidr_block == other.cidr_block && compartment_id == other.compartment_id && == other. && default_route_table_id == other.default_route_table_id && default_security_list_id == other.default_security_list_id && == other. && display_name == other.display_name && dns_label == other.dns_label && == other. && id == other.id && ipv6_cidr_block == other.ipv6_cidr_block && ipv6_public_cidr_block == other.ipv6_public_cidr_block && lifecycle_state == other.lifecycle_state && time_created == other.time_created && vcn_domain_name == other.vcn_domain_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 355 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
335 336 337 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 335 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
344 345 346 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 344 def hash [cidr_block, compartment_id, , default_route_table_id, default_security_list_id, , display_name, dns_label, , id, ipv6_cidr_block, ipv6_public_cidr_block, lifecycle_state, time_created, vcn_domain_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
388 389 390 391 392 393 394 395 396 397 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 388 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
382 383 384 |
# File 'lib/oci/vn_monitoring/models/vcn.rb', line 382 def to_s to_hash.to_s end |