Class: VnMonitoring::Models::Vnic
- Inherits:
-
Object
- Object
- VnMonitoring::Models::Vnic
- Defined in:
- lib/oci/vn_monitoring/models/vnic.rb
Overview
A virtual network interface card. Each VNIC resides in a subnet in a VCN. An instance attaches to a VNIC to obtain a network connection into the VCN through that subnet. Each instance has a *primary VNIC* that is automatically created and attached during launch. You can add *secondary VNICs* to an instance after it's launched. For more information, see [Virtual Network Interface Cards (VNICs)](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVNICs.htm).
Each VNIC has a *primary private IP* that is automatically assigned during launch. You can add *secondary private IPs* to a VNIC after it's created. For more information, see create_private_ip and [IP Addresses](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingIPaddresses.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
**[Required]** The VNIC's availability domain.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the VNIC.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#hostname_label ⇒ String
The hostname for the VNIC's primary private IP.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VNIC.
-
#is_primary ⇒ BOOLEAN
Whether the VNIC is the primary VNIC (the VNIC that is automatically created and attached during instance launch).
-
#lifecycle_state ⇒ String
**[Required]** The current state of the VNIC.
-
#mac_address ⇒ String
The MAC address of the VNIC.
-
#nsg_ids ⇒ Array<String>
A list of the OCIDs of the network security groups that the VNIC belongs to.
-
#private_ip ⇒ String
The private IP address of the primary `privateIp` object on the VNIC.
-
#public_ip ⇒ String
The public IP address of the VNIC, if one is assigned.
-
#skip_source_dest_check ⇒ BOOLEAN
Whether the source/destination check is disabled on the VNIC.
-
#subnet_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet the VNIC is in.
-
#time_created ⇒ DateTime
**[Required]** The date and time the VNIC was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Vnic
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Vnic
Initializes the object
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 213 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel'] raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label') self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label'] self.id = attributes[:'id'] if attributes[:'id'] self.is_primary = attributes[:'isPrimary'] unless attributes[:'isPrimary'].nil? raise 'You cannot provide both :isPrimary and :is_primary' if attributes.key?(:'isPrimary') && attributes.key?(:'is_primary') self.is_primary = attributes[:'is_primary'] unless attributes[:'is_primary'].nil? self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.mac_address = attributes[:'macAddress'] if attributes[:'macAddress'] raise 'You cannot provide both :macAddress and :mac_address' if attributes.key?(:'macAddress') && attributes.key?(:'mac_address') self.mac_address = attributes[:'mac_address'] if attributes[:'mac_address'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.private_ip = attributes[:'privateIp'] if attributes[:'privateIp'] raise 'You cannot provide both :privateIp and :private_ip' if attributes.key?(:'privateIp') && attributes.key?(:'private_ip') self.private_ip = attributes[:'private_ip'] if attributes[:'private_ip'] self.public_ip = attributes[:'publicIp'] if attributes[:'publicIp'] raise 'You cannot provide both :publicIp and :public_ip' if attributes.key?(:'publicIp') && attributes.key?(:'public_ip') self.public_ip = attributes[:'public_ip'] if attributes[:'public_ip'] self.skip_source_dest_check = attributes[:'skipSourceDestCheck'] unless attributes[:'skipSourceDestCheck'].nil? raise 'You cannot provide both :skipSourceDestCheck and :skip_source_dest_check' if attributes.key?(:'skipSourceDestCheck') && attributes.key?(:'skip_source_dest_check') self.skip_source_dest_check = attributes[:'skip_source_dest_check'] unless attributes[:'skip_source_dest_check'].nil? self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#availability_domain ⇒ String
**[Required]** The VNIC's availability domain.
Example: `Uocm:PHX-AD-1`
40 41 42 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 40 def availability_domain @availability_domain end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the VNIC.
44 45 46 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 44 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
50 51 52 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 50 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
56 57 58 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 56 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
62 63 64 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 62 def @freeform_tags end |
#hostname_label ⇒ String
The hostname for the VNIC's primary private IP. Used for DNS. The value is the hostname portion of the primary private IP's fully qualified domain name (FQDN) (for example, `bminstance-1` in FQDN `bminstance-1.subnet123.vcn1.oraclevcn.com`). Must be unique across all VNICs in the subnet and comply with [RFC 952](tools.ietf.org/html/rfc952) and [RFC 1123](tools.ietf.org/html/rfc1123).
For more information, see [DNS in Your Virtual Cloud Network](docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
Example: `bminstance-1`
77 78 79 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 77 def hostname_label @hostname_label end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VNIC.
81 82 83 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 81 def id @id end |
#is_primary ⇒ BOOLEAN
Whether the VNIC is the primary VNIC (the VNIC that is automatically created and attached during instance launch).
87 88 89 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 87 def is_primary @is_primary end |
#lifecycle_state ⇒ String
**[Required]** The current state of the VNIC.
91 92 93 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 91 def lifecycle_state @lifecycle_state end |
#mac_address ⇒ String
The MAC address of the VNIC.
Example: `00:00:00:00:00:01`
98 99 100 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 98 def mac_address @mac_address end |
#nsg_ids ⇒ Array<String>
A list of the OCIDs of the network security groups that the VNIC belongs to.
For more information about NSGs, see OCI::VnMonitoring::Models::NetworkSecurityGroup.
106 107 108 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 106 def nsg_ids @nsg_ids end |
#private_ip ⇒ String
The private IP address of the primary `privateIp` object on the VNIC. The address is within the CIDR of the VNIC's subnet.
Example: `10.0.3.3`
114 115 116 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 114 def private_ip @private_ip end |
#public_ip ⇒ String
The public IP address of the VNIC, if one is assigned.
119 120 121 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 119 def public_ip @public_ip end |
#skip_source_dest_check ⇒ BOOLEAN
Whether the source/destination check is disabled on the VNIC. Defaults to `false`, which means the check is performed. For information about why you would skip the source/destination check, see [Using a Private IP as a Route Target](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm#privateip).
Example: `true`
130 131 132 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 130 def skip_source_dest_check @skip_source_dest_check end |
#subnet_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet the VNIC is in.
134 135 136 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 134 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
**[Required]** The date and time the VNIC was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
141 142 143 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 141 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 144 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'hostname_label': :'hostnameLabel', 'id': :'id', 'is_primary': :'isPrimary', 'lifecycle_state': :'lifecycleState', 'mac_address': :'macAddress', 'nsg_ids': :'nsgIds', 'private_ip': :'privateIp', 'public_ip': :'publicIp', 'skip_source_dest_check': :'skipSourceDestCheck', 'subnet_id': :'subnetId', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 168 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'hostname_label': :'String', 'id': :'String', 'is_primary': :'BOOLEAN', 'lifecycle_state': :'String', 'mac_address': :'String', 'nsg_ids': :'Array<String>', 'private_ip': :'String', 'public_ip': :'String', 'skip_source_dest_check': :'BOOLEAN', 'subnet_id': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 332 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && hostname_label == other.hostname_label && id == other.id && is_primary == other.is_primary && lifecycle_state == other.lifecycle_state && mac_address == other.mac_address && nsg_ids == other.nsg_ids && private_ip == other.private_ip && public_ip == other.public_ip && skip_source_dest_check == other.skip_source_dest_check && subnet_id == other.subnet_id && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 377 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
357 358 359 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 357 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
366 367 368 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 366 def hash [availability_domain, compartment_id, , display_name, , hostname_label, id, is_primary, lifecycle_state, mac_address, nsg_ids, private_ip, public_ip, skip_source_dest_check, subnet_id, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
410 411 412 413 414 415 416 417 418 419 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 410 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
404 405 406 |
# File 'lib/oci/vn_monitoring/models/vnic.rb', line 404 def to_s to_hash.to_s end |