Class: OCI::VulnerabilityScanning::Models::ContainerScanRecipe

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vulnerability_scanning/models/container_scan_recipe.rb

Overview

A container scan recipe (collection of container scanning configuration settings)

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ContainerScanRecipe

Initializes the object

Options Hash (attributes):



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 119

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.scan_settings = attributes[:'scanSettings'] if attributes[:'scanSettings']

  raise 'You cannot provide both :scanSettings and :scan_settings' if attributes.key?(:'scanSettings') && attributes.key?(:'scan_settings')

  self.scan_settings = attributes[:'scan_settings'] if attributes[:'scan_settings']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container scan recipe’s compartment



31
32
33
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 31

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`



59
60
61
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 59

def defined_tags
  @defined_tags
end

#display_nameString

[Required] User friendly name of container scan recipe



27
28
29
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 27

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`



53
54
55
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 53

def freeform_tags
  @freeform_tags
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of container scan recipe. Immutable and generated on creation.



23
24
25
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 23

def id
  @id
end

#lifecycle_stateString

[Required] The current state of the config.



35
36
37
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 35

def lifecycle_state
  @lifecycle_state
end

#scan_settingsOCI::VulnerabilityScanning::Models::ContainerScanSettings

This attribute is required.



47
48
49
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 47

def scan_settings
  @scan_settings
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`



65
66
67
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 65

def system_tags
  @system_tags
end

#time_createdDateTime

[Required] Date and time the recipe was created, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)



39
40
41
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 39

def time_created
  @time_created
end

#time_updatedDateTime

[Required] Date and time the recipe was last updated, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)



43
44
45
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 43

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 68

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'scan_settings': :'scanSettings',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 86

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'scan_settings': :'OCI::VulnerabilityScanning::Models::ContainerScanSettings',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 202

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    scan_settings == other.scan_settings &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


221
222
223
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 221

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



230
231
232
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 230

def hash
  [id, display_name, compartment_id, lifecycle_state, time_created, time_updated, scan_settings, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



268
269
270
# File 'lib/oci/vulnerability_scanning/models/container_scan_recipe.rb', line 268

def to_s
  to_hash.to_s
end