Class: OCI::VulnerabilityScanning::Models::ContainerScanTargetSummary
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::ContainerScanTargetSummary
- Defined in:
- lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb
Overview
Summary of a container scan target (application of a container scan recipe to the registry or list of repos)
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container scan target's compartment.
-
#container_scan_recipe_id ⇒ String
**[Required]** ID of the container scan recipe this target applies.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** User friendly name of container scan target.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of container scan target.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the config.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
- #target_registry ⇒ OCI::VulnerabilityScanning::Models::ContainerScanRegistry
-
#time_created ⇒ DateTime
**[Required]** Date and time the target was created, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
-
#time_updated ⇒ DateTime
**[Required]** Date and time the target was last updated, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContainerScanTargetSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ContainerScanTargetSummary
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 125 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.container_scan_recipe_id = attributes[:'containerScanRecipeId'] if attributes[:'containerScanRecipeId'] raise 'You cannot provide both :containerScanRecipeId and :container_scan_recipe_id' if attributes.key?(:'containerScanRecipeId') && attributes.key?(:'container_scan_recipe_id') self.container_scan_recipe_id = attributes[:'container_scan_recipe_id'] if attributes[:'container_scan_recipe_id'] self.target_registry = attributes[:'targetRegistry'] if attributes[:'targetRegistry'] raise 'You cannot provide both :targetRegistry and :target_registry' if attributes.key?(:'targetRegistry') && attributes.key?(:'target_registry') self.target_registry = attributes[:'target_registry'] if attributes[:'target_registry'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container scan target's compartment
31 32 33 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 31 def compartment_id @compartment_id end |
#container_scan_recipe_id ⇒ String
**[Required]** ID of the container scan recipe this target applies.
35 36 37 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 35 def container_scan_recipe_id @container_scan_recipe_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
62 63 64 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 62 def @defined_tags end |
#display_name ⇒ String
**[Required]** User friendly name of container scan target
27 28 29 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 27 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
56 57 58 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 56 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of container scan target. Immutable and generated on creation.
23 24 25 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 23 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the config.
42 43 44 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 42 def lifecycle_state @lifecycle_state end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
68 69 70 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 68 def @system_tags end |
#target_registry ⇒ OCI::VulnerabilityScanning::Models::ContainerScanRegistry
38 39 40 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 38 def target_registry @target_registry end |
#time_created ⇒ DateTime
**[Required]** Date and time the target was created, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)
46 47 48 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 46 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** Date and time the target was last updated, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)
50 51 52 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 50 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 71 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'container_scan_recipe_id': :'containerScanRecipeId', 'target_registry': :'targetRegistry', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 90 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'container_scan_recipe_id': :'String', 'target_registry': :'OCI::VulnerabilityScanning::Models::ContainerScanRegistry', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 214 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && container_scan_recipe_id == other.container_scan_recipe_id && target_registry == other.target_registry && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 254 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
234 235 236 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 234 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 243 def hash [id, display_name, compartment_id, container_scan_recipe_id, target_registry, lifecycle_state, time_created, time_updated, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
281 282 283 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_target_summary.rb', line 281 def to_s to_hash.to_s end |