Class: OCI::VulnerabilityScanning::Models::CreateContainerScanTargetDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb

Overview

The information for a new container scan target

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateContainerScanTargetDetails

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 85

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.description = attributes[:'description'] if attributes[:'description']

  self.target_registry = attributes[:'targetRegistry'] if attributes[:'targetRegistry']

  raise 'You cannot provide both :targetRegistry and :target_registry' if attributes.key?(:'targetRegistry') && attributes.key?(:'target_registry')

  self.target_registry = attributes[:'target_registry'] if attributes[:'target_registry']

  self.container_scan_recipe_id = attributes[:'containerScanRecipeId'] if attributes[:'containerScanRecipeId']

  raise 'You cannot provide both :containerScanRecipeId and :container_scan_recipe_id' if attributes.key?(:'containerScanRecipeId') && attributes.key?(:'container_scan_recipe_id')

  self.container_scan_recipe_id = attributes[:'container_scan_recipe_id'] if attributes[:'container_scan_recipe_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container scan target’s compartment

Returns:



16
17
18
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 16

def compartment_id
  @compartment_id
end

#container_scan_recipe_idString

[Required] ID of the container scan recipe this target applies.

Returns:



28
29
30
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 28

def container_scan_recipe_id
  @container_scan_recipe_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:



40
41
42
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 40

def defined_tags
  @defined_tags
end

#descriptionString

Target description.

Returns:



20
21
22
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 20

def description
  @description
end

#display_nameString

User friendly name of container scan target. If not present, will be auto-generated.

Returns:



12
13
14
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 12

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:



34
35
36
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 34

def freeform_tags
  @freeform_tags
end

#target_registryOCI::VulnerabilityScanning::Models::CreateContainerScanRegistryDetails

This attribute is required.

Returns:



24
25
26
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 24

def target_registry
  @target_registry
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'description': :'description',
    'target_registry': :'targetRegistry',
    'container_scan_recipe_id': :'containerScanRecipeId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 58

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'compartment_id': :'String',
    'description': :'String',
    'target_registry': :'OCI::VulnerabilityScanning::Models::CreateContainerScanRegistryDetails',
    'container_scan_recipe_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 137

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    description == other.description &&
    target_registry == other.target_registry &&
    container_scan_recipe_id == other.container_scan_recipe_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 173

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



153
154
155
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 153

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



162
163
164
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 162

def hash
  [display_name, compartment_id, description, target_registry, container_scan_recipe_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 206

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



200
201
202
# File 'lib/oci/vulnerability_scanning/models/create_container_scan_target_details.rb', line 200

def to_s
  to_hash.to_s
end