Class: OCI::VulnerabilityScanning::Models::CreateHostScanRecipeDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb

Overview

The information for a new host scan recipe

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateHostScanRecipeDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 91

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.port_settings = attributes[:'portSettings'] if attributes[:'portSettings']

  raise 'You cannot provide both :portSettings and :port_settings' if attributes.key?(:'portSettings') && attributes.key?(:'port_settings')

  self.port_settings = attributes[:'port_settings'] if attributes[:'port_settings']

  self.agent_settings = attributes[:'agentSettings'] if attributes[:'agentSettings']

  raise 'You cannot provide both :agentSettings and :agent_settings' if attributes.key?(:'agentSettings') && attributes.key?(:'agent_settings')

  self.agent_settings = attributes[:'agent_settings'] if attributes[:'agent_settings']

  self.application_settings = attributes[:'applicationSettings'] if attributes[:'applicationSettings']

  raise 'You cannot provide both :applicationSettings and :application_settings' if attributes.key?(:'applicationSettings') && attributes.key?(:'application_settings')

  self.application_settings = attributes[:'application_settings'] if attributes[:'application_settings']

  self.schedule = attributes[:'schedule'] if attributes[:'schedule']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#agent_settingsOCI::VulnerabilityScanning::Models::HostScanAgentSettings

This attribute is required.



24
25
26
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 24

def agent_settings
  @agent_settings
end

#application_settingsOCI::VulnerabilityScanning::Models::ApplicationScanSettings



27
28
29
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 27

def application_settings
  @application_settings
end

#compartment_idString

**[Required]** Compartment ID of the scanning config. If no individual hosts are specified, all hosts in this compartment are scanned

Returns:

  • (String)


16
17
18
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 16

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


43
44
45
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 43

def defined_tags
  @defined_tags
end

#display_nameString

Recipe identifier, which can be renamed. If not present, it will be auto-generated. Avoid entering confidential information.

Returns:

  • (String)


12
13
14
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 12

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


37
38
39
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 37

def freeform_tags
  @freeform_tags
end

#port_settingsOCI::VulnerabilityScanning::Models::HostScanPortSettings

This attribute is required.



20
21
22
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 20

def port_settings
  @port_settings
end

#scheduleOCI::VulnerabilityScanning::Models::Schedule

This attribute is required.

Returns:

  • (OCI::VulnerabilityScanning::Models::Schedule)


31
32
33
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 31

def schedule
  @schedule
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 46

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'port_settings': :'portSettings',
    'agent_settings': :'agentSettings',
    'application_settings': :'applicationSettings',
    'schedule': :'schedule',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 62

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'compartment_id': :'String',
    'port_settings': :'OCI::VulnerabilityScanning::Models::HostScanPortSettings',
    'agent_settings': :'OCI::VulnerabilityScanning::Models::HostScanAgentSettings',
    'application_settings': :'OCI::VulnerabilityScanning::Models::ApplicationScanSettings',
    'schedule': :'OCI::VulnerabilityScanning::Models::Schedule',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 149

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    port_settings == other.port_settings &&
    agent_settings == other.agent_settings &&
    application_settings == other.application_settings &&
    schedule == other.schedule &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 186

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 166

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



175
176
177
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 175

def hash
  [display_name, compartment_id, port_settings, agent_settings, application_settings, schedule, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



213
214
215
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_recipe_details.rb', line 213

def to_s
  to_hash.to_s
end