Class: OCI::VulnerabilityScanning::Models::CreateHostScanTargetDetails
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::CreateHostScanTargetDetails
- Defined in:
- lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb
Overview
The information for a new host scan target
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment ID of the object (this).
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Target description.
-
#display_name ⇒ String
Target identifier, which can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#host_scan_recipe_id ⇒ String
[Required] ID of the host scan recipe this target applies.
-
#instance_ids ⇒ Array<String>
List of compute instance IDs to target (optional).
-
#target_compartment_id ⇒ String
[Required] Compartment ID to target.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateHostScanTargetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateHostScanTargetDetails
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.target_compartment_id = attributes[:'targetCompartmentId'] if attributes[:'targetCompartmentId'] raise 'You cannot provide both :targetCompartmentId and :target_compartment_id' if attributes.key?(:'targetCompartmentId') && attributes.key?(:'target_compartment_id') self.target_compartment_id = attributes[:'target_compartment_id'] if attributes[:'target_compartment_id'] self.instance_ids = attributes[:'instanceIds'] if attributes[:'instanceIds'] raise 'You cannot provide both :instanceIds and :instance_ids' if attributes.key?(:'instanceIds') && attributes.key?(:'instance_ids') self.instance_ids = attributes[:'instance_ids'] if attributes[:'instance_ids'] self.host_scan_recipe_id = attributes[:'hostScanRecipeId'] if attributes[:'hostScanRecipeId'] raise 'You cannot provide both :hostScanRecipeId and :host_scan_recipe_id' if attributes.key?(:'hostScanRecipeId') && attributes.key?(:'host_scan_recipe_id') self.host_scan_recipe_id = attributes[:'host_scan_recipe_id'] if attributes[:'host_scan_recipe_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment ID of the object (this).
16 17 18 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 16 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
44 45 46 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 44 def end |
#description ⇒ String
Target description.
20 21 22 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 20 def description @description end |
#display_name ⇒ String
Target identifier, which can be renamed. If not present, it will be auto-generated. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
38 39 40 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 38 def end |
#host_scan_recipe_id ⇒ String
[Required] ID of the host scan recipe this target applies.
32 33 34 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 32 def host_scan_recipe_id @host_scan_recipe_id end |
#instance_ids ⇒ Array<String>
List of compute instance IDs to target (optional). If empty, targets the entire targetCompartmentId.
28 29 30 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 28 def instance_ids @instance_ids end |
#target_compartment_id ⇒ String
[Required] Compartment ID to target. If a list of hosts is provided, all hosts must be in this compartment.
24 25 26 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 24 def target_compartment_id @target_compartment_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'description': :'description', 'target_compartment_id': :'targetCompartmentId', 'instance_ids': :'instanceIds', 'host_scan_recipe_id': :'hostScanRecipeId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'description': :'String', 'target_compartment_id': :'String', 'instance_ids': :'Array<String>', 'host_scan_recipe_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 150 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && description == other.description && target_compartment_id == other.target_compartment_id && instance_ids == other.instance_ids && host_scan_recipe_id == other.host_scan_recipe_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 187 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
167 168 169 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 167 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 176 def hash [display_name, compartment_id, description, target_compartment_id, instance_ids, host_scan_recipe_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
214 215 216 |
# File 'lib/oci/vulnerability_scanning/models/create_host_scan_target_details.rb', line 214 def to_s to_hash.to_s end |