Class: OCI::VulnerabilityScanning::Models::HostAgentScanResult

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb

Overview

A scan result for a host agent scan

Constant Summary collapse

HIGHEST_PROBLEM_SEVERITY_ENUM =
[
  HIGHEST_PROBLEM_SEVERITY_NONE = 'NONE'.freeze,
  HIGHEST_PROBLEM_SEVERITY_LOW = 'LOW'.freeze,
  HIGHEST_PROBLEM_SEVERITY_MEDIUM = 'MEDIUM'.freeze,
  HIGHEST_PROBLEM_SEVERITY_HIGH = 'HIGH'.freeze,
  HIGHEST_PROBLEM_SEVERITY_CRITICAL = 'CRITICAL'.freeze,
  HIGHEST_PROBLEM_SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HostAgentScanResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 136

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.instance_id = attributes[:'instanceId'] if attributes[:'instanceId']

  raise 'You cannot provide both :instanceId and :instance_id' if attributes.key?(:'instanceId') && attributes.key?(:'instance_id')

  self.instance_id = attributes[:'instance_id'] if attributes[:'instance_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.highest_problem_severity = attributes[:'highestProblemSeverity'] if attributes[:'highestProblemSeverity']

  raise 'You cannot provide both :highestProblemSeverity and :highest_problem_severity' if attributes.key?(:'highestProblemSeverity') && attributes.key?(:'highest_problem_severity')

  self.highest_problem_severity = attributes[:'highest_problem_severity'] if attributes[:'highest_problem_severity']

  self.operating_system = attributes[:'operatingSystem'] if attributes[:'operatingSystem']

  raise 'You cannot provide both :operatingSystem and :operating_system' if attributes.key?(:'operatingSystem') && attributes.key?(:'operating_system')

  self.operating_system = attributes[:'operating_system'] if attributes[:'operating_system']

  self.kernel_version = attributes[:'kernelVersion'] if attributes[:'kernelVersion']

  raise 'You cannot provide both :kernelVersion and :kernel_version' if attributes.key?(:'kernelVersion') && attributes.key?(:'kernel_version')

  self.kernel_version = attributes[:'kernel_version'] if attributes[:'kernel_version']

  self.problem_count = attributes[:'problemCount'] if attributes[:'problemCount']

  raise 'You cannot provide both :problemCount and :problem_count' if attributes.key?(:'problemCount') && attributes.key?(:'problem_count')

  self.problem_count = attributes[:'problem_count'] if attributes[:'problem_count']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']

  self.problems = attributes[:'problems'] if attributes[:'problems']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']
end

Instance Attribute Details

#compartment_idString

**[Required]** Compartment ID of the resource. This is set to the same as the compartment ID of the scan target

Returns:

  • (String)


44
45
46
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 44

def compartment_id
  @compartment_id
end

#display_nameString

Name of the resource

Returns:

  • (String)


36
37
38
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 36

def display_name
  @display_name
end

#highest_problem_severityString

**[Required]** Highest problem severity in this report

Returns:

  • (String)


48
49
50
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 48

def highest_problem_severity
  @highest_problem_severity
end

#idString

**[Required]** Unique identifier of the scan

Returns:

  • (String)


32
33
34
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 32

def id
  @id
end

#instance_idString

**[Required]** Instance ID of the Compute Instance scanned

Returns:

  • (String)


40
41
42
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 40

def instance_id
  @instance_id
end

#kernel_versionString

Kernel version of the operating system

Returns:

  • (String)


56
57
58
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 56

def kernel_version
  @kernel_version
end

#lifecycle_stateString

The current state of the result.

Returns:

  • (String)


76
77
78
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 76

def lifecycle_state
  @lifecycle_state
end

#operating_systemString

**[Required]** Operating system of the host

Returns:

  • (String)


52
53
54
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 52

def operating_system
  @operating_system
end

#problem_countInteger

Total number of problems found in this scan

Returns:

  • (Integer)


60
61
62
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 60

def problem_count
  @problem_count
end

#problemsArray<OCI::VulnerabilityScanning::Models::HostAgentScanResultProblem>

**[Required]** List of problems found in this scan



72
73
74
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 72

def problems
  @problems
end

#time_finishedDateTime

**[Required]** Date and time the scan was completed, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)

Returns:

  • (DateTime)


68
69
70
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 68

def time_finished
  @time_finished
end

#time_startedDateTime

**[Required]** Date and time the scan was started, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)

Returns:

  • (DateTime)


64
65
66
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 64

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 79

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'instance_id': :'instanceId',
    'compartment_id': :'compartmentId',
    'highest_problem_severity': :'highestProblemSeverity',
    'operating_system': :'operatingSystem',
    'kernel_version': :'kernelVersion',
    'problem_count': :'problemCount',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished',
    'problems': :'problems',
    'lifecycle_state': :'lifecycleState'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 99

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'instance_id': :'String',
    'compartment_id': :'String',
    'highest_problem_severity': :'String',
    'operating_system': :'String',
    'kernel_version': :'String',
    'problem_count': :'Integer',
    'time_started': :'DateTime',
    'time_finished': :'DateTime',
    'problems': :'Array<OCI::VulnerabilityScanning::Models::HostAgentScanResultProblem>',
    'lifecycle_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 240

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    instance_id == other.instance_id &&
    compartment_id == other.compartment_id &&
    highest_problem_severity == other.highest_problem_severity &&
    operating_system == other.operating_system &&
    kernel_version == other.kernel_version &&
    problem_count == other.problem_count &&
    time_started == other.time_started &&
    time_finished == other.time_finished &&
    problems == other.problems &&
    lifecycle_state == other.lifecycle_state
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 281

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 261

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



270
271
272
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 270

def hash
  [id, display_name, instance_id, compartment_id, highest_problem_severity, operating_system, kernel_version, problem_count, time_started, time_finished, problems, lifecycle_state].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
317
318
319
320
321
322
323
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 314

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



308
309
310
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result.rb', line 308

def to_s
  to_hash.to_s
end