Class: OCI::VulnerabilityScanning::Models::HostAgentScanResultProblem
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::HostAgentScanResultProblem
- Defined in:
- lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb
Overview
A problem found in a host agent scan
Constant Summary collapse
- SEVERITY_ENUM =
[ SEVERITY_NONE = 'NONE'.freeze, SEVERITY_LOW = 'LOW'.freeze, SEVERITY_MEDIUM = 'MEDIUM'.freeze, SEVERITY_HIGH = 'HIGH'.freeze, SEVERITY_CRITICAL = 'CRITICAL'.freeze, SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATE_ENUM =
[ STATE_OPEN = 'OPEN'.freeze, STATE_FIXED = 'FIXED'.freeze, STATE_NOT_APPLICABLE = 'NOT_APPLICABLE'.freeze, STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cve_reference ⇒ String
Reference to problem MITRE CVE ID.
-
#description ⇒ String
Problem description.
-
#issue_id ⇒ Integer
Reference to problem issue ID.
-
#name ⇒ String
**[Required]** Name of the problem.
-
#severity ⇒ String
**[Required]** Problem severity.
-
#state ⇒ String
State of the vulnerability.
-
#time_first_detected ⇒ DateTime
Date of scan result that first reported the vulnerability.
-
#time_last_detected ⇒ DateTime
Date of scan result that most recently reported the vulnerability.
-
#vulnerable_packages ⇒ Array<OCI::VulnerabilityScanning::Models::Package>
Packages in which the problem is detected.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostAgentScanResultProblem
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HostAgentScanResultProblem
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 112 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.severity = attributes[:'severity'] if attributes[:'severity'] self.state = attributes[:'state'] if attributes[:'state'] self.cve_reference = attributes[:'cveReference'] if attributes[:'cveReference'] raise 'You cannot provide both :cveReference and :cve_reference' if attributes.key?(:'cveReference') && attributes.key?(:'cve_reference') self.cve_reference = attributes[:'cve_reference'] if attributes[:'cve_reference'] self.issue_id = attributes[:'issueId'] if attributes[:'issueId'] raise 'You cannot provide both :issueId and :issue_id' if attributes.key?(:'issueId') && attributes.key?(:'issue_id') self.issue_id = attributes[:'issue_id'] if attributes[:'issue_id'] self.time_first_detected = attributes[:'timeFirstDetected'] if attributes[:'timeFirstDetected'] raise 'You cannot provide both :timeFirstDetected and :time_first_detected' if attributes.key?(:'timeFirstDetected') && attributes.key?(:'time_first_detected') self.time_first_detected = attributes[:'time_first_detected'] if attributes[:'time_first_detected'] self.time_last_detected = attributes[:'timeLastDetected'] if attributes[:'timeLastDetected'] raise 'You cannot provide both :timeLastDetected and :time_last_detected' if attributes.key?(:'timeLastDetected') && attributes.key?(:'time_last_detected') self.time_last_detected = attributes[:'time_last_detected'] if attributes[:'time_last_detected'] self.vulnerable_packages = attributes[:'vulnerablePackages'] if attributes[:'vulnerablePackages'] raise 'You cannot provide both :vulnerablePackages and :vulnerable_packages' if attributes.key?(:'vulnerablePackages') && attributes.key?(:'vulnerable_packages') self.vulnerable_packages = attributes[:'vulnerable_packages'] if attributes[:'vulnerable_packages'] end |
Instance Attribute Details
#cve_reference ⇒ String
Reference to problem MITRE CVE ID
45 46 47 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 45 def cve_reference @cve_reference end |
#description ⇒ String
Problem description
33 34 35 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 33 def description @description end |
#issue_id ⇒ Integer
Reference to problem issue ID
49 50 51 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 49 def issue_id @issue_id end |
#name ⇒ String
**[Required]** Name of the problem
29 30 31 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 29 def name @name end |
#severity ⇒ String
**[Required]** Problem severity
37 38 39 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 37 def severity @severity end |
#state ⇒ String
State of the vulnerability
41 42 43 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 41 def state @state end |
#time_first_detected ⇒ DateTime
Date of scan result that first reported the vulnerability
53 54 55 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 53 def time_first_detected @time_first_detected end |
#time_last_detected ⇒ DateTime
Date of scan result that most recently reported the vulnerability
57 58 59 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 57 def time_last_detected @time_last_detected end |
#vulnerable_packages ⇒ Array<OCI::VulnerabilityScanning::Models::Package>
Packages in which the problem is detected
61 62 63 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 61 def vulnerable_packages @vulnerable_packages end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 64 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'severity': :'severity', 'state': :'state', 'cve_reference': :'cveReference', 'issue_id': :'issueId', 'time_first_detected': :'timeFirstDetected', 'time_last_detected': :'timeLastDetected', 'vulnerable_packages': :'vulnerablePackages' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'severity': :'String', 'state': :'String', 'cve_reference': :'String', 'issue_id': :'Integer', 'time_first_detected': :'DateTime', 'time_last_detected': :'DateTime', 'vulnerable_packages': :'Array<OCI::VulnerabilityScanning::Models::Package>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 190 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && severity == other.severity && state == other.state && cve_reference == other.cve_reference && issue_id == other.issue_id && time_first_detected == other.time_first_detected && time_last_detected == other.time_last_detected && vulnerable_packages == other.vulnerable_packages end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 228 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
208 209 210 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 208 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 217 def hash [name, description, severity, state, cve_reference, issue_id, time_first_detected, time_last_detected, vulnerable_packages].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 270 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
255 256 257 |
# File 'lib/oci/vulnerability_scanning/models/host_agent_scan_result_problem.rb', line 255 def to_s to_hash.to_s end |