Class: OCI::VulnerabilityScanning::Models::HostCisBenchmarkScanResult
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::HostCisBenchmarkScanResult
- Defined in:
- lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb
Overview
A scan result of all CIS (Center for Internet Security) benchmark execution for this host
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cis_benchmark_scan_issues_count ⇒ Integer
[Required] Total number of CIS (Center for Internet Security) benchmark issues found in this scan.
-
#cis_benchmark_scan_result_scores ⇒ Array<OCI::VulnerabilityScanning::Models::HostCisBenchmarkScanResultScore>
[Required] A single CIS (Center for Internet Security) benchmark scan executed on a host.
-
#compartment_id ⇒ String
[Required] Compartment ID of the resource.
-
#display_name ⇒ String
Name of the result.
-
#id ⇒ String
[Required] Unique identifier of the scan.
-
#instance_id ⇒ String
[Required] Instance ID of the Compute Instance scanned.
-
#lifecycle_state ⇒ String
The current state of the result.
-
#time_finished ⇒ DateTime
[Required] Date and time the scan was completed, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
-
#time_started ⇒ DateTime
[Required] Date and time the scan was started, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostCisBenchmarkScanResult
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HostCisBenchmarkScanResult
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 106 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.instance_id = attributes[:'instanceId'] if attributes[:'instanceId'] raise 'You cannot provide both :instanceId and :instance_id' if attributes.key?(:'instanceId') && attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] if attributes[:'instance_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] self.cis_benchmark_scan_issues_count = attributes[:'cisBenchmarkScanIssuesCount'] if attributes[:'cisBenchmarkScanIssuesCount'] raise 'You cannot provide both :cisBenchmarkScanIssuesCount and :cis_benchmark_scan_issues_count' if attributes.key?(:'cisBenchmarkScanIssuesCount') && attributes.key?(:'cis_benchmark_scan_issues_count') self.cis_benchmark_scan_issues_count = attributes[:'cis_benchmark_scan_issues_count'] if attributes[:'cis_benchmark_scan_issues_count'] self.cis_benchmark_scan_result_scores = attributes[:'cisBenchmarkScanResultScores'] if attributes[:'cisBenchmarkScanResultScores'] raise 'You cannot provide both :cisBenchmarkScanResultScores and :cis_benchmark_scan_result_scores' if attributes.key?(:'cisBenchmarkScanResultScores') && attributes.key?(:'cis_benchmark_scan_result_scores') self.cis_benchmark_scan_result_scores = attributes[:'cis_benchmark_scan_result_scores'] if attributes[:'cis_benchmark_scan_result_scores'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#cis_benchmark_scan_issues_count ⇒ Integer
[Required] Total number of CIS (Center for Internet Security) benchmark issues found in this scan
47 48 49 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 47 def cis_benchmark_scan_issues_count @cis_benchmark_scan_issues_count end |
#cis_benchmark_scan_result_scores ⇒ Array<OCI::VulnerabilityScanning::Models::HostCisBenchmarkScanResultScore>
[Required] A single CIS (Center for Internet Security) benchmark scan executed on a host.
51 52 53 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 51 def cis_benchmark_scan_result_scores @cis_benchmark_scan_result_scores end |
#compartment_id ⇒ String
[Required] Compartment ID of the resource. This is set to the same as the compartment ID of the scan target
35 36 37 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 35 def compartment_id @compartment_id end |
#display_name ⇒ String
Name of the result
27 28 29 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 27 def display_name @display_name end |
#id ⇒ String
[Required] Unique identifier of the scan
23 24 25 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 23 def id @id end |
#instance_id ⇒ String
[Required] Instance ID of the Compute Instance scanned
31 32 33 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 31 def instance_id @instance_id end |
#lifecycle_state ⇒ String
The current state of the result.
55 56 57 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 55 def lifecycle_state @lifecycle_state end |
#time_finished ⇒ DateTime
[Required] Date and time the scan was completed, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)
43 44 45 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 43 def time_finished @time_finished end |
#time_started ⇒ DateTime
[Required] Date and time the scan was started, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)
39 40 41 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 39 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'instance_id': :'instanceId', 'compartment_id': :'compartmentId', 'time_started': :'timeStarted', 'time_finished': :'timeFinished', 'cis_benchmark_scan_issues_count': :'cisBenchmarkScanIssuesCount', 'cis_benchmark_scan_result_scores': :'cisBenchmarkScanResultScores', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'instance_id': :'String', 'compartment_id': :'String', 'time_started': :'DateTime', 'time_finished': :'DateTime', 'cis_benchmark_scan_issues_count': :'Integer', 'cis_benchmark_scan_result_scores': :'Array<OCI::VulnerabilityScanning::Models::HostCisBenchmarkScanResultScore>', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 183 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && instance_id == other.instance_id && compartment_id == other.compartment_id && time_started == other.time_started && time_finished == other.time_finished && cis_benchmark_scan_issues_count == other.cis_benchmark_scan_issues_count && cis_benchmark_scan_result_scores == other.cis_benchmark_scan_result_scores && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 221 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
201 202 203 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 201 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
210 211 212 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 210 def hash [id, display_name, instance_id, compartment_id, time_started, time_finished, cis_benchmark_scan_issues_count, cis_benchmark_scan_result_scores, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 254 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
248 249 250 |
# File 'lib/oci/vulnerability_scanning/models/host_cis_benchmark_scan_result.rb', line 248 def to_s to_hash.to_s end |