Class: OCI::VulnerabilityScanning::Models::HostPortScanResult

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vulnerability_scanning/models/host_port_scan_result.rb

Overview

A scan result for a host port scan

Constant Summary collapse

HIGHEST_PROBLEM_SEVERITY_ENUM =
[
  HIGHEST_PROBLEM_SEVERITY_NONE = 'NONE'.freeze,
  HIGHEST_PROBLEM_SEVERITY_LOW = 'LOW'.freeze,
  HIGHEST_PROBLEM_SEVERITY_MEDIUM = 'MEDIUM'.freeze,
  HIGHEST_PROBLEM_SEVERITY_HIGH = 'HIGH'.freeze,
  HIGHEST_PROBLEM_SEVERITY_CRITICAL = 'CRITICAL'.freeze,
  HIGHEST_PROBLEM_SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HostPortScanResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 122

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.instance_id = attributes[:'instanceId'] if attributes[:'instanceId']

  raise 'You cannot provide both :instanceId and :instance_id' if attributes.key?(:'instanceId') && attributes.key?(:'instance_id')

  self.instance_id = attributes[:'instance_id'] if attributes[:'instance_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.highest_problem_severity = attributes[:'highestProblemSeverity'] if attributes[:'highestProblemSeverity']

  raise 'You cannot provide both :highestProblemSeverity and :highest_problem_severity' if attributes.key?(:'highestProblemSeverity') && attributes.key?(:'highest_problem_severity')

  self.highest_problem_severity = attributes[:'highest_problem_severity'] if attributes[:'highest_problem_severity']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']

  self.open_port_count = attributes[:'openPortCount'] if attributes[:'openPortCount']

  raise 'You cannot provide both :openPortCount and :open_port_count' if attributes.key?(:'openPortCount') && attributes.key?(:'open_port_count')

  self.open_port_count = attributes[:'open_port_count'] if attributes[:'open_port_count']

  self.open_ports = attributes[:'openPorts'] if attributes[:'openPorts']

  raise 'You cannot provide both :openPorts and :open_ports' if attributes.key?(:'openPorts') && attributes.key?(:'open_ports')

  self.open_ports = attributes[:'open_ports'] if attributes[:'open_ports']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']
end

Instance Attribute Details

#compartment_idString

[Required] Compartment ID of the resource. This is set to the same as the compartment ID of the scan target

Returns:

  • (String)


44
45
46
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 44

def compartment_id
  @compartment_id
end

#display_nameString

Name of the resource

Returns:

  • (String)


36
37
38
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 36

def display_name
  @display_name
end

#highest_problem_severityString

[Required] Highest problem severity in this report

Returns:

  • (String)


48
49
50
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 48

def highest_problem_severity
  @highest_problem_severity
end

#idString

[Required] Unique identifier of the scan

Returns:

  • (String)


32
33
34
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 32

def id
  @id
end

#instance_idString

[Required] Instance ID of the Compute Instance scanned

Returns:

  • (String)


40
41
42
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 40

def instance_id
  @instance_id
end

#lifecycle_stateString

The current state of the result.

Returns:

  • (String)


68
69
70
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 68

def lifecycle_state
  @lifecycle_state
end

#open_port_countInteger

Total number of open ports across all attached VNICs found in this scan

Returns:

  • (Integer)


60
61
62
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 60

def open_port_count
  @open_port_count
end

#open_portsArray<OCI::VulnerabilityScanning::Models::HostPortScanResultOpenPort>

[Required] List of open ports (including interface) found in this scan



64
65
66
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 64

def open_ports
  @open_ports
end

#time_finishedDateTime

[Required] Date and time the scan was completed, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)

Returns:

  • (DateTime)


56
57
58
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 56

def time_finished
  @time_finished
end

#time_startedDateTime

[Required] Date and time the scan was started, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)

Returns:

  • (DateTime)


52
53
54
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 52

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 71

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'instance_id': :'instanceId',
    'compartment_id': :'compartmentId',
    'highest_problem_severity': :'highestProblemSeverity',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished',
    'open_port_count': :'openPortCount',
    'open_ports': :'openPorts',
    'lifecycle_state': :'lifecycleState'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 89

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'instance_id': :'String',
    'compartment_id': :'String',
    'highest_problem_severity': :'String',
    'time_started': :'DateTime',
    'time_finished': :'DateTime',
    'open_port_count': :'Integer',
    'open_ports': :'Array<OCI::VulnerabilityScanning::Models::HostPortScanResultOpenPort>',
    'lifecycle_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 218

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    instance_id == other.instance_id &&
    compartment_id == other.compartment_id &&
    highest_problem_severity == other.highest_problem_severity &&
    time_started == other.time_started &&
    time_finished == other.time_finished &&
    open_port_count == other.open_port_count &&
    open_ports == other.open_ports &&
    lifecycle_state == other.lifecycle_state
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 257

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


237
238
239
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 237

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



246
247
248
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 246

def hash
  [id, display_name, instance_id, compartment_id, highest_problem_severity, time_started, time_finished, open_port_count, open_ports, lifecycle_state].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



290
291
292
293
294
295
296
297
298
299
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 290

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



284
285
286
# File 'lib/oci/vulnerability_scanning/models/host_port_scan_result.rb', line 284

def to_s
  to_hash.to_s
end