Class: OCI::VulnerabilityScanning::Models::HostScanAgentConfiguration
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::HostScanAgentConfiguration
- Defined in:
- lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb
Overview
Agent configuration for host scan agent settings. This model is polymorphic, presenting different configuration options based on selected agent vendor. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- VENDOR_ENUM =
[ VENDOR_OCI = 'OCI'.freeze, VENDOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#vendor ⇒ String
[Required] Vendor to use for the host scan agent.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostScanAgentConfiguration
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HostScanAgentConfiguration
Initializes the object
61 62 63 64 65 66 67 68 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 61 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.vendor = attributes[:'vendor'] if attributes[:'vendor'] end |
Instance Attribute Details
#vendor ⇒ String
[Required] Vendor to use for the host scan agent.
19 20 21 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 19 def vendor @vendor end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 27 28 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 22 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'vendor': :'vendor' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
44 45 46 47 48 49 50 51 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 44 def self.get_subtype(object_hash) type = object_hash[:'vendor'] # rubocop:disable Style/SymbolLiteral return 'OCI::VulnerabilityScanning::Models::HostScanAgentConfigurationOCI' if type == 'OCI' # TODO: Log a warning when the subtype is not found. 'OCI::VulnerabilityScanning::Models::HostScanAgentConfiguration' end |
.swagger_types ⇒ Object
Attribute type mapping.
31 32 33 34 35 36 37 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 31 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'vendor': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && vendor == other.vendor end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 120 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
100 101 102 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 100 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
109 110 111 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 109 def hash [vendor].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 153 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
147 148 149 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_agent_configuration.rb', line 147 def to_s to_hash.to_s end |