Class: OCI::VulnerabilityScanning::Models::HostScanRecipe
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::HostScanRecipe
- Defined in:
- lib/oci/vulnerability_scanning/models/host_scan_recipe.rb
Overview
A host scan recipe (collection of host scanning configuration settings)
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#agent_settings ⇒ OCI::VulnerabilityScanning::Models::HostScanAgentSettings
This attribute is required.
-
#compartment_id ⇒ String
[Required] Compartment ID of the scan recipe.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] Recipe identifier, which can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier of the config that is immutable on creation.
-
#lifecycle_state ⇒ String
[Required] The current state of the config.
-
#port_settings ⇒ OCI::VulnerabilityScanning::Models::HostScanPortSettings
This attribute is required.
-
#schedule ⇒ OCI::VulnerabilityScanning::Models::Schedule
This attribute is required.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
[Required] Date and time the recipe was created, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
-
#time_updated ⇒ DateTime
[Required] Date and time the recipe was last updated, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostScanRecipe
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HostScanRecipe
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 133 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.port_settings = attributes[:'portSettings'] if attributes[:'portSettings'] raise 'You cannot provide both :portSettings and :port_settings' if attributes.key?(:'portSettings') && attributes.key?(:'port_settings') self.port_settings = attributes[:'port_settings'] if attributes[:'port_settings'] self.agent_settings = attributes[:'agentSettings'] if attributes[:'agentSettings'] raise 'You cannot provide both :agentSettings and :agent_settings' if attributes.key?(:'agentSettings') && attributes.key?(:'agent_settings') self.agent_settings = attributes[:'agent_settings'] if attributes[:'agent_settings'] self.schedule = attributes[:'schedule'] if attributes[:'schedule'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#agent_settings ⇒ OCI::VulnerabilityScanning::Models::HostScanAgentSettings
This attribute is required.
51 52 53 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 51 def agent_settings @agent_settings end |
#compartment_id ⇒ String
[Required] Compartment ID of the scan recipe
31 32 33 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 31 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
67 68 69 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 67 def end |
#display_name ⇒ String
[Required] Recipe identifier, which can be renamed
27 28 29 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 27 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
61 62 63 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 61 def end |
#id ⇒ String
[Required] Unique identifier of the config that is immutable on creation
23 24 25 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 23 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of the config.
35 36 37 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 35 def lifecycle_state @lifecycle_state end |
#port_settings ⇒ OCI::VulnerabilityScanning::Models::HostScanPortSettings
This attribute is required.
47 48 49 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 47 def port_settings @port_settings end |
#schedule ⇒ OCI::VulnerabilityScanning::Models::Schedule
This attribute is required.
55 56 57 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 55 def schedule @schedule end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`
73 74 75 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 73 def end |
#time_created ⇒ DateTime
[Required] Date and time the recipe was created, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)
39 40 41 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 39 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] Date and time the recipe was last updated, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)
43 44 45 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 43 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'port_settings': :'portSettings', 'agent_settings': :'agentSettings', 'schedule': :'schedule', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 96 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'port_settings': :'OCI::VulnerabilityScanning::Models::HostScanPortSettings', 'agent_settings': :'OCI::VulnerabilityScanning::Models::HostScanAgentSettings', 'schedule': :'OCI::VulnerabilityScanning::Models::Schedule', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 224 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && port_settings == other.port_settings && agent_settings == other.agent_settings && schedule == other.schedule && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 265 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
245 246 247 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 245 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 254 def hash [id, display_name, compartment_id, lifecycle_state, time_created, time_updated, port_settings, agent_settings, schedule, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
298 299 300 301 302 303 304 305 306 307 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 298 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
292 293 294 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_recipe.rb', line 292 def to_s to_hash.to_s end |