Class: OCI::VulnerabilityScanning::Models::HostScanTargetSummary
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::HostScanTargetSummary
- Defined in:
- lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb
Overview
Summary of a host scan target (application of a host scan recipe to a compartment or list of hosts)
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment ID of the object (this).
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] Target identifier, which can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#host_scan_recipe_id ⇒ String
[Required] ID of the host scan recipe this target applies.
-
#id ⇒ String
[Required] Unique identifier of the config that is immutable on creation.
-
#instance_ids ⇒ Array<String>
List of compute instance IDs to target (optional).
-
#lifecycle_state ⇒ String
[Required] The current state of the config.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#target_compartment_id ⇒ String
[Required] Compartment ID to target.
-
#time_created ⇒ DateTime
[Required] Date and time the target was created, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
-
#time_updated ⇒ DateTime
[Required] Date and time the target was last updated, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HostScanTargetSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ HostScanTargetSummary
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 133 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.target_compartment_id = attributes[:'targetCompartmentId'] if attributes[:'targetCompartmentId'] raise 'You cannot provide both :targetCompartmentId and :target_compartment_id' if attributes.key?(:'targetCompartmentId') && attributes.key?(:'target_compartment_id') self.target_compartment_id = attributes[:'target_compartment_id'] if attributes[:'target_compartment_id'] self.instance_ids = attributes[:'instanceIds'] if attributes[:'instanceIds'] raise 'You cannot provide both :instanceIds and :instance_ids' if attributes.key?(:'instanceIds') && attributes.key?(:'instance_ids') self.instance_ids = attributes[:'instance_ids'] if attributes[:'instance_ids'] self.host_scan_recipe_id = attributes[:'hostScanRecipeId'] if attributes[:'hostScanRecipeId'] raise 'You cannot provide both :hostScanRecipeId and :host_scan_recipe_id' if attributes.key?(:'hostScanRecipeId') && attributes.key?(:'host_scan_recipe_id') self.host_scan_recipe_id = attributes[:'host_scan_recipe_id'] if attributes[:'host_scan_recipe_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment ID of the object (this).
31 32 33 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 31 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
67 68 69 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 67 def end |
#display_name ⇒ String
[Required] Target identifier, which can be renamed.
27 28 29 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 27 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
61 62 63 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 61 def end |
#host_scan_recipe_id ⇒ String
[Required] ID of the host scan recipe this target applies.
43 44 45 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 43 def host_scan_recipe_id @host_scan_recipe_id end |
#id ⇒ String
[Required] Unique identifier of the config that is immutable on creation
23 24 25 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 23 def id @id end |
#instance_ids ⇒ Array<String>
List of compute instance IDs to target (optional). If empty, targets the entire targetCompartmentId.
39 40 41 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 39 def instance_ids @instance_ids end |
#lifecycle_state ⇒ String
[Required] The current state of the config.
47 48 49 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 47 def lifecycle_state @lifecycle_state end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`
73 74 75 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 73 def end |
#target_compartment_id ⇒ String
[Required] Compartment ID to target. If a list of hosts is provided, all hosts must be in this compartment.
35 36 37 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 35 def target_compartment_id @target_compartment_id end |
#time_created ⇒ DateTime
[Required] Date and time the target was created, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)
51 52 53 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 51 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] Date and time the target was last updated, format as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)
55 56 57 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 55 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'target_compartment_id': :'targetCompartmentId', 'instance_ids': :'instanceIds', 'host_scan_recipe_id': :'hostScanRecipeId', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 96 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'target_compartment_id': :'String', 'instance_ids': :'Array<String>', 'host_scan_recipe_id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 228 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && target_compartment_id == other.target_compartment_id && instance_ids == other.instance_ids && host_scan_recipe_id == other.host_scan_recipe_id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 269 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
249 250 251 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 249 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
258 259 260 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 258 def hash [id, display_name, compartment_id, target_compartment_id, instance_ids, host_scan_recipe_id, lifecycle_state, time_created, time_updated, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
296 297 298 |
# File 'lib/oci/vulnerability_scanning/models/host_scan_target_summary.rb', line 296 def to_s to_hash.to_s end |