Class: OCI::VulnerabilityScanning::Models::UpdateContainerScanRecipeDetails
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::UpdateContainerScanRecipeDetails
- Defined in:
- lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb
Overview
The information to update an existing container scan recipe
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
User friendly name of container scan recipe.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #scan_settings ⇒ OCI::VulnerabilityScanning::Models::ContainerScanSettings
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateContainerScanRecipeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateContainerScanRecipeDetails
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.scan_settings = attributes[:'scanSettings'] if attributes[:'scanSettings'] raise 'You cannot provide both :scanSettings and :scan_settings' if attributes.key?(:'scanSettings') && attributes.key?(:'scan_settings') self.scan_settings = attributes[:'scan_settings'] if attributes[:'scan_settings'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
27 28 29 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 27 def end |
#display_name ⇒ String
User friendly name of container scan recipe
12 13 14 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
21 22 23 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 21 def end |
#scan_settings ⇒ OCI::VulnerabilityScanning::Models::ContainerScanSettings
15 16 17 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 15 def scan_settings @scan_settings end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'scan_settings': :'scanSettings', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 42 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'scan_settings': :'OCI::VulnerabilityScanning::Models::ContainerScanSettings', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 101 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && scan_settings == other.scan_settings && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 134 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
114 115 116 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 114 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
123 124 125 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 123 def hash [display_name, scan_settings, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 167 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
161 162 163 |
# File 'lib/oci/vulnerability_scanning/models/update_container_scan_recipe_details.rb', line 161 def to_s to_hash.to_s end |