Class: OCI::VulnerabilityScanning::Models::UpdateHostScanRecipeDetails
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::UpdateHostScanRecipeDetails
- Defined in:
- lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb
Overview
The information to update an existing host scan recipe
Instance Attribute Summary collapse
- #agent_settings ⇒ OCI::VulnerabilityScanning::Models::HostScanAgentSettings
- #application_settings ⇒ OCI::VulnerabilityScanning::Models::ApplicationScanSettings
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Recipe identifier, which can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #port_settings ⇒ OCI::VulnerabilityScanning::Models::HostScanPortSettings
- #schedule ⇒ OCI::VulnerabilityScanning::Models::Schedule
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateHostScanRecipeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateHostScanRecipeDetails
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.port_settings = attributes[:'portSettings'] if attributes[:'portSettings'] raise 'You cannot provide both :portSettings and :port_settings' if attributes.key?(:'portSettings') && attributes.key?(:'port_settings') self.port_settings = attributes[:'port_settings'] if attributes[:'port_settings'] self.agent_settings = attributes[:'agentSettings'] if attributes[:'agentSettings'] raise 'You cannot provide both :agentSettings and :agent_settings' if attributes.key?(:'agentSettings') && attributes.key?(:'agent_settings') self.agent_settings = attributes[:'agent_settings'] if attributes[:'agent_settings'] self.application_settings = attributes[:'applicationSettings'] if attributes[:'applicationSettings'] raise 'You cannot provide both :applicationSettings and :application_settings' if attributes.key?(:'applicationSettings') && attributes.key?(:'application_settings') self.application_settings = attributes[:'application_settings'] if attributes[:'application_settings'] self.schedule = attributes[:'schedule'] if attributes[:'schedule'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#agent_settings ⇒ OCI::VulnerabilityScanning::Models::HostScanAgentSettings
18 19 20 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 18 def agent_settings @agent_settings end |
#application_settings ⇒ OCI::VulnerabilityScanning::Models::ApplicationScanSettings
21 22 23 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 21 def application_settings @application_settings end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
36 37 38 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 36 def @defined_tags end |
#display_name ⇒ String
Recipe identifier, which can be renamed. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
30 31 32 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 30 def @freeform_tags end |
#port_settings ⇒ OCI::VulnerabilityScanning::Models::HostScanPortSettings
15 16 17 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 15 def port_settings @port_settings end |
#schedule ⇒ OCI::VulnerabilityScanning::Models::Schedule
24 25 26 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 24 def schedule @schedule end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'port_settings': :'portSettings', 'agent_settings': :'agentSettings', 'application_settings': :'applicationSettings', 'schedule': :'schedule', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'port_settings': :'OCI::VulnerabilityScanning::Models::HostScanPortSettings', 'agent_settings': :'OCI::VulnerabilityScanning::Models::HostScanAgentSettings', 'application_settings': :'OCI::VulnerabilityScanning::Models::ApplicationScanSettings', 'schedule': :'OCI::VulnerabilityScanning::Models::Schedule', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 133 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && port_settings == other.port_settings && agent_settings == other.agent_settings && application_settings == other.application_settings && schedule == other.schedule && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 169 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
149 150 151 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 149 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 158 def hash [display_name, port_settings, agent_settings, application_settings, schedule, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
196 197 198 |
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_recipe_details.rb', line 196 def to_s to_hash.to_s end |