Class: OCI::VulnerabilityScanning::Models::UpdateHostScanTargetDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb

Overview

The information to update an existing host scan target

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateHostScanTargetDetails

Initializes the object

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :target_compartment_id (String)

    The value to assign to the #target_compartment_id property

  • :instance_ids (Array<String>)

    The value to assign to the #instance_ids property

  • :host_scan_recipe_id (String)

    The value to assign to the #host_scan_recipe_id property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 85

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.target_compartment_id = attributes[:'targetCompartmentId'] if attributes[:'targetCompartmentId']

  raise 'You cannot provide both :targetCompartmentId and :target_compartment_id' if attributes.key?(:'targetCompartmentId') && attributes.key?(:'target_compartment_id')

  self.target_compartment_id = attributes[:'target_compartment_id'] if attributes[:'target_compartment_id']

  self.instance_ids = attributes[:'instanceIds'] if attributes[:'instanceIds']

  raise 'You cannot provide both :instanceIds and :instance_ids' if attributes.key?(:'instanceIds') && attributes.key?(:'instance_ids')

  self.instance_ids = attributes[:'instance_ids'] if attributes[:'instance_ids']

  self.host_scan_recipe_id = attributes[:'hostScanRecipeId'] if attributes[:'hostScanRecipeId']

  raise 'You cannot provide both :hostScanRecipeId and :host_scan_recipe_id' if attributes.key?(:'hostScanRecipeId') && attributes.key?(:'host_scan_recipe_id')

  self.host_scan_recipe_id = attributes[:'host_scan_recipe_id'] if attributes[:'host_scan_recipe_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`



40
41
42
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 40

def defined_tags
  @defined_tags
end

#descriptionString

Target description.



16
17
18
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 16

def description
  @description
end

#display_nameString

Target identifier, which can be renamed. Avoid entering confidential information.



12
13
14
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 12

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`



34
35
36
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 34

def freeform_tags
  @freeform_tags
end

#host_scan_recipe_idString

ID of the host scan recipe this target applies.



28
29
30
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 28

def host_scan_recipe_id
  @host_scan_recipe_id
end

#instance_idsArray<String>

List of compute instance IDs to target (optional). If empty, targets the entire targetCompartmentId.



24
25
26
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 24

def instance_ids
  @instance_ids
end

#target_compartment_idString

Compartment ID to target. If a list of hosts is provided, all hosts must be in this compartment.



20
21
22
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 20

def target_compartment_id
  @target_compartment_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'description': :'description',
    'target_compartment_id': :'targetCompartmentId',
    'instance_ids': :'instanceIds',
    'host_scan_recipe_id': :'hostScanRecipeId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 58

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'description': :'String',
    'target_compartment_id': :'String',
    'instance_ids': :'Array<String>',
    'host_scan_recipe_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 137

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    description == other.description &&
    target_compartment_id == other.target_compartment_id &&
    instance_ids == other.instance_ids &&
    host_scan_recipe_id == other.host_scan_recipe_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 173

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


153
154
155
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 153

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



162
163
164
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 162

def hash
  [display_name, description, target_compartment_id, instance_ids, host_scan_recipe_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash



206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 206

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



200
201
202
# File 'lib/oci/vulnerability_scanning/models/update_host_scan_target_details.rb', line 200

def to_s
  to_hash.to_s
end