Class: VulnerabilityScanning::Models::Vulnerability

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vulnerability_scanning/models/vulnerability.rb

Overview

A vulnerability found from scans in a compartment

Constant Summary collapse

SEVERITY_ENUM =
[
  SEVERITY_NONE = 'NONE'.freeze,
  SEVERITY_LOW = 'LOW'.freeze,
  SEVERITY_MEDIUM = 'MEDIUM'.freeze,
  SEVERITY_HIGH = 'HIGH'.freeze,
  SEVERITY_CRITICAL = 'CRITICAL'.freeze,
  SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATE_ENUM =
[
  STATE_OPEN = 'OPEN'.freeze,
  STATE_FIXED = 'FIXED'.freeze,
  STATE_NOT_APPLICABLE = 'NOT_APPLICABLE'.freeze,
  STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
VULNERABILITY_TYPE_ENUM =
[
  VULNERABILITY_TYPE_CVE = 'CVE'.freeze,
  VULNERABILITY_TYPE_PROBLEM = 'PROBLEM'.freeze,
  VULNERABILITY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Vulnerability

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 162

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.authentication = attributes[:'authentication'] if attributes[:'authentication']

  self.vulnerability_reference = attributes[:'vulnerabilityReference'] if attributes[:'vulnerabilityReference']

  raise 'You cannot provide both :vulnerabilityReference and :vulnerability_reference' if attributes.key?(:'vulnerabilityReference') && attributes.key?(:'vulnerability_reference')

  self.vulnerability_reference = attributes[:'vulnerability_reference'] if attributes[:'vulnerability_reference']

  self.cve_details = attributes[:'cveDetails'] if attributes[:'cveDetails']

  raise 'You cannot provide both :cveDetails and :cve_details' if attributes.key?(:'cveDetails') && attributes.key?(:'cve_details')

  self.cve_details = attributes[:'cve_details'] if attributes[:'cve_details']

  self.severity = attributes[:'severity'] if attributes[:'severity']

  self.state = attributes[:'state'] if attributes[:'state']

  self.cve_description = attributes[:'cveDescription'] if attributes[:'cveDescription']

  raise 'You cannot provide both :cveDescription and :cve_description' if attributes.key?(:'cveDescription') && attributes.key?(:'cve_description')

  self.cve_description = attributes[:'cve_description'] if attributes[:'cve_description']

  self.name = attributes[:'name'] if attributes[:'name']

  self.time_last_detected = attributes[:'timeLastDetected'] if attributes[:'timeLastDetected']

  raise 'You cannot provide both :timeLastDetected and :time_last_detected' if attributes.key?(:'timeLastDetected') && attributes.key?(:'time_last_detected')

  self.time_last_detected = attributes[:'time_last_detected'] if attributes[:'time_last_detected']

  self.time_first_detected = attributes[:'timeFirstDetected'] if attributes[:'timeFirstDetected']

  raise 'You cannot provide both :timeFirstDetected and :time_first_detected' if attributes.key?(:'timeFirstDetected') && attributes.key?(:'time_first_detected')

  self.time_first_detected = attributes[:'time_first_detected'] if attributes[:'time_first_detected']

  self.impacted_resources_count = attributes[:'impactedResourcesCount'] if attributes[:'impactedResourcesCount']

  raise 'You cannot provide both :impactedResourcesCount and :impacted_resources_count' if attributes.key?(:'impactedResourcesCount') && attributes.key?(:'impacted_resources_count')

  self.impacted_resources_count = attributes[:'impacted_resources_count'] if attributes[:'impacted_resources_count']

  self.vulnerability_type = attributes[:'vulnerabilityType'] if attributes[:'vulnerabilityType']

  raise 'You cannot provide both :vulnerabilityType and :vulnerability_type' if attributes.key?(:'vulnerabilityType') && attributes.key?(:'vulnerability_type')

  self.vulnerability_type = attributes[:'vulnerability_type'] if attributes[:'vulnerability_type']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']
end

Instance Attribute Details

#authenticationString

Mechanism used for scan authentication

Returns:

  • (String)


53
54
55
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 53

def authentication
  @authentication
end

#compartment_idString

**[Required]** Compartment ID of the vulnerability. Vulnerabilities with identical CVEs can exist in different compartments, based on scan target location

Returns:

  • (String)


49
50
51
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 49

def compartment_id
  @compartment_id
end

#cve_descriptionString

The description of CVE vulnerability

Returns:

  • (String)


72
73
74
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 72

def cve_description
  @cve_description
end

#cve_detailsOCI::VulnerabilityScanning::Models::CveDetails

Returns:

  • (OCI::VulnerabilityScanning::Models::CveDetails)


60
61
62
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 60

def cve_details
  @cve_details
end

#idString

**[Required]** ID of the vulnerability

Returns:

  • (String)


45
46
47
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 45

def id
  @id
end

#impacted_resources_countOCI::VulnerabilityScanning::Models::ImpactedResourcesCount

This attribute is required.



88
89
90
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 88

def impacted_resources_count
  @impacted_resources_count
end

#lifecycle_stateString

The current state of the resource.

Returns:

  • (String)


96
97
98
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 96

def lifecycle_state
  @lifecycle_state
end

#nameString

**[Required]** Vulnerability name

Returns:

  • (String)


76
77
78
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 76

def name
  @name
end

#severityString

**[Required]** Severity of the vulnerability

Returns:

  • (String)


64
65
66
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 64

def severity
  @severity
end

#stateString

State of the vulnerability

Returns:

  • (String)


68
69
70
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 68

def state
  @state
end

#time_first_detectedDateTime

**[Required]** Date of scan result that first reported the vulnerability

Returns:

  • (DateTime)


84
85
86
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 84

def time_first_detected
  @time_first_detected
end

#time_last_detectedDateTime

**[Required]** Date of scan result that most recently reported the vulnerability

Returns:

  • (DateTime)


80
81
82
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 80

def time_last_detected
  @time_last_detected
end

#vulnerability_referenceString

Reference to the vulnerability type's unique identifier. For CVE, this is the MITRE CVE ID

Returns:

  • (String)


57
58
59
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 57

def vulnerability_reference
  @vulnerability_reference
end

#vulnerability_typeString

**[Required]** Specifies the type of Vulnerability

Returns:

  • (String)


92
93
94
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 92

def vulnerability_type
  @vulnerability_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 99

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'authentication': :'authentication',
    'vulnerability_reference': :'vulnerabilityReference',
    'cve_details': :'cveDetails',
    'severity': :'severity',
    'state': :'state',
    'cve_description': :'cveDescription',
    'name': :'name',
    'time_last_detected': :'timeLastDetected',
    'time_first_detected': :'timeFirstDetected',
    'impacted_resources_count': :'impactedResourcesCount',
    'vulnerability_type': :'vulnerabilityType',
    'lifecycle_state': :'lifecycleState'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 121

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'authentication': :'String',
    'vulnerability_reference': :'String',
    'cve_details': :'OCI::VulnerabilityScanning::Models::CveDetails',
    'severity': :'String',
    'state': :'String',
    'cve_description': :'String',
    'name': :'String',
    'time_last_detected': :'DateTime',
    'time_first_detected': :'DateTime',
    'impacted_resources_count': :'OCI::VulnerabilityScanning::Models::ImpactedResourcesCount',
    'vulnerability_type': :'String',
    'lifecycle_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 292

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    authentication == other.authentication &&
    vulnerability_reference == other.vulnerability_reference &&
    cve_details == other.cve_details &&
    severity == other.severity &&
    state == other.state &&
    cve_description == other.cve_description &&
    name == other.name &&
    time_last_detected == other.time_last_detected &&
    time_first_detected == other.time_first_detected &&
    impacted_resources_count == other.impacted_resources_count &&
    vulnerability_type == other.vulnerability_type &&
    lifecycle_state == other.lifecycle_state
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 335

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


315
316
317
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 315

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



324
325
326
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 324

def hash
  [id, compartment_id, authentication, vulnerability_reference, cve_details, severity, state, cve_description, name, time_last_detected, time_first_detected, impacted_resources_count, vulnerability_type, lifecycle_state].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



368
369
370
371
372
373
374
375
376
377
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 368

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



362
363
364
# File 'lib/oci/vulnerability_scanning/models/vulnerability.rb', line 362

def to_s
  to_hash.to_s
end