Class: OCI::VulnerabilityScanning::Models::VulnerabilityImpactedContainerSummary
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::VulnerabilityImpactedContainerSummary
- Defined in:
- lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb
Overview
Information on a container image impacted by a vulnerability
Instance Attribute Summary collapse
-
#container_scan_target_id ⇒ String
**[Required]** The scan target id of the repository scan result.
-
#image ⇒ String
**[Required]** The name of the container image.
-
#last_container_scan_id ⇒ String
**[Required]** The ID of the last container image scan result Id.
-
#registry ⇒ String
**[Required]** The registry key of the container image.
-
#repository ⇒ String
**[Required]** The repository id of the container image.
-
#time_scan_completed ⇒ DateTime
**[Required]** Date and time the scan was completed, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VulnerabilityImpactedContainerSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VulnerabilityImpactedContainerSummary
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 74 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.container_scan_target_id = attributes[:'containerScanTargetId'] if attributes[:'containerScanTargetId'] raise 'You cannot provide both :containerScanTargetId and :container_scan_target_id' if attributes.key?(:'containerScanTargetId') && attributes.key?(:'container_scan_target_id') self.container_scan_target_id = attributes[:'container_scan_target_id'] if attributes[:'container_scan_target_id'] self.repository = attributes[:'repository'] if attributes[:'repository'] self.registry = attributes[:'registry'] if attributes[:'registry'] self.image = attributes[:'image'] if attributes[:'image'] self.last_container_scan_id = attributes[:'lastContainerScanId'] if attributes[:'lastContainerScanId'] raise 'You cannot provide both :lastContainerScanId and :last_container_scan_id' if attributes.key?(:'lastContainerScanId') && attributes.key?(:'last_container_scan_id') self.last_container_scan_id = attributes[:'last_container_scan_id'] if attributes[:'last_container_scan_id'] self.time_scan_completed = attributes[:'timeScanCompleted'] if attributes[:'timeScanCompleted'] raise 'You cannot provide both :timeScanCompleted and :time_scan_completed' if attributes.key?(:'timeScanCompleted') && attributes.key?(:'time_scan_completed') self.time_scan_completed = attributes[:'time_scan_completed'] if attributes[:'time_scan_completed'] end |
Instance Attribute Details
#container_scan_target_id ⇒ String
**[Required]** The scan target id of the repository scan result
12 13 14 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 12 def container_scan_target_id @container_scan_target_id end |
#image ⇒ String
**[Required]** The name of the container image.
24 25 26 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 24 def image @image end |
#last_container_scan_id ⇒ String
**[Required]** The ID of the last container image scan result Id
28 29 30 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 28 def last_container_scan_id @last_container_scan_id end |
#registry ⇒ String
**[Required]** The registry key of the container image.
20 21 22 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 20 def registry @registry end |
#repository ⇒ String
**[Required]** The repository id of the container image.
16 17 18 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 16 def repository @repository end |
#time_scan_completed ⇒ DateTime
**[Required]** Date and time the scan was completed, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)
32 33 34 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 32 def time_scan_completed @time_scan_completed end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'container_scan_target_id': :'containerScanTargetId', 'repository': :'repository', 'registry': :'registry', 'image': :'image', 'last_container_scan_id': :'lastContainerScanId', 'time_scan_completed': :'timeScanCompleted' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'container_scan_target_id': :'String', 'repository': :'String', 'registry': :'String', 'image': :'String', 'last_container_scan_id': :'String', 'time_scan_completed': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && container_scan_target_id == other.container_scan_target_id && repository == other.repository && registry == other.registry && image == other.image && last_container_scan_id == other.last_container_scan_id && time_scan_completed == other.time_scan_completed end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 147 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
127 128 129 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 127 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 136 def hash [container_scan_target_id, repository, registry, image, last_container_scan_id, time_scan_completed].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
174 175 176 |
# File 'lib/oci/vulnerability_scanning/models/vulnerability_impacted_container_summary.rb', line 174 def to_s to_hash.to_s end |