Class: OCI::Waa::Models::CreateWebAppAccelerationPolicyDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/waa/models/create_web_app_acceleration_policy_details.rb

Overview

The information about new WebAppAccelerationPolicy.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateWebAppAccelerationPolicyDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 85

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.response_caching_policy = attributes[:'responseCachingPolicy'] if attributes[:'responseCachingPolicy']

  raise 'You cannot provide both :responseCachingPolicy and :response_caching_policy' if attributes.key?(:'responseCachingPolicy') && attributes.key?(:'response_caching_policy')

  self.response_caching_policy = attributes[:'response_caching_policy'] if attributes[:'response_caching_policy']

  self.response_compression_policy = attributes[:'responseCompressionPolicy'] if attributes[:'responseCompressionPolicy']

  raise 'You cannot provide both :responseCompressionPolicy and :response_compression_policy' if attributes.key?(:'responseCompressionPolicy') && attributes.key?(:'response_compression_policy')

  self.response_compression_policy = attributes[:'response_compression_policy'] if attributes[:'response_compression_policy']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


16
17
18
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 16

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


34
35
36
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 34

def defined_tags
  @defined_tags
end

#display_nameString

WebAppAccelerationPolicy display name, can be renamed.

Returns:

  • (String)


12
13
14
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 12

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


28
29
30
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 28

def freeform_tags
  @freeform_tags
end

#response_caching_policyOCI::Waa::Models::ResponseCachingPolicy



19
20
21
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 19

def response_caching_policy
  @response_caching_policy
end

#response_compression_policyOCI::Waa::Models::ResponseCompressionPolicy



22
23
24
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 22

def response_compression_policy
  @response_compression_policy
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


40
41
42
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 40

def system_tags
  @system_tags
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 43

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'response_caching_policy': :'responseCachingPolicy',
    'response_compression_policy': :'responseCompressionPolicy',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 58

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'compartment_id': :'String',
    'response_caching_policy': :'OCI::Waa::Models::ResponseCachingPolicy',
    'response_compression_policy': :'OCI::Waa::Models::ResponseCompressionPolicy',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 141

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    response_caching_policy == other.response_caching_policy &&
    response_compression_policy == other.response_compression_policy &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 177

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


157
158
159
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 157

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



166
167
168
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 166

def hash
  [display_name, compartment_id, response_caching_policy, response_compression_policy, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



204
205
206
# File 'lib/oci/waa/models/create_web_app_acceleration_policy_details.rb', line 204

def to_s
  to_hash.to_s
end