Class: OCI::Waa::Models::ResponseCompressionPolicy

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/waa/models/response_compression_policy.rb

Overview

An object that specifies a compression policy for HTTP response from ENABLEMENT POINT to the client.

This compression policy can be used to enable support for HTTP response compression algorithms like gzip and configure the conditions of when a compression algorithm will be used.

HTTP responses will only be compressed if the client indicates support for one of the enabled compression algorithms via the "Accept-Encoding" request header.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResponseCompressionPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/waa/models/response_compression_policy.rb', line 45

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.gzip_compression = attributes[:'gzipCompression'] if attributes[:'gzipCompression']

  raise 'You cannot provide both :gzipCompression and :gzip_compression' if attributes.key?(:'gzipCompression') && attributes.key?(:'gzip_compression')

  self.gzip_compression = attributes[:'gzip_compression'] if attributes[:'gzip_compression']
end

Instance Attribute Details

#gzip_compressionOCI::Waa::Models::GzipCompressionPolicy



18
19
20
# File 'lib/oci/waa/models/response_compression_policy.rb', line 18

def gzip_compression
  @gzip_compression
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



21
22
23
24
25
26
27
# File 'lib/oci/waa/models/response_compression_policy.rb', line 21

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'gzip_compression': :'gzipCompression'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



30
31
32
33
34
35
36
# File 'lib/oci/waa/models/response_compression_policy.rb', line 30

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'gzip_compression': :'OCI::Waa::Models::GzipCompressionPolicy'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



65
66
67
68
69
70
# File 'lib/oci/waa/models/response_compression_policy.rb', line 65

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    gzip_compression == other.gzip_compression
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/oci/waa/models/response_compression_policy.rb', line 95

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


75
76
77
# File 'lib/oci/waa/models/response_compression_policy.rb', line 75

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



84
85
86
# File 'lib/oci/waa/models/response_compression_policy.rb', line 84

def hash
  [gzip_compression].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/waa/models/response_compression_policy.rb', line 128

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



122
123
124
# File 'lib/oci/waa/models/response_compression_policy.rb', line 122

def to_s
  to_hash.to_s
end