Class: OCI::Waa::Models::WebAppAccelerationPolicy

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/waa/models/web_app_acceleration_policy.rb

Overview

The details of WebAppAccelerationPolicy. A policy is comprised of rules, which allows enablement of Caching and Compression of HTTP response. Caching can be enabled for a particular path Compression is enabled at global level

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WebAppAccelerationPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 137

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.response_caching_policy = attributes[:'responseCachingPolicy'] if attributes[:'responseCachingPolicy']

  raise 'You cannot provide both :responseCachingPolicy and :response_caching_policy' if attributes.key?(:'responseCachingPolicy') && attributes.key?(:'response_caching_policy')

  self.response_caching_policy = attributes[:'response_caching_policy'] if attributes[:'response_caching_policy']

  self.response_compression_policy = attributes[:'responseCompressionPolicy'] if attributes[:'responseCompressionPolicy']

  raise 'You cannot provide both :responseCompressionPolicy and :response_compression_policy' if attributes.key?(:'responseCompressionPolicy') && attributes.key?(:'response_compression_policy')

  self.response_compression_policy = attributes[:'response_compression_policy'] if attributes[:'response_compression_policy']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


35
36
37
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 35

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


71
72
73
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 71

def defined_tags
  @defined_tags
end

#display_nameString

**[Required]** WebAppAccelerationPolicy display name, can be renamed.

Returns:

  • (String)


31
32
33
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 31

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`

Returns:

  • (Hash<String, String>)


65
66
67
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 65

def freeform_tags
  @freeform_tags
end

#idString

**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the WebAppAccelerationPolicy.

Returns:

  • (String)


27
28
29
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 27

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in FAILED state.

Returns:

  • (String)


53
54
55
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 53

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

**[Required]** The current state of the WebAppAccelerationPolicy.

Returns:

  • (String)


47
48
49
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 47

def lifecycle_state
  @lifecycle_state
end

#response_caching_policyOCI::Waa::Models::ResponseCachingPolicy



56
57
58
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 56

def response_caching_policy
  @response_caching_policy
end

#response_compression_policyOCI::Waa::Models::ResponseCompressionPolicy



59
60
61
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 59

def response_compression_policy
  @response_compression_policy
end

#system_tagsHash<String, Hash<String, Object>>

**[Required]** Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


77
78
79
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 77

def system_tags
  @system_tags
end

#time_createdDateTime

**[Required]** The time the WebAppAccelerationPolicy was created. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


39
40
41
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 39

def time_created
  @time_created
end

#time_updatedDateTime

The time the WebAppAccelerationPolicy was updated. An RFC3339 formatted datetime string.

Returns:

  • (DateTime)


43
44
45
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 43

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 80

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'response_caching_policy': :'responseCachingPolicy',
    'response_compression_policy': :'responseCompressionPolicy',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 100

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'response_caching_policy': :'OCI::Waa::Models::ResponseCachingPolicy',
    'response_compression_policy': :'OCI::Waa::Models::ResponseCompressionPolicy',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 232

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    response_caching_policy == other.response_caching_policy &&
    response_compression_policy == other.response_compression_policy &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 273

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 253

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



262
263
264
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 262

def hash
  [id, display_name, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, response_caching_policy, response_compression_policy, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



306
307
308
309
310
311
312
313
314
315
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 306

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



300
301
302
# File 'lib/oci/waa/models/web_app_acceleration_policy.rb', line 300

def to_s
  to_hash.to_s
end