Class: OCI::Waas::Models::Certificate
- Inherits:
-
Object
- Object
- OCI::Waas::Models::Certificate
- Defined in:
- lib/oci/waas/models/certificate.rb
Overview
The details of the SSL certificate. *Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#certificate_data ⇒ String
The data of the SSL certificate.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the certificate's compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** The user-friendly name of the certificate.
-
#extensions ⇒ Array<OCI::Waas::Models::CertificateExtensions>
Additional attributes associated with users or public keys for managing relationships between Certificate Authorities.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the certificate.
-
#is_trust_verification_disabled ⇒ BOOLEAN
This indicates whether trust verification was disabled during the creation of SSL certificate.
- #issued_by ⇒ String
- #issuer_name ⇒ OCI::Waas::Models::CertificateIssuerName
-
#lifecycle_state ⇒ String
The current lifecycle state of the SSL certificate.
- #public_key_info ⇒ OCI::Waas::Models::CertificatePublicKeyInfo
-
#serial_number ⇒ String
**[Required]** A unique, positive integer assigned by the Certificate Authority (CA).
-
#signature_algorithm ⇒ String
**[Required]** The identifier for the cryptographic algorithm used by the Certificate Authority (CA) to sign this certificate.
- #subject_name ⇒ OCI::Waas::Models::CertificateSubjectName
-
#time_created ⇒ DateTime
The date and time the certificate was created, expressed in RFC 3339 timestamp format.
-
#time_not_valid_after ⇒ DateTime
**[Required]** The date and time the certificate will expire, expressed in RFC 3339 timestamp format.
-
#time_not_valid_before ⇒ DateTime
**[Required]** The date and time the certificate will become valid, expressed in RFC 3339 timestamp format.
-
#version ⇒ Integer
**[Required]** The version of the encoded certificate.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Certificate
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Certificate
Initializes the object
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/oci/waas/models/certificate.rb', line 183 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.issued_by = attributes[:'issuedBy'] if attributes[:'issuedBy'] raise 'You cannot provide both :issuedBy and :issued_by' if attributes.key?(:'issuedBy') && attributes.key?(:'issued_by') self.issued_by = attributes[:'issued_by'] if attributes[:'issued_by'] self.subject_name = attributes[:'subjectName'] if attributes[:'subjectName'] raise 'You cannot provide both :subjectName and :subject_name' if attributes.key?(:'subjectName') && attributes.key?(:'subject_name') self.subject_name = attributes[:'subject_name'] if attributes[:'subject_name'] self.issuer_name = attributes[:'issuerName'] if attributes[:'issuerName'] raise 'You cannot provide both :issuerName and :issuer_name' if attributes.key?(:'issuerName') && attributes.key?(:'issuer_name') self.issuer_name = attributes[:'issuer_name'] if attributes[:'issuer_name'] self.serial_number = attributes[:'serialNumber'] if attributes[:'serialNumber'] raise 'You cannot provide both :serialNumber and :serial_number' if attributes.key?(:'serialNumber') && attributes.key?(:'serial_number') self.serial_number = attributes[:'serial_number'] if attributes[:'serial_number'] self.version = attributes[:'version'] if attributes[:'version'] self.signature_algorithm = attributes[:'signatureAlgorithm'] if attributes[:'signatureAlgorithm'] raise 'You cannot provide both :signatureAlgorithm and :signature_algorithm' if attributes.key?(:'signatureAlgorithm') && attributes.key?(:'signature_algorithm') self.signature_algorithm = attributes[:'signature_algorithm'] if attributes[:'signature_algorithm'] self.time_not_valid_before = attributes[:'timeNotValidBefore'] if attributes[:'timeNotValidBefore'] raise 'You cannot provide both :timeNotValidBefore and :time_not_valid_before' if attributes.key?(:'timeNotValidBefore') && attributes.key?(:'time_not_valid_before') self.time_not_valid_before = attributes[:'time_not_valid_before'] if attributes[:'time_not_valid_before'] self.time_not_valid_after = attributes[:'timeNotValidAfter'] if attributes[:'timeNotValidAfter'] raise 'You cannot provide both :timeNotValidAfter and :time_not_valid_after' if attributes.key?(:'timeNotValidAfter') && attributes.key?(:'time_not_valid_after') self.time_not_valid_after = attributes[:'time_not_valid_after'] if attributes[:'time_not_valid_after'] self.public_key_info = attributes[:'publicKeyInfo'] if attributes[:'publicKeyInfo'] raise 'You cannot provide both :publicKeyInfo and :public_key_info' if attributes.key?(:'publicKeyInfo') && attributes.key?(:'public_key_info') self.public_key_info = attributes[:'public_key_info'] if attributes[:'public_key_info'] self.extensions = attributes[:'extensions'] if attributes[:'extensions'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.is_trust_verification_disabled = attributes[:'isTrustVerificationDisabled'] unless attributes[:'isTrustVerificationDisabled'].nil? self.is_trust_verification_disabled = false if is_trust_verification_disabled.nil? && !attributes.key?(:'isTrustVerificationDisabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isTrustVerificationDisabled and :is_trust_verification_disabled' if attributes.key?(:'isTrustVerificationDisabled') && attributes.key?(:'is_trust_verification_disabled') self.is_trust_verification_disabled = attributes[:'is_trust_verification_disabled'] unless attributes[:'is_trust_verification_disabled'].nil? self.is_trust_verification_disabled = false if is_trust_verification_disabled.nil? && !attributes.key?(:'isTrustVerificationDisabled') && !attributes.key?(:'is_trust_verification_disabled') # rubocop:disable Style/StringLiterals self.certificate_data = attributes[:'certificateData'] if attributes[:'certificateData'] raise 'You cannot provide both :certificateData and :certificate_data' if attributes.key?(:'certificateData') && attributes.key?(:'certificate_data') self.certificate_data = attributes[:'certificate_data'] if attributes[:'certificate_data'] end |
Instance Attribute Details
#certificate_data ⇒ String
The data of the SSL certificate.
102 103 104 |
# File 'lib/oci/waas/models/certificate.rb', line 102 def certificate_data @certificate_data end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the certificate's compartment.
28 29 30 |
# File 'lib/oci/waas/models/certificate.rb', line 28 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
84 85 86 |
# File 'lib/oci/waas/models/certificate.rb', line 84 def @defined_tags end |
#display_name ⇒ String
**[Required]** The user-friendly name of the certificate.
32 33 34 |
# File 'lib/oci/waas/models/certificate.rb', line 32 def display_name @display_name end |
#extensions ⇒ Array<OCI::Waas::Models::CertificateExtensions>
Additional attributes associated with users or public keys for managing relationships between Certificate Authorities.
68 69 70 |
# File 'lib/oci/waas/models/certificate.rb', line 68 def extensions @extensions end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
76 77 78 |
# File 'lib/oci/waas/models/certificate.rb', line 76 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the certificate.
24 25 26 |
# File 'lib/oci/waas/models/certificate.rb', line 24 def id @id end |
#is_trust_verification_disabled ⇒ BOOLEAN
This indicates whether trust verification was disabled during the creation of SSL certificate. If `true` SSL certificate trust verification was disabled and this SSL certificate is most likely self-signed.
98 99 100 |
# File 'lib/oci/waas/models/certificate.rb', line 98 def is_trust_verification_disabled @is_trust_verification_disabled end |
#issued_by ⇒ String
35 36 37 |
# File 'lib/oci/waas/models/certificate.rb', line 35 def issued_by @issued_by end |
#issuer_name ⇒ OCI::Waas::Models::CertificateIssuerName
41 42 43 |
# File 'lib/oci/waas/models/certificate.rb', line 41 def issuer_name @issuer_name end |
#lifecycle_state ⇒ String
The current lifecycle state of the SSL certificate.
88 89 90 |
# File 'lib/oci/waas/models/certificate.rb', line 88 def lifecycle_state @lifecycle_state end |
#public_key_info ⇒ OCI::Waas::Models::CertificatePublicKeyInfo
64 65 66 |
# File 'lib/oci/waas/models/certificate.rb', line 64 def public_key_info @public_key_info end |
#serial_number ⇒ String
**[Required]** A unique, positive integer assigned by the Certificate Authority (CA). The issuer name and serial number identify a unique certificate.
45 46 47 |
# File 'lib/oci/waas/models/certificate.rb', line 45 def serial_number @serial_number end |
#signature_algorithm ⇒ String
**[Required]** The identifier for the cryptographic algorithm used by the Certificate Authority (CA) to sign this certificate.
53 54 55 |
# File 'lib/oci/waas/models/certificate.rb', line 53 def signature_algorithm @signature_algorithm end |
#subject_name ⇒ OCI::Waas::Models::CertificateSubjectName
38 39 40 |
# File 'lib/oci/waas/models/certificate.rb', line 38 def subject_name @subject_name end |
#time_created ⇒ DateTime
The date and time the certificate was created, expressed in RFC 3339 timestamp format.
92 93 94 |
# File 'lib/oci/waas/models/certificate.rb', line 92 def time_created @time_created end |
#time_not_valid_after ⇒ DateTime
**[Required]** The date and time the certificate will expire, expressed in RFC 3339 timestamp format.
61 62 63 |
# File 'lib/oci/waas/models/certificate.rb', line 61 def time_not_valid_after @time_not_valid_after end |
#time_not_valid_before ⇒ DateTime
**[Required]** The date and time the certificate will become valid, expressed in RFC 3339 timestamp format.
57 58 59 |
# File 'lib/oci/waas/models/certificate.rb', line 57 def time_not_valid_before @time_not_valid_before end |
#version ⇒ Integer
**[Required]** The version of the encoded certificate.
49 50 51 |
# File 'lib/oci/waas/models/certificate.rb', line 49 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/waas/models/certificate.rb', line 105 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'issued_by': :'issuedBy', 'subject_name': :'subjectName', 'issuer_name': :'issuerName', 'serial_number': :'serialNumber', 'version': :'version', 'signature_algorithm': :'signatureAlgorithm', 'time_not_valid_before': :'timeNotValidBefore', 'time_not_valid_after': :'timeNotValidAfter', 'public_key_info': :'publicKeyInfo', 'extensions': :'extensions', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'is_trust_verification_disabled': :'isTrustVerificationDisabled', 'certificate_data': :'certificateData' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/waas/models/certificate.rb', line 132 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'issued_by': :'String', 'subject_name': :'OCI::Waas::Models::CertificateSubjectName', 'issuer_name': :'OCI::Waas::Models::CertificateIssuerName', 'serial_number': :'String', 'version': :'Integer', 'signature_algorithm': :'String', 'time_not_valid_before': :'DateTime', 'time_not_valid_after': :'DateTime', 'public_key_info': :'OCI::Waas::Models::CertificatePublicKeyInfo', 'extensions': :'Array<OCI::Waas::Models::CertificateExtensions>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'is_trust_verification_disabled': :'BOOLEAN', 'certificate_data': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/oci/waas/models/certificate.rb', line 314 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && issued_by == other.issued_by && subject_name == other.subject_name && issuer_name == other.issuer_name && serial_number == other.serial_number && version == other.version && signature_algorithm == other.signature_algorithm && time_not_valid_before == other.time_not_valid_before && time_not_valid_after == other.time_not_valid_after && public_key_info == other.public_key_info && extensions == other.extensions && == other. && == other. && lifecycle_state == other.lifecycle_state && time_created == other.time_created && is_trust_verification_disabled == other.is_trust_verification_disabled && certificate_data == other.certificate_data end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/oci/waas/models/certificate.rb', line 362 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
342 343 344 |
# File 'lib/oci/waas/models/certificate.rb', line 342 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
351 352 353 |
# File 'lib/oci/waas/models/certificate.rb', line 351 def hash [id, compartment_id, display_name, issued_by, subject_name, issuer_name, serial_number, version, signature_algorithm, time_not_valid_before, time_not_valid_after, public_key_info, extensions, , , lifecycle_state, time_created, is_trust_verification_disabled, certificate_data].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
395 396 397 398 399 400 401 402 403 404 |
# File 'lib/oci/waas/models/certificate.rb', line 395 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
389 390 391 |
# File 'lib/oci/waas/models/certificate.rb', line 389 def to_s to_hash.to_s end |