Class: OCI::Waas::Models::ProtectionRuleExclusion

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/waas/models/protection_rule_exclusion.rb

Overview

Allows specified types of requests to bypass the protection rule. If the requests matches any of the criteria in the exclusions field, the protection rule will not be executed. Rules can have more than one exclusion and exclusions are applied to requests disjunctively.

Constant Summary collapse

TARGET_ENUM =
[
  TARGET_REQUEST_COOKIES = 'REQUEST_COOKIES'.freeze,
  TARGET_REQUEST_COOKIE_NAMES = 'REQUEST_COOKIE_NAMES'.freeze,
  TARGET_ARGS = 'ARGS'.freeze,
  TARGET_ARGS_NAMES = 'ARGS_NAMES'.freeze,
  TARGET_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProtectionRuleExclusion

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :target (String)

    The value to assign to the #target property

  • :exclusions (Array<String>)

    The value to assign to the #exclusions property



53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 53

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.target = attributes[:'target'] if attributes[:'target']

  self.exclusions = attributes[:'exclusions'] if attributes[:'exclusions']
end

Instance Attribute Details

#exclusionsArray<String>

Returns:

  • (Array<String>)


23
24
25
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 23

def exclusions
  @exclusions
end

#targetString

The target of the exclusion.

Returns:

  • (String)


20
21
22
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 20

def target
  @target
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 26

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'target': :'target',
    'exclusions': :'exclusions'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



36
37
38
39
40
41
42
43
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 36

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'target': :'String',
    'exclusions': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



84
85
86
87
88
89
90
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 84

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    target == other.target &&
    exclusions == other.exclusions
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 115

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


95
96
97
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 95

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



104
105
106
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 104

def hash
  [target, exclusions].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 148

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



142
143
144
# File 'lib/oci/waas/models/protection_rule_exclusion.rb', line 142

def to_s
  to_hash.to_s
end