Method: OCI::Waas::Models::UpdateCustomProtectionRuleDetails#template

Defined in:
lib/oci/waas/models/update_custom_protection_rule_details.rb

#templateString

The template text of the custom protection rule. All custom protection rules are expressed in ModSecurity Rule Language.

Additionally, each rule must include two placeholder variables that are updated by the WAF service upon publication of the rule.

‘id: {id_1}` - This field is populated with a unique rule ID generated by the WAF service which identifies a SecRule. More than one SecRule can be defined in the template field of a CreateCustomSecurityRule call. The value of the first SecRule must be `id: {id_1}` and the id field of each subsequent SecRule should increase by one, as shown in the example.

‘ctl:ruleEngine={mode}` - The action to be taken when the criteria of the SecRule are met, either OFF, DETECT or BLOCK. This field is automatically populated with the corresponding value of the action field of the CustomProtectionRuleSetting schema when the WafConfig is updated.

Example:

```
SecRule REQUEST_COOKIES \"regex matching SQL injection - part 1/2\" \\
        \"phase:2,                                                 \\
        msg:'Detects chained SQL injection attempts 1/2.',        \\
        id: {{id_1}},                                             \\
        ctl:ruleEngine={{mode}},                                  \\
        deny\"
SecRule REQUEST_COOKIES \"regex matching SQL injection - part 2/2\" \\
        \"phase:2,                                                 \\
        msg:'Detects chained SQL injection attempts 2/2.',        \\
        id: {{id_2}},                                             \\
        ctl:ruleEngine={{mode}},                                  \\
        deny\"
```

The example contains two SecRules each having distinct regex expression to match the Cookie header value during the second input analysis phase.

For more information about custom protection rules, see [Custom Protection Rules](docs.cloud.oracle.com/Content/WAF/tasks/customprotectionrules.htm).

For more information about ModSecurity syntax, see [Making Rules: The Basic Syntax](www.modsecurity.org/CRS/Documentation/making.html).

For more information about ModSecurity’s open source WAF rules, see [Mod Security’s OWASP Core Rule Set documentation](www.modsecurity.org/CRS/Documentation/index.html).

Returns:

  • (String)


52
53
54
# File 'lib/oci/waas/models/update_custom_protection_rule_details.rb', line 52

def template
  @template
end