Class: OCI::Waf::Models::Action
- Inherits:
-
Object
- Object
- OCI::Waf::Models::Action
- Defined in:
- lib/oci/waf/models/action.rb
Overview
An object that represents action and its options. The action can be terminating, if it stops further execution of rules and modules. And non-terminating, if it does not interrupt execution flow.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_CHECK = 'CHECK'.freeze, TYPE_ALLOW = 'ALLOW'.freeze, TYPE_RETURN_HTTP_RESPONSE = 'RETURN_HTTP_RESPONSE'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#name ⇒ String
**[Required]** Action name.
-
#type ⇒ String
**[Required]** * *CHECK* is a non-terminating action that does not stop the execution of rules in current module, just emits a log message documenting result of rule execution.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Action
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Action
Initializes the object
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/waf/models/action.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.name = attributes[:'name'] if attributes[:'name'] end |
Instance Attribute Details
#name ⇒ String
**[Required]** Action name. Can be used to reference the action.
34 35 36 |
# File 'lib/oci/waf/models/action.rb', line 34 def name @name end |
#type ⇒ String
**[Required]** * *CHECK* is a non-terminating action that does not stop the execution of rules in current module,
just emits a log message documenting result of rule execution.
-
*ALLOW* is a non-terminating action which upon matching rule skips all remaining rules in the current module.
-
*RETURN_HTTP_RESPONSE* is a terminating action which is executed immediately, returns a defined HTTP response.
30 31 32 |
# File 'lib/oci/waf/models/action.rb', line 30 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 |
# File 'lib/oci/waf/models/action.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'name': :'name' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/waf/models/action.rb', line 61 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::Waf::Models::ReturnHttpResponseAction' if type == 'RETURN_HTTP_RESPONSE' return 'OCI::Waf::Models::AllowAction' if type == 'ALLOW' return 'OCI::Waf::Models::CheckAction' if type == 'CHECK' # TODO: Log a warning when the subtype is not found. 'OCI::Waf::Models::Action' end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 |
# File 'lib/oci/waf/models/action.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 |
# File 'lib/oci/waf/models/action.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && name == other.name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/waf/models/action.rb', line 143 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
123 124 125 |
# File 'lib/oci/waf/models/action.rb', line 123 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
132 133 134 |
# File 'lib/oci/waf/models/action.rb', line 132 def hash [type, name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/waf/models/action.rb', line 176 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
170 171 172 |
# File 'lib/oci/waf/models/action.rb', line 170 def to_s to_hash.to_s end |