Class: OCI::Waf::Models::CreateWebAppFirewallPolicyDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/waf/models/create_web_app_firewall_policy_details.rb

Overview

The information about new WebAppFirewallPolicy.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateWebAppFirewallPolicyDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 113

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.actions = attributes[:'actions'] if attributes[:'actions']

  self.request_access_control = attributes[:'requestAccessControl'] if attributes[:'requestAccessControl']

  raise 'You cannot provide both :requestAccessControl and :request_access_control' if attributes.key?(:'requestAccessControl') && attributes.key?(:'request_access_control')

  self.request_access_control = attributes[:'request_access_control'] if attributes[:'request_access_control']

  self.request_rate_limiting = attributes[:'requestRateLimiting'] if attributes[:'requestRateLimiting']

  raise 'You cannot provide both :requestRateLimiting and :request_rate_limiting' if attributes.key?(:'requestRateLimiting') && attributes.key?(:'request_rate_limiting')

  self.request_rate_limiting = attributes[:'request_rate_limiting'] if attributes[:'request_rate_limiting']

  self.request_protection = attributes[:'requestProtection'] if attributes[:'requestProtection']

  raise 'You cannot provide both :requestProtection and :request_protection' if attributes.key?(:'requestProtection') && attributes.key?(:'request_protection')

  self.request_protection = attributes[:'request_protection'] if attributes[:'request_protection']

  self.response_access_control = attributes[:'responseAccessControl'] if attributes[:'responseAccessControl']

  raise 'You cannot provide both :responseAccessControl and :response_access_control' if attributes.key?(:'responseAccessControl') && attributes.key?(:'response_access_control')

  self.response_access_control = attributes[:'response_access_control'] if attributes[:'response_access_control']

  self.response_protection = attributes[:'responseProtection'] if attributes[:'responseProtection']

  raise 'You cannot provide both :responseProtection and :response_protection' if attributes.key?(:'responseProtection') && attributes.key?(:'response_protection')

  self.response_protection = attributes[:'response_protection'] if attributes[:'response_protection']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#actionsArray<OCI::Waf::Models::Action>

Predefined actions for use in multiple different rules. Not all actions are supported in every module. Some actions terminate further execution of modules and rules in a module and some do not. Actions names must be unique within this array.

Returns:



23
24
25
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 23

def actions
  @actions
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


16
17
18
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 16

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


50
51
52
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 50

def defined_tags
  @defined_tags
end

#display_nameString

WebAppFirewallPolicy display name, can be renamed.

Returns:

  • (String)


12
13
14
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 12

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


44
45
46
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 44

def freeform_tags
  @freeform_tags
end

#request_access_controlOCI::Waf::Models::RequestAccessControl



26
27
28
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 26

def request_access_control
  @request_access_control
end

#request_protectionOCI::Waf::Models::RequestProtection



32
33
34
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 32

def request_protection
  @request_protection
end

#request_rate_limitingOCI::Waf::Models::RequestRateLimiting



29
30
31
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 29

def request_rate_limiting
  @request_rate_limiting
end

#response_access_controlOCI::Waf::Models::ResponseAccessControl



35
36
37
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 35

def response_access_control
  @response_access_control
end

#response_protectionOCI::Waf::Models::ResponseProtection



38
39
40
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 38

def response_protection
  @response_protection
end

#system_tagsHash<String, Hash<String, Object>>

Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


56
57
58
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 56

def system_tags
  @system_tags
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 59

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'actions': :'actions',
    'request_access_control': :'requestAccessControl',
    'request_rate_limiting': :'requestRateLimiting',
    'request_protection': :'requestProtection',
    'response_access_control': :'responseAccessControl',
    'response_protection': :'responseProtection',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 78

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'compartment_id': :'String',
    'actions': :'Array<OCI::Waf::Models::Action>',
    'request_access_control': :'OCI::Waf::Models::RequestAccessControl',
    'request_rate_limiting': :'OCI::Waf::Models::RequestRateLimiting',
    'request_protection': :'OCI::Waf::Models::RequestProtection',
    'response_access_control': :'OCI::Waf::Models::ResponseAccessControl',
    'response_protection': :'OCI::Waf::Models::ResponseProtection',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 189

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    actions == other.actions &&
    request_access_control == other.request_access_control &&
    request_rate_limiting == other.request_rate_limiting &&
    request_protection == other.request_protection &&
    response_access_control == other.response_access_control &&
    response_protection == other.response_protection &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 229

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 209

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



218
219
220
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 218

def hash
  [display_name, compartment_id, actions, request_access_control, request_rate_limiting, request_protection, response_access_control, response_protection, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



256
257
258
# File 'lib/oci/waf/models/create_web_app_firewall_policy_details.rb', line 256

def to_s
  to_hash.to_s
end