Class: OCI::Waf::Models::NetworkAddressListSummary
- Inherits:
-
Object
- Object
- OCI::Waf::Models::NetworkAddressListSummary
- Defined in:
- lib/oci/waf/models/network_address_list_summary.rb
Overview
Summary of NetworkAddressList. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
NetworkAddressListAddressesSummary, NetworkAddressListVcnAddressesSummary
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_ADDRESSES = 'ADDRESSES'.freeze, TYPE_VCN_ADDRESSES = 'VCN_ADDRESSES'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Defined tags for this resource.
-
#display_name ⇒ String
[Required] NetworkAddressList display name, can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
[Required] Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the NetworkAddressList.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
[Required] The current state of the NetworkAddress List.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Usage of system tag keys.
-
#time_created ⇒ DateTime
[Required] The time the NetworkAddressList was created.
-
#time_updated ⇒ DateTime
The time the NetworkAddressList was updated.
-
#type ⇒ String
[Required] Type of NetworkAddressList.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkAddressListSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NetworkAddressListSummary
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 141 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.type = attributes[:'type'] if attributes[:'type'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
28 29 30 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 28 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{\“bar-key\”: \“value\”}`
62 63 64 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 62 def end |
#display_name ⇒ String
[Required] NetworkAddressList display name, can be renamed.
24 25 26 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 24 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
[Required] Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘\“value\”`
56 57 58 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 56 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the NetworkAddressList.
20 21 22 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 20 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in FAILED state.
46 47 48 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 46 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the NetworkAddress List.
40 41 42 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 40 def lifecycle_state @lifecycle_state end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{\“free-tier-retained\”: \“true\”}`
68 69 70 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 68 def end |
#time_created ⇒ DateTime
[Required] The time the NetworkAddressList was created. An RFC3339 formatted datetime string.
32 33 34 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 32 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the NetworkAddressList was updated. An RFC3339 formatted datetime string.
36 37 38 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 36 def time_updated @time_updated end |
#type ⇒ String
[Required] Type of NetworkAddressList.
50 51 52 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 50 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 71 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'type': :'type', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 113 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::Waf::Models::NetworkAddressListVcnAddressesSummary' if type == 'VCN_ADDRESSES' return 'OCI::Waf::Models::NetworkAddressListAddressesSummary' if type == 'ADDRESSES' # TODO: Log a warning when the subtype is not found. 'OCI::Waf::Models::NetworkAddressListSummary' end |
.swagger_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 90 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 226 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && type == other.type && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 266 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
246 247 248 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 246 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 255 def hash [id, display_name, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, type, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
293 294 295 |
# File 'lib/oci/waf/models/network_address_list_summary.rb', line 293 def to_s to_hash.to_s end |