Class: OCI::Waf::Models::ProtectionCapability

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/waf/models/protection_capability.rb

Overview

References an OCI-managed protection capability. Checks if HTTP requests/responses are malicious.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProtectionCapability

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/oci/waf/models/protection_capability.rb', line 80

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.version = attributes[:'version'] if attributes[:'version']

  self.exclusions = attributes[:'exclusions'] if attributes[:'exclusions']

  self.action_name = attributes[:'actionName'] if attributes[:'actionName']

  raise 'You cannot provide both :actionName and :action_name' if attributes.key?(:'actionName') && attributes.key?(:'action_name')

  self.action_name = attributes[:'action_name'] if attributes[:'action_name']

  self.collaborative_action_threshold = attributes[:'collaborativeActionThreshold'] if attributes[:'collaborativeActionThreshold']

  raise 'You cannot provide both :collaborativeActionThreshold and :collaborative_action_threshold' if attributes.key?(:'collaborativeActionThreshold') && attributes.key?(:'collaborative_action_threshold')

  self.collaborative_action_threshold = attributes[:'collaborative_action_threshold'] if attributes[:'collaborative_action_threshold']

  self.collaborative_weights = attributes[:'collaborativeWeights'] if attributes[:'collaborativeWeights']

  raise 'You cannot provide both :collaborativeWeights and :collaborative_weights' if attributes.key?(:'collaborativeWeights') && attributes.key?(:'collaborative_weights')

  self.collaborative_weights = attributes[:'collaborative_weights'] if attributes[:'collaborative_weights']
end

Instance Attribute Details

#action_nameString

Override action to take if capability was triggered, defined in Protection Rule for this capability. Only actions of type CHECK are allowed.

Returns:

  • (String)


26
27
28
# File 'lib/oci/waf/models/protection_capability.rb', line 26

def action_name
  @action_name
end

#collaborative_action_thresholdInteger

The minimum sum of weights of associated collaborative protection capabilities that have triggered which must be reached in order for this capability to trigger. This field is ignored for non-collaborative capabilities.

Returns:

  • (Integer)


33
34
35
# File 'lib/oci/waf/models/protection_capability.rb', line 33

def collaborative_action_threshold
  @collaborative_action_threshold
end

#collaborative_weightsArray<OCI::Waf::Models::CollaborativeCapabilityWeightOverride>

Explicit weight values to use for associated collaborative protection capabilities.



38
39
40
# File 'lib/oci/waf/models/protection_capability.rb', line 38

def collaborative_weights
  @collaborative_weights
end

#exclusionsOCI::Waf::Models::ProtectionCapabilityExclusions



20
21
22
# File 'lib/oci/waf/models/protection_capability.rb', line 20

def exclusions
  @exclusions
end

#keyString

[Required] Unique key of referenced protection capability.

Returns:

  • (String)


13
14
15
# File 'lib/oci/waf/models/protection_capability.rb', line 13

def key
  @key
end

#versionInteger

[Required] Version of referenced protection capability.

Returns:

  • (Integer)


17
18
19
# File 'lib/oci/waf/models/protection_capability.rb', line 17

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/waf/models/protection_capability.rb', line 41

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'version': :'version',
    'exclusions': :'exclusions',
    'action_name': :'actionName',
    'collaborative_action_threshold': :'collaborativeActionThreshold',
    'collaborative_weights': :'collaborativeWeights'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/waf/models/protection_capability.rb', line 55

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'version': :'Integer',
    'exclusions': :'OCI::Waf::Models::ProtectionCapabilityExclusions',
    'action_name': :'String',
    'collaborative_action_threshold': :'Integer',
    'collaborative_weights': :'Array<OCI::Waf::Models::CollaborativeCapabilityWeightOverride>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/waf/models/protection_capability.rb', line 118

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    version == other.version &&
    exclusions == other.exclusions &&
    action_name == other.action_name &&
    collaborative_action_threshold == other.collaborative_action_threshold &&
    collaborative_weights == other.collaborative_weights
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/waf/models/protection_capability.rb', line 153

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


133
134
135
# File 'lib/oci/waf/models/protection_capability.rb', line 133

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



142
143
144
# File 'lib/oci/waf/models/protection_capability.rb', line 142

def hash
  [key, version, exclusions, action_name, collaborative_action_threshold, collaborative_weights].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/waf/models/protection_capability.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



180
181
182
# File 'lib/oci/waf/models/protection_capability.rb', line 180

def to_s
  to_hash.to_s
end