Class: OCI::Waf::Models::ProtectionCapabilitySettings
- Inherits:
-
Object
- Object
- OCI::Waf::Models::ProtectionCapabilitySettings
- Defined in:
- lib/oci/waf/models/protection_capability_settings.rb
Overview
Settings for protection capabilities
Instance Attribute Summary collapse
-
#allowed_http_methods ⇒ Array<String>
List of allowed HTTP methods.
-
#max_http_request_header_length ⇒ Integer
Maximum allowed length of headers in an HTTP request.
-
#max_http_request_headers ⇒ Integer
Maximum number of headers allowed in an HTTP request.
-
#max_number_of_arguments ⇒ Integer
Maximum number of arguments allowed.
-
#max_single_argument_length ⇒ Integer
Maximum allowed length of a single argument.
-
#max_total_argument_length ⇒ Integer
Maximum allowed total length of all arguments.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProtectionCapabilitySettings
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ProtectionCapabilitySettings
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.max_number_of_arguments = attributes[:'maxNumberOfArguments'] if attributes[:'maxNumberOfArguments'] raise 'You cannot provide both :maxNumberOfArguments and :max_number_of_arguments' if attributes.key?(:'maxNumberOfArguments') && attributes.key?(:'max_number_of_arguments') self.max_number_of_arguments = attributes[:'max_number_of_arguments'] if attributes[:'max_number_of_arguments'] self.max_single_argument_length = attributes[:'maxSingleArgumentLength'] if attributes[:'maxSingleArgumentLength'] raise 'You cannot provide both :maxSingleArgumentLength and :max_single_argument_length' if attributes.key?(:'maxSingleArgumentLength') && attributes.key?(:'max_single_argument_length') self.max_single_argument_length = attributes[:'max_single_argument_length'] if attributes[:'max_single_argument_length'] self.max_total_argument_length = attributes[:'maxTotalArgumentLength'] if attributes[:'maxTotalArgumentLength'] raise 'You cannot provide both :maxTotalArgumentLength and :max_total_argument_length' if attributes.key?(:'maxTotalArgumentLength') && attributes.key?(:'max_total_argument_length') self.max_total_argument_length = attributes[:'max_total_argument_length'] if attributes[:'max_total_argument_length'] self.max_http_request_headers = attributes[:'maxHttpRequestHeaders'] if attributes[:'maxHttpRequestHeaders'] raise 'You cannot provide both :maxHttpRequestHeaders and :max_http_request_headers' if attributes.key?(:'maxHttpRequestHeaders') && attributes.key?(:'max_http_request_headers') self.max_http_request_headers = attributes[:'max_http_request_headers'] if attributes[:'max_http_request_headers'] self.max_http_request_header_length = attributes[:'maxHttpRequestHeaderLength'] if attributes[:'maxHttpRequestHeaderLength'] raise 'You cannot provide both :maxHttpRequestHeaderLength and :max_http_request_header_length' if attributes.key?(:'maxHttpRequestHeaderLength') && attributes.key?(:'max_http_request_header_length') self.max_http_request_header_length = attributes[:'max_http_request_header_length'] if attributes[:'max_http_request_header_length'] self.allowed_http_methods = attributes[:'allowedHttpMethods'] if attributes[:'allowedHttpMethods'] raise 'You cannot provide both :allowedHttpMethods and :allowed_http_methods' if attributes.key?(:'allowedHttpMethods') && attributes.key?(:'allowed_http_methods') self.allowed_http_methods = attributes[:'allowed_http_methods'] if attributes[:'allowed_http_methods'] end |
Instance Attribute Details
#allowed_http_methods ⇒ Array<String>
List of allowed HTTP methods. Each value as a RFC7230 formated token string. Used in protection capability 911100: Restrict HTTP Request Methods.
40 41 42 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 40 def allowed_http_methods @allowed_http_methods end |
#max_http_request_header_length ⇒ Integer
Maximum allowed length of headers in an HTTP request. Used in protection capability: 9200024: Limit length of request header size.
34 35 36 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 34 def max_http_request_header_length @max_http_request_header_length end |
#max_http_request_headers ⇒ Integer
Maximum number of headers allowed in an HTTP request. Used in protection capability 9200014: Limit Number of Request Headers.
29 30 31 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 29 def max_http_request_headers @max_http_request_headers end |
#max_number_of_arguments ⇒ Integer
Maximum number of arguments allowed. Used in protection capability 920380: Number of Arguments Limits.
14 15 16 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 14 def max_number_of_arguments @max_number_of_arguments end |
#max_single_argument_length ⇒ Integer
Maximum allowed length of a single argument. Used in protection capability 920370: Limit argument value length.
19 20 21 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 19 def max_single_argument_length @max_single_argument_length end |
#max_total_argument_length ⇒ Integer
Maximum allowed total length of all arguments. Used in protection capability 920390: Limit arguments total length.
24 25 26 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 24 def max_total_argument_length @max_total_argument_length end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'max_number_of_arguments': :'maxNumberOfArguments', 'max_single_argument_length': :'maxSingleArgumentLength', 'max_total_argument_length': :'maxTotalArgumentLength', 'max_http_request_headers': :'maxHttpRequestHeaders', 'max_http_request_header_length': :'maxHttpRequestHeaderLength', 'allowed_http_methods': :'allowedHttpMethods' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'max_number_of_arguments': :'Integer', 'max_single_argument_length': :'Integer', 'max_total_argument_length': :'Integer', 'max_http_request_headers': :'Integer', 'max_http_request_header_length': :'Integer', 'allowed_http_methods': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 132 def ==(other) return true if equal?(other) self.class == other.class && max_number_of_arguments == other.max_number_of_arguments && max_single_argument_length == other.max_single_argument_length && max_total_argument_length == other.max_total_argument_length && max_http_request_headers == other.max_http_request_headers && max_http_request_header_length == other.max_http_request_header_length && allowed_http_methods == other.allowed_http_methods end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 167 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
147 148 149 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 147 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 156 def hash [max_number_of_arguments, max_single_argument_length, max_total_argument_length, max_http_request_headers, max_http_request_header_length, allowed_http_methods].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
194 195 196 |
# File 'lib/oci/waf/models/protection_capability_settings.rb', line 194 def to_s to_hash.to_s end |