Class: OCI::Waf::Models::ProtectionRule
- Inherits:
-
WebAppFirewallPolicyRule
- Object
- WebAppFirewallPolicyRule
- OCI::Waf::Models::ProtectionRule
- Defined in:
- lib/oci/waf/models/protection_rule.rb
Overview
Rule that represents Request/Response Protection. Only actions of the following types are allowed to be referenced in this rule:
* CHECK
* RETURN_HTTP_RESPONSE
Constant Summary
Constants inherited from WebAppFirewallPolicyRule
WebAppFirewallPolicyRule::CONDITION_LANGUAGE_ENUM, WebAppFirewallPolicyRule::TYPE_ENUM
Instance Attribute Summary collapse
-
#is_body_inspection_enabled ⇒ BOOLEAN
Enables/disables body inspection for this protection rule.
-
#protection_capabilities ⇒ Array<OCI::Waf::Models::ProtectionCapability>
**[Required]** An ordered list that references OCI-managed protection capabilities.
- #protection_capability_settings ⇒ OCI::Waf::Models::ProtectionCapabilitySettings
Attributes inherited from WebAppFirewallPolicyRule
#action_name, #condition, #condition_language, #name, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProtectionRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from WebAppFirewallPolicyRule
Constructor Details
#initialize(attributes = {}) ⇒ ProtectionRule
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/waf/models/protection_rule.rb', line 79 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'PROTECTION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.protection_capabilities = attributes[:'protectionCapabilities'] if attributes[:'protectionCapabilities'] raise 'You cannot provide both :protectionCapabilities and :protection_capabilities' if attributes.key?(:'protectionCapabilities') && attributes.key?(:'protection_capabilities') self.protection_capabilities = attributes[:'protection_capabilities'] if attributes[:'protection_capabilities'] self.protection_capability_settings = attributes[:'protectionCapabilitySettings'] if attributes[:'protectionCapabilitySettings'] raise 'You cannot provide both :protectionCapabilitySettings and :protection_capability_settings' if attributes.key?(:'protectionCapabilitySettings') && attributes.key?(:'protection_capability_settings') self.protection_capability_settings = attributes[:'protection_capability_settings'] if attributes[:'protection_capability_settings'] self.is_body_inspection_enabled = attributes[:'isBodyInspectionEnabled'] unless attributes[:'isBodyInspectionEnabled'].nil? self.is_body_inspection_enabled = false if is_body_inspection_enabled.nil? && !attributes.key?(:'isBodyInspectionEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isBodyInspectionEnabled and :is_body_inspection_enabled' if attributes.key?(:'isBodyInspectionEnabled') && attributes.key?(:'is_body_inspection_enabled') self.is_body_inspection_enabled = attributes[:'is_body_inspection_enabled'] unless attributes[:'is_body_inspection_enabled'].nil? self.is_body_inspection_enabled = false if is_body_inspection_enabled.nil? && !attributes.key?(:'isBodyInspectionEnabled') && !attributes.key?(:'is_body_inspection_enabled') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#is_body_inspection_enabled ⇒ BOOLEAN
Enables/disables body inspection for this protection rule. Only Protection Rules in RequestProtection can have this option enabled. Response body inspection will be available at a later date.
32 33 34 |
# File 'lib/oci/waf/models/protection_rule.rb', line 32 def is_body_inspection_enabled @is_body_inspection_enabled end |
#protection_capabilities ⇒ Array<OCI::Waf::Models::ProtectionCapability>
**[Required]** An ordered list that references OCI-managed protection capabilities. Referenced protection capabilities are not necessarily executed in order of appearance. Their execution order is decided at runtime for improved performance. The array cannot contain entries with the same pair of capability key and version more than once.
22 23 24 |
# File 'lib/oci/waf/models/protection_rule.rb', line 22 def protection_capabilities @protection_capabilities end |
#protection_capability_settings ⇒ OCI::Waf::Models::ProtectionCapabilitySettings
25 26 27 |
# File 'lib/oci/waf/models/protection_rule.rb', line 25 def protection_capability_settings @protection_capability_settings end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/waf/models/protection_rule.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'name': :'name', 'condition_language': :'conditionLanguage', 'condition': :'condition', 'action_name': :'actionName', 'protection_capabilities': :'protectionCapabilities', 'protection_capability_settings': :'protectionCapabilitySettings', 'is_body_inspection_enabled': :'isBodyInspectionEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/waf/models/protection_rule.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'name': :'String', 'condition_language': :'String', 'condition': :'String', 'action_name': :'String', 'protection_capabilities': :'Array<OCI::Waf::Models::ProtectionCapability>', 'protection_capability_settings': :'OCI::Waf::Models::ProtectionCapabilitySettings', 'is_body_inspection_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/waf/models/protection_rule.rb', line 117 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && name == other.name && condition_language == other.condition_language && condition == other.condition && action_name == other.action_name && protection_capabilities == other.protection_capabilities && protection_capability_settings == other.protection_capability_settings && is_body_inspection_enabled == other.is_body_inspection_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/waf/models/protection_rule.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/waf/models/protection_rule.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/waf/models/protection_rule.rb', line 143 def hash [type, name, condition_language, condition, action_name, protection_capabilities, protection_capability_settings, is_body_inspection_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/waf/models/protection_rule.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/waf/models/protection_rule.rb', line 181 def to_s to_hash.to_s end |