Class: OCI::Waf::Models::RequestProtection

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/waf/models/request_protection.rb

Overview

Module that allows to enable OCI-managed protection capabilities for incoming HTTP requests.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RequestProtection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/oci/waf/models/request_protection.rb', line 66

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.rules = attributes[:'rules'] if attributes[:'rules']

  self.body_inspection_size_limit_in_bytes = attributes[:'bodyInspectionSizeLimitInBytes'] if attributes[:'bodyInspectionSizeLimitInBytes']

  raise 'You cannot provide both :bodyInspectionSizeLimitInBytes and :body_inspection_size_limit_in_bytes' if attributes.key?(:'bodyInspectionSizeLimitInBytes') && attributes.key?(:'body_inspection_size_limit_in_bytes')

  self.body_inspection_size_limit_in_bytes = attributes[:'body_inspection_size_limit_in_bytes'] if attributes[:'body_inspection_size_limit_in_bytes']

  self.body_inspection_size_limit_exceeded_action_name = attributes[:'bodyInspectionSizeLimitExceededActionName'] if attributes[:'bodyInspectionSizeLimitExceededActionName']

  raise 'You cannot provide both :bodyInspectionSizeLimitExceededActionName and :body_inspection_size_limit_exceeded_action_name' if attributes.key?(:'bodyInspectionSizeLimitExceededActionName') && attributes.key?(:'body_inspection_size_limit_exceeded_action_name')

  self.body_inspection_size_limit_exceeded_action_name = attributes[:'body_inspection_size_limit_exceeded_action_name'] if attributes[:'body_inspection_size_limit_exceeded_action_name']
end

Instance Attribute Details

#body_inspection_size_limit_exceeded_action_nameString

References action by name from actions defined in WebAppFirewallPolicy. Executed if HTTP message body size exceeds limit set in field `bodyInspectionSizeLimitInBytes`.

If this field is `null` HTTP message body will inspected up to `bodyInspectionSizeLimitInBytes` and the rest will not be inspected by Protection Capabilities.

Allowed action types:

  • *RETURN_HTTP_RESPONSE* terminates further execution of modules and rules and returns defined HTTP response.

Returns:

  • (String)


33
34
35
# File 'lib/oci/waf/models/request_protection.rb', line 33

def body_inspection_size_limit_exceeded_action_name
  @body_inspection_size_limit_exceeded_action_name
end

#body_inspection_size_limit_in_bytesInteger

Maximum size of inspected HTTP message body in bytes. Actions to take if this limit is exceeded are defined in `bodyInspectionSizeLimitExceededActionName`.

Body inspection maximum size allowed is defined with per-tenancy limit: 8192 bytes.

Returns:

  • (Integer)


21
22
23
# File 'lib/oci/waf/models/request_protection.rb', line 21

def body_inspection_size_limit_in_bytes
  @body_inspection_size_limit_in_bytes
end

#rulesArray<OCI::Waf::Models::ProtectionRule>

Ordered list of ProtectionRules. Rules are executed in order of appearance in this array. ProtectionRules in this array can only use protection Capabilities of REQUEST_PROTECTION_CAPABILITY type.



14
15
16
# File 'lib/oci/waf/models/request_protection.rb', line 14

def rules
  @rules
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
# File 'lib/oci/waf/models/request_protection.rb', line 36

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'rules': :'rules',
    'body_inspection_size_limit_in_bytes': :'bodyInspectionSizeLimitInBytes',
    'body_inspection_size_limit_exceeded_action_name': :'bodyInspectionSizeLimitExceededActionName'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
55
# File 'lib/oci/waf/models/request_protection.rb', line 47

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'rules': :'Array<OCI::Waf::Models::ProtectionRule>',
    'body_inspection_size_limit_in_bytes': :'Integer',
    'body_inspection_size_limit_exceeded_action_name': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



94
95
96
97
98
99
100
101
# File 'lib/oci/waf/models/request_protection.rb', line 94

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    rules == other.rules &&
    body_inspection_size_limit_in_bytes == other.body_inspection_size_limit_in_bytes &&
    body_inspection_size_limit_exceeded_action_name == other.body_inspection_size_limit_exceeded_action_name
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/oci/waf/models/request_protection.rb', line 126

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


106
107
108
# File 'lib/oci/waf/models/request_protection.rb', line 106

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



115
116
117
# File 'lib/oci/waf/models/request_protection.rb', line 115

def hash
  [rules, body_inspection_size_limit_in_bytes, body_inspection_size_limit_exceeded_action_name].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/waf/models/request_protection.rb', line 159

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



153
154
155
# File 'lib/oci/waf/models/request_protection.rb', line 153

def to_s
  to_hash.to_s
end