Class: OCI::Adm::Models::VulnerabilityAudit
- Inherits:
-
Object
- Object
- OCI::Adm::Models::VulnerabilityAudit
- Defined in:
- lib/oci/adm/models/vulnerability_audit.rb
Overview
A Vulnerability Audit associates the Application Dependencies of a project with their associated vulnerabilities. Each Vulnerability is associated with a score (Common Vulnerability Scoring System V2 or V3).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- BUILD_TYPE_ENUM =
[ BUILD_TYPE_MAVEN = 'MAVEN'.freeze, BUILD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#build_type ⇒ String
**[Required]** The type of the build tool.
-
#compartment_id ⇒ String
**[Required]** The Oracle Cloud identifier ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.
- #configuration ⇒ OCI::Adm::Models::VulnerabilityAuditConfiguration
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The name of the Vulnerability Audit.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The Oracle Cloud identifier ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the Vulnerability Audit.
-
#is_success ⇒ BOOLEAN
Indicates if an audit succeeded according to the configuration.
-
#knowledge_base_id ⇒ String
**[Required]** The Oracle Cloud identifier ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
-
#lifecycle_state ⇒ String
**[Required]** The current lifecycle state of the Vulnerability Audit.
-
#max_observed_cvss_v2_score ⇒ Float
**[Required]** Maximum Common Vulnerability Scoring System Version 2 score of vulnerabilities.
-
#max_observed_cvss_v3_score ⇒ Float
**[Required]** Maximum Common Vulnerability Scoring System Version 3 score of vulnerabilities.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The creation date and time of the Vulnerability Audit (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).
-
#time_updated ⇒ DateTime
**[Required]** The update date and time of the Vulnerability Audit (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).
-
#vulnerabilities ⇒ Array<OCI::Adm::Models::Vulnerability>
**[Required]** List of vulnerabilities found in the Vulnerability Audit.
-
#vulnerable_artifacts_count ⇒ Integer
**[Required]** Count of vulnerable artifacts.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VulnerabilityAudit
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VulnerabilityAudit
Initializes the object
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 173 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.knowledge_base_id = attributes[:'knowledgeBaseId'] if attributes[:'knowledgeBaseId'] raise 'You cannot provide both :knowledgeBaseId and :knowledge_base_id' if attributes.key?(:'knowledgeBaseId') && attributes.key?(:'knowledge_base_id') self.knowledge_base_id = attributes[:'knowledge_base_id'] if attributes[:'knowledge_base_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.vulnerabilities = attributes[:'vulnerabilities'] if attributes[:'vulnerabilities'] self.max_observed_cvss_v2_score = attributes[:'maxObservedCvssV2Score'] if attributes[:'maxObservedCvssV2Score'] raise 'You cannot provide both :maxObservedCvssV2Score and :max_observed_cvss_v2_score' if attributes.key?(:'maxObservedCvssV2Score') && attributes.key?(:'max_observed_cvss_v2_score') self.max_observed_cvss_v2_score = attributes[:'max_observed_cvss_v2_score'] if attributes[:'max_observed_cvss_v2_score'] self.max_observed_cvss_v3_score = attributes[:'maxObservedCvssV3Score'] if attributes[:'maxObservedCvssV3Score'] raise 'You cannot provide both :maxObservedCvssV3Score and :max_observed_cvss_v3_score' if attributes.key?(:'maxObservedCvssV3Score') && attributes.key?(:'max_observed_cvss_v3_score') self.max_observed_cvss_v3_score = attributes[:'max_observed_cvss_v3_score'] if attributes[:'max_observed_cvss_v3_score'] self.vulnerable_artifacts_count = attributes[:'vulnerableArtifactsCount'] if attributes[:'vulnerableArtifactsCount'] raise 'You cannot provide both :vulnerableArtifactsCount and :vulnerable_artifacts_count' if attributes.key?(:'vulnerableArtifactsCount') && attributes.key?(:'vulnerable_artifacts_count') self.vulnerable_artifacts_count = attributes[:'vulnerable_artifacts_count'] if attributes[:'vulnerable_artifacts_count'] self.configuration = attributes[:'configuration'] if attributes[:'configuration'] self.is_success = attributes[:'isSuccess'] unless attributes[:'isSuccess'].nil? raise 'You cannot provide both :isSuccess and :is_success' if attributes.key?(:'isSuccess') && attributes.key?(:'is_success') self.is_success = attributes[:'is_success'] unless attributes[:'is_success'].nil? self.build_type = attributes[:'buildType'] if attributes[:'buildType'] raise 'You cannot provide both :buildType and :build_type' if attributes.key?(:'buildType') && attributes.key?(:'build_type') self.build_type = attributes[:'build_type'] if attributes[:'build_type'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#build_type ⇒ String
**[Required]** The type of the build tool.
76 77 78 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 76 def build_type @build_type end |
#compartment_id ⇒ String
**[Required]** The Oracle Cloud identifier ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.
80 81 82 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 80 def compartment_id @compartment_id end |
#configuration ⇒ OCI::Adm::Models::VulnerabilityAuditConfiguration
68 69 70 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 68 def configuration @configuration end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
92 93 94 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 92 def @defined_tags end |
#display_name ⇒ String
The name of the Vulnerability Audit.
33 34 35 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 33 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
86 87 88 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 86 def @freeform_tags end |
#id ⇒ String
**[Required]** The Oracle Cloud identifier ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the Vulnerability Audit.
29 30 31 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 29 def id @id end |
#is_success ⇒ BOOLEAN
Indicates if an audit succeeded according to the configuration. The value is `null` if the audit is in the `CREATING` state.
72 73 74 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 72 def is_success @is_success end |
#knowledge_base_id ⇒ String
**[Required]** The Oracle Cloud identifier ([OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
37 38 39 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 37 def knowledge_base_id @knowledge_base_id end |
#lifecycle_state ⇒ String
**[Required]** The current lifecycle state of the Vulnerability Audit.
49 50 51 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 49 def lifecycle_state @lifecycle_state end |
#max_observed_cvss_v2_score ⇒ Float
**[Required]** Maximum Common Vulnerability Scoring System Version 2 score of vulnerabilities.
57 58 59 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 57 def max_observed_cvss_v2_score @max_observed_cvss_v2_score end |
#max_observed_cvss_v3_score ⇒ Float
**[Required]** Maximum Common Vulnerability Scoring System Version 3 score of vulnerabilities.
61 62 63 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 61 def max_observed_cvss_v3_score @max_observed_cvss_v3_score end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
98 99 100 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 98 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The creation date and time of the Vulnerability Audit (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).
41 42 43 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 41 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The update date and time of the Vulnerability Audit (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).
45 46 47 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 45 def time_updated @time_updated end |
#vulnerabilities ⇒ Array<OCI::Adm::Models::Vulnerability>
**[Required]** List of vulnerabilities found in the Vulnerability Audit.
53 54 55 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 53 def vulnerabilities @vulnerabilities end |
#vulnerable_artifacts_count ⇒ Integer
**[Required]** Count of vulnerable artifacts.
65 66 67 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 65 def vulnerable_artifacts_count @vulnerable_artifacts_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 101 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'knowledge_base_id': :'knowledgeBaseId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'vulnerabilities': :'vulnerabilities', 'max_observed_cvss_v2_score': :'maxObservedCvssV2Score', 'max_observed_cvss_v3_score': :'maxObservedCvssV3Score', 'vulnerable_artifacts_count': :'vulnerableArtifactsCount', 'configuration': :'configuration', 'is_success': :'isSuccess', 'build_type': :'buildType', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 126 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'knowledge_base_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'vulnerabilities': :'Array<OCI::Adm::Models::Vulnerability>', 'max_observed_cvss_v2_score': :'Float', 'max_observed_cvss_v3_score': :'Float', 'vulnerable_artifacts_count': :'Integer', 'configuration': :'OCI::Adm::Models::VulnerabilityAuditConfiguration', 'is_success': :'BOOLEAN', 'build_type': :'String', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 303 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && knowledge_base_id == other.knowledge_base_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && vulnerabilities == other.vulnerabilities && max_observed_cvss_v2_score == other.max_observed_cvss_v2_score && max_observed_cvss_v3_score == other.max_observed_cvss_v3_score && vulnerable_artifacts_count == other.vulnerable_artifacts_count && configuration == other.configuration && is_success == other.is_success && build_type == other.build_type && compartment_id == other.compartment_id && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 349 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
329 330 331 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 329 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
338 339 340 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 338 def hash [id, display_name, knowledge_base_id, time_created, time_updated, lifecycle_state, vulnerabilities, max_observed_cvss_v2_score, max_observed_cvss_v3_score, vulnerable_artifacts_count, configuration, is_success, build_type, compartment_id, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
382 383 384 385 386 387 388 389 390 391 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 382 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
376 377 378 |
# File 'lib/oci/adm/models/vulnerability_audit.rb', line 376 def to_s to_hash.to_s end |