Class: OCI::AiLanguage::AIServiceLanguageClient
- Inherits:
-
Object
- Object
- OCI::AiLanguage::AIServiceLanguageClient
- Defined in:
- lib/oci/ai_language/ai_service_language_client.rb
Overview
OCI AI Service solutions can help Enterprise customers integrate AI into their products immediately using our proven,
pre-trained and custom models or containers, without a need to set up an house team of AI and ML experts.
This allows enterprises to focus on business drivers and development work rather than AI and ML operations, which shortens the time to market.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#detect_dominant_language(detect_dominant_language_details, opts = {}) ⇒ Response
Make a detect call to language detection pre-deployed model.
-
#detect_language_entities(detect_language_entities_details, opts = {}) ⇒ Response
Make a detect call to enitiy pre-deployed model.
-
#detect_language_key_phrases(detect_language_key_phrases_details, opts = {}) ⇒ Response
Make a detect call to the keyPhrase pre-deployed model.
-
#detect_language_sentiments(detect_language_sentiments_details, opts = {}) ⇒ Response
Make a detect call to sentiment pre-deployed model.
-
#detect_language_text_classification(detect_language_text_classification_details, opts = {}) ⇒ Response
Make a detect call to text classification from the pre-deployed model.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ AIServiceLanguageClient
constructor
Creates a new AIServiceLanguageClient.
-
#logger ⇒ Logger
The logger for this client.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ AIServiceLanguageClient
Creates a new AIServiceLanguageClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 55 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20210101' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "AIServiceLanguageClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
15 16 17 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 15 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
19 20 21 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 19 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
29 30 31 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 29 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
25 26 27 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 25 def retry_config @retry_config end |
Instance Method Details
#detect_dominant_language(detect_dominant_language_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ailanguage/detect_dominant_language.rb.html) to see an example of how to use detect_dominant_language API.
Make a detect call to language detection pre-deployed model.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 114 def detect_dominant_language(detect_dominant_language_details, opts = {}) logger.debug 'Calling operation AIServiceLanguageClient#detect_dominant_language.' if logger raise "Missing the required parameter 'detect_dominant_language_details' when calling detect_dominant_language." if detect_dominant_language_details.nil? path = '/actions/detectDominantLanguage' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(detect_dominant_language_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'AIServiceLanguageClient#detect_dominant_language') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::AiLanguage::Models::DetectDominantLanguageResult' ) end # rubocop:enable Metrics/BlockLength end |
#detect_language_entities(detect_language_entities_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ailanguage/detect_language_entities.rb.html) to see an example of how to use detect_language_entities API.
Make a detect call to enitiy pre-deployed model
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 174 def detect_language_entities(detect_language_entities_details, opts = {}) logger.debug 'Calling operation AIServiceLanguageClient#detect_language_entities.' if logger raise "Missing the required parameter 'detect_language_entities_details' when calling detect_language_entities." if detect_language_entities_details.nil? if opts[:model_version] && !OCI::AiLanguage::Models::NER_MODEL_VERSION_ENUM.include?(opts[:model_version]) raise 'Invalid value for "model_version", must be one of the values in OCI::AiLanguage::Models::NER_MODEL_VERSION_ENUM.' end path = '/actions/detectLanguageEntities' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:modelVersion] = opts[:model_version] if opts[:model_version] query_params[:isPii] = opts[:is_pii] if !opts[:is_pii].nil? # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(detect_language_entities_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'AIServiceLanguageClient#detect_language_entities') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::AiLanguage::Models::DetectLanguageEntitiesResult' ) end # rubocop:enable Metrics/BlockLength end |
#detect_language_key_phrases(detect_language_key_phrases_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ailanguage/detect_language_key_phrases.rb.html) to see an example of how to use detect_language_key_phrases API.
Make a detect call to the keyPhrase pre-deployed model.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 236 def detect_language_key_phrases(detect_language_key_phrases_details, opts = {}) logger.debug 'Calling operation AIServiceLanguageClient#detect_language_key_phrases.' if logger raise "Missing the required parameter 'detect_language_key_phrases_details' when calling detect_language_key_phrases." if detect_language_key_phrases_details.nil? path = '/actions/detectLanguageKeyPhrases' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(detect_language_key_phrases_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'AIServiceLanguageClient#detect_language_key_phrases') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::AiLanguage::Models::DetectLanguageKeyPhrasesResult' ) end # rubocop:enable Metrics/BlockLength end |
#detect_language_sentiments(detect_language_sentiments_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ailanguage/detect_language_sentiments.rb.html) to see an example of how to use detect_language_sentiments API.
Make a detect call to sentiment pre-deployed model.
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 292 def detect_language_sentiments(detect_language_sentiments_details, opts = {}) logger.debug 'Calling operation AIServiceLanguageClient#detect_language_sentiments.' if logger raise "Missing the required parameter 'detect_language_sentiments_details' when calling detect_language_sentiments." if detect_language_sentiments_details.nil? path = '/actions/detectLanguageSentiments' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(detect_language_sentiments_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'AIServiceLanguageClient#detect_language_sentiments') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::AiLanguage::Models::DetectLanguageSentimentsResult' ) end # rubocop:enable Metrics/BlockLength end |
#detect_language_text_classification(detect_language_text_classification_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ailanguage/detect_language_text_classification.rb.html) to see an example of how to use detect_language_text_classification API.
Make a detect call to text classification from the pre-deployed model.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 347 def detect_language_text_classification(detect_language_text_classification_details, opts = {}) logger.debug 'Calling operation AIServiceLanguageClient#detect_language_text_classification.' if logger raise "Missing the required parameter 'detect_language_text_classification_details' when calling detect_language_text_classification." if detect_language_text_classification_details.nil? path = '/actions/detectLanguageTextClassification' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(detect_language_text_classification_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'AIServiceLanguageClient#detect_language_text_classification') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::AiLanguage::Models::DetectLanguageTextClassificationResult' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
94 95 96 |
# File 'lib/oci/ai_language/ai_service_language_client.rb', line 94 def logger @api_client.config.logger end |