Class: OCI::Analytics::Models::AnalyticsInstance
- Inherits:
-
Object
- Object
- OCI::Analytics::Models::AnalyticsInstance
- Defined in:
- lib/oci/analytics/models/analytics_instance.rb
Overview
Analytics Instance metadata.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- FEATURE_SET_ENUM =
[ FEATURE_SET_SELF_SERVICE_ANALYTICS = 'SELF_SERVICE_ANALYTICS'.freeze, FEATURE_SET_ENTERPRISE_ANALYTICS = 'ENTERPRISE_ANALYTICS'.freeze, FEATURE_SET_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LICENSE_TYPE_ENUM =
[ LICENSE_TYPE_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_TYPE_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze, LICENSE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#capacity ⇒ OCI::Analytics::Models::Capacity
This attribute is required.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Optional description.
-
#email_notification ⇒ String
Email address receiving notifications.
-
#feature_set ⇒ String
**[Required]** Analytics feature set.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The resource OCID.
-
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the OCI Vault Key encrypting the customer data stored in this Analytics instance.
-
#license_type ⇒ String
The license used for the service.
-
#lifecycle_state ⇒ String
**[Required]** The current state of an instance.
-
#name ⇒ String
**[Required]** The name of the Analytics instance.
-
#network_endpoint_details ⇒ OCI::Analytics::Models::NetworkEndpointDetails
This attribute is required.
-
#private_access_channels ⇒ Hash<String, OCI::Analytics::Models::PrivateAccessChannel>
Map of PrivateAccessChannel unique identifier key as KEY and PrivateAccessChannel Object as VALUE.
-
#service_url ⇒ String
URL of the Analytics service.
-
#time_created ⇒ DateTime
**[Required]** The date and time the instance was created, in the format defined by RFC3339.
-
#time_updated ⇒ DateTime
The date and time the instance was last updated (in the format defined by RFC3339).
-
#vanity_url_details ⇒ Hash<String, OCI::Analytics::Models::VanityUrlDetails>
Map of VanityUrl unique identifier key as KEY and VanityUrl Object as VALUE.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnalyticsInstance
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AnalyticsInstance
Initializes the object
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 209 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.feature_set = attributes[:'featureSet'] if attributes[:'featureSet'] raise 'You cannot provide both :featureSet and :feature_set' if attributes.key?(:'featureSet') && attributes.key?(:'feature_set') self.feature_set = attributes[:'feature_set'] if attributes[:'feature_set'] self.capacity = attributes[:'capacity'] if attributes[:'capacity'] self.license_type = attributes[:'licenseType'] if attributes[:'licenseType'] raise 'You cannot provide both :licenseType and :license_type' if attributes.key?(:'licenseType') && attributes.key?(:'license_type') self.license_type = attributes[:'license_type'] if attributes[:'license_type'] self.email_notification = attributes[:'emailNotification'] if attributes[:'emailNotification'] raise 'You cannot provide both :emailNotification and :email_notification' if attributes.key?(:'emailNotification') && attributes.key?(:'email_notification') self.email_notification = attributes[:'email_notification'] if attributes[:'email_notification'] self.network_endpoint_details = attributes[:'networkEndpointDetails'] if attributes[:'networkEndpointDetails'] raise 'You cannot provide both :networkEndpointDetails and :network_endpoint_details' if attributes.key?(:'networkEndpointDetails') && attributes.key?(:'network_endpoint_details') self.network_endpoint_details = attributes[:'network_endpoint_details'] if attributes[:'network_endpoint_details'] self.private_access_channels = attributes[:'privateAccessChannels'] if attributes[:'privateAccessChannels'] raise 'You cannot provide both :privateAccessChannels and :private_access_channels' if attributes.key?(:'privateAccessChannels') && attributes.key?(:'private_access_channels') self.private_access_channels = attributes[:'private_access_channels'] if attributes[:'private_access_channels'] self.vanity_url_details = attributes[:'vanityUrlDetails'] if attributes[:'vanityUrlDetails'] raise 'You cannot provide both :vanityUrlDetails and :vanity_url_details' if attributes.key?(:'vanityUrlDetails') && attributes.key?(:'vanity_url_details') self.vanity_url_details = attributes[:'vanity_url_details'] if attributes[:'vanity_url_details'] self.service_url = attributes[:'serviceUrl'] if attributes[:'serviceUrl'] raise 'You cannot provide both :serviceUrl and :service_url' if attributes.key?(:'serviceUrl') && attributes.key?(:'service_url') self.service_url = attributes[:'service_url'] if attributes[:'service_url'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#capacity ⇒ OCI::Analytics::Models::Capacity
This attribute is required.
67 68 69 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 67 def capacity @capacity end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment.
53 54 55 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 53 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
104 105 106 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 104 def @defined_tags end |
#description ⇒ String
Optional description.
48 49 50 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 48 def description @description end |
#email_notification ⇒ String
Email address receiving notifications.
77 78 79 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 77 def email_notification @email_notification end |
#feature_set ⇒ String
**[Required]** Analytics feature set.
63 64 65 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 63 def feature_set @feature_set end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
112 113 114 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 112 def @freeform_tags end |
#id ⇒ String
**[Required]** The resource OCID.
38 39 40 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 38 def id @id end |
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the OCI Vault Key encrypting the customer data stored in this Analytics instance. A null value indicates Oracle managed default encryption.
117 118 119 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 117 def kms_key_id @kms_key_id end |
#license_type ⇒ String
The license used for the service.
72 73 74 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 72 def license_type @license_type end |
#lifecycle_state ⇒ String
**[Required]** The current state of an instance.
58 59 60 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 58 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** The name of the Analytics instance. This name must be unique in the tenancy and cannot be changed.
43 44 45 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 43 def name @name end |
#network_endpoint_details ⇒ OCI::Analytics::Models::NetworkEndpointDetails
This attribute is required.
81 82 83 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 81 def network_endpoint_details @network_endpoint_details end |
#private_access_channels ⇒ Hash<String, OCI::Analytics::Models::PrivateAccessChannel>
Map of PrivateAccessChannel unique identifier key as KEY and PrivateAccessChannel Object as VALUE.
86 87 88 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 86 def private_access_channels @private_access_channels end |
#service_url ⇒ String
URL of the Analytics service.
96 97 98 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 96 def service_url @service_url end |
#time_created ⇒ DateTime
**[Required]** The date and time the instance was created, in the format defined by RFC3339.
Example: `2016-08-25T21:10:29.600Z`
124 125 126 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 124 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the instance was last updated (in the format defined by RFC3339). This timestamp represents updates made through this API. External events do not influence it.
131 132 133 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 131 def time_updated @time_updated end |
#vanity_url_details ⇒ Hash<String, OCI::Analytics::Models::VanityUrlDetails>
Map of VanityUrl unique identifier key as KEY and VanityUrl Object as VALUE.
91 92 93 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 91 def vanity_url_details @vanity_url_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 134 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'description': :'description', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'feature_set': :'featureSet', 'capacity': :'capacity', 'license_type': :'licenseType', 'email_notification': :'emailNotification', 'network_endpoint_details': :'networkEndpointDetails', 'private_access_channels': :'privateAccessChannels', 'vanity_url_details': :'vanityUrlDetails', 'service_url': :'serviceUrl', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'kms_key_id': :'kmsKeyId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 160 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'description': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'feature_set': :'String', 'capacity': :'OCI::Analytics::Models::Capacity', 'license_type': :'String', 'email_notification': :'String', 'network_endpoint_details': :'OCI::Analytics::Models::NetworkEndpointDetails', 'private_access_channels': :'Hash<String, OCI::Analytics::Models::PrivateAccessChannel>', 'vanity_url_details': :'Hash<String, OCI::Analytics::Models::VanityUrlDetails>', 'service_url': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'kms_key_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 354 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && feature_set == other.feature_set && capacity == other.capacity && license_type == other.license_type && email_notification == other.email_notification && network_endpoint_details == other.network_endpoint_details && private_access_channels == other.private_access_channels && vanity_url_details == other.vanity_url_details && service_url == other.service_url && == other. && == other. && kms_key_id == other.kms_key_id && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 401 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
381 382 383 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 381 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
390 391 392 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 390 def hash [id, name, description, compartment_id, lifecycle_state, feature_set, capacity, license_type, email_notification, network_endpoint_details, private_access_channels, vanity_url_details, service_url, , , kms_key_id, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
434 435 436 437 438 439 440 441 442 443 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 434 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
428 429 430 |
# File 'lib/oci/analytics/models/analytics_instance.rb', line 428 def to_s to_hash.to_s end |