Class: OCI::Analytics::Models::WorkRequestSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/analytics/models/work_request_summary.rb

Overview

An asynchronous work request.

Constant Summary collapse

OPERATION_TYPE_ENUM =
[
  OPERATION_TYPE_CREATE_ANALYTICS_INSTANCE = 'CREATE_ANALYTICS_INSTANCE'.freeze,
  OPERATION_TYPE_DELETE_ANALYTICS_INSTANCE = 'DELETE_ANALYTICS_INSTANCE'.freeze,
  OPERATION_TYPE_START_ANALYTICS_INSTANCE = 'START_ANALYTICS_INSTANCE'.freeze,
  OPERATION_TYPE_STOP_ANALYTICS_INSTANCE = 'STOP_ANALYTICS_INSTANCE'.freeze,
  OPERATION_TYPE_SCALE_ANALYTICS_INSTANCE = 'SCALE_ANALYTICS_INSTANCE'.freeze,
  OPERATION_TYPE_CHANGE_ANALYTICS_INSTANCE_COMPARTMENT = 'CHANGE_ANALYTICS_INSTANCE_COMPARTMENT'.freeze,
  OPERATION_TYPE_CHANGE_ANALYTICS_INSTANCE_NETWORK_ENDPOINT = 'CHANGE_ANALYTICS_INSTANCE_NETWORK_ENDPOINT'.freeze,
  OPERATION_TYPE_CREATE_VANITY_URL = 'CREATE_VANITY_URL'.freeze,
  OPERATION_TYPE_UPDATE_VANITY_URL = 'UPDATE_VANITY_URL'.freeze,
  OPERATION_TYPE_DELETE_VANITY_URL = 'DELETE_VANITY_URL'.freeze,
  OPERATION_TYPE_CREATE_PRIVATE_ACCESS_CHANNEL = 'CREATE_PRIVATE_ACCESS_CHANNEL'.freeze,
  OPERATION_TYPE_UPDATE_PRIVATE_ACCESS_CHANNEL = 'UPDATE_PRIVATE_ACCESS_CHANNEL'.freeze,
  OPERATION_TYPE_DELETE_PRIVATE_ACCESS_CHANNEL = 'DELETE_PRIVATE_ACCESS_CHANNEL'.freeze,
  OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_ACCEPTED = 'ACCEPTED'.freeze,
  STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  STATUS_FAILED = 'FAILED'.freeze,
  STATUS_SUCCEEDED = 'SUCCEEDED'.freeze,
  STATUS_CANCELING = 'CANCELING'.freeze,
  STATUS_CANCELED = 'CANCELED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkRequestSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/analytics/models/work_request_summary.rb', line 130

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.operation_type = attributes[:'operationType'] if attributes[:'operationType']

  raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type')

  self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type']

  self.status = attributes[:'status'] if attributes[:'status']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.resources = attributes[:'resources'] if attributes[:'resources']

  self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted']

  raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted')

  self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']
end

Instance Attribute Details

#compartment_idString

[Required] The compartment OCID of this work request.

Returns:

  • (String)


56
57
58
# File 'lib/oci/analytics/models/work_request_summary.rb', line 56

def compartment_id
  @compartment_id
end

#idString

[Required] The resource OCID.

Returns:

  • (String)


41
42
43
# File 'lib/oci/analytics/models/work_request_summary.rb', line 41

def id
  @id
end

#operation_typeString

[Required] The operation performed by the work request.

Returns:

  • (String)


46
47
48
# File 'lib/oci/analytics/models/work_request_summary.rb', line 46

def operation_type
  @operation_type
end

#resourcesArray<OCI::Analytics::Models::WorkRequestResource>

[Required] The resources this work request affects.



61
62
63
# File 'lib/oci/analytics/models/work_request_summary.rb', line 61

def resources
  @resources
end

#statusString

[Required] The current status of the work request.

Returns:

  • (String)


51
52
53
# File 'lib/oci/analytics/models/work_request_summary.rb', line 51

def status
  @status
end

#time_acceptedDateTime

[Required] The time the work request was accepted, in the format defined by RFC3339.

Example: 2016-08-25T21:10:29.600Z

Returns:

  • (DateTime)


68
69
70
# File 'lib/oci/analytics/models/work_request_summary.rb', line 68

def time_accepted
  @time_accepted
end

#time_finishedDateTime

The time the work request was finished, in the format defined by RFC3339.

Example: 2016-08-25T21:10:29.600Z

Returns:

  • (DateTime)


82
83
84
# File 'lib/oci/analytics/models/work_request_summary.rb', line 82

def time_finished
  @time_finished
end

#time_startedDateTime

The time the work request was started, in the format defined by RFC3339.

Example: 2016-08-25T21:10:29.600Z

Returns:

  • (DateTime)


75
76
77
# File 'lib/oci/analytics/models/work_request_summary.rb', line 75

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/analytics/models/work_request_summary.rb', line 85

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'operation_type': :'operationType',
    'status': :'status',
    'compartment_id': :'compartmentId',
    'resources': :'resources',
    'time_accepted': :'timeAccepted',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/oci/analytics/models/work_request_summary.rb', line 101

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'operation_type': :'String',
    'status': :'String',
    'compartment_id': :'String',
    'resources': :'Array<OCI::Analytics::Models::WorkRequestResource>',
    'time_accepted': :'DateTime',
    'time_started': :'DateTime',
    'time_finished': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/oci/analytics/models/work_request_summary.rb', line 206

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    operation_type == other.operation_type &&
    status == other.status &&
    compartment_id == other.compartment_id &&
    resources == other.resources &&
    time_accepted == other.time_accepted &&
    time_started == other.time_started &&
    time_finished == other.time_finished
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/oci/analytics/models/work_request_summary.rb', line 243

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/oci/analytics/models/work_request_summary.rb', line 223

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



232
233
234
# File 'lib/oci/analytics/models/work_request_summary.rb', line 232

def hash
  [id, operation_type, status, compartment_id, resources, time_accepted, time_started, time_finished].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



276
277
278
279
280
281
282
283
284
285
# File 'lib/oci/analytics/models/work_request_summary.rb', line 276

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



270
271
272
# File 'lib/oci/analytics/models/work_request_summary.rb', line 270

def to_s
  to_hash.to_s
end