Class: OCI::Apigateway::Models::ExecutionLogPolicy
- Inherits:
-
Object
- Object
- OCI::Apigateway::Models::ExecutionLogPolicy
- Defined in:
- lib/oci/apigateway/models/execution_log_policy.rb
Overview
Configures the logging policies for the execution logs of an API Deployment.
Constant Summary collapse
- LOG_LEVEL_ENUM =
[ LOG_LEVEL_INFO = 'INFO'.freeze, LOG_LEVEL_WARN = 'WARN'.freeze, LOG_LEVEL_ERROR = 'ERROR'.freeze, LOG_LEVEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#is_enabled ⇒ BOOLEAN
Enables pushing of execution logs to the legacy OCI Object Storage log archival bucket.
-
#log_level ⇒ String
Specifies the log level used to control logging output of execution logs.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExecutionLogPolicy
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ExecutionLogPolicy
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 66 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? self.is_enabled = false if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_enabled = false if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals self.log_level = attributes[:'logLevel'] if attributes[:'logLevel'] self.log_level = "INFO" if log_level.nil? && !attributes.key?(:'logLevel') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :logLevel and :log_level' if attributes.key?(:'logLevel') && attributes.key?(:'log_level') self.log_level = attributes[:'log_level'] if attributes[:'log_level'] self.log_level = "INFO" if log_level.nil? && !attributes.key?(:'logLevel') && !attributes.key?(:'log_level') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#is_enabled ⇒ BOOLEAN
Enables pushing of execution logs to the legacy OCI Object Storage log archival bucket.
Oracle recommends using the OCI Logging service to enable, retrieve, and query execution logs for an API Deployment. If there is an active log object for the API Deployment and its category is set to ‘execution’ in OCI Logging service, the logs will not be uploaded to the legacy OCI Object Storage log archival bucket.
Please note that the functionality to push to the legacy OCI Object Storage log archival bucket has been deprecated and will be removed in the future.
30 31 32 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 30 def is_enabled @is_enabled end |
#log_level ⇒ String
Specifies the log level used to control logging output of execution logs. Enabling logging at a given level also enables logging at all higher levels.
36 37 38 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 36 def log_level @log_level end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'is_enabled': :'isEnabled', 'log_level': :'logLevel' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'is_enabled': :'BOOLEAN', 'log_level': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
109 110 111 112 113 114 115 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 109 def ==(other) return true if equal?(other) self.class == other.class && is_enabled == other.is_enabled && log_level == other.log_level end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 140 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
120 121 122 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 120 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
129 130 131 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 129 def hash [is_enabled, log_level].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
167 168 169 |
# File 'lib/oci/apigateway/models/execution_log_policy.rb', line 167 def to_s to_hash.to_s end |