Class: OCI::ApmConfig::Models::CreateMetricGroupDetails

Inherits:
CreateConfigDetails show all
Defined in:
lib/oci/apm_config/models/create_metric_group_details.rb

Overview

A Metric Group.

Constant Summary

Constants inherited from CreateConfigDetails

OCI::ApmConfig::Models::CreateConfigDetails::CONFIG_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from CreateConfigDetails

#config_type, #defined_tags, #freeform_tags

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from CreateConfigDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ CreateMetricGroupDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 79

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['configType'] = 'METRIC_GROUP'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.filter_id = attributes[:'filterId'] if attributes[:'filterId']

  raise 'You cannot provide both :filterId and :filter_id' if attributes.key?(:'filterId') && attributes.key?(:'filter_id')

  self.filter_id = attributes[:'filter_id'] if attributes[:'filter_id']

  self.namespace = attributes[:'namespace'] if attributes[:'namespace']

  self.dimensions = attributes[:'dimensions'] if attributes[:'dimensions']

  self.metrics = attributes[:'metrics'] if attributes[:'metrics']
end

Instance Attribute Details

#dimensionsArray<OCI::ApmConfig::Models::Dimension>

A list of dimensions for this metric



28
29
30
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 28

def dimensions
  @dimensions
end

#display_nameString

[Required] The name of this metric group

Returns:

  • (String)


14
15
16
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 14

def display_name
  @display_name
end

#filter_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of a Span Filter. The filterId is mandatory for the creation of MetricGroups. A filterId will be generated when a Span Filter is created.

Returns:

  • (String)


20
21
22
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 20

def filter_id
  @filter_id
end

#metricsArray<OCI::ApmConfig::Models::Metric>

This attribute is required.

Returns:



32
33
34
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 32

def metrics
  @metrics
end

#namespaceString

The namespace to write the metrics to

Returns:

  • (String)


24
25
26
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 24

def namespace
  @namespace
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 35

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'config_type': :'configType',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'filter_id': :'filterId',
    'namespace': :'namespace',
    'dimensions': :'dimensions',
    'metrics': :'metrics'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 51

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'config_type': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'filter_id': :'String',
    'namespace': :'String',
    'dimensions': :'Array<OCI::ApmConfig::Models::Dimension>',
    'metrics': :'Array<OCI::ApmConfig::Models::Metric>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 115

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    config_type == other.config_type &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    filter_id == other.filter_id &&
    namespace == other.namespace &&
    dimensions == other.dimensions &&
    metrics == other.metrics
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 152

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


132
133
134
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 132

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



141
142
143
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 141

def hash
  [config_type, freeform_tags, defined_tags, display_name, filter_id, namespace, dimensions, metrics].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



179
180
181
# File 'lib/oci/apm_config/models/create_metric_group_details.rb', line 179

def to_s
  to_hash.to_s
end