Class: OCI::ApplicationMigration::Models::ConfigurationField
- Inherits:
-
Object
- Object
- OCI::ApplicationMigration::Models::ConfigurationField
- Defined in:
- lib/oci/application_migration/models/configuration_field.rb
Overview
Provide configuration information about the application in the target environment. Application Migration migrates the application to the target environment only after you provide this information. The information that you must provide varies depending on the type of application that you are migrating.
Instance Attribute Summary collapse
-
#description ⇒ String
Help text to guide the user in setting the configuration value.
-
#group ⇒ String
The name of the group to which this field belongs, if any.
-
#is_mutable ⇒ BOOLEAN
Indicates whether or not the field may be modified (defaults to
true). -
#is_required ⇒ BOOLEAN
Indicates whether or not the field is required (defaults to
true). -
#name ⇒ String
The name of the configuration field.
-
#resource_list ⇒ Array<OCI::ApplicationMigration::Models::ResourceField>
A list of resources associated with a specific configuration object.
-
#type ⇒ String
The type of the configuration field.
-
#value ⇒ String
The value of the field.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConfigurationField
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConfigurationField
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.group = attributes[:'group'] if attributes[:'group'] self.type = attributes[:'type'] if attributes[:'type'] self.value = attributes[:'value'] if attributes[:'value'] self.description = attributes[:'description'] if attributes[:'description'] self.resource_list = attributes[:'resourceList'] if attributes[:'resourceList'] raise 'You cannot provide both :resourceList and :resource_list' if attributes.key?(:'resourceList') && attributes.key?(:'resource_list') self.resource_list = attributes[:'resource_list'] if attributes[:'resource_list'] self.is_required = attributes[:'isRequired'] unless attributes[:'isRequired'].nil? self.is_required = true if is_required.nil? && !attributes.key?(:'isRequired') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isRequired and :is_required' if attributes.key?(:'isRequired') && attributes.key?(:'is_required') self.is_required = attributes[:'is_required'] unless attributes[:'is_required'].nil? self.is_required = true if is_required.nil? && !attributes.key?(:'isRequired') && !attributes.key?(:'is_required') # rubocop:disable Style/StringLiterals self.is_mutable = attributes[:'isMutable'] unless attributes[:'isMutable'].nil? self.is_mutable = true if is_mutable.nil? && !attributes.key?(:'isMutable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isMutable and :is_mutable' if attributes.key?(:'isMutable') && attributes.key?(:'is_mutable') self.is_mutable = attributes[:'is_mutable'] unless attributes[:'is_mutable'].nil? self.is_mutable = true if is_mutable.nil? && !attributes.key?(:'isMutable') && !attributes.key?(:'is_mutable') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#description ⇒ String
Help text to guide the user in setting the configuration value.
31 32 33 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 31 def description @description end |
#group ⇒ String
The name of the group to which this field belongs, if any.
19 20 21 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 19 def group @group end |
#is_mutable ⇒ BOOLEAN
Indicates whether or not the field may be modified (defaults to true).
46 47 48 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 46 def is_mutable @is_mutable end |
#is_required ⇒ BOOLEAN
Indicates whether or not the field is required (defaults to true).
41 42 43 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 41 def is_required @is_required end |
#name ⇒ String
The name of the configuration field.
15 16 17 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 15 def name @name end |
#resource_list ⇒ Array<OCI::ApplicationMigration::Models::ResourceField>
A list of resources associated with a specific configuration object.
36 37 38 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 36 def resource_list @resource_list end |
#type ⇒ String
The type of the configuration field.
23 24 25 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 23 def type @type end |
#value ⇒ String
The value of the field.
27 28 29 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 27 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'group': :'group', 'type': :'type', 'value': :'value', 'description': :'description', 'resource_list': :'resourceList', 'is_required': :'isRequired', 'is_mutable': :'isMutable' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'group': :'String', 'type': :'String', 'value': :'String', 'description': :'String', 'resource_list': :'Array<OCI::ApplicationMigration::Models::ResourceField>', 'is_required': :'BOOLEAN', 'is_mutable': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 140 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && group == other.group && type == other.type && value == other.value && description == other.description && resource_list == other.resource_list && is_required == other.is_required && is_mutable == other.is_mutable end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 177 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
157 158 159 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 157 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 166 def hash [name, group, type, value, description, resource_list, is_required, is_mutable].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
204 205 206 |
# File 'lib/oci/application_migration/models/configuration_field.rb', line 204 def to_s to_hash.to_s end |