Class: ApplicationMigration::Models::Migration
- Inherits:
-
Object
- Object
- ApplicationMigration::Models::Migration
- Defined in:
- lib/oci/application_migration/models/migration.rb
Overview
The properties that define a migration. A migration represents the end-to-end workflow of moving an application from a source environment to Oracle Cloud Infrastructure. Each migration moves a single application to Oracle Cloud Infrastructure. For more information, see [Manage Migrations](docs.cloud.oracle.com/iaas/application-migration/manage_migrations.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- APPLICATION_TYPE_ENUM =
[ APPLICATION_TYPE_JCS = 'JCS'.freeze, APPLICATION_TYPE_SOACS = 'SOACS'.freeze, APPLICATION_TYPE_OIC = 'OIC'.freeze, APPLICATION_TYPE_OAC = 'OAC'.freeze, APPLICATION_TYPE_ICS = 'ICS'.freeze, APPLICATION_TYPE_PCS = 'PCS'.freeze, APPLICATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- PRE_CREATED_TARGET_DATABASE_TYPE_ENUM =
[ PRE_CREATED_TARGET_DATABASE_TYPE_DATABASE_SYSTEM = 'DATABASE_SYSTEM'.freeze, PRE_CREATED_TARGET_DATABASE_TYPE_NOT_SET = 'NOT_SET'.freeze, PRE_CREATED_TARGET_DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- MIGRATION_STATE_ENUM =
[ MIGRATION_STATE_DISCOVERING_APPLICATION = 'DISCOVERING_APPLICATION'.freeze, MIGRATION_STATE_DISCOVERY_FAILED = 'DISCOVERY_FAILED'.freeze, MIGRATION_STATE_MISSING_CONFIG_VALUES = 'MISSING_CONFIG_VALUES'.freeze, MIGRATION_STATE_READY = 'READY'.freeze, MIGRATION_STATE_MIGRATING = 'MIGRATING'.freeze, MIGRATION_STATE_MIGRATION_FAILED = 'MIGRATION_FAILED'.freeze, MIGRATION_STATE_MIGRATION_SUCCEEDED = 'MIGRATION_SUCCEEDED'.freeze, MIGRATION_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#application_config ⇒ Hash<String, OCI::ApplicationMigration::Models::ConfigurationField>
Configuration required to migrate the application.
-
#application_name ⇒ String
Name of the application which is being migrated.
-
#application_type ⇒ String
The type of application being migrated.
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the migration.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the migration.
-
#display_name ⇒ String
User-friendly name of the migration.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the migration.
-
#is_selective_migration ⇒ BOOLEAN
If set to `true`, Application Migration migrates only the application resources that you specify.
-
#lifecycle_details ⇒ String
Details about the current lifecycle state of the migration.
-
#lifecycle_state ⇒ String
The current state of the migration.
-
#migration_state ⇒ String
The current state of the overall migration process.
-
#pre_created_target_database_type ⇒ String
The pre-existing database type to be used in this migration.
-
#service_config ⇒ Hash<String, OCI::ApplicationMigration::Models::ConfigurationField>
Configuration required to migrate the application.
-
#source_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the source with which this migration is associated.
-
#time_created ⇒ DateTime
The date and time at which the migration was created, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Migration
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Migration
Initializes the object
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/oci/application_migration/models/migration.rb', line 211 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.source_id = attributes[:'sourceId'] if attributes[:'sourceId'] raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] if attributes[:'source_id'] self.application_name = attributes[:'applicationName'] if attributes[:'applicationName'] raise 'You cannot provide both :applicationName and :application_name' if attributes.key?(:'applicationName') && attributes.key?(:'application_name') self.application_name = attributes[:'application_name'] if attributes[:'application_name'] self.application_type = attributes[:'applicationType'] if attributes[:'applicationType'] raise 'You cannot provide both :applicationType and :application_type' if attributes.key?(:'applicationType') && attributes.key?(:'application_type') self.application_type = attributes[:'application_type'] if attributes[:'application_type'] self.pre_created_target_database_type = attributes[:'preCreatedTargetDatabaseType'] if attributes[:'preCreatedTargetDatabaseType'] raise 'You cannot provide both :preCreatedTargetDatabaseType and :pre_created_target_database_type' if attributes.key?(:'preCreatedTargetDatabaseType') && attributes.key?(:'pre_created_target_database_type') self.pre_created_target_database_type = attributes[:'pre_created_target_database_type'] if attributes[:'pre_created_target_database_type'] self.is_selective_migration = attributes[:'isSelectiveMigration'] unless attributes[:'isSelectiveMigration'].nil? self.is_selective_migration = false if is_selective_migration.nil? && !attributes.key?(:'isSelectiveMigration') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isSelectiveMigration and :is_selective_migration' if attributes.key?(:'isSelectiveMigration') && attributes.key?(:'is_selective_migration') self.is_selective_migration = attributes[:'is_selective_migration'] unless attributes[:'is_selective_migration'].nil? self.is_selective_migration = false if is_selective_migration.nil? && !attributes.key?(:'isSelectiveMigration') && !attributes.key?(:'is_selective_migration') # rubocop:disable Style/StringLiterals self.service_config = attributes[:'serviceConfig'] if attributes[:'serviceConfig'] raise 'You cannot provide both :serviceConfig and :service_config' if attributes.key?(:'serviceConfig') && attributes.key?(:'service_config') self.service_config = attributes[:'service_config'] if attributes[:'service_config'] self.application_config = attributes[:'applicationConfig'] if attributes[:'applicationConfig'] raise 'You cannot provide both :applicationConfig and :application_config' if attributes.key?(:'applicationConfig') && attributes.key?(:'application_config') self.application_config = attributes[:'application_config'] if attributes[:'application_config'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.migration_state = attributes[:'migrationState'] if attributes[:'migrationState'] raise 'You cannot provide both :migrationState and :migration_state' if attributes.key?(:'migrationState') && attributes.key?(:'migration_state') self.migration_state = attributes[:'migration_state'] if attributes[:'migration_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#application_config ⇒ Hash<String, OCI::ApplicationMigration::Models::ConfigurationField>
Configuration required to migrate the application. In addition to the key and value, additional fields are provided to describe type type and purpose of each field. Only the value for each key is required when passing configuration to the CreateMigration operation.
112 113 114 |
# File 'lib/oci/application_migration/models/migration.rb', line 112 def application_config @application_config end |
#application_name ⇒ String
Name of the application which is being migrated. This is the name of the application in the source environment.
83 84 85 |
# File 'lib/oci/application_migration/models/migration.rb', line 83 def application_name @application_name end |
#application_type ⇒ String
The type of application being migrated.
87 88 89 |
# File 'lib/oci/application_migration/models/migration.rb', line 87 def application_type @application_type end |
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the migration.
63 64 65 |
# File 'lib/oci/application_migration/models/migration.rb', line 63 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
136 137 138 |
# File 'lib/oci/application_migration/models/migration.rb', line 136 def @defined_tags end |
#description ⇒ String
Description of the migration.
71 72 73 |
# File 'lib/oci/application_migration/models/migration.rb', line 71 def description @description end |
#display_name ⇒ String
User-friendly name of the migration.
67 68 69 |
# File 'lib/oci/application_migration/models/migration.rb', line 67 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
130 131 132 |
# File 'lib/oci/application_migration/models/migration.rb', line 130 def @freeform_tags end |
#id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the migration.
58 59 60 |
# File 'lib/oci/application_migration/models/migration.rb', line 58 def id @id end |
#is_selective_migration ⇒ BOOLEAN
If set to `true`, Application Migration migrates only the application resources that you specify. If set to `false`, Application Migration migrates the entire application. When you migrate the entire application, all the application resources are migrated to the target environment. You can selectively migrate resources only for the Oracle Integration Cloud and Oracle Integration Cloud Service applications.
98 99 100 |
# File 'lib/oci/application_migration/models/migration.rb', line 98 def is_selective_migration @is_selective_migration end |
#lifecycle_details ⇒ String
Details about the current lifecycle state of the migration.
120 121 122 |
# File 'lib/oci/application_migration/models/migration.rb', line 120 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the migration.
116 117 118 |
# File 'lib/oci/application_migration/models/migration.rb', line 116 def lifecycle_state @lifecycle_state end |
#migration_state ⇒ String
The current state of the overall migration process.
124 125 126 |
# File 'lib/oci/application_migration/models/migration.rb', line 124 def migration_state @migration_state end |
#pre_created_target_database_type ⇒ String
The pre-existing database type to be used in this migration. Currently, Application migration only supports Oracle Cloud Infrastructure databases and this option is currently available only for `JAVA_CLOUD_SERVICE` and `WEBLOGIC_CLOUD_SERVICE` target instance types.
93 94 95 |
# File 'lib/oci/application_migration/models/migration.rb', line 93 def pre_created_target_database_type @pre_created_target_database_type end |
#service_config ⇒ Hash<String, OCI::ApplicationMigration::Models::ConfigurationField>
Configuration required to migrate the application. In addition to the key and value, additional fields are provided to describe type type and purpose of each field. Only the value for each key is required when passing configuration to the CreateMigration operation.
105 106 107 |
# File 'lib/oci/application_migration/models/migration.rb', line 105 def service_config @service_config end |
#source_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the source with which this migration is associated.
79 80 81 |
# File 'lib/oci/application_migration/models/migration.rb', line 79 def source_id @source_id end |
#time_created ⇒ DateTime
The date and time at which the migration was created, in the format defined by RFC3339.
75 76 77 |
# File 'lib/oci/application_migration/models/migration.rb', line 75 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/application_migration/models/migration.rb', line 139 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'time_created': :'timeCreated', 'source_id': :'sourceId', 'application_name': :'applicationName', 'application_type': :'applicationType', 'pre_created_target_database_type': :'preCreatedTargetDatabaseType', 'is_selective_migration': :'isSelectiveMigration', 'service_config': :'serviceConfig', 'application_config': :'applicationConfig', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'migration_state': :'migrationState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/application_migration/models/migration.rb', line 164 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'time_created': :'DateTime', 'source_id': :'String', 'application_name': :'String', 'application_type': :'String', 'pre_created_target_database_type': :'String', 'is_selective_migration': :'BOOLEAN', 'service_config': :'Hash<String, OCI::ApplicationMigration::Models::ConfigurationField>', 'application_config': :'Hash<String, OCI::ApplicationMigration::Models::ConfigurationField>', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'migration_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/oci/application_migration/models/migration.rb', line 373 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && time_created == other.time_created && source_id == other.source_id && application_name == other.application_name && application_type == other.application_type && pre_created_target_database_type == other.pre_created_target_database_type && is_selective_migration == other.is_selective_migration && service_config == other.service_config && application_config == other.application_config && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && migration_state == other.migration_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/oci/application_migration/models/migration.rb', line 419 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
399 400 401 |
# File 'lib/oci/application_migration/models/migration.rb', line 399 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
408 409 410 |
# File 'lib/oci/application_migration/models/migration.rb', line 408 def hash [id, compartment_id, display_name, description, time_created, source_id, application_name, application_type, pre_created_target_database_type, is_selective_migration, service_config, application_config, lifecycle_state, lifecycle_details, migration_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
452 453 454 455 456 457 458 459 460 461 |
# File 'lib/oci/application_migration/models/migration.rb', line 452 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
446 447 448 |
# File 'lib/oci/application_migration/models/migration.rb', line 446 def to_s to_hash.to_s end |