Class: OCI::ApplicationMigration::Models::ResourceField
- Inherits:
-
Object
- Object
- OCI::ApplicationMigration::Models::ResourceField
- Defined in:
- lib/oci/application_migration/models/resource_field.rb
Overview
Resource object that can be used to pass details about any list of resources associated with Migrations. The List of resources are added to ConfigurationField to add the capability to pass lists of resources of any type and group.
Instance Attribute Summary collapse
-
#group ⇒ String
The name of the group to which this field belongs to.
-
#name ⇒ String
The display name of the resource field.
-
#type ⇒ String
[Required] The type of the resource field.
-
#value ⇒ String
[Required] The value of the field.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourceField
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ResourceField
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.group = attributes[:'group'] if attributes[:'group'] self.type = attributes[:'type'] if attributes[:'type'] self.value = attributes[:'value'] if attributes[:'value'] end |
Instance Attribute Details
#group ⇒ String
The name of the group to which this field belongs to.
16 17 18 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 16 def group @group end |
#name ⇒ String
The display name of the resource field.
12 13 14 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 12 def name @name end |
#type ⇒ String
[Required] The type of the resource field.
20 21 22 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 20 def type @type end |
#value ⇒ String
[Required] The value of the field.
24 25 26 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 24 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'group': :'group', 'type': :'type', 'value': :'value' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'group': :'String', 'type': :'String', 'value': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 82 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && group == other.group && type == other.type && value == other.value end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 115 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
95 96 97 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 95 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
104 105 106 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 104 def hash [name, group, type, value].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 148 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
142 143 144 |
# File 'lib/oci/application_migration/models/resource_field.rb', line 142 def to_s to_hash.to_s end |