Class: OCI::ApplicationMigration::Models::SourceDetails
- Inherits:
-
Object
- Object
- OCI::ApplicationMigration::Models::SourceDetails
- Defined in:
- lib/oci/application_migration/models/source_details.rb
Overview
Specify one of the following values depending for the ‘type’ attribute based on the application that you want to migrate.
Specify OCIC if you want to migrate Oracle Java Cloud Service, Oracle Analytics Cloud - Classic, Oracle Integration, and Oracle SOA Cloud Service applications from Oracle Cloud Infrastructure - Classic.
Specify INTERNAL_COMPUTE if you have a traditional Oracle Cloud Infrastructure - Classic account and you want to migrate Oracle Process Cloud Service or Oracle Integration Cloud Service applications.
Specify OCC if you want to migrate applications from Oracle Cloud@Customer.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_OCIC = 'OCIC'.freeze, TYPE_INTERNAL_COMPUTE = 'INTERNAL_COMPUTE'.freeze, TYPE_OCC = 'OCC'.freeze, TYPE_OCIC_IDCS = 'OCIC_IDCS'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#type ⇒ String
[Required] The type of source environment.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SourceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SourceDetails
Initializes the object
76 77 78 79 80 81 82 83 |
# File 'lib/oci/application_migration/models/source_details.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] end |
Instance Attribute Details
#type ⇒ String
[Required] The type of source environment.
32 33 34 |
# File 'lib/oci/application_migration/models/source_details.rb', line 32 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 |
# File 'lib/oci/application_migration/models/source_details.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/application_migration/models/source_details.rb', line 57 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::ApplicationMigration::Models::OccSourceDetails' if type == 'OCC' return 'OCI::ApplicationMigration::Models::InternalSourceDetails' if type == 'INTERNAL_COMPUTE' return 'OCI::ApplicationMigration::Models::OcicSourceDetails' if type == 'OCIC' # TODO: Log a warning when the subtype is not found. 'OCI::ApplicationMigration::Models::SourceDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 |
# File 'lib/oci/application_migration/models/source_details.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
105 106 107 108 109 110 |
# File 'lib/oci/application_migration/models/source_details.rb', line 105 def ==(other) return true if equal?(other) self.class == other.class && type == other.type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/application_migration/models/source_details.rb', line 135 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
115 116 117 |
# File 'lib/oci/application_migration/models/source_details.rb', line 115 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
124 125 126 |
# File 'lib/oci/application_migration/models/source_details.rb', line 124 def hash [type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/application_migration/models/source_details.rb', line 168 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
162 163 164 |
# File 'lib/oci/application_migration/models/source_details.rb', line 162 def to_s to_hash.to_s end |