Class: OCI::AppmgmtControl::Models::MonitoredInstance
- Inherits:
-
Object
- Object
- OCI::AppmgmtControl::Models::MonitoredInstance
- Defined in:
- lib/oci/appmgmt_control/models/monitored_instance.rb
Overview
Description of Monitored Instance.
Constant Summary collapse
- MONITORING_STATE_ENUM =
[ MONITORING_STATE_ENABLED = 'ENABLED'.freeze, MONITORING_STATE_DISABLED = 'DISABLED'.freeze, MONITORING_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
-
#display_name ⇒ String
A user-friendly name of the monitored instance.
-
#instance_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of monitored instance.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the monitored instance.
-
#management_agent_id ⇒ String
Management Agent Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
-
#monitoring_state ⇒ String
Monitoring status.
-
#time_created ⇒ DateTime
The time the MonitoredInstance was created.
-
#time_updated ⇒ DateTime
The time the MonitoredInstance was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MonitoredInstance
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ MonitoredInstance
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 117 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.instance_id = attributes[:'instanceId'] if attributes[:'instanceId'] raise 'You cannot provide both :instanceId and :instance_id' if attributes.key?(:'instanceId') && attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] if attributes[:'instance_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.management_agent_id = attributes[:'managementAgentId'] if attributes[:'managementAgentId'] raise 'You cannot provide both :managementAgentId and :management_agent_id' if attributes.key?(:'managementAgentId') && attributes.key?(:'management_agent_id') self.management_agent_id = attributes[:'management_agent_id'] if attributes[:'management_agent_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.monitoring_state = attributes[:'monitoringState'] if attributes[:'monitoringState'] self.monitoring_state = "DISABLED" if monitoring_state.nil? && !attributes.key?(:'monitoringState') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :monitoringState and :monitoring_state' if attributes.key?(:'monitoringState') && attributes.key?(:'monitoring_state') self.monitoring_state = attributes[:'monitoring_state'] if attributes[:'monitoring_state'] self.monitoring_state = "DISABLED" if monitoring_state.nil? && !attributes.key?(:'monitoringState') && !attributes.key?(:'monitoring_state') # rubocop:disable Style/StringLiterals self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)
34 35 36 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 34 def compartment_id @compartment_id end |
#display_name ⇒ String
A user-friendly name of the monitored instance. It is binded to [Compute Instance](docs.cloud.oracle.com/Content/Compute/Concepts/computeoverview.htm). DisplayName is fetched from [Core Service API](docs.cloud.oracle.com/api/#/en/iaas/20160918/Instance/).
40 41 42 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 40 def display_name @display_name end |
#instance_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of monitored instance.
30 31 32 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 30 def instance_id @instance_id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
66 67 68 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 66 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the monitored instance.
62 63 64 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 62 def lifecycle_state @lifecycle_state end |
#management_agent_id ⇒ String
Management Agent Identifier [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm). Used to invoke manage operations on Management Agent Cloud Service.
46 47 48 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 46 def management_agent_id @management_agent_id end |
#monitoring_state ⇒ String
Monitoring status. Can be either enabled or disabled.
58 59 60 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 58 def monitoring_state @monitoring_state end |
#time_created ⇒ DateTime
The time the MonitoredInstance was created. An RFC3339 formatted datetime string
50 51 52 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 50 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the MonitoredInstance was updated. An RFC3339 formatted datetime string
54 55 56 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 54 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'instance_id': :'instanceId', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'management_agent_id': :'managementAgentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'monitoring_state': :'monitoringState', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 86 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'instance_id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'management_agent_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'monitoring_state': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 213 def ==(other) return true if equal?(other) self.class == other.class && instance_id == other.instance_id && compartment_id == other.compartment_id && display_name == other.display_name && management_agent_id == other.management_agent_id && time_created == other.time_created && time_updated == other.time_updated && monitoring_state == other.monitoring_state && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 251 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
231 232 233 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 231 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 240 def hash [instance_id, compartment_id, display_name, management_agent_id, time_created, time_updated, monitoring_state, lifecycle_state, lifecycle_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
284 285 286 287 288 289 290 291 292 293 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 284 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
278 279 280 |
# File 'lib/oci/appmgmt_control/models/monitored_instance.rb', line 278 def to_s to_hash.to_s end |