Class: OCI::Artifacts::Models::ContainerRepository
- Inherits:
-
Object
- Object
- OCI::Artifacts::Models::ContainerRepository
- Defined in:
- lib/oci/artifacts/models/container_repository.rb
Overview
Container repository metadata.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment in which the container repository exists.
-
#created_by ⇒ String
[Required] The id of the user or principal that created the resource.
-
#display_name ⇒ String
[Required] The container repository name.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container repository.
-
#image_count ⇒ Integer
[Required] Total number of images.
-
#is_immutable ⇒ BOOLEAN
[Required] Whether the repository is immutable.
-
#is_public ⇒ BOOLEAN
[Required] Whether the repository is public.
-
#layer_count ⇒ Integer
[Required] Total number of layers.
-
#layers_size_in_bytes ⇒ Integer
[Required] Total storage in bytes consumed by layers.
-
#lifecycle_state ⇒ String
[Required] The current state of the container repository.
- #readme ⇒ OCI::Artifacts::Models::ContainerRepositoryReadme
-
#time_created ⇒ DateTime
[Required] An RFC 3339 timestamp indicating when the repository was created.
-
#time_last_pushed ⇒ DateTime
An RFC 3339 timestamp indicating when an image was last pushed to the repository.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContainerRepository
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ContainerRepository
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 133 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.created_by = attributes[:'createdBy'] if attributes[:'createdBy'] raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] if attributes[:'created_by'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.image_count = attributes[:'imageCount'] if attributes[:'imageCount'] raise 'You cannot provide both :imageCount and :image_count' if attributes.key?(:'imageCount') && attributes.key?(:'image_count') self.image_count = attributes[:'image_count'] if attributes[:'image_count'] self.is_immutable = attributes[:'isImmutable'] unless attributes[:'isImmutable'].nil? raise 'You cannot provide both :isImmutable and :is_immutable' if attributes.key?(:'isImmutable') && attributes.key?(:'is_immutable') self.is_immutable = attributes[:'is_immutable'] unless attributes[:'is_immutable'].nil? self.is_public = attributes[:'isPublic'] unless attributes[:'isPublic'].nil? raise 'You cannot provide both :isPublic and :is_public' if attributes.key?(:'isPublic') && attributes.key?(:'is_public') self.is_public = attributes[:'is_public'] unless attributes[:'is_public'].nil? self.layer_count = attributes[:'layerCount'] if attributes[:'layerCount'] raise 'You cannot provide both :layerCount and :layer_count' if attributes.key?(:'layerCount') && attributes.key?(:'layer_count') self.layer_count = attributes[:'layer_count'] if attributes[:'layer_count'] self.layers_size_in_bytes = attributes[:'layersSizeInBytes'] if attributes[:'layersSizeInBytes'] raise 'You cannot provide both :layersSizeInBytes and :layers_size_in_bytes' if attributes.key?(:'layersSizeInBytes') && attributes.key?(:'layers_size_in_bytes') self.layers_size_in_bytes = attributes[:'layers_size_in_bytes'] if attributes[:'layers_size_in_bytes'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.readme = attributes[:'readme'] if attributes[:'readme'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_last_pushed = attributes[:'timeLastPushed'] if attributes[:'timeLastPushed'] raise 'You cannot provide both :timeLastPushed and :time_last_pushed' if attributes.key?(:'timeLastPushed') && attributes.key?(:'time_last_pushed') self.time_last_pushed = attributes[:'time_last_pushed'] if attributes[:'time_last_pushed'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment in which the container repository exists.
20 21 22 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 20 def compartment_id @compartment_id end |
#created_by ⇒ String
[Required] The id of the user or principal that created the resource.
24 25 26 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 24 def created_by @created_by end |
#display_name ⇒ String
[Required] The container repository name.
28 29 30 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 28 def display_name @display_name end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container repository.
Example: ocid1.containerrepo.oc1..exampleuniqueID
35 36 37 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 35 def id @id end |
#image_count ⇒ Integer
[Required] Total number of images.
39 40 41 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 39 def image_count @image_count end |
#is_immutable ⇒ BOOLEAN
[Required] Whether the repository is immutable. Images cannot be overwritten in an immutable repository.
43 44 45 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 43 def is_immutable @is_immutable end |
#is_public ⇒ BOOLEAN
[Required] Whether the repository is public. A public repository allows unauthenticated access.
47 48 49 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 47 def is_public @is_public end |
#layer_count ⇒ Integer
[Required] Total number of layers.
51 52 53 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 51 def layer_count @layer_count end |
#layers_size_in_bytes ⇒ Integer
[Required] Total storage in bytes consumed by layers.
55 56 57 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 55 def layers_size_in_bytes @layers_size_in_bytes end |
#lifecycle_state ⇒ String
[Required] The current state of the container repository.
59 60 61 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 59 def lifecycle_state @lifecycle_state end |
#readme ⇒ OCI::Artifacts::Models::ContainerRepositoryReadme
62 63 64 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 62 def readme @readme end |
#time_created ⇒ DateTime
[Required] An RFC 3339 timestamp indicating when the repository was created.
66 67 68 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 66 def time_created @time_created end |
#time_last_pushed ⇒ DateTime
An RFC 3339 timestamp indicating when an image was last pushed to the repository.
70 71 72 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 70 def time_last_pushed @time_last_pushed end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 73 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'created_by': :'createdBy', 'display_name': :'displayName', 'id': :'id', 'image_count': :'imageCount', 'is_immutable': :'isImmutable', 'is_public': :'isPublic', 'layer_count': :'layerCount', 'layers_size_in_bytes': :'layersSizeInBytes', 'lifecycle_state': :'lifecycleState', 'readme': :'readme', 'time_created': :'timeCreated', 'time_last_pushed': :'timeLastPushed' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 94 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'created_by': :'String', 'display_name': :'String', 'id': :'String', 'image_count': :'Integer', 'is_immutable': :'BOOLEAN', 'is_public': :'BOOLEAN', 'layer_count': :'Integer', 'layers_size_in_bytes': :'Integer', 'lifecycle_state': :'String', 'readme': :'OCI::Artifacts::Models::ContainerRepositoryReadme', 'time_created': :'DateTime', 'time_last_pushed': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 230 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && created_by == other.created_by && display_name == other.display_name && id == other.id && image_count == other.image_count && is_immutable == other.is_immutable && is_public == other.is_public && layer_count == other.layer_count && layers_size_in_bytes == other.layers_size_in_bytes && lifecycle_state == other.lifecycle_state && readme == other.readme && time_created == other.time_created && time_last_pushed == other.time_last_pushed end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 272 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
252 253 254 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 252 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 261 def hash [compartment_id, created_by, display_name, id, image_count, is_immutable, is_public, layer_count, layers_size_in_bytes, lifecycle_state, readme, time_created, time_last_pushed].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
299 300 301 |
# File 'lib/oci/artifacts/models/container_repository.rb', line 299 def to_s to_hash.to_s end |