Class: OCI::Artifacts::Models::RepositorySummary
- Inherits:
-
Object
- Object
- OCI::Artifacts::Models::RepositorySummary
- Defined in:
- lib/oci/artifacts/models/repository_summary.rb
Overview
Summary information for a repository. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the repository's compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#description ⇒ String
The repository description.
-
#display_name ⇒ String
**[Required]** The repository name.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the repository.
-
#is_immutable ⇒ BOOLEAN
**[Required]** Whether the repository is immutable.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the artifact repository.
-
#repository_type ⇒ String
**[Required]** The repository's supported artifact type.
-
#time_created ⇒ DateTime
**[Required]** An RFC 3339 timestamp indicating when the repository was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RepositorySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RepositorySummary
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 129 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.repository_type = attributes[:'repositoryType'] if attributes[:'repositoryType'] raise 'You cannot provide both :repositoryType and :repository_type' if attributes.key?(:'repositoryType') && attributes.key?(:'repository_type') self.repository_type = attributes[:'repository_type'] if attributes[:'repository_type'] self.description = attributes[:'description'] if attributes[:'description'] self.is_immutable = attributes[:'isImmutable'] unless attributes[:'isImmutable'].nil? raise 'You cannot provide both :isImmutable and :is_immutable' if attributes.key?(:'isImmutable') && attributes.key?(:'is_immutable') self.is_immutable = attributes[:'is_immutable'] unless attributes[:'is_immutable'].nil? self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the repository's compartment.
24 25 26 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 24 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
56 57 58 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 56 def @defined_tags end |
#description ⇒ String
The repository description.
32 33 34 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 32 def description @description end |
#display_name ⇒ String
**[Required]** The repository name.
20 21 22 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 20 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
48 49 50 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 48 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the repository.
Example: `ocid1.artifactrepository.oc1..exampleuniqueID`
16 17 18 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 16 def id @id end |
#is_immutable ⇒ BOOLEAN
**[Required]** Whether the repository is immutable. The artifacts of an immutable repository cannot be overwritten.
36 37 38 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 36 def is_immutable @is_immutable end |
#lifecycle_state ⇒ String
**[Required]** The current state of the artifact repository.
40 41 42 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 40 def lifecycle_state @lifecycle_state end |
#repository_type ⇒ String
**[Required]** The repository's supported artifact type.
28 29 30 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 28 def repository_type @repository_type end |
#time_created ⇒ DateTime
**[Required]** An RFC 3339 timestamp indicating when the repository was created.
60 61 62 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 60 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'repository_type': :'repositoryType', 'description': :'description', 'is_immutable': :'isImmutable', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
103 104 105 106 107 108 109 110 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 103 def self.get_subtype(object_hash) type = object_hash[:'repositoryType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Artifacts::Models::GenericRepositorySummary' if type == 'GENERIC' # TODO: Log a warning when the subtype is not found. 'OCI::Artifacts::Models::RepositorySummary' end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'repository_type': :'String', 'description': :'String', 'is_immutable': :'BOOLEAN', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 195 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && repository_type == other.repository_type && description == other.description && is_immutable == other.is_immutable && lifecycle_state == other.lifecycle_state && == other. && == other. && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 234 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
214 215 216 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 214 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
223 224 225 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 223 def hash [id, display_name, compartment_id, repository_type, description, is_immutable, lifecycle_state, , , time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 267 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
261 262 263 |
# File 'lib/oci/artifacts/models/repository_summary.rb', line 261 def to_s to_hash.to_s end |