Class: OCI::Bastion::Models::CreatePortForwardingSessionTargetResourceDetails
- Inherits:
-
CreateSessionTargetResourceDetails
- Object
- CreateSessionTargetResourceDetails
- OCI::Bastion::Models::CreatePortForwardingSessionTargetResourceDetails
- Defined in:
- lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb
Overview
Details about a port forwarding session for a target resource.
Constant Summary
Constants inherited from CreateSessionTargetResourceDetails
OCI::Bastion::Models::CreateSessionTargetResourceDetails::SESSION_TYPE_ENUM
Instance Attribute Summary collapse
-
#target_resource_id ⇒ String
The unique identifier (OCID) of the target resource (a Compute instance, for example) that the session connects to.
-
#target_resource_private_ip_address ⇒ String
The private IP address of the target resource that the session connects to.
Attributes inherited from CreateSessionTargetResourceDetails
#session_type, #target_resource_port
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePortForwardingSessionTargetResourceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateSessionTargetResourceDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreatePortForwardingSessionTargetResourceDetails
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 52 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['sessionType'] = 'PORT_FORWARDING' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.target_resource_id = attributes[:'targetResourceId'] if attributes[:'targetResourceId'] raise 'You cannot provide both :targetResourceId and :target_resource_id' if attributes.key?(:'targetResourceId') && attributes.key?(:'target_resource_id') self.target_resource_id = attributes[:'target_resource_id'] if attributes[:'target_resource_id'] self.target_resource_private_ip_address = attributes[:'targetResourcePrivateIpAddress'] if attributes[:'targetResourcePrivateIpAddress'] raise 'You cannot provide both :targetResourcePrivateIpAddress and :target_resource_private_ip_address' if attributes.key?(:'targetResourcePrivateIpAddress') && attributes.key?(:'target_resource_private_ip_address') self.target_resource_private_ip_address = attributes[:'target_resource_private_ip_address'] if attributes[:'target_resource_private_ip_address'] end |
Instance Attribute Details
#target_resource_id ⇒ String
The unique identifier (OCID) of the target resource (a Compute instance, for example) that the session connects to.
13 14 15 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 13 def target_resource_id @target_resource_id end |
#target_resource_private_ip_address ⇒ String
The private IP address of the target resource that the session connects to.
17 18 19 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 17 def target_resource_private_ip_address @target_resource_private_ip_address end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 27 28 29 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'session_type': :'sessionType', 'target_resource_port': :'targetResourcePort', 'target_resource_id': :'targetResourceId', 'target_resource_private_ip_address': :'targetResourcePrivateIpAddress' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 32 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'session_type': :'String', 'target_resource_port': :'Integer', 'target_resource_id': :'String', 'target_resource_private_ip_address': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 82 def ==(other) return true if equal?(other) self.class == other.class && session_type == other.session_type && target_resource_port == other.target_resource_port && target_resource_id == other.target_resource_id && target_resource_private_ip_address == other.target_resource_private_ip_address end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 115 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
95 96 97 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 95 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
104 105 106 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 104 def hash [session_type, target_resource_port, target_resource_id, target_resource_private_ip_address].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 148 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
142 143 144 |
# File 'lib/oci/bastion/models/create_port_forwarding_session_target_resource_details.rb', line 142 def to_s to_hash.to_s end |