Class: OCI::Bastion::Models::SessionSummary
- Inherits:
-
Object
- Object
- OCI::Bastion::Models::SessionSummary
- Defined in:
- lib/oci/bastion/models/session_summary.rb
Overview
Summary information for a bastion session resource.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#bastion_id ⇒ String
**[Required]** The unique identifier (OCID) of the bastion that is hosting this session.
-
#bastion_name ⇒ String
**[Required]** The name of the bastion that is hosting this session.
-
#display_name ⇒ String
The name of the session.
-
#id ⇒ String
**[Required]** The unique identifier (OCID) of the session, which can't be changed after creation.
-
#lifecycle_details ⇒ String
A message describing the current session state in more detail.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the session.
-
#session_ttl_in_seconds ⇒ Integer
**[Required]** The amount of time the session can remain active.
-
#target_resource_details ⇒ OCI::Bastion::Models::TargetResourceDetails
This attribute is required.
-
#time_created ⇒ DateTime
**[Required]** The time the session was created.
-
#time_updated ⇒ DateTime
The time the session was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SessionSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SessionSummary
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/bastion/models/session_summary.rb', line 116 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.bastion_name = attributes[:'bastionName'] if attributes[:'bastionName'] raise 'You cannot provide both :bastionName and :bastion_name' if attributes.key?(:'bastionName') && attributes.key?(:'bastion_name') self.bastion_name = attributes[:'bastion_name'] if attributes[:'bastion_name'] self.bastion_id = attributes[:'bastionId'] if attributes[:'bastionId'] raise 'You cannot provide both :bastionId and :bastion_id' if attributes.key?(:'bastionId') && attributes.key?(:'bastion_id') self.bastion_id = attributes[:'bastion_id'] if attributes[:'bastion_id'] self.target_resource_details = attributes[:'targetResourceDetails'] if attributes[:'targetResourceDetails'] raise 'You cannot provide both :targetResourceDetails and :target_resource_details' if attributes.key?(:'targetResourceDetails') && attributes.key?(:'target_resource_details') self.target_resource_details = attributes[:'target_resource_details'] if attributes[:'target_resource_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.session_ttl_in_seconds = attributes[:'sessionTtlInSeconds'] if attributes[:'sessionTtlInSeconds'] raise 'You cannot provide both :sessionTtlInSeconds and :session_ttl_in_seconds' if attributes.key?(:'sessionTtlInSeconds') && attributes.key?(:'session_ttl_in_seconds') self.session_ttl_in_seconds = attributes[:'session_ttl_in_seconds'] if attributes[:'session_ttl_in_seconds'] end |
Instance Attribute Details
#bastion_id ⇒ String
**[Required]** The unique identifier (OCID) of the bastion that is hosting this session.
34 35 36 |
# File 'lib/oci/bastion/models/session_summary.rb', line 34 def bastion_id @bastion_id end |
#bastion_name ⇒ String
**[Required]** The name of the bastion that is hosting this session.
30 31 32 |
# File 'lib/oci/bastion/models/session_summary.rb', line 30 def bastion_name @bastion_name end |
#display_name ⇒ String
The name of the session.
26 27 28 |
# File 'lib/oci/bastion/models/session_summary.rb', line 26 def display_name @display_name end |
#id ⇒ String
**[Required]** The unique identifier (OCID) of the session, which can't be changed after creation.
22 23 24 |
# File 'lib/oci/bastion/models/session_summary.rb', line 22 def id @id end |
#lifecycle_details ⇒ String
A message describing the current session state in more detail.
58 59 60 |
# File 'lib/oci/bastion/models/session_summary.rb', line 58 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the session.
54 55 56 |
# File 'lib/oci/bastion/models/session_summary.rb', line 54 def lifecycle_state @lifecycle_state end |
#session_ttl_in_seconds ⇒ Integer
**[Required]** The amount of time the session can remain active.
62 63 64 |
# File 'lib/oci/bastion/models/session_summary.rb', line 62 def session_ttl_in_seconds @session_ttl_in_seconds end |
#target_resource_details ⇒ OCI::Bastion::Models::TargetResourceDetails
This attribute is required.
38 39 40 |
# File 'lib/oci/bastion/models/session_summary.rb', line 38 def target_resource_details @target_resource_details end |
#time_created ⇒ DateTime
**[Required]** The time the session was created. Format is defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
44 45 46 |
# File 'lib/oci/bastion/models/session_summary.rb', line 44 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the session was updated. Format is defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2020-01-25T21:10:29.600Z`
50 51 52 |
# File 'lib/oci/bastion/models/session_summary.rb', line 50 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/bastion/models/session_summary.rb', line 65 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'bastion_name': :'bastionName', 'bastion_id': :'bastionId', 'target_resource_details': :'targetResourceDetails', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'session_ttl_in_seconds': :'sessionTtlInSeconds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/bastion/models/session_summary.rb', line 83 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'bastion_name': :'String', 'bastion_id': :'String', 'target_resource_details': :'OCI::Bastion::Models::TargetResourceDetails', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'session_ttl_in_seconds': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/bastion/models/session_summary.rb', line 199 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && bastion_name == other.bastion_name && bastion_id == other.bastion_id && target_resource_details == other.target_resource_details && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && session_ttl_in_seconds == other.session_ttl_in_seconds end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/bastion/models/session_summary.rb', line 238 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
218 219 220 |
# File 'lib/oci/bastion/models/session_summary.rb', line 218 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/oci/bastion/models/session_summary.rb', line 227 def hash [id, display_name, bastion_name, bastion_id, target_resource_details, time_created, time_updated, lifecycle_state, lifecycle_details, session_ttl_in_seconds].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 |
# File 'lib/oci/bastion/models/session_summary.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
265 266 267 |
# File 'lib/oci/bastion/models/session_summary.rb', line 265 def to_s to_hash.to_s end |