Class: OCI::Bastion::Models::TargetResourceDetails
- Inherits:
-
Object
- Object
- OCI::Bastion::Models::TargetResourceDetails
- Defined in:
- lib/oci/bastion/models/target_resource_details.rb
Overview
Details about a bastion session's target resource. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
ManagedSshSessionTargetResourceDetails, PortForwardingSessionTargetResourceDetails
Constant Summary collapse
- SESSION_TYPE_ENUM =
[ SESSION_TYPE_MANAGED_SSH = 'MANAGED_SSH'.freeze, SESSION_TYPE_PORT_FORWARDING = 'PORT_FORWARDING'.freeze, SESSION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#session_type ⇒ String
**[Required]** The Bastion service recognizes two types of sessions, managed SSH sessions and SSH port forwarding sessions.
-
#target_resource_port ⇒ Integer
**[Required]** The port number to connect to on the target resource.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetResourceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TargetResourceDetails
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 70 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.session_type = attributes[:'sessionType'] if attributes[:'sessionType'] raise 'You cannot provide both :sessionType and :session_type' if attributes.key?(:'sessionType') && attributes.key?(:'session_type') self.session_type = attributes[:'session_type'] if attributes[:'session_type'] self.target_resource_port = attributes[:'targetResourcePort'] if attributes[:'targetResourcePort'] raise 'You cannot provide both :targetResourcePort and :target_resource_port' if attributes.key?(:'targetResourcePort') && attributes.key?(:'target_resource_port') self.target_resource_port = attributes[:'target_resource_port'] if attributes[:'target_resource_port'] end |
Instance Attribute Details
#session_type ⇒ String
**[Required]** The Bastion service recognizes two types of sessions, managed SSH sessions and SSH port forwarding sessions. Managed SSH sessions require that the target resource has an OpenSSH server and the Oracle Cloud Agent both running.
20 21 22 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 20 def session_type @session_type end |
#target_resource_port ⇒ Integer
**[Required]** The port number to connect to on the target resource.
24 25 26 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 24 def target_resource_port @target_resource_port end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'session_type': :'sessionType', 'target_resource_port': :'targetResourcePort' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 51 def self.get_subtype(object_hash) type = object_hash[:'sessionType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Bastion::Models::ManagedSshSessionTargetResourceDetails' if type == 'MANAGED_SSH' return 'OCI::Bastion::Models::PortForwardingSessionTargetResourceDetails' if type == 'PORT_FORWARDING' # TODO: Log a warning when the subtype is not found. 'OCI::Bastion::Models::TargetResourceDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 37 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'session_type': :'String', 'target_resource_port': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
109 110 111 112 113 114 115 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 109 def ==(other) return true if equal?(other) self.class == other.class && session_type == other.session_type && target_resource_port == other.target_resource_port end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 140 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
120 121 122 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 120 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
129 130 131 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 129 def hash [session_type, target_resource_port].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
167 168 169 |
# File 'lib/oci/bastion/models/target_resource_details.rb', line 167 def to_s to_hash.to_s end |