Class: OCI::Bds::Models::AddAutoScalingConfigurationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/bds/models/add_auto_scaling_configuration_details.rb

Overview

The information about the autoscale configuration.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AddAutoScalingConfigurationDetails

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.node_type = attributes[:'nodeType'] if attributes[:'nodeType']

  raise 'You cannot provide both :nodeType and :node_type' if attributes.key?(:'nodeType') && attributes.key?(:'node_type')

  self.node_type = attributes[:'node_type'] if attributes[:'node_type']

  self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil?

  raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled')

  self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil?

  self.cluster_admin_password = attributes[:'clusterAdminPassword'] if attributes[:'clusterAdminPassword']

  raise 'You cannot provide both :clusterAdminPassword and :cluster_admin_password' if attributes.key?(:'clusterAdminPassword') && attributes.key?(:'cluster_admin_password')

  self.cluster_admin_password = attributes[:'cluster_admin_password'] if attributes[:'cluster_admin_password']

  self.policy = attributes[:'policy'] if attributes[:'policy']
end

Instance Attribute Details

#cluster_admin_passwordString

[Required] Base-64 encoded password for the cluster (and Cloudera Manager) admin user.

Returns:



24
25
26
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 24

def cluster_admin_password
  @cluster_admin_password
end

#display_nameString

A user-friendly name. The name does not have to be unique, and it may be changed. Avoid entering confidential information.

Returns:



12
13
14
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 12

def display_name
  @display_name
end

#is_enabledBOOLEAN

[Required] Whether the autoscale configuration is enabled.

Returns:



20
21
22
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 20

def is_enabled
  @is_enabled
end

#node_typeString

[Required] A node type that is managed by an autoscale configuration. The only supported type is WORKER.

Returns:



16
17
18
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 16

def node_type
  @node_type
end

#policyOCI::Bds::Models::AutoScalePolicy

This attribute is required.

Returns:



28
29
30
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 28

def policy
  @policy
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'node_type': :'nodeType',
    'is_enabled': :'isEnabled',
    'cluster_admin_password': :'clusterAdminPassword',
    'policy': :'policy'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'node_type': :'String',
    'is_enabled': :'BOOLEAN',
    'cluster_admin_password': :'String',
    'policy': :'OCI::Bds::Models::AutoScalePolicy'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



107
108
109
110
111
112
113
114
115
116
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 107

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    node_type == other.node_type &&
    is_enabled == other.is_enabled &&
    cluster_admin_password == other.cluster_admin_password &&
    policy == other.policy
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 141

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



121
122
123
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 121

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



130
131
132
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 130

def hash
  [display_name, node_type, is_enabled, cluster_admin_password, policy].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



174
175
176
177
178
179
180
181
182
183
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 174

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



168
169
170
# File 'lib/oci/bds/models/add_auto_scaling_configuration_details.rb', line 168

def to_s
  to_hash.to_s
end