Class: OCI::Bds::Models::AddWorkerNodesDetails
- Inherits:
-
Object
- Object
- OCI::Bds::Models::AddWorkerNodesDetails
- Defined in:
- lib/oci/bds/models/add_worker_nodes_details.rb
Overview
The information about added nodes.
Constant Summary collapse
- NODE_TYPE_ENUM =
[ NODE_TYPE_WORKER = 'WORKER'.freeze, NODE_TYPE_COMPUTE_ONLY_WORKER = 'COMPUTE_ONLY_WORKER'.freeze ].freeze
Instance Attribute Summary collapse
-
#block_volume_size_in_gbs ⇒ Integer
The size of block volume in GB to be attached to the given node.
-
#cluster_admin_password ⇒ String
**[Required]** Base-64 encoded password for the cluster (and Cloudera Manager) admin user.
-
#node_type ⇒ String
**[Required]** Worker node types, can either be Worker Data node or Compute only worker node.
-
#number_of_worker_nodes ⇒ Integer
**[Required]** Number of additional worker nodes for the cluster.
-
#shape ⇒ String
Shape of the node.
- #shape_config ⇒ OCI::Bds::Models::ShapeConfigDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddWorkerNodesDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AddWorkerNodesDetails
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 79 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cluster_admin_password = attributes[:'clusterAdminPassword'] if attributes[:'clusterAdminPassword'] raise 'You cannot provide both :clusterAdminPassword and :cluster_admin_password' if attributes.key?(:'clusterAdminPassword') && attributes.key?(:'cluster_admin_password') self.cluster_admin_password = attributes[:'cluster_admin_password'] if attributes[:'cluster_admin_password'] self.number_of_worker_nodes = attributes[:'numberOfWorkerNodes'] if attributes[:'numberOfWorkerNodes'] raise 'You cannot provide both :numberOfWorkerNodes and :number_of_worker_nodes' if attributes.key?(:'numberOfWorkerNodes') && attributes.key?(:'number_of_worker_nodes') self.number_of_worker_nodes = attributes[:'number_of_worker_nodes'] if attributes[:'number_of_worker_nodes'] self.node_type = attributes[:'nodeType'] if attributes[:'nodeType'] raise 'You cannot provide both :nodeType and :node_type' if attributes.key?(:'nodeType') && attributes.key?(:'node_type') self.node_type = attributes[:'node_type'] if attributes[:'node_type'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.block_volume_size_in_gbs = attributes[:'blockVolumeSizeInGBs'] if attributes[:'blockVolumeSizeInGBs'] raise 'You cannot provide both :blockVolumeSizeInGBs and :block_volume_size_in_gbs' if attributes.key?(:'blockVolumeSizeInGBs') && attributes.key?(:'block_volume_size_in_gbs') self.block_volume_size_in_gbs = attributes[:'block_volume_size_in_gbs'] if attributes[:'block_volume_size_in_gbs'] self.shape_config = attributes[:'shapeConfig'] if attributes[:'shapeConfig'] raise 'You cannot provide both :shapeConfig and :shape_config' if attributes.key?(:'shapeConfig') && attributes.key?(:'shape_config') self.shape_config = attributes[:'shape_config'] if attributes[:'shape_config'] end |
Instance Attribute Details
#block_volume_size_in_gbs ⇒ Integer
The size of block volume in GB to be attached to the given node. This has to be specified when adding compute only worker node at the first time. Otherwise, it's a read-only property.
34 35 36 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 34 def block_volume_size_in_gbs @block_volume_size_in_gbs end |
#cluster_admin_password ⇒ String
**[Required]** Base-64 encoded password for the cluster (and Cloudera Manager) admin user.
17 18 19 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 17 def cluster_admin_password @cluster_admin_password end |
#node_type ⇒ String
**[Required]** Worker node types, can either be Worker Data node or Compute only worker node.
25 26 27 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 25 def node_type @node_type end |
#number_of_worker_nodes ⇒ Integer
**[Required]** Number of additional worker nodes for the cluster.
21 22 23 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 21 def number_of_worker_nodes @number_of_worker_nodes end |
#shape ⇒ String
Shape of the node. This has to be specified when adding compute only worker node at the first time. Otherwise, it's a read-only property.
29 30 31 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 29 def shape @shape end |
#shape_config ⇒ OCI::Bds::Models::ShapeConfigDetails
37 38 39 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 37 def shape_config @shape_config end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cluster_admin_password': :'clusterAdminPassword', 'number_of_worker_nodes': :'numberOfWorkerNodes', 'node_type': :'nodeType', 'shape': :'shape', 'block_volume_size_in_gbs': :'blockVolumeSizeInGBs', 'shape_config': :'shapeConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cluster_admin_password': :'String', 'number_of_worker_nodes': :'Integer', 'node_type': :'String', 'shape': :'String', 'block_volume_size_in_gbs': :'Integer', 'shape_config': :'OCI::Bds::Models::ShapeConfigDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 133 def ==(other) return true if equal?(other) self.class == other.class && cluster_admin_password == other.cluster_admin_password && number_of_worker_nodes == other.number_of_worker_nodes && node_type == other.node_type && shape == other.shape && block_volume_size_in_gbs == other.block_volume_size_in_gbs && shape_config == other.shape_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 157 def hash [cluster_admin_password, number_of_worker_nodes, node_type, shape, block_volume_size_in_gbs, shape_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/bds/models/add_worker_nodes_details.rb', line 195 def to_s to_hash.to_s end |