Class: OCI::Bds::Models::AutoScalingConfiguration
- Inherits:
-
Object
- Object
- OCI::Bds::Models::AutoScalingConfiguration
- Defined in:
- lib/oci/bds/models/auto_scaling_configuration.rb
Overview
The information about auto scale configuration.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#id ⇒ String
[Required] The unique identifier for autoscaling configuration.
-
#lifecycle_state ⇒ String
[Required] The state of the autoscaling configuration.
-
#node_type ⇒ String
[Required] A node type that is managed by an autoscaling configuration.
-
#policy ⇒ OCI::Bds::Models::AutoScalePolicy
This attribute is required.
-
#time_created ⇒ DateTime
[Required] The time the BDS instance was created.
-
#time_updated ⇒ DateTime
[Required] The time the autoscale configuration was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutoScalingConfiguration
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutoScalingConfiguration
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.node_type = attributes[:'nodeType'] if attributes[:'nodeType'] raise 'You cannot provide both :nodeType and :node_type' if attributes.key?(:'nodeType') && attributes.key?(:'node_type') self.node_type = attributes[:'node_type'] if attributes[:'node_type'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.policy = attributes[:'policy'] if attributes[:'policy'] end |
Instance Attribute Details
#display_name ⇒ String
[Required] A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
27 28 29 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 27 def display_name @display_name end |
#id ⇒ String
[Required] The unique identifier for autoscaling configuration.
23 24 25 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 23 def id @id end |
#lifecycle_state ⇒ String
[Required] The state of the autoscaling configuration
35 36 37 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 35 def lifecycle_state @lifecycle_state end |
#node_type ⇒ String
[Required] A node type that is managed by an autoscaling configuration. The only supported type is WORKER.
31 32 33 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 31 def node_type @node_type end |
#policy ⇒ OCI::Bds::Models::AutoScalePolicy
This attribute is required.
49 50 51 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 49 def policy @policy end |
#time_created ⇒ DateTime
[Required] The time the BDS instance was created. An RFC3339 formatted datetime string
39 40 41 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 39 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The time the autoscale configuration was updated. An RFC3339 formatted datetime string
45 46 47 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 45 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'node_type': :'nodeType', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'policy': :'policy' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 67 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'node_type': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'policy': :'OCI::Bds::Models::AutoScalePolicy' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 155 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && node_type == other.node_type && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && policy == other.policy end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 191 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
171 172 173 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 171 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 180 def hash [id, display_name, node_type, lifecycle_state, time_created, time_updated, policy].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/oci/bds/models/auto_scaling_configuration.rb', line 218 def to_s to_hash.to_s end |