Class: OCI::Bds::Models::AutoScalingConfigurationSummary
- Inherits:
-
Object
- Object
- OCI::Bds::Models::AutoScalingConfigurationSummary
- Defined in:
- lib/oci/bds/models/auto_scaling_configuration_summary.rb
Overview
The information about the autoscale configuration.
Instance Attribute Summary collapse
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#id ⇒ String
[Required] The OCID of the autoscale configuration.
-
#lifecycle_state ⇒ String
[Required] The state of the autoscale configuration.
-
#node_type ⇒ String
[Required] A node type that is managed by an autoscale configuration.
-
#policy ⇒ OCI::Bds::Models::AutoScalePolicy
This attribute is required.
-
#time_created ⇒ DateTime
[Required] The time the cluster was created, shown as an RFC 3339 formatted datetime string.
-
#time_updated ⇒ DateTime
[Required] The time the autoscale configuration was updated, shown as an RFC 3339 formatted datetime string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutoScalingConfigurationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutoScalingConfigurationSummary
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 82 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.node_type = attributes[:'nodeType'] if attributes[:'nodeType'] raise 'You cannot provide both :nodeType and :node_type' if attributes.key?(:'nodeType') && attributes.key?(:'node_type') self.node_type = attributes[:'node_type'] if attributes[:'node_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.policy = attributes[:'policy'] if attributes[:'policy'] end |
Instance Attribute Details
#display_name ⇒ String
[Required] A user-friendly name. The name does not have to be unique, and it may be changed. Avoid entering confidential information.
16 17 18 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 16 def display_name @display_name end |
#id ⇒ String
[Required] The OCID of the autoscale configuration.
12 13 14 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 12 def id @id end |
#lifecycle_state ⇒ String
[Required] The state of the autoscale configuration.
20 21 22 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 20 def lifecycle_state @lifecycle_state end |
#node_type ⇒ String
[Required] A node type that is managed by an autoscale configuration. The only supported type is WORKER.
24 25 26 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 24 def node_type @node_type end |
#policy ⇒ OCI::Bds::Models::AutoScalePolicy
This attribute is required.
37 38 39 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 37 def policy @policy end |
#time_created ⇒ DateTime
[Required] The time the cluster was created, shown as an RFC 3339 formatted datetime string.
28 29 30 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 28 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The time the autoscale configuration was updated, shown as an RFC 3339 formatted datetime string.
33 34 35 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 33 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'lifecycle_state': :'lifecycleState', 'node_type': :'nodeType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'policy': :'policy' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'lifecycle_state': :'String', 'node_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'policy': :'OCI::Bds::Models::AutoScalePolicy' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 130 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && lifecycle_state == other.lifecycle_state && node_type == other.node_type && time_created == other.time_created && time_updated == other.time_updated && policy == other.policy end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 166 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
146 147 148 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 146 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 155 def hash [id, display_name, lifecycle_state, node_type, time_created, time_updated, policy].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
193 194 195 |
# File 'lib/oci/bds/models/auto_scaling_configuration_summary.rb', line 193 def to_s to_hash.to_s end |