Class: OCI::Bds::Models::BdsInstance
- Inherits:
-
Object
- Object
- OCI::Bds::Models::BdsInstance
- Defined in:
- lib/oci/bds/models/bds_instance.rb
Overview
Description of the cluster.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_SUSPENDING = 'SUSPENDING'.freeze, LIFECYCLE_STATE_SUSPENDED = 'SUSPENDED'.freeze, LIFECYCLE_STATE_RESUMING = 'RESUMING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CLUSTER_VERSION_ENUM =
[ CLUSTER_VERSION_CDH5 = 'CDH5'.freeze, CLUSTER_VERSION_CDH6 = 'CDH6'.freeze, CLUSTER_VERSION_ODH1 = 'ODH1'.freeze, CLUSTER_VERSION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #cloud_sql_details ⇒ OCI::Bds::Models::CloudSqlDetails
- #cluster_details ⇒ OCI::Bds::Models::ClusterDetails
-
#cluster_version ⇒ String
Version of the Hadoop distribution.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment.
-
#created_by ⇒ String
The user who created the cluster.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The name of the cluster.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
[Required] The OCID of the Big Data Service resource.
-
#is_cloud_sql_configured ⇒ BOOLEAN
[Required] Boolean flag specifying whether or not Cloud SQL should be configured.
-
#is_high_availability ⇒ BOOLEAN
[Required] Boolean flag specifying whether or not the cluster is highly available (HA).
-
#is_secure ⇒ BOOLEAN
[Required] Boolean flag specifying whether or not the cluster should be set up as secure.
-
#lifecycle_state ⇒ String
[Required] The state of the cluster.
- #network_config ⇒ OCI::Bds::Models::NetworkConfig
-
#nodes ⇒ Array<OCI::Bds::Models::Node>
[Required] The list of nodes in the cluster.
-
#number_of_nodes ⇒ Integer
[Required] Number of nodes that forming the cluster.
-
#time_created ⇒ DateTime
The time the cluster was created, shown as an RFC 3339 formatted datetime string.
-
#time_updated ⇒ DateTime
The time the cluster was updated, shown as an RFC 3339 formatted datetime string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BdsInstance
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BdsInstance
Initializes the object
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/oci/bds/models/bds_instance.rb', line 180 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.cluster_version = attributes[:'clusterVersion'] if attributes[:'clusterVersion'] raise 'You cannot provide both :clusterVersion and :cluster_version' if attributes.key?(:'clusterVersion') && attributes.key?(:'cluster_version') self.cluster_version = attributes[:'cluster_version'] if attributes[:'cluster_version'] self.is_high_availability = attributes[:'isHighAvailability'] unless attributes[:'isHighAvailability'].nil? raise 'You cannot provide both :isHighAvailability and :is_high_availability' if attributes.key?(:'isHighAvailability') && attributes.key?(:'is_high_availability') self.is_high_availability = attributes[:'is_high_availability'] unless attributes[:'is_high_availability'].nil? self.is_secure = attributes[:'isSecure'] unless attributes[:'isSecure'].nil? raise 'You cannot provide both :isSecure and :is_secure' if attributes.key?(:'isSecure') && attributes.key?(:'is_secure') self.is_secure = attributes[:'is_secure'] unless attributes[:'is_secure'].nil? self.is_cloud_sql_configured = attributes[:'isCloudSqlConfigured'] unless attributes[:'isCloudSqlConfigured'].nil? self.is_cloud_sql_configured = false if is_cloud_sql_configured.nil? && !attributes.key?(:'isCloudSqlConfigured') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isCloudSqlConfigured and :is_cloud_sql_configured' if attributes.key?(:'isCloudSqlConfigured') && attributes.key?(:'is_cloud_sql_configured') self.is_cloud_sql_configured = attributes[:'is_cloud_sql_configured'] unless attributes[:'is_cloud_sql_configured'].nil? self.is_cloud_sql_configured = false if is_cloud_sql_configured.nil? && !attributes.key?(:'isCloudSqlConfigured') && !attributes.key?(:'is_cloud_sql_configured') # rubocop:disable Style/StringLiterals self.network_config = attributes[:'networkConfig'] if attributes[:'networkConfig'] raise 'You cannot provide both :networkConfig and :network_config' if attributes.key?(:'networkConfig') && attributes.key?(:'network_config') self.network_config = attributes[:'network_config'] if attributes[:'network_config'] self.cluster_details = attributes[:'clusterDetails'] if attributes[:'clusterDetails'] raise 'You cannot provide both :clusterDetails and :cluster_details' if attributes.key?(:'clusterDetails') && attributes.key?(:'cluster_details') self.cluster_details = attributes[:'cluster_details'] if attributes[:'cluster_details'] self.nodes = attributes[:'nodes'] if attributes[:'nodes'] self.cloud_sql_details = attributes[:'cloudSqlDetails'] if attributes[:'cloudSqlDetails'] raise 'You cannot provide both :cloudSqlDetails and :cloud_sql_details' if attributes.key?(:'cloudSqlDetails') && attributes.key?(:'cloud_sql_details') self.cloud_sql_details = attributes[:'cloud_sql_details'] if attributes[:'cloud_sql_details'] self.created_by = attributes[:'createdBy'] if attributes[:'createdBy'] raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] if attributes[:'created_by'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.number_of_nodes = attributes[:'numberOfNodes'] if attributes[:'numberOfNodes'] raise 'You cannot provide both :numberOfNodes and :number_of_nodes' if attributes.key?(:'numberOfNodes') && attributes.key?(:'number_of_nodes') self.number_of_nodes = attributes[:'number_of_nodes'] if attributes[:'number_of_nodes'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#cloud_sql_details ⇒ OCI::Bds::Models::CloudSqlDetails
74 75 76 |
# File 'lib/oci/bds/models/bds_instance.rb', line 74 def cloud_sql_details @cloud_sql_details end |
#cluster_details ⇒ OCI::Bds::Models::ClusterDetails
67 68 69 |
# File 'lib/oci/bds/models/bds_instance.rb', line 67 def cluster_details @cluster_details end |
#cluster_version ⇒ String
Version of the Hadoop distribution.
49 50 51 |
# File 'lib/oci/bds/models/bds_instance.rb', line 49 def cluster_version @cluster_version end |
#compartment_id ⇒ String
[Required] The OCID of the compartment.
37 38 39 |
# File 'lib/oci/bds/models/bds_instance.rb', line 37 def compartment_id @compartment_id end |
#created_by ⇒ String
The user who created the cluster.
78 79 80 |
# File 'lib/oci/bds/models/bds_instance.rb', line 78 def created_by @created_by end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For example, ‘{"bar-key": "value"}`
102 103 104 |
# File 'lib/oci/bds/models/bds_instance.rb', line 102 def @defined_tags end |
#display_name ⇒ String
[Required] The name of the cluster.
41 42 43 |
# File 'lib/oci/bds/models/bds_instance.rb', line 41 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. For example, ‘"value"`
96 97 98 |
# File 'lib/oci/bds/models/bds_instance.rb', line 96 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the Big Data Service resource.
33 34 35 |
# File 'lib/oci/bds/models/bds_instance.rb', line 33 def id @id end |
#is_cloud_sql_configured ⇒ BOOLEAN
[Required] Boolean flag specifying whether or not Cloud SQL should be configured.
61 62 63 |
# File 'lib/oci/bds/models/bds_instance.rb', line 61 def is_cloud_sql_configured @is_cloud_sql_configured end |
#is_high_availability ⇒ BOOLEAN
[Required] Boolean flag specifying whether or not the cluster is highly available (HA)
53 54 55 |
# File 'lib/oci/bds/models/bds_instance.rb', line 53 def is_high_availability @is_high_availability end |
#is_secure ⇒ BOOLEAN
[Required] Boolean flag specifying whether or not the cluster should be set up as secure.
57 58 59 |
# File 'lib/oci/bds/models/bds_instance.rb', line 57 def is_secure @is_secure end |
#lifecycle_state ⇒ String
[Required] The state of the cluster.
45 46 47 |
# File 'lib/oci/bds/models/bds_instance.rb', line 45 def lifecycle_state @lifecycle_state end |
#network_config ⇒ OCI::Bds::Models::NetworkConfig
64 65 66 |
# File 'lib/oci/bds/models/bds_instance.rb', line 64 def network_config @network_config end |
#nodes ⇒ Array<OCI::Bds::Models::Node>
[Required] The list of nodes in the cluster.
71 72 73 |
# File 'lib/oci/bds/models/bds_instance.rb', line 71 def nodes @nodes end |
#number_of_nodes ⇒ Integer
[Required] Number of nodes that forming the cluster
90 91 92 |
# File 'lib/oci/bds/models/bds_instance.rb', line 90 def number_of_nodes @number_of_nodes end |
#time_created ⇒ DateTime
The time the cluster was created, shown as an RFC 3339 formatted datetime string.
82 83 84 |
# File 'lib/oci/bds/models/bds_instance.rb', line 82 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the cluster was updated, shown as an RFC 3339 formatted datetime string.
86 87 88 |
# File 'lib/oci/bds/models/bds_instance.rb', line 86 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/bds/models/bds_instance.rb', line 105 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'lifecycle_state': :'lifecycleState', 'cluster_version': :'clusterVersion', 'is_high_availability': :'isHighAvailability', 'is_secure': :'isSecure', 'is_cloud_sql_configured': :'isCloudSqlConfigured', 'network_config': :'networkConfig', 'cluster_details': :'clusterDetails', 'nodes': :'nodes', 'cloud_sql_details': :'cloudSqlDetails', 'created_by': :'createdBy', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'number_of_nodes': :'numberOfNodes', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/bds/models/bds_instance.rb', line 131 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'lifecycle_state': :'String', 'cluster_version': :'String', 'is_high_availability': :'BOOLEAN', 'is_secure': :'BOOLEAN', 'is_cloud_sql_configured': :'BOOLEAN', 'network_config': :'OCI::Bds::Models::NetworkConfig', 'cluster_details': :'OCI::Bds::Models::ClusterDetails', 'nodes': :'Array<OCI::Bds::Models::Node>', 'cloud_sql_details': :'OCI::Bds::Models::CloudSqlDetails', 'created_by': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'number_of_nodes': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/oci/bds/models/bds_instance.rb', line 322 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && lifecycle_state == other.lifecycle_state && cluster_version == other.cluster_version && is_high_availability == other.is_high_availability && is_secure == other.is_secure && is_cloud_sql_configured == other.is_cloud_sql_configured && network_config == other.network_config && cluster_details == other.cluster_details && nodes == other.nodes && cloud_sql_details == other.cloud_sql_details && created_by == other.created_by && time_created == other.time_created && time_updated == other.time_updated && number_of_nodes == other.number_of_nodes && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/oci/bds/models/bds_instance.rb', line 369 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
349 350 351 |
# File 'lib/oci/bds/models/bds_instance.rb', line 349 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
358 359 360 |
# File 'lib/oci/bds/models/bds_instance.rb', line 358 def hash [id, compartment_id, display_name, lifecycle_state, cluster_version, is_high_availability, is_secure, is_cloud_sql_configured, network_config, cluster_details, nodes, cloud_sql_details, created_by, time_created, time_updated, number_of_nodes, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
402 403 404 405 406 407 408 409 410 411 |
# File 'lib/oci/bds/models/bds_instance.rb', line 402 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
396 397 398 |
# File 'lib/oci/bds/models/bds_instance.rb', line 396 def to_s to_hash.to_s end |