Class: OCI::Bds::Models::Node
- Inherits:
-
Object
- Object
- OCI::Bds::Models::Node
- Defined in:
- lib/oci/bds/models/node.rb
Overview
Details about a node.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- NODE_TYPE_ENUM =
[ NODE_TYPE_MASTER = 'MASTER'.freeze, NODE_TYPE_EDGE = 'EDGE'.freeze, NODE_TYPE_UTILITY = 'UTILITY'.freeze, NODE_TYPE_WORKER = 'WORKER'.freeze, NODE_TYPE_COMPUTE_ONLY_WORKER = 'COMPUTE_ONLY_WORKER'.freeze, NODE_TYPE_BURSTING = 'BURSTING'.freeze, NODE_TYPE_CLOUD_SQL = 'CLOUD_SQL'.freeze, NODE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#attached_block_volumes ⇒ Array<OCI::Bds::Models::VolumeAttachmentDetail>
The list of block volumes attached to a given node.
-
#availability_domain ⇒ String
**[Required]** The name of the availability domain in which the node is running.
-
#display_name ⇒ String
**[Required]** The name of the node.
-
#fault_domain ⇒ String
**[Required]** The name of the fault domain in which the node is running.
-
#hostname ⇒ String
The fully-qualified hostname (FQDN) of the node.
-
#image_id ⇒ String
The OCID of the image from which the node was created.
-
#instance_id ⇒ String
**[Required]** The OCID of the underlying Oracle Cloud Infrastructure Compute instance.
-
#ip_address ⇒ String
**[Required]** IP address of the node.
-
#lifecycle_state ⇒ String
**[Required]** The state of the node.
-
#memory_in_gbs ⇒ Integer
The total amount of memory available to the node, in gigabytes.
-
#node_type ⇒ String
**[Required]** Cluster node type.
-
#ocpus ⇒ Integer
The total number of OCPUs available to the node.
-
#shape ⇒ String
**[Required]** Shape of the node.
-
#ssh_fingerprint ⇒ String
**[Required]** The fingerprint of the SSH key used for node access.
-
#subnet_id ⇒ String
**[Required]** The OCID of the subnet in which the node is to be created.
-
#time_created ⇒ DateTime
**[Required]** The time the node was created, shown as an RFC 3339 formatted datetime string.
-
#time_updated ⇒ DateTime
The time the cluster was updated, shown as an RFC 3339 formatted datetime string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Node
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Node
Initializes the object
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/bds/models/node.rb', line 174 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.instance_id = attributes[:'instanceId'] if attributes[:'instanceId'] raise 'You cannot provide both :instanceId and :instance_id' if attributes.key?(:'instanceId') && attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] if attributes[:'instance_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.node_type = attributes[:'nodeType'] if attributes[:'nodeType'] raise 'You cannot provide both :nodeType and :node_type' if attributes.key?(:'nodeType') && attributes.key?(:'node_type') self.node_type = attributes[:'node_type'] if attributes[:'node_type'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.attached_block_volumes = attributes[:'attachedBlockVolumes'] if attributes[:'attachedBlockVolumes'] raise 'You cannot provide both :attachedBlockVolumes and :attached_block_volumes' if attributes.key?(:'attachedBlockVolumes') && attributes.key?(:'attached_block_volumes') self.attached_block_volumes = attributes[:'attached_block_volumes'] if attributes[:'attached_block_volumes'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress'] raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address'] self.hostname = attributes[:'hostname'] if attributes[:'hostname'] self.image_id = attributes[:'imageId'] if attributes[:'imageId'] raise 'You cannot provide both :imageId and :image_id' if attributes.key?(:'imageId') && attributes.key?(:'image_id') self.image_id = attributes[:'image_id'] if attributes[:'image_id'] self.ssh_fingerprint = attributes[:'sshFingerprint'] if attributes[:'sshFingerprint'] raise 'You cannot provide both :sshFingerprint and :ssh_fingerprint' if attributes.key?(:'sshFingerprint') && attributes.key?(:'ssh_fingerprint') self.ssh_fingerprint = attributes[:'ssh_fingerprint'] if attributes[:'ssh_fingerprint'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain'] raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain') self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.ocpus = attributes[:'ocpus'] if attributes[:'ocpus'] self.memory_in_gbs = attributes[:'memoryInGBs'] if attributes[:'memoryInGBs'] raise 'You cannot provide both :memoryInGBs and :memory_in_gbs' if attributes.key?(:'memoryInGBs') && attributes.key?(:'memory_in_gbs') self.memory_in_gbs = attributes[:'memory_in_gbs'] if attributes[:'memory_in_gbs'] end |
Instance Attribute Details
#attached_block_volumes ⇒ Array<OCI::Bds::Models::VolumeAttachmentDetail>
The list of block volumes attached to a given node.
55 56 57 |
# File 'lib/oci/bds/models/node.rb', line 55 def attached_block_volumes @attached_block_volumes end |
#availability_domain ⇒ String
**[Required]** The name of the availability domain in which the node is running.
79 80 81 |
# File 'lib/oci/bds/models/node.rb', line 79 def availability_domain @availability_domain end |
#display_name ⇒ String
**[Required]** The name of the node.
39 40 41 |
# File 'lib/oci/bds/models/node.rb', line 39 def display_name @display_name end |
#fault_domain ⇒ String
**[Required]** The name of the fault domain in which the node is running.
83 84 85 |
# File 'lib/oci/bds/models/node.rb', line 83 def fault_domain @fault_domain end |
#hostname ⇒ String
The fully-qualified hostname (FQDN) of the node.
67 68 69 |
# File 'lib/oci/bds/models/node.rb', line 67 def hostname @hostname end |
#image_id ⇒ String
The OCID of the image from which the node was created.
71 72 73 |
# File 'lib/oci/bds/models/node.rb', line 71 def image_id @image_id end |
#instance_id ⇒ String
**[Required]** The OCID of the underlying Oracle Cloud Infrastructure Compute instance.
35 36 37 |
# File 'lib/oci/bds/models/node.rb', line 35 def instance_id @instance_id end |
#ip_address ⇒ String
**[Required]** IP address of the node.
63 64 65 |
# File 'lib/oci/bds/models/node.rb', line 63 def ip_address @ip_address end |
#lifecycle_state ⇒ String
**[Required]** The state of the node.
43 44 45 |
# File 'lib/oci/bds/models/node.rb', line 43 def lifecycle_state @lifecycle_state end |
#memory_in_gbs ⇒ Integer
The total amount of memory available to the node, in gigabytes.
99 100 101 |
# File 'lib/oci/bds/models/node.rb', line 99 def memory_in_gbs @memory_in_gbs end |
#node_type ⇒ String
**[Required]** Cluster node type.
47 48 49 |
# File 'lib/oci/bds/models/node.rb', line 47 def node_type @node_type end |
#ocpus ⇒ Integer
The total number of OCPUs available to the node.
95 96 97 |
# File 'lib/oci/bds/models/node.rb', line 95 def ocpus @ocpus end |
#shape ⇒ String
**[Required]** Shape of the node.
51 52 53 |
# File 'lib/oci/bds/models/node.rb', line 51 def shape @shape end |
#ssh_fingerprint ⇒ String
**[Required]** The fingerprint of the SSH key used for node access.
75 76 77 |
# File 'lib/oci/bds/models/node.rb', line 75 def ssh_fingerprint @ssh_fingerprint end |
#subnet_id ⇒ String
**[Required]** The OCID of the subnet in which the node is to be created.
59 60 61 |
# File 'lib/oci/bds/models/node.rb', line 59 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
**[Required]** The time the node was created, shown as an RFC 3339 formatted datetime string.
87 88 89 |
# File 'lib/oci/bds/models/node.rb', line 87 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the cluster was updated, shown as an RFC 3339 formatted datetime string.
91 92 93 |
# File 'lib/oci/bds/models/node.rb', line 91 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/bds/models/node.rb', line 102 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'instance_id': :'instanceId', 'display_name': :'displayName', 'lifecycle_state': :'lifecycleState', 'node_type': :'nodeType', 'shape': :'shape', 'attached_block_volumes': :'attachedBlockVolumes', 'subnet_id': :'subnetId', 'ip_address': :'ipAddress', 'hostname': :'hostname', 'image_id': :'imageId', 'ssh_fingerprint': :'sshFingerprint', 'availability_domain': :'availabilityDomain', 'fault_domain': :'faultDomain', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'ocpus': :'ocpus', 'memory_in_gbs': :'memoryInGBs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/bds/models/node.rb', line 127 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'instance_id': :'String', 'display_name': :'String', 'lifecycle_state': :'String', 'node_type': :'String', 'shape': :'String', 'attached_block_volumes': :'Array<OCI::Bds::Models::VolumeAttachmentDetail>', 'subnet_id': :'String', 'ip_address': :'String', 'hostname': :'String', 'image_id': :'String', 'ssh_fingerprint': :'String', 'availability_domain': :'String', 'fault_domain': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'ocpus': :'Integer', 'memory_in_gbs': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/oci/bds/models/node.rb', line 304 def ==(other) return true if equal?(other) self.class == other.class && instance_id == other.instance_id && display_name == other.display_name && lifecycle_state == other.lifecycle_state && node_type == other.node_type && shape == other.shape && attached_block_volumes == other.attached_block_volumes && subnet_id == other.subnet_id && ip_address == other.ip_address && hostname == other.hostname && image_id == other.image_id && ssh_fingerprint == other.ssh_fingerprint && availability_domain == other.availability_domain && fault_domain == other.fault_domain && time_created == other.time_created && time_updated == other.time_updated && ocpus == other.ocpus && memory_in_gbs == other.memory_in_gbs end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/oci/bds/models/node.rb', line 350 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
330 331 332 |
# File 'lib/oci/bds/models/node.rb', line 330 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
339 340 341 |
# File 'lib/oci/bds/models/node.rb', line 339 def hash [instance_id, display_name, lifecycle_state, node_type, shape, attached_block_volumes, subnet_id, ip_address, hostname, image_id, ssh_fingerprint, availability_domain, fault_domain, time_created, time_updated, ocpus, memory_in_gbs].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
383 384 385 386 387 388 389 390 391 392 |
# File 'lib/oci/bds/models/node.rb', line 383 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
377 378 379 |
# File 'lib/oci/bds/models/node.rb', line 377 def to_s to_hash.to_s end |