Class: OCI::CloudGuard::Models::CreateManagedListDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/cloud_guard/models/create_managed_list_details.rb

Overview

Create ManagedList

Constant Summary collapse

LIST_TYPE_ENUM =
[
  LIST_TYPE_CIDR_BLOCK = 'CIDR_BLOCK'.freeze,
  LIST_TYPE_USERS = 'USERS'.freeze,
  LIST_TYPE_GROUPS = 'GROUPS'.freeze,
  LIST_TYPE_IPV4_ADDRESS = 'IPV4ADDRESS'.freeze,
  LIST_TYPE_IPV6_ADDRESS = 'IPV6ADDRESS'.freeze,
  LIST_TYPE_RESOURCE_OCID = 'RESOURCE_OCID'.freeze,
  LIST_TYPE_REGION = 'REGION'.freeze,
  LIST_TYPE_COUNTRY = 'COUNTRY'.freeze,
  LIST_TYPE_STATE = 'STATE'.freeze,
  LIST_TYPE_CITY = 'CITY'.freeze,
  LIST_TYPE_TAGS = 'TAGS'.freeze,
  LIST_TYPE_GENERIC = 'GENERIC'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateManagedListDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :source_managed_list_id (String)

    The value to assign to the #source_managed_list_id property

  • :description (String)

    The value to assign to the #description property

  • :list_type (String)

    The value to assign to the #list_type property

  • :list_items (Array<String>)

    The value to assign to the #list_items property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 107

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.source_managed_list_id = attributes[:'sourceManagedListId'] if attributes[:'sourceManagedListId']

  raise 'You cannot provide both :sourceManagedListId and :source_managed_list_id' if attributes.key?(:'sourceManagedListId') && attributes.key?(:'source_managed_list_id')

  self.source_managed_list_id = attributes[:'source_managed_list_id'] if attributes[:'source_managed_list_id']

  self.description = attributes[:'description'] if attributes[:'description']

  self.list_type = attributes[:'listType'] if attributes[:'listType']

  raise 'You cannot provide both :listType and :list_type' if attributes.key?(:'listType') && attributes.key?(:'list_type')

  self.list_type = attributes[:'list_type'] if attributes[:'list_type']

  self.list_items = attributes[:'listItems'] if attributes[:'listItems']

  raise 'You cannot provide both :listItems and :list_items' if attributes.key?(:'listItems') && attributes.key?(:'list_items')

  self.list_items = attributes[:'list_items'] if attributes[:'list_items']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

[Required] Compartment Identifier

Returns:

  • (String)


31
32
33
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 31

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


59
60
61
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 59

def defined_tags
  @defined_tags
end

#descriptionString

ManagedList description

Returns:

  • (String)


39
40
41
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 39

def description
  @description
end

#display_nameString

[Required] ManagedList display name

Returns:

  • (String)


27
28
29
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 27

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


53
54
55
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 53

def freeform_tags
  @freeform_tags
end

#list_itemsArray<String>

List of ManagedListItem

Returns:

  • (Array<String>)


47
48
49
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 47

def list_items
  @list_items
end

#list_typeString

type of the list

Returns:

  • (String)


43
44
45
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 43

def list_type
  @list_type
end

#source_managed_list_idString

OCID of the Source ManagedList

Returns:

  • (String)


35
36
37
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 35

def source_managed_list_id
  @source_managed_list_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 62

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'source_managed_list_id': :'sourceManagedListId',
    'description': :'description',
    'list_type': :'listType',
    'list_items': :'listItems',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 78

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'compartment_id': :'String',
    'source_managed_list_id': :'String',
    'description': :'String',
    'list_type': :'String',
    'list_items': :'Array<String>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 173

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    source_managed_list_id == other.source_managed_list_id &&
    description == other.description &&
    list_type == other.list_type &&
    list_items == other.list_items &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 210

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


190
191
192
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 190

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



199
200
201
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 199

def hash
  [display_name, compartment_id, source_managed_list_id, description, list_type, list_items, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



237
238
239
# File 'lib/oci/cloud_guard/models/create_managed_list_details.rb', line 237

def to_s
  to_hash.to_s
end