Class: OCI::CloudGuard::Models::Problem
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::Problem
- Defined in:
- lib/oci/cloud_guard/models/problem.rb
Overview
Problem Definition.
Constant Summary collapse
- RISK_LEVEL_ENUM =
[ RISK_LEVEL_CRITICAL = 'CRITICAL'.freeze, RISK_LEVEL_HIGH = 'HIGH'.freeze, RISK_LEVEL_MEDIUM = 'MEDIUM'.freeze, RISK_LEVEL_LOW = 'LOW'.freeze, RISK_LEVEL_MINOR = 'MINOR'.freeze, RISK_LEVEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_DETAIL_ENUM =
[ LIFECYCLE_DETAIL_OPEN = 'OPEN'.freeze, LIFECYCLE_DETAIL_RESOLVED = 'RESOLVED'.freeze, LIFECYCLE_DETAIL_DISMISSED = 'DISMISSED'.freeze, LIFECYCLE_DETAIL_DELETED = 'DELETED'.freeze, LIFECYCLE_DETAIL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DETECTOR_ID_ENUM =
[ DETECTOR_ID_IAAS_ACTIVITY_DETECTOR = 'IAAS_ACTIVITY_DETECTOR'.freeze, DETECTOR_ID_IAAS_CONFIGURATION_DETECTOR = 'IAAS_CONFIGURATION_DETECTOR'.freeze, DETECTOR_ID_IAAS_THREAT_DETECTOR = 'IAAS_THREAT_DETECTOR'.freeze, DETECTOR_ID_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#additional_details ⇒ Hash<String, String>
The additional details of the Problem.
-
#auto_resolve_date ⇒ String
The date and time when the problem will be auto resolved.
-
#comment ⇒ String
User Comments.
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier where the resource is created.
-
#description ⇒ String
Description of the problem.
-
#detector_id ⇒ String
Id of the detector associated with the Problem.
-
#detector_rule_id ⇒ String
Identifier of the rule.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#labels ⇒ Array<String>
user defined labels on the problem.
-
#lifecycle_detail ⇒ String
The lifecycleDetail will give more detail on the substate of the lifecycleState.
-
#lifecycle_state ⇒ String
The current state of the Problem.
-
#peak_risk_score ⇒ Float
Peak risk score for the problem.
-
#peak_risk_score_date ⇒ String
The date and time for the peak risk score that is observed.
-
#peak_risk_score_lookup_period_in_days ⇒ Integer
Number of days for which peak score is calculated for the problem.
-
#recommendation ⇒ String
Recommendation for the problem.
-
#region ⇒ String
DEPRECATED.
-
#regions ⇒ Array<String>
Regions where the problem is found.
-
#resource_id ⇒ String
Identifier of the Resource.
-
#resource_name ⇒ String
DisplayName of the Resource.
-
#resource_type ⇒ String
Type of the Resource.
-
#risk_level ⇒ String
The Risk Level.
-
#risk_score ⇒ Float
Risk Score for the problem.
-
#target_id ⇒ String
targetId of the problem.
-
#time_first_detected ⇒ DateTime
The date and time the problem was first detected.
-
#time_last_detected ⇒ DateTime
The date and time the problem was last detected.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Problem
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Problem
Initializes the object
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 238 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.detector_rule_id = attributes[:'detectorRuleId'] if attributes[:'detectorRuleId'] raise 'You cannot provide both :detectorRuleId and :detector_rule_id' if attributes.key?(:'detectorRuleId') && attributes.key?(:'detector_rule_id') self.detector_rule_id = attributes[:'detector_rule_id'] if attributes[:'detector_rule_id'] self.region = attributes[:'region'] if attributes[:'region'] self.regions = attributes[:'regions'] if attributes[:'regions'] self.risk_level = attributes[:'riskLevel'] if attributes[:'riskLevel'] raise 'You cannot provide both :riskLevel and :risk_level' if attributes.key?(:'riskLevel') && attributes.key?(:'risk_level') self.risk_level = attributes[:'risk_level'] if attributes[:'risk_level'] self.risk_score = attributes[:'riskScore'] if attributes[:'riskScore'] raise 'You cannot provide both :riskScore and :risk_score' if attributes.key?(:'riskScore') && attributes.key?(:'risk_score') self.risk_score = attributes[:'risk_score'] if attributes[:'risk_score'] self.peak_risk_score_date = attributes[:'peakRiskScoreDate'] if attributes[:'peakRiskScoreDate'] raise 'You cannot provide both :peakRiskScoreDate and :peak_risk_score_date' if attributes.key?(:'peakRiskScoreDate') && attributes.key?(:'peak_risk_score_date') self.peak_risk_score_date = attributes[:'peak_risk_score_date'] if attributes[:'peak_risk_score_date'] self.peak_risk_score = attributes[:'peakRiskScore'] if attributes[:'peakRiskScore'] raise 'You cannot provide both :peakRiskScore and :peak_risk_score' if attributes.key?(:'peakRiskScore') && attributes.key?(:'peak_risk_score') self.peak_risk_score = attributes[:'peak_risk_score'] if attributes[:'peak_risk_score'] self.auto_resolve_date = attributes[:'autoResolveDate'] if attributes[:'autoResolveDate'] raise 'You cannot provide both :autoResolveDate and :auto_resolve_date' if attributes.key?(:'autoResolveDate') && attributes.key?(:'auto_resolve_date') self.auto_resolve_date = attributes[:'auto_resolve_date'] if attributes[:'auto_resolve_date'] self.peak_risk_score_lookup_period_in_days = attributes[:'peakRiskScoreLookupPeriodInDays'] if attributes[:'peakRiskScoreLookupPeriodInDays'] raise 'You cannot provide both :peakRiskScoreLookupPeriodInDays and :peak_risk_score_lookup_period_in_days' if attributes.key?(:'peakRiskScoreLookupPeriodInDays') && attributes.key?(:'peak_risk_score_lookup_period_in_days') self.peak_risk_score_lookup_period_in_days = attributes[:'peak_risk_score_lookup_period_in_days'] if attributes[:'peak_risk_score_lookup_period_in_days'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.labels = attributes[:'labels'] if attributes[:'labels'] self.time_last_detected = attributes[:'timeLastDetected'] if attributes[:'timeLastDetected'] raise 'You cannot provide both :timeLastDetected and :time_last_detected' if attributes.key?(:'timeLastDetected') && attributes.key?(:'time_last_detected') self.time_last_detected = attributes[:'time_last_detected'] if attributes[:'time_last_detected'] self.time_first_detected = attributes[:'timeFirstDetected'] if attributes[:'timeFirstDetected'] raise 'You cannot provide both :timeFirstDetected and :time_first_detected' if attributes.key?(:'timeFirstDetected') && attributes.key?(:'time_first_detected') self.time_first_detected = attributes[:'time_first_detected'] if attributes[:'time_first_detected'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_detail = attributes[:'lifecycleDetail'] if attributes[:'lifecycleDetail'] raise 'You cannot provide both :lifecycleDetail and :lifecycle_detail' if attributes.key?(:'lifecycleDetail') && attributes.key?(:'lifecycle_detail') self.lifecycle_detail = attributes[:'lifecycle_detail'] if attributes[:'lifecycle_detail'] self.detector_id = attributes[:'detectorId'] if attributes[:'detectorId'] raise 'You cannot provide both :detectorId and :detector_id' if attributes.key?(:'detectorId') && attributes.key?(:'detector_id') self.detector_id = attributes[:'detector_id'] if attributes[:'detector_id'] self.target_id = attributes[:'targetId'] if attributes[:'targetId'] raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id') self.target_id = attributes[:'target_id'] if attributes[:'target_id'] self.additional_details = attributes[:'additionalDetails'] if attributes[:'additionalDetails'] raise 'You cannot provide both :additionalDetails and :additional_details' if attributes.key?(:'additionalDetails') && attributes.key?(:'additional_details') self.additional_details = attributes[:'additional_details'] if attributes[:'additional_details'] self.description = attributes[:'description'] if attributes[:'description'] self.recommendation = attributes[:'recommendation'] if attributes[:'recommendation'] self.comment = attributes[:'comment'] if attributes[:'comment'] end |
Instance Attribute Details
#additional_details ⇒ Hash<String, String>
The additional details of the Problem
127 128 129 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 127 def additional_details @additional_details end |
#auto_resolve_date ⇒ String
The date and time when the problem will be auto resolved. Format defined by RFC3339.
79 80 81 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 79 def auto_resolve_date @auto_resolve_date end |
#comment ⇒ String
User Comments
139 140 141 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 139 def comment @comment end |
#compartment_id ⇒ String
**[Required]** Compartment Identifier where the resource is created
47 48 49 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 47 def compartment_id @compartment_id end |
#description ⇒ String
Description of the problem
131 132 133 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 131 def description @description end |
#detector_id ⇒ String
Id of the detector associated with the Problem.
119 120 121 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 119 def detector_id @detector_id end |
#detector_rule_id ⇒ String
Identifier of the rule
51 52 53 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 51 def detector_rule_id @detector_rule_id end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
43 44 45 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 43 def id @id end |
#labels ⇒ Array<String>
user defined labels on the problem
99 100 101 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 99 def labels @labels end |
#lifecycle_detail ⇒ String
The lifecycleDetail will give more detail on the substate of the lifecycleState.
115 116 117 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 115 def lifecycle_detail @lifecycle_detail end |
#lifecycle_state ⇒ String
The current state of the Problem.
111 112 113 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 111 def lifecycle_state @lifecycle_state end |
#peak_risk_score ⇒ Float
Peak risk score for the problem
75 76 77 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 75 def peak_risk_score @peak_risk_score end |
#peak_risk_score_date ⇒ String
The date and time for the peak risk score that is observed. Format defined by RFC3339.
71 72 73 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 71 def peak_risk_score_date @peak_risk_score_date end |
#peak_risk_score_lookup_period_in_days ⇒ Integer
Number of days for which peak score is calculated for the problem
83 84 85 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 83 def peak_risk_score_lookup_period_in_days @peak_risk_score_lookup_period_in_days end |
#recommendation ⇒ String
Recommendation for the problem
135 136 137 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 135 def recommendation @recommendation end |
#region ⇒ String
DEPRECATED
55 56 57 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 55 def region @region end |
#regions ⇒ Array<String>
Regions where the problem is found
59 60 61 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 59 def regions @regions end |
#resource_id ⇒ String
Identifier of the Resource
87 88 89 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 87 def resource_id @resource_id end |
#resource_name ⇒ String
DisplayName of the Resource
91 92 93 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 91 def resource_name @resource_name end |
#resource_type ⇒ String
Type of the Resource
95 96 97 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 95 def resource_type @resource_type end |
#risk_level ⇒ String
The Risk Level
63 64 65 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 63 def risk_level @risk_level end |
#risk_score ⇒ Float
Risk Score for the problem
67 68 69 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 67 def risk_score @risk_score end |
#target_id ⇒ String
targetId of the problem
123 124 125 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 123 def target_id @target_id end |
#time_first_detected ⇒ DateTime
The date and time the problem was first detected. Format defined by RFC3339.
107 108 109 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 107 def time_first_detected @time_first_detected end |
#time_last_detected ⇒ DateTime
The date and time the problem was last detected. Format defined by RFC3339.
103 104 105 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 103 def time_last_detected @time_last_detected end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 142 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'detector_rule_id': :'detectorRuleId', 'region': :'region', 'regions': :'regions', 'risk_level': :'riskLevel', 'risk_score': :'riskScore', 'peak_risk_score_date': :'peakRiskScoreDate', 'peak_risk_score': :'peakRiskScore', 'auto_resolve_date': :'autoResolveDate', 'peak_risk_score_lookup_period_in_days': :'peakRiskScoreLookupPeriodInDays', 'resource_id': :'resourceId', 'resource_name': :'resourceName', 'resource_type': :'resourceType', 'labels': :'labels', 'time_last_detected': :'timeLastDetected', 'time_first_detected': :'timeFirstDetected', 'lifecycle_state': :'lifecycleState', 'lifecycle_detail': :'lifecycleDetail', 'detector_id': :'detectorId', 'target_id': :'targetId', 'additional_details': :'additionalDetails', 'description': :'description', 'recommendation': :'recommendation', 'comment': :'comment' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 175 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'detector_rule_id': :'String', 'region': :'String', 'regions': :'Array<String>', 'risk_level': :'String', 'risk_score': :'Float', 'peak_risk_score_date': :'String', 'peak_risk_score': :'Float', 'auto_resolve_date': :'String', 'peak_risk_score_lookup_period_in_days': :'Integer', 'resource_id': :'String', 'resource_name': :'String', 'resource_type': :'String', 'labels': :'Array<String>', 'time_last_detected': :'DateTime', 'time_first_detected': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_detail': :'String', 'detector_id': :'String', 'target_id': :'String', 'additional_details': :'Hash<String, String>', 'description': :'String', 'recommendation': :'String', 'comment': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 426 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && detector_rule_id == other.detector_rule_id && region == other.region && regions == other.regions && risk_level == other.risk_level && risk_score == other.risk_score && peak_risk_score_date == other.peak_risk_score_date && peak_risk_score == other.peak_risk_score && auto_resolve_date == other.auto_resolve_date && peak_risk_score_lookup_period_in_days == other.peak_risk_score_lookup_period_in_days && resource_id == other.resource_id && resource_name == other.resource_name && resource_type == other.resource_type && labels == other.labels && time_last_detected == other.time_last_detected && time_first_detected == other.time_first_detected && lifecycle_state == other.lifecycle_state && lifecycle_detail == other.lifecycle_detail && detector_id == other.detector_id && target_id == other.target_id && additional_details == other.additional_details && description == other.description && recommendation == other.recommendation && comment == other.comment end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 480 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
460 461 462 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 460 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
469 470 471 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 469 def hash [id, compartment_id, detector_rule_id, region, regions, risk_level, risk_score, peak_risk_score_date, peak_risk_score, auto_resolve_date, peak_risk_score_lookup_period_in_days, resource_id, resource_name, resource_type, labels, time_last_detected, time_first_detected, lifecycle_state, lifecycle_detail, detector_id, target_id, additional_details, description, recommendation, comment].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
513 514 515 516 517 518 519 520 521 522 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 513 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
507 508 509 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 507 def to_s to_hash.to_s end |