Class: OCI::CloudGuard::Models::Problem
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::Problem
- Defined in:
- lib/oci/cloud_guard/models/problem.rb
Overview
Problem Definition.
Constant Summary collapse
- RISK_LEVEL_ENUM =
[ RISK_LEVEL_CRITICAL = 'CRITICAL'.freeze, RISK_LEVEL_HIGH = 'HIGH'.freeze, RISK_LEVEL_MEDIUM = 'MEDIUM'.freeze, RISK_LEVEL_LOW = 'LOW'.freeze, RISK_LEVEL_MINOR = 'MINOR'.freeze, RISK_LEVEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_DETAIL_ENUM =
[ LIFECYCLE_DETAIL_OPEN = 'OPEN'.freeze, LIFECYCLE_DETAIL_RESOLVED = 'RESOLVED'.freeze, LIFECYCLE_DETAIL_DISMISSED = 'DISMISSED'.freeze, LIFECYCLE_DETAIL_DELETED = 'DELETED'.freeze, LIFECYCLE_DETAIL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DETECTOR_ID_ENUM =
[ DETECTOR_ID_IAAS_ACTIVITY_DETECTOR = 'IAAS_ACTIVITY_DETECTOR'.freeze, DETECTOR_ID_IAAS_CONFIGURATION_DETECTOR = 'IAAS_CONFIGURATION_DETECTOR'.freeze, DETECTOR_ID_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#additional_details ⇒ Hash<String, String>
The additional details of the Problem.
-
#comment ⇒ String
User Comments.
-
#compartment_id ⇒ String
[Required] Compartment Identifier where the resource is created.
-
#description ⇒ String
Description of the problem.
-
#detector_id ⇒ String
Id of the detector associated with the Problem.
-
#detector_rule_id ⇒ String
Identifier of the rule.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#labels ⇒ Array<String>
user defined labels on the problem.
-
#lifecycle_detail ⇒ String
The lifecycleDetail will give more detail on the substate of the lifecycleState.
-
#lifecycle_state ⇒ String
The current state of the Problem.
-
#recommendation ⇒ String
Recommendation for the problem.
-
#region ⇒ String
DEPRECATED.
-
#regions ⇒ Array<String>
Regions where the problem is found.
-
#resource_id ⇒ String
Identifier of the Resource.
-
#resource_name ⇒ String
DisplayName of the Resource.
-
#resource_type ⇒ String
Type of the Resource.
-
#risk_level ⇒ String
The Risk Level.
-
#target_id ⇒ String
targetId of the problem.
-
#time_first_detected ⇒ DateTime
The date and time the problem was first detected.
-
#time_last_detected ⇒ DateTime
The date and time the problem was last detected.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Problem
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Problem
Initializes the object
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 202 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.detector_rule_id = attributes[:'detectorRuleId'] if attributes[:'detectorRuleId'] raise 'You cannot provide both :detectorRuleId and :detector_rule_id' if attributes.key?(:'detectorRuleId') && attributes.key?(:'detector_rule_id') self.detector_rule_id = attributes[:'detector_rule_id'] if attributes[:'detector_rule_id'] self.region = attributes[:'region'] if attributes[:'region'] self.regions = attributes[:'regions'] if attributes[:'regions'] self.risk_level = attributes[:'riskLevel'] if attributes[:'riskLevel'] raise 'You cannot provide both :riskLevel and :risk_level' if attributes.key?(:'riskLevel') && attributes.key?(:'risk_level') self.risk_level = attributes[:'risk_level'] if attributes[:'risk_level'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.labels = attributes[:'labels'] if attributes[:'labels'] self.time_last_detected = attributes[:'timeLastDetected'] if attributes[:'timeLastDetected'] raise 'You cannot provide both :timeLastDetected and :time_last_detected' if attributes.key?(:'timeLastDetected') && attributes.key?(:'time_last_detected') self.time_last_detected = attributes[:'time_last_detected'] if attributes[:'time_last_detected'] self.time_first_detected = attributes[:'timeFirstDetected'] if attributes[:'timeFirstDetected'] raise 'You cannot provide both :timeFirstDetected and :time_first_detected' if attributes.key?(:'timeFirstDetected') && attributes.key?(:'time_first_detected') self.time_first_detected = attributes[:'time_first_detected'] if attributes[:'time_first_detected'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_detail = attributes[:'lifecycleDetail'] if attributes[:'lifecycleDetail'] raise 'You cannot provide both :lifecycleDetail and :lifecycle_detail' if attributes.key?(:'lifecycleDetail') && attributes.key?(:'lifecycle_detail') self.lifecycle_detail = attributes[:'lifecycle_detail'] if attributes[:'lifecycle_detail'] self.detector_id = attributes[:'detectorId'] if attributes[:'detectorId'] raise 'You cannot provide both :detectorId and :detector_id' if attributes.key?(:'detectorId') && attributes.key?(:'detector_id') self.detector_id = attributes[:'detector_id'] if attributes[:'detector_id'] self.target_id = attributes[:'targetId'] if attributes[:'targetId'] raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id') self.target_id = attributes[:'target_id'] if attributes[:'target_id'] self.additional_details = attributes[:'additionalDetails'] if attributes[:'additionalDetails'] raise 'You cannot provide both :additionalDetails and :additional_details' if attributes.key?(:'additionalDetails') && attributes.key?(:'additional_details') self.additional_details = attributes[:'additional_details'] if attributes[:'additional_details'] self.description = attributes[:'description'] if attributes[:'description'] self.recommendation = attributes[:'recommendation'] if attributes[:'recommendation'] self.comment = attributes[:'comment'] if attributes[:'comment'] end |
Instance Attribute Details
#additional_details ⇒ Hash<String, String>
The additional details of the Problem
106 107 108 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 106 def additional_details @additional_details end |
#comment ⇒ String
User Comments
118 119 120 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 118 def comment @comment end |
#compartment_id ⇒ String
[Required] Compartment Identifier where the resource is created
46 47 48 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 46 def compartment_id @compartment_id end |
#description ⇒ String
Description of the problem
110 111 112 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 110 def description @description end |
#detector_id ⇒ String
Id of the detector associated with the Problem.
98 99 100 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 98 def detector_id @detector_id end |
#detector_rule_id ⇒ String
Identifier of the rule
50 51 52 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 50 def detector_rule_id @detector_rule_id end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation
42 43 44 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 42 def id @id end |
#labels ⇒ Array<String>
user defined labels on the problem
78 79 80 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 78 def labels @labels end |
#lifecycle_detail ⇒ String
The lifecycleDetail will give more detail on the substate of the lifecycleState.
94 95 96 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 94 def lifecycle_detail @lifecycle_detail end |
#lifecycle_state ⇒ String
The current state of the Problem.
90 91 92 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 90 def lifecycle_state @lifecycle_state end |
#recommendation ⇒ String
Recommendation for the problem
114 115 116 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 114 def recommendation @recommendation end |
#region ⇒ String
DEPRECATED
54 55 56 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 54 def region @region end |
#regions ⇒ Array<String>
Regions where the problem is found
58 59 60 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 58 def regions @regions end |
#resource_id ⇒ String
Identifier of the Resource
66 67 68 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 66 def resource_id @resource_id end |
#resource_name ⇒ String
DisplayName of the Resource
70 71 72 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 70 def resource_name @resource_name end |
#resource_type ⇒ String
Type of the Resource
74 75 76 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 74 def resource_type @resource_type end |
#risk_level ⇒ String
The Risk Level
62 63 64 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 62 def risk_level @risk_level end |
#target_id ⇒ String
targetId of the problem
102 103 104 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 102 def target_id @target_id end |
#time_first_detected ⇒ DateTime
The date and time the problem was first detected. Format defined by RFC3339.
86 87 88 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 86 def time_first_detected @time_first_detected end |
#time_last_detected ⇒ DateTime
The date and time the problem was last detected. Format defined by RFC3339.
82 83 84 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 82 def time_last_detected @time_last_detected end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 121 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'detector_rule_id': :'detectorRuleId', 'region': :'region', 'regions': :'regions', 'risk_level': :'riskLevel', 'resource_id': :'resourceId', 'resource_name': :'resourceName', 'resource_type': :'resourceType', 'labels': :'labels', 'time_last_detected': :'timeLastDetected', 'time_first_detected': :'timeFirstDetected', 'lifecycle_state': :'lifecycleState', 'lifecycle_detail': :'lifecycleDetail', 'detector_id': :'detectorId', 'target_id': :'targetId', 'additional_details': :'additionalDetails', 'description': :'description', 'recommendation': :'recommendation', 'comment': :'comment' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 149 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'detector_rule_id': :'String', 'region': :'String', 'regions': :'Array<String>', 'risk_level': :'String', 'resource_id': :'String', 'resource_name': :'String', 'resource_type': :'String', 'labels': :'Array<String>', 'time_last_detected': :'DateTime', 'time_first_detected': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_detail': :'String', 'detector_id': :'String', 'target_id': :'String', 'additional_details': :'Hash<String, String>', 'description': :'String', 'recommendation': :'String', 'comment': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 360 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && detector_rule_id == other.detector_rule_id && region == other.region && regions == other.regions && risk_level == other.risk_level && resource_id == other.resource_id && resource_name == other.resource_name && resource_type == other.resource_type && labels == other.labels && time_last_detected == other.time_last_detected && time_first_detected == other.time_first_detected && lifecycle_state == other.lifecycle_state && lifecycle_detail == other.lifecycle_detail && detector_id == other.detector_id && target_id == other.target_id && additional_details == other.additional_details && description == other.description && recommendation == other.recommendation && comment == other.comment end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 409 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
389 390 391 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 389 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
398 399 400 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 398 def hash [id, compartment_id, detector_rule_id, region, regions, risk_level, resource_id, resource_name, resource_type, labels, time_last_detected, time_first_detected, lifecycle_state, lifecycle_detail, detector_id, target_id, additional_details, description, recommendation, comment].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
442 443 444 445 446 447 448 449 450 451 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 442 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
436 437 438 |
# File 'lib/oci/cloud_guard/models/problem.rb', line 436 def to_s to_hash.to_s end |