Class: OCI::CloudGuard::Models::SecurityPolicy
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::SecurityPolicy
- Defined in:
- lib/oci/cloud_guard/models/security_policy.rb
Overview
A security policy defines a security requirement for resources in a security zone. If a security zone enables a policy (using a recipe), then any action that attempts to violate that policy is denied.
Constant Summary collapse
- OWNER_ENUM =
[ OWNER_CUSTOMER = 'CUSTOMER'.freeze, OWNER_ORACLE = 'ORACLE'.freeze, OWNER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#category ⇒ String
The category of security policy.
-
#compartment_id ⇒ String
**[Required]** The id of the security policy's compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The security policy's description.
-
#display_name ⇒ String
The security policy's full name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#friendly_name ⇒ String
A shorter version of the security policy's name.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the security policy.
-
#owner ⇒ String
**[Required]** The owner of the security policy.
-
#services ⇒ Array<String>
The list of services that the security policy protects.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
The time the security policy was created.
-
#time_updated ⇒ DateTime
The time the security policy was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SecurityPolicy
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SecurityPolicy
Initializes the object
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 166 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.friendly_name = attributes[:'friendlyName'] if attributes[:'friendlyName'] raise 'You cannot provide both :friendlyName and :friendly_name' if attributes.key?(:'friendlyName') && attributes.key?(:'friendly_name') self.friendly_name = attributes[:'friendly_name'] if attributes[:'friendly_name'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.owner = attributes[:'owner'] if attributes[:'owner'] self.category = attributes[:'category'] if attributes[:'category'] self.services = attributes[:'services'] if attributes[:'services'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#category ⇒ String
The category of security policy
54 55 56 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 54 def category @category end |
#compartment_id ⇒ String
**[Required]** The id of the security policy's compartment
46 47 48 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 46 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
88 89 90 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 88 def @defined_tags end |
#description ⇒ String
The security policy's description
42 43 44 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 42 def description @description end |
#display_name ⇒ String
The security policy's full name
38 39 40 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 38 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
Avoid entering confidential information.
82 83 84 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 82 def @freeform_tags end |
#friendly_name ⇒ String
A shorter version of the security policy's name
34 35 36 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 34 def friendly_name @friendly_name end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
30 31 32 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 30 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, this can be used to provide actionable information for a resource in a `Failed` state.
74 75 76 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 74 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the security policy
70 71 72 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 70 def lifecycle_state @lifecycle_state end |
#owner ⇒ String
**[Required]** The owner of the security policy
50 51 52 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 50 def owner @owner end |
#services ⇒ Array<String>
The list of services that the security policy protects
58 59 60 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 58 def services @services end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.
Example: `{"free-tier-retained": "true"}`
97 98 99 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 97 def @system_tags end |
#time_created ⇒ DateTime
The time the security policy was created. An RFC3339 formatted datetime string.
62 63 64 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 62 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the security policy was last updated. An RFC3339 formatted datetime string.
66 67 68 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 66 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 100 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'friendly_name': :'friendlyName', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'owner': :'owner', 'category': :'category', 'services': :'services', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 123 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'friendly_name': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'owner': :'String', 'category': :'String', 'services': :'Array<String>', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 276 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && friendly_name == other.friendly_name && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && owner == other.owner && category == other.category && services == other.services && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 320 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
300 301 302 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 300 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 309 def hash [id, friendly_name, display_name, description, compartment_id, owner, category, services, time_created, time_updated, lifecycle_state, lifecycle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 362 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
347 348 349 |
# File 'lib/oci/cloud_guard/models/security_policy.rb', line 347 def to_s to_hash.to_s end |