Class: OCI::CloudGuard::Models::SightingEndpointSummary
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::SightingEndpointSummary
- Defined in:
- lib/oci/cloud_guard/models/sighting_endpoint_summary.rb
Overview
Sighting Endpoints summary.
Instance Attribute Summary collapse
-
#asn_number ⇒ String
ASN number.
-
#country ⇒ String
Country.
-
#id ⇒ String
**[Required]** Unique identifier for sighting endpoints.
-
#ip_address ⇒ String
**[Required]** IP Address.
-
#ip_address_type ⇒ String
**[Required]** IP Address type.
-
#ip_classification_type ⇒ String
IP Address classification type.
-
#latitude ⇒ Float
Latitude.
-
#longitude ⇒ Float
Longitude.
-
#problem_id ⇒ String
Problem Id for sighting endpoints.
-
#regions ⇒ Array<String>
Regions where activities were performed from this IP.
-
#services ⇒ Array<String>
Services where activities were performed from this IP.
-
#sighting_id ⇒ String
**[Required]** Sighitng Id for sighting endpoints.
-
#time_last_detected ⇒ DateTime
**[Required]** Time when activities were created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SightingEndpointSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SightingEndpointSummary
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 123 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.sighting_id = attributes[:'sightingId'] if attributes[:'sightingId'] raise 'You cannot provide both :sightingId and :sighting_id' if attributes.key?(:'sightingId') && attributes.key?(:'sighting_id') self.sighting_id = attributes[:'sighting_id'] if attributes[:'sighting_id'] self.problem_id = attributes[:'problemId'] if attributes[:'problemId'] raise 'You cannot provide both :problemId and :problem_id' if attributes.key?(:'problemId') && attributes.key?(:'problem_id') self.problem_id = attributes[:'problem_id'] if attributes[:'problem_id'] self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress'] raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address'] self.ip_address_type = attributes[:'ipAddressType'] if attributes[:'ipAddressType'] raise 'You cannot provide both :ipAddressType and :ip_address_type' if attributes.key?(:'ipAddressType') && attributes.key?(:'ip_address_type') self.ip_address_type = attributes[:'ip_address_type'] if attributes[:'ip_address_type'] self.ip_classification_type = attributes[:'ipClassificationType'] if attributes[:'ipClassificationType'] raise 'You cannot provide both :ipClassificationType and :ip_classification_type' if attributes.key?(:'ipClassificationType') && attributes.key?(:'ip_classification_type') self.ip_classification_type = attributes[:'ip_classification_type'] if attributes[:'ip_classification_type'] self.country = attributes[:'country'] if attributes[:'country'] self.latitude = attributes[:'latitude'] if attributes[:'latitude'] self.longitude = attributes[:'longitude'] if attributes[:'longitude'] self.asn_number = attributes[:'asnNumber'] if attributes[:'asnNumber'] raise 'You cannot provide both :asnNumber and :asn_number' if attributes.key?(:'asnNumber') && attributes.key?(:'asn_number') self.asn_number = attributes[:'asn_number'] if attributes[:'asn_number'] self.regions = attributes[:'regions'] if attributes[:'regions'] self.services = attributes[:'services'] if attributes[:'services'] self.time_last_detected = attributes[:'timeLastDetected'] if attributes[:'timeLastDetected'] raise 'You cannot provide both :timeLastDetected and :time_last_detected' if attributes.key?(:'timeLastDetected') && attributes.key?(:'time_last_detected') self.time_last_detected = attributes[:'time_last_detected'] if attributes[:'time_last_detected'] end |
Instance Attribute Details
#asn_number ⇒ String
ASN number
48 49 50 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 48 def asn_number @asn_number end |
#country ⇒ String
Country
36 37 38 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 36 def country @country end |
#id ⇒ String
**[Required]** Unique identifier for sighting endpoints
12 13 14 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 12 def id @id end |
#ip_address ⇒ String
**[Required]** IP Address
24 25 26 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 24 def ip_address @ip_address end |
#ip_address_type ⇒ String
**[Required]** IP Address type
28 29 30 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 28 def ip_address_type @ip_address_type end |
#ip_classification_type ⇒ String
IP Address classification type
32 33 34 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 32 def ip_classification_type @ip_classification_type end |
#latitude ⇒ Float
Latitude
40 41 42 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 40 def latitude @latitude end |
#longitude ⇒ Float
Longitude
44 45 46 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 44 def longitude @longitude end |
#problem_id ⇒ String
Problem Id for sighting endpoints
20 21 22 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 20 def problem_id @problem_id end |
#regions ⇒ Array<String>
Regions where activities were performed from this IP
52 53 54 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 52 def regions @regions end |
#services ⇒ Array<String>
Services where activities were performed from this IP
56 57 58 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 56 def services @services end |
#sighting_id ⇒ String
**[Required]** Sighitng Id for sighting endpoints
16 17 18 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 16 def sighting_id @sighting_id end |
#time_last_detected ⇒ DateTime
**[Required]** Time when activities were created
60 61 62 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 60 def time_last_detected @time_last_detected end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'sighting_id': :'sightingId', 'problem_id': :'problemId', 'ip_address': :'ipAddress', 'ip_address_type': :'ipAddressType', 'ip_classification_type': :'ipClassificationType', 'country': :'country', 'latitude': :'latitude', 'longitude': :'longitude', 'asn_number': :'asnNumber', 'regions': :'regions', 'services': :'services', 'time_last_detected': :'timeLastDetected' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 84 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'sighting_id': :'String', 'problem_id': :'String', 'ip_address': :'String', 'ip_address_type': :'String', 'ip_classification_type': :'String', 'country': :'String', 'latitude': :'Float', 'longitude': :'Float', 'asn_number': :'String', 'regions': :'Array<String>', 'services': :'Array<String>', 'time_last_detected': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 191 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && sighting_id == other.sighting_id && problem_id == other.problem_id && ip_address == other.ip_address && ip_address_type == other.ip_address_type && ip_classification_type == other.ip_classification_type && country == other.country && latitude == other.latitude && longitude == other.longitude && asn_number == other.asn_number && regions == other.regions && services == other.services && time_last_detected == other.time_last_detected end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 233 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
213 214 215 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 213 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 222 def hash [id, sighting_id, problem_id, ip_address, ip_address_type, ip_classification_type, country, latitude, longitude, asn_number, regions, services, time_last_detected].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 266 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
260 261 262 |
# File 'lib/oci/cloud_guard/models/sighting_endpoint_summary.rb', line 260 def to_s to_hash.to_s end |