Class: OCI::CloudGuard::Models::Target

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/cloud_guard/models/target.rb

Overview

Description of Target.

Constant Summary collapse

TARGET_RESOURCE_TYPE_ENUM =
[
  TARGET_RESOURCE_TYPE_COMPARTMENT = 'COMPARTMENT'.freeze,
  TARGET_RESOURCE_TYPE_ERPCLOUD = 'ERPCLOUD'.freeze,
  TARGET_RESOURCE_TYPE_HCMCLOUD = 'HCMCLOUD'.freeze,
  TARGET_RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Target

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/oci/cloud_guard/models/target.rb', line 179

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.description = attributes[:'description'] if attributes[:'description']

  self.target_resource_type = attributes[:'targetResourceType'] if attributes[:'targetResourceType']

  raise 'You cannot provide both :targetResourceType and :target_resource_type' if attributes.key?(:'targetResourceType') && attributes.key?(:'target_resource_type')

  self.target_resource_type = attributes[:'target_resource_type'] if attributes[:'target_resource_type']

  self.target_resource_id = attributes[:'targetResourceId'] if attributes[:'targetResourceId']

  raise 'You cannot provide both :targetResourceId and :target_resource_id' if attributes.key?(:'targetResourceId') && attributes.key?(:'target_resource_id')

  self.target_resource_id = attributes[:'target_resource_id'] if attributes[:'target_resource_id']

  self.recipe_count = attributes[:'recipeCount'] if attributes[:'recipeCount']

  raise 'You cannot provide both :recipeCount and :recipe_count' if attributes.key?(:'recipeCount') && attributes.key?(:'recipe_count')

  self.recipe_count = attributes[:'recipe_count'] if attributes[:'recipe_count']

  self.target_detector_recipes = attributes[:'targetDetectorRecipes'] if attributes[:'targetDetectorRecipes']

  raise 'You cannot provide both :targetDetectorRecipes and :target_detector_recipes' if attributes.key?(:'targetDetectorRecipes') && attributes.key?(:'target_detector_recipes')

  self.target_detector_recipes = attributes[:'target_detector_recipes'] if attributes[:'target_detector_recipes']

  self.target_responder_recipes = attributes[:'targetResponderRecipes'] if attributes[:'targetResponderRecipes']

  raise 'You cannot provide both :targetResponderRecipes and :target_responder_recipes' if attributes.key?(:'targetResponderRecipes') && attributes.key?(:'target_responder_recipes')

  self.target_responder_recipes = attributes[:'target_responder_recipes'] if attributes[:'target_responder_recipes']

  self.inherited_by_compartments = attributes[:'inheritedByCompartments'] if attributes[:'inheritedByCompartments']

  raise 'You cannot provide both :inheritedByCompartments and :inherited_by_compartments' if attributes.key?(:'inheritedByCompartments') && attributes.key?(:'inherited_by_compartments')

  self.inherited_by_compartments = attributes[:'inherited_by_compartments'] if attributes[:'inherited_by_compartments']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecyle_details = attributes[:'lifecyleDetails'] if attributes[:'lifecyleDetails']

  raise 'You cannot provide both :lifecyleDetails and :lifecyle_details' if attributes.key?(:'lifecyleDetails') && attributes.key?(:'lifecyle_details')

  self.lifecyle_details = attributes[:'lifecyle_details'] if attributes[:'lifecyle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

[Required] Compartment Identifier where the resource is created

Returns:

  • (String)


39
40
41
# File 'lib/oci/cloud_guard/models/target.rb', line 39

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


95
96
97
# File 'lib/oci/cloud_guard/models/target.rb', line 95

def defined_tags
  @defined_tags
end

#descriptionString

The target description.

Returns:

  • (String)


43
44
45
# File 'lib/oci/cloud_guard/models/target.rb', line 43

def description
  @description
end

#display_nameString

Target Identifier, can be renamed

Returns:

  • (String)


35
36
37
# File 'lib/oci/cloud_guard/models/target.rb', line 35

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


89
90
91
# File 'lib/oci/cloud_guard/models/target.rb', line 89

def freeform_tags
  @freeform_tags
end

#idString

[Required] Unique identifier that is immutable on creation

Returns:

  • (String)


31
32
33
# File 'lib/oci/cloud_guard/models/target.rb', line 31

def id
  @id
end

#inherited_by_compartmentsArray<String>

List of inherited compartments

Returns:

  • (Array<String>)


67
68
69
# File 'lib/oci/cloud_guard/models/target.rb', line 67

def inherited_by_compartments
  @inherited_by_compartments
end

#lifecycle_stateString

The current state of the Target.

Returns:

  • (String)


79
80
81
# File 'lib/oci/cloud_guard/models/target.rb', line 79

def lifecycle_state
  @lifecycle_state
end

#lifecyle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


83
84
85
# File 'lib/oci/cloud_guard/models/target.rb', line 83

def lifecyle_details
  @lifecyle_details
end

#recipe_countInteger

[Required] Total number of recipes attached to target

Returns:

  • (Integer)


55
56
57
# File 'lib/oci/cloud_guard/models/target.rb', line 55

def recipe_count
  @recipe_count
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.

Example: ‘{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


104
105
106
# File 'lib/oci/cloud_guard/models/target.rb', line 104

def system_tags
  @system_tags
end

#target_detector_recipesArray<OCI::CloudGuard::Models::TargetDetectorRecipe>

List of detector recipes associated with target



59
60
61
# File 'lib/oci/cloud_guard/models/target.rb', line 59

def target_detector_recipes
  @target_detector_recipes
end

#target_resource_idString

[Required] Resource ID which the target uses to monitor

Returns:

  • (String)


51
52
53
# File 'lib/oci/cloud_guard/models/target.rb', line 51

def target_resource_id
  @target_resource_id
end

#target_resource_typeString

[Required] possible type of targets

Returns:

  • (String)


47
48
49
# File 'lib/oci/cloud_guard/models/target.rb', line 47

def target_resource_type
  @target_resource_type
end

#target_responder_recipesArray<OCI::CloudGuard::Models::TargetResponderRecipe>

List of responder recipes associated with target



63
64
65
# File 'lib/oci/cloud_guard/models/target.rb', line 63

def target_responder_recipes
  @target_responder_recipes
end

#time_createdDateTime

The date and time the target was created. Format defined by RFC3339.

Returns:

  • (DateTime)


71
72
73
# File 'lib/oci/cloud_guard/models/target.rb', line 71

def time_created
  @time_created
end

#time_updatedDateTime

The date and time the target was updated. Format defined by RFC3339.

Returns:

  • (DateTime)


75
76
77
# File 'lib/oci/cloud_guard/models/target.rb', line 75

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/cloud_guard/models/target.rb', line 107

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'description': :'description',
    'target_resource_type': :'targetResourceType',
    'target_resource_id': :'targetResourceId',
    'recipe_count': :'recipeCount',
    'target_detector_recipes': :'targetDetectorRecipes',
    'target_responder_recipes': :'targetResponderRecipes',
    'inherited_by_compartments': :'inheritedByCompartments',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecyle_details': :'lifecyleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/oci/cloud_guard/models/target.rb', line 132

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'description': :'String',
    'target_resource_type': :'String',
    'target_resource_id': :'String',
    'recipe_count': :'Integer',
    'target_detector_recipes': :'Array<OCI::CloudGuard::Models::TargetDetectorRecipe>',
    'target_responder_recipes': :'Array<OCI::CloudGuard::Models::TargetResponderRecipe>',
    'inherited_by_compartments': :'Array<String>',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecyle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/oci/cloud_guard/models/target.rb', line 313

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    description == other.description &&
    target_resource_type == other.target_resource_type &&
    target_resource_id == other.target_resource_id &&
    recipe_count == other.recipe_count &&
    target_detector_recipes == other.target_detector_recipes &&
    target_responder_recipes == other.target_responder_recipes &&
    inherited_by_compartments == other.inherited_by_compartments &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecyle_details == other.lifecyle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/oci/cloud_guard/models/target.rb', line 359

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


339
340
341
# File 'lib/oci/cloud_guard/models/target.rb', line 339

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



348
349
350
# File 'lib/oci/cloud_guard/models/target.rb', line 348

def hash
  [id, display_name, compartment_id, description, target_resource_type, target_resource_id, recipe_count, target_detector_recipes, target_responder_recipes, inherited_by_compartments, time_created, time_updated, lifecycle_state, lifecyle_details, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



392
393
394
395
396
397
398
399
400
401
# File 'lib/oci/cloud_guard/models/target.rb', line 392

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



386
387
388
# File 'lib/oci/cloud_guard/models/target.rb', line 386

def to_s
  to_hash.to_s
end