Class: OCI::CloudGuard::Models::TargetDetectorDetails
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::TargetDetectorDetails
- Defined in:
- lib/oci/cloud_guard/models/target_detector_details.rb
Overview
Overriden settings of a Detector Rule applied on target
Constant Summary collapse
- RISK_LEVEL_ENUM =
[ RISK_LEVEL_CRITICAL = 'CRITICAL'.freeze, RISK_LEVEL_HIGH = 'HIGH'.freeze, RISK_LEVEL_MEDIUM = 'MEDIUM'.freeze, RISK_LEVEL_LOW = 'LOW'.freeze, RISK_LEVEL_MINOR = 'MINOR'.freeze, RISK_LEVEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#condition_groups ⇒ Array<OCI::CloudGuard::Models::ConditionGroup>
Condition group corresponding to each compartment.
-
#configurations ⇒ Array<OCI::CloudGuard::Models::DetectorConfiguration>
Configuration details.
-
#is_configuration_allowed ⇒ BOOLEAN
configuration allowed or not.
-
#is_enabled ⇒ BOOLEAN
[Required] Enables the control.
-
#labels ⇒ Array<String>
user defined labels for a detector rule.
-
#risk_level ⇒ String
[Required] The Risk Level.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetDetectorDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TargetDetectorDetails
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.risk_level = attributes[:'riskLevel'] if attributes[:'riskLevel'] raise 'You cannot provide both :riskLevel and :risk_level' if attributes.key?(:'riskLevel') && attributes.key?(:'risk_level') self.risk_level = attributes[:'risk_level'] if attributes[:'risk_level'] self.configurations = attributes[:'configurations'] if attributes[:'configurations'] self.condition_groups = attributes[:'conditionGroups'] if attributes[:'conditionGroups'] raise 'You cannot provide both :conditionGroups and :condition_groups' if attributes.key?(:'conditionGroups') && attributes.key?(:'condition_groups') self.condition_groups = attributes[:'condition_groups'] if attributes[:'condition_groups'] self.labels = attributes[:'labels'] if attributes[:'labels'] self.is_configuration_allowed = attributes[:'isConfigurationAllowed'] unless attributes[:'isConfigurationAllowed'].nil? raise 'You cannot provide both :isConfigurationAllowed and :is_configuration_allowed' if attributes.key?(:'isConfigurationAllowed') && attributes.key?(:'is_configuration_allowed') self.is_configuration_allowed = attributes[:'is_configuration_allowed'] unless attributes[:'is_configuration_allowed'].nil? end |
Instance Attribute Details
#condition_groups ⇒ Array<OCI::CloudGuard::Models::ConditionGroup>
Condition group corresponding to each compartment
34 35 36 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 34 def condition_groups @condition_groups end |
#configurations ⇒ Array<OCI::CloudGuard::Models::DetectorConfiguration>
Configuration details
30 31 32 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 30 def configurations @configurations end |
#is_configuration_allowed ⇒ BOOLEAN
configuration allowed or not
42 43 44 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 42 def is_configuration_allowed @is_configuration_allowed end |
#is_enabled ⇒ BOOLEAN
[Required] Enables the control
22 23 24 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 22 def is_enabled @is_enabled end |
#labels ⇒ Array<String>
user defined labels for a detector rule
38 39 40 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 38 def labels @labels end |
#risk_level ⇒ String
[Required] The Risk Level
26 27 28 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 26 def risk_level @risk_level end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'is_enabled': :'isEnabled', 'risk_level': :'riskLevel', 'configurations': :'configurations', 'condition_groups': :'conditionGroups', 'labels': :'labels', 'is_configuration_allowed': :'isConfigurationAllowed' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'is_enabled': :'BOOLEAN', 'risk_level': :'String', 'configurations': :'Array<OCI::CloudGuard::Models::DetectorConfiguration>', 'condition_groups': :'Array<OCI::CloudGuard::Models::ConditionGroup>', 'labels': :'Array<String>', 'is_configuration_allowed': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 139 def ==(other) return true if equal?(other) self.class == other.class && is_enabled == other.is_enabled && risk_level == other.risk_level && configurations == other.configurations && condition_groups == other.condition_groups && labels == other.labels && is_configuration_allowed == other.is_configuration_allowed end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 174 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
154 155 156 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 154 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
163 164 165 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 163 def hash [is_enabled, risk_level, configurations, condition_groups, labels, is_configuration_allowed].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 207 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
201 202 203 |
# File 'lib/oci/cloud_guard/models/target_detector_details.rb', line 201 def to_s to_hash.to_s end |