Class: OCI::CloudGuard::Models::TargetDetectorRecipe

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/cloud_guard/models/target_detector_recipe.rb

Overview

Target Detector recipe

Constant Summary collapse

OWNER_ENUM =
[
  OWNER_CUSTOMER = 'CUSTOMER'.freeze,
  OWNER_ORACLE = 'ORACLE'.freeze,
  OWNER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DETECTOR_ENUM =
[
  DETECTOR_IAAS_ACTIVITY_DETECTOR = 'IAAS_ACTIVITY_DETECTOR'.freeze,
  DETECTOR_IAAS_CONFIGURATION_DETECTOR = 'IAAS_CONFIGURATION_DETECTOR'.freeze,
  DETECTOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TargetDetectorRecipe

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 140

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.detector_recipe_id = attributes[:'detectorRecipeId'] if attributes[:'detectorRecipeId']

  raise 'You cannot provide both :detectorRecipeId and :detector_recipe_id' if attributes.key?(:'detectorRecipeId') && attributes.key?(:'detector_recipe_id')

  self.detector_recipe_id = attributes[:'detector_recipe_id'] if attributes[:'detector_recipe_id']

  self.owner = attributes[:'owner'] if attributes[:'owner']

  self.detector = attributes[:'detector'] if attributes[:'detector']

  self.detector_rules = attributes[:'detectorRules'] if attributes[:'detectorRules']

  raise 'You cannot provide both :detectorRules and :detector_rules' if attributes.key?(:'detectorRules') && attributes.key?(:'detector_rules')

  self.detector_rules = attributes[:'detector_rules'] if attributes[:'detector_rules']

  self.effective_detector_rules = attributes[:'effectiveDetectorRules'] if attributes[:'effectiveDetectorRules']

  raise 'You cannot provide both :effectiveDetectorRules and :effective_detector_rules' if attributes.key?(:'effectiveDetectorRules') && attributes.key?(:'effective_detector_rules')

  self.effective_detector_rules = attributes[:'effective_detector_rules'] if attributes[:'effective_detector_rules']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']
end

Instance Attribute Details

#compartment_idString

[Required] compartmentId of detector recipe

Returns:

  • (String)


48
49
50
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 48

def compartment_id
  @compartment_id
end

#descriptionString

Detector recipe description

Returns:

  • (String)


44
45
46
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 44

def description
  @description
end

#detectorString

[Required] Type of detector

Returns:

  • (String)


60
61
62
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 60

def detector
  @detector
end

#detector_recipe_idString

[Required] Unique identifier for Detector Recipe of which this is an extension

Returns:

  • (String)


52
53
54
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 52

def detector_recipe_id
  @detector_recipe_id
end

#detector_rulesArray<OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule>

List of detector rules for the detector type for recipe - user input



64
65
66
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 64

def detector_rules
  @detector_rules
end

#display_nameString

[Required] DisplayName of detector recipe

Returns:

  • (String)


40
41
42
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 40

def display_name
  @display_name
end

#effective_detector_rulesArray<OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule>

List of effective detector rules for the detector type for recipe after applying defaults



68
69
70
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 68

def effective_detector_rules
  @effective_detector_rules
end

#idString

[Required] Ocid for detector recipe

Returns:

  • (String)


36
37
38
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 36

def id
  @id
end

#lifecycle_stateString

The current state of the resource.

Returns:

  • (String)


80
81
82
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 80

def lifecycle_state
  @lifecycle_state
end

#ownerString

[Required] Owner of detector recipe

Returns:

  • (String)


56
57
58
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 56

def owner
  @owner
end

#time_createdDateTime

The date and time the target detector recipe was created. Format defined by RFC3339.

Returns:

  • (DateTime)


72
73
74
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 72

def time_created
  @time_created
end

#time_updatedDateTime

The date and time the target detector recipe was updated. Format defined by RFC3339.

Returns:

  • (DateTime)


76
77
78
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 76

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 83

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'detector_recipe_id': :'detectorRecipeId',
    'owner': :'owner',
    'detector': :'detector',
    'detector_rules': :'detectorRules',
    'effective_detector_rules': :'effectiveDetectorRules',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 103

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'detector_recipe_id': :'String',
    'owner': :'String',
    'detector': :'String',
    'detector_rules': :'Array<OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule>',
    'effective_detector_rules': :'Array<OCI::CloudGuard::Models::TargetDetectorRecipeDetectorRule>',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 249

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    detector_recipe_id == other.detector_recipe_id &&
    owner == other.owner &&
    detector == other.detector &&
    detector_rules == other.detector_rules &&
    effective_detector_rules == other.effective_detector_rules &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 290

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


270
271
272
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 270

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



279
280
281
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 279

def hash
  [id, display_name, description, compartment_id, detector_recipe_id, owner, detector, detector_rules, effective_detector_rules, time_created, time_updated, lifecycle_state].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



323
324
325
326
327
328
329
330
331
332
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 323

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



317
318
319
# File 'lib/oci/cloud_guard/models/target_detector_recipe.rb', line 317

def to_s
  to_hash.to_s
end