Class: OCI::CloudGuard::Models::TargetDetectorRecipeSummary
- Inherits:
-
Object
- Object
- OCI::CloudGuard::Models::TargetDetectorRecipeSummary
- Defined in:
- lib/oci/cloud_guard/models/target_detector_recipe_summary.rb
Overview
Summary of DetectorRecipe
Constant Summary collapse
- OWNER_ENUM =
[ OWNER_CUSTOMER = 'CUSTOMER'.freeze, OWNER_ORACLE = 'ORACLE'.freeze, OWNER_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DETECTOR_ENUM =
[ DETECTOR_IAAS_ACTIVITY_DETECTOR = 'IAAS_ACTIVITY_DETECTOR'.freeze, DETECTOR_IAAS_CONFIGURATION_DETECTOR = 'IAAS_CONFIGURATION_DETECTOR'.freeze, DETECTOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment Identifier.
-
#description ⇒ String
[Required] DetectorRecipe Description.
-
#detector ⇒ String
Type of detector.
-
#detector_recipe_id ⇒ String
[Required] Unique identifier for Detector Recipe of which this is an extension.
-
#display_name ⇒ String
[Required] DetectorRecipe Identifier Name.
-
#id ⇒ String
[Required] Unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the resource.
-
#owner ⇒ String
[Required] Owner of DetectorRecipe.
-
#time_created ⇒ DateTime
The date and time the target detector recipe was created.
-
#time_updated ⇒ DateTime
The date and time the target detector recipe was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetDetectorRecipeSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TargetDetectorRecipeSummary
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 133 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.owner = attributes[:'owner'] if attributes[:'owner'] self.detector_recipe_id = attributes[:'detectorRecipeId'] if attributes[:'detectorRecipeId'] raise 'You cannot provide both :detectorRecipeId and :detector_recipe_id' if attributes.key?(:'detectorRecipeId') && attributes.key?(:'detector_recipe_id') self.detector_recipe_id = attributes[:'detector_recipe_id'] if attributes[:'detector_recipe_id'] self.detector = attributes[:'detector'] if attributes[:'detector'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment Identifier
40 41 42 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 40 def compartment_id @compartment_id end |
#description ⇒ String
[Required] DetectorRecipe Description
48 49 50 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 48 def description @description end |
#detector ⇒ String
Type of detector
60 61 62 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 60 def detector @detector end |
#detector_recipe_id ⇒ String
[Required] Unique identifier for Detector Recipe of which this is an extension
56 57 58 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 56 def detector_recipe_id @detector_recipe_id end |
#display_name ⇒ String
[Required] DetectorRecipe Identifier Name
44 45 46 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 44 def display_name @display_name end |
#id ⇒ String
[Required] Unique identifier that is immutable on creation
36 37 38 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 36 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
76 77 78 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 76 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the resource.
64 65 66 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 64 def lifecycle_state @lifecycle_state end |
#owner ⇒ String
[Required] Owner of DetectorRecipe
52 53 54 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 52 def owner @owner end |
#time_created ⇒ DateTime
The date and time the target detector recipe was created. Format defined by RFC3339.
68 69 70 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 68 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the target detector recipe was updated. Format defined by RFC3339.
72 73 74 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 72 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 79 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'owner': :'owner', 'detector_recipe_id': :'detectorRecipeId', 'detector': :'detector', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_details': :'lifecycleDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 98 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'owner': :'String', 'detector_recipe_id': :'String', 'detector': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 236 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && owner == other.owner && detector_recipe_id == other.detector_recipe_id && detector == other.detector && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && lifecycle_details == other.lifecycle_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 276 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
256 257 258 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 256 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
265 266 267 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 265 def hash [id, compartment_id, display_name, description, owner, detector_recipe_id, detector, lifecycle_state, time_created, time_updated, lifecycle_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
309 310 311 312 313 314 315 316 317 318 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 309 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
303 304 305 |
# File 'lib/oci/cloud_guard/models/target_detector_recipe_summary.rb', line 303 def to_s to_hash.to_s end |