Class: OCI::ContainerEngine::Models::ClusterEndpoints

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/container_engine/models/cluster_endpoints.rb

Overview

The properties that define endpoints for a cluster.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ClusterEndpoints

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :kubernetes (String)

    The value to assign to the #kubernetes property

  • :public_endpoint (String)

    The value to assign to the #public_endpoint property

  • :private_endpoint (String)

    The value to assign to the #private_endpoint property



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 53

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.kubernetes = attributes[:'kubernetes'] if attributes[:'kubernetes']

  self.public_endpoint = attributes[:'publicEndpoint'] if attributes[:'publicEndpoint']

  raise 'You cannot provide both :publicEndpoint and :public_endpoint' if attributes.key?(:'publicEndpoint') && attributes.key?(:'public_endpoint')

  self.public_endpoint = attributes[:'public_endpoint'] if attributes[:'public_endpoint']

  self.private_endpoint = attributes[:'privateEndpoint'] if attributes[:'privateEndpoint']

  raise 'You cannot provide both :privateEndpoint and :private_endpoint' if attributes.key?(:'privateEndpoint') && attributes.key?(:'private_endpoint')

  self.private_endpoint = attributes[:'private_endpoint'] if attributes[:'private_endpoint']
end

Instance Attribute Details

#kubernetesString

The non-native networking Kubernetes API server endpoint.

Returns:

  • (String)


12
13
14
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 12

def kubernetes
  @kubernetes
end

#private_endpointString

The private native networking Kubernetes API server endpoint.

Returns:

  • (String)


20
21
22
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 20

def private_endpoint
  @private_endpoint
end

#public_endpointString

The public native networking Kubernetes API server endpoint, if one was requested.

Returns:

  • (String)


16
17
18
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 16

def public_endpoint
  @public_endpoint
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 23

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'kubernetes': :'kubernetes',
    'public_endpoint': :'publicEndpoint',
    'private_endpoint': :'privateEndpoint'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



34
35
36
37
38
39
40
41
42
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 34

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'kubernetes': :'String',
    'public_endpoint': :'String',
    'private_endpoint': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



81
82
83
84
85
86
87
88
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 81

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    kubernetes == other.kubernetes &&
    public_endpoint == other.public_endpoint &&
    private_endpoint == other.private_endpoint
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 113

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


93
94
95
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 93

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



102
103
104
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 102

def hash
  [kubernetes, public_endpoint, private_endpoint].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



146
147
148
149
150
151
152
153
154
155
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 146

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



140
141
142
# File 'lib/oci/container_engine/models/cluster_endpoints.rb', line 140

def to_s
  to_hash.to_s
end