Class: OCI::ContainerEngine::Models::CreateClusterDetails
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::CreateClusterDetails
- Defined in:
- lib/oci/container_engine/models/create_cluster_details.rb
Overview
The properties that define a request to create a cluster.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment in which to create the cluster.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#endpoint_config ⇒ OCI::ContainerEngine::Models::CreateClusterEndpointConfigDetails
The network configuration for access to the Cluster control plane.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#image_policy_config ⇒ OCI::ContainerEngine::Models::CreateImagePolicyConfigDetails
The image verification policy for signature validation.
-
#kms_key_id ⇒ String
The OCID of the KMS key to be used as the master encryption key for Kubernetes secret encryption.
-
#kubernetes_version ⇒ String
[Required] The version of Kubernetes to install into the cluster masters.
-
#name ⇒ String
[Required] The name of the cluster.
-
#options ⇒ OCI::ContainerEngine::Models::ClusterCreateOptions
Optional attributes for the cluster.
-
#vcn_id ⇒ String
[Required] The OCID of the virtual cloud network (VCN) in which to create the cluster.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateClusterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateClusterDetails
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.endpoint_config = attributes[:'endpointConfig'] if attributes[:'endpointConfig'] raise 'You cannot provide both :endpointConfig and :endpoint_config' if attributes.key?(:'endpointConfig') && attributes.key?(:'endpoint_config') self.endpoint_config = attributes[:'endpoint_config'] if attributes[:'endpoint_config'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.kubernetes_version = attributes[:'kubernetesVersion'] if attributes[:'kubernetesVersion'] raise 'You cannot provide both :kubernetesVersion and :kubernetes_version' if attributes.key?(:'kubernetesVersion') && attributes.key?(:'kubernetes_version') self.kubernetes_version = attributes[:'kubernetes_version'] if attributes[:'kubernetes_version'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'options'] if attributes[:'options'] self.image_policy_config = attributes[:'imagePolicyConfig'] if attributes[:'imagePolicyConfig'] raise 'You cannot provide both :imagePolicyConfig and :image_policy_config' if attributes.key?(:'imagePolicyConfig') && attributes.key?(:'image_policy_config') self.image_policy_config = attributes[:'image_policy_config'] if attributes[:'image_policy_config'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment in which to create the cluster.
16 17 18 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 16 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
49 50 51 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 49 def @defined_tags end |
#endpoint_config ⇒ OCI::ContainerEngine::Models::CreateClusterEndpointConfigDetails
The network configuration for access to the Cluster control plane.
21 22 23 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 21 def endpoint_config @endpoint_config end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
42 43 44 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 42 def @freeform_tags end |
#image_policy_config ⇒ OCI::ContainerEngine::Models::CreateImagePolicyConfigDetails
The image verification policy for signature validation. Once a policy is created and enabled with one or more kms keys, the policy will ensure all images deployed has been signed with the key(s) attached to the policy.
60 61 62 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 60 def image_policy_config @image_policy_config end |
#kms_key_id ⇒ String
The OCID of the KMS key to be used as the master encryption key for Kubernetes secret encryption. When used, kubernetesVersion must be at least v1.13.0.
35 36 37 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 35 def kms_key_id @kms_key_id end |
#kubernetes_version ⇒ String
[Required] The version of Kubernetes to install into the cluster masters.
29 30 31 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 29 def kubernetes_version @kubernetes_version end |
#name ⇒ String
[Required] The name of the cluster. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 12 def name @name end |
#options ⇒ OCI::ContainerEngine::Models::ClusterCreateOptions
Optional attributes for the cluster.
53 54 55 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 53 def @options end |
#vcn_id ⇒ String
[Required] The OCID of the virtual cloud network (VCN) in which to create the cluster.
25 26 27 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 25 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'compartment_id': :'compartmentId', 'endpoint_config': :'endpointConfig', 'vcn_id': :'vcnId', 'kubernetes_version': :'kubernetesVersion', 'kms_key_id': :'kmsKeyId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'options': :'options', 'image_policy_config': :'imagePolicyConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'compartment_id': :'String', 'endpoint_config': :'OCI::ContainerEngine::Models::CreateClusterEndpointConfigDetails', 'vcn_id': :'String', 'kubernetes_version': :'String', 'kms_key_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'options': :'OCI::ContainerEngine::Models::ClusterCreateOptions', 'image_policy_config': :'OCI::ContainerEngine::Models::CreateImagePolicyConfigDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 180 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && compartment_id == other.compartment_id && endpoint_config == other.endpoint_config && vcn_id == other.vcn_id && kubernetes_version == other.kubernetes_version && kms_key_id == other.kms_key_id && == other. && == other. && == other. && image_policy_config == other.image_policy_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 219 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
199 200 201 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 199 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 208 def hash [name, compartment_id, endpoint_config, vcn_id, kubernetes_version, kms_key_id, , , , image_policy_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 252 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
246 247 248 |
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 246 def to_s to_hash.to_s end |