Class: OCI::ContainerEngine::Models::CreateClusterDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/container_engine/models/create_cluster_details.rb

Overview

The properties that define a request to create a cluster.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateClusterDetails

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 76

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId']

  raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id')

  self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id']

  self.kubernetes_version = attributes[:'kubernetesVersion'] if attributes[:'kubernetesVersion']

  raise 'You cannot provide both :kubernetesVersion and :kubernetes_version' if attributes.key?(:'kubernetesVersion') && attributes.key?(:'kubernetes_version')

  self.kubernetes_version = attributes[:'kubernetes_version'] if attributes[:'kubernetes_version']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.options = attributes[:'options'] if attributes[:'options']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment in which to create the cluster.

Returns:



16
17
18
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 16

def compartment_id
  @compartment_id
end

#kms_key_idString

The OCID of the KMS key to be used as the master encryption key for Kubernetes secret encryption. When used, kubernetesVersion must be at least v1.13.0.

Returns:



30
31
32
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 30

def kms_key_id
  @kms_key_id
end

#kubernetes_versionString

[Required] The version of Kubernetes to install into the cluster masters.

Returns:



24
25
26
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 24

def kubernetes_version
  @kubernetes_version
end

#nameString

[Required] The name of the cluster. Avoid entering confidential information.

Returns:



12
13
14
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 12

def name
  @name
end

#optionsOCI::ContainerEngine::Models::ClusterCreateOptions

Optional attributes for the cluster.

Returns:



34
35
36
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 34

def options
  @options
end

#vcn_idString

[Required] The OCID of the virtual cloud network (VCN) in which to create the cluster.

Returns:



20
21
22
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 20

def vcn_id
  @vcn_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'compartment_id': :'compartmentId',
    'vcn_id': :'vcnId',
    'kubernetes_version': :'kubernetesVersion',
    'kms_key_id': :'kmsKeyId',
    'options': :'options'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 51

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'compartment_id': :'String',
    'vcn_id': :'String',
    'kubernetes_version': :'String',
    'kms_key_id': :'String',
    'options': :'OCI::ContainerEngine::Models::ClusterCreateOptions'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 118

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    vcn_id == other.vcn_id &&
    kubernetes_version == other.kubernetes_version &&
    kms_key_id == other.kms_key_id &&
    options == other.options
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 153

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



133
134
135
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 133

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



142
143
144
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 142

def hash
  [name, compartment_id, vcn_id, kubernetes_version, kms_key_id, options].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



180
181
182
# File 'lib/oci/container_engine/models/create_cluster_details.rb', line 180

def to_s
  to_hash.to_s
end