Class: OCI::ContainerEngine::Models::CreateNodePoolDetails
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::CreateNodePoolDetails
- Defined in:
- lib/oci/container_engine/models/create_node_pool_details.rb
Overview
The properties that define a request to create a node pool.
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
[Required] The OCID of the cluster to which this node pool is attached.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment in which the node pool exists.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#initial_node_labels ⇒ Array<OCI::ContainerEngine::Models::KeyValue>
A list of key/value pairs to add to nodes after they join the Kubernetes cluster.
-
#kubernetes_version ⇒ String
[Required] The version of Kubernetes to install on the nodes in the node pool.
-
#name ⇒ String
[Required] The name of the node pool.
-
#node_config_details ⇒ OCI::ContainerEngine::Models::CreateNodePoolNodeConfigDetails
The configuration of nodes in the node pool.
-
#node_image_name ⇒ String
Deprecated.
-
#node_metadata ⇒ Hash<String, String>
A list of key/value pairs to add to each underlying OCI instance in the node pool on launch.
-
#node_shape ⇒ String
[Required] The name of the node shape of the nodes in the node pool.
-
#node_shape_config ⇒ OCI::ContainerEngine::Models::CreateNodeShapeConfigDetails
Specify the configuration of the shape to launch nodes in the node pool.
-
#node_source_details ⇒ OCI::ContainerEngine::Models::NodeSourceDetails
Specify the source to use to launch nodes in the node pool.
-
#quantity_per_subnet ⇒ Integer
Optional, default to 1.
-
#ssh_public_key ⇒ String
The SSH public key on each node in the node pool on launch.
-
#subnet_ids ⇒ Array<String>
The OCIDs of the subnets in which to place nodes for this node pool.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateNodePoolDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateNodePoolDetails
Initializes the object
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 162 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.cluster_id = attributes[:'clusterId'] if attributes[:'clusterId'] raise 'You cannot provide both :clusterId and :cluster_id' if attributes.key?(:'clusterId') && attributes.key?(:'cluster_id') self.cluster_id = attributes[:'cluster_id'] if attributes[:'cluster_id'] self.name = attributes[:'name'] if attributes[:'name'] self.kubernetes_version = attributes[:'kubernetesVersion'] if attributes[:'kubernetesVersion'] raise 'You cannot provide both :kubernetesVersion and :kubernetes_version' if attributes.key?(:'kubernetesVersion') && attributes.key?(:'kubernetes_version') self.kubernetes_version = attributes[:'kubernetes_version'] if attributes[:'kubernetes_version'] self. = attributes[:'nodeMetadata'] if attributes[:'nodeMetadata'] raise 'You cannot provide both :nodeMetadata and :node_metadata' if attributes.key?(:'nodeMetadata') && attributes.key?(:'node_metadata') self. = attributes[:'node_metadata'] if attributes[:'node_metadata'] self.node_image_name = attributes[:'nodeImageName'] if attributes[:'nodeImageName'] raise 'You cannot provide both :nodeImageName and :node_image_name' if attributes.key?(:'nodeImageName') && attributes.key?(:'node_image_name') self.node_image_name = attributes[:'node_image_name'] if attributes[:'node_image_name'] self.node_source_details = attributes[:'nodeSourceDetails'] if attributes[:'nodeSourceDetails'] raise 'You cannot provide both :nodeSourceDetails and :node_source_details' if attributes.key?(:'nodeSourceDetails') && attributes.key?(:'node_source_details') self.node_source_details = attributes[:'node_source_details'] if attributes[:'node_source_details'] self.node_shape = attributes[:'nodeShape'] if attributes[:'nodeShape'] raise 'You cannot provide both :nodeShape and :node_shape' if attributes.key?(:'nodeShape') && attributes.key?(:'node_shape') self.node_shape = attributes[:'node_shape'] if attributes[:'node_shape'] self.node_shape_config = attributes[:'nodeShapeConfig'] if attributes[:'nodeShapeConfig'] raise 'You cannot provide both :nodeShapeConfig and :node_shape_config' if attributes.key?(:'nodeShapeConfig') && attributes.key?(:'node_shape_config') self.node_shape_config = attributes[:'node_shape_config'] if attributes[:'node_shape_config'] self.initial_node_labels = attributes[:'initialNodeLabels'] if attributes[:'initialNodeLabels'] raise 'You cannot provide both :initialNodeLabels and :initial_node_labels' if attributes.key?(:'initialNodeLabels') && attributes.key?(:'initial_node_labels') self.initial_node_labels = attributes[:'initial_node_labels'] if attributes[:'initial_node_labels'] self.ssh_public_key = attributes[:'sshPublicKey'] if attributes[:'sshPublicKey'] raise 'You cannot provide both :sshPublicKey and :ssh_public_key' if attributes.key?(:'sshPublicKey') && attributes.key?(:'ssh_public_key') self.ssh_public_key = attributes[:'ssh_public_key'] if attributes[:'ssh_public_key'] self.quantity_per_subnet = attributes[:'quantityPerSubnet'] if attributes[:'quantityPerSubnet'] self.quantity_per_subnet = 1 if quantity_per_subnet.nil? && !attributes.key?(:'quantityPerSubnet') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :quantityPerSubnet and :quantity_per_subnet' if attributes.key?(:'quantityPerSubnet') && attributes.key?(:'quantity_per_subnet') self.quantity_per_subnet = attributes[:'quantity_per_subnet'] if attributes[:'quantity_per_subnet'] self.quantity_per_subnet = 1 if quantity_per_subnet.nil? && !attributes.key?(:'quantityPerSubnet') && !attributes.key?(:'quantity_per_subnet') # rubocop:disable Style/StringLiterals self.subnet_ids = attributes[:'subnetIds'] if attributes[:'subnetIds'] raise 'You cannot provide both :subnetIds and :subnet_ids' if attributes.key?(:'subnetIds') && attributes.key?(:'subnet_ids') self.subnet_ids = attributes[:'subnet_ids'] if attributes[:'subnet_ids'] self.node_config_details = attributes[:'nodeConfigDetails'] if attributes[:'nodeConfigDetails'] raise 'You cannot provide both :nodeConfigDetails and :node_config_details' if attributes.key?(:'nodeConfigDetails') && attributes.key?(:'node_config_details') self.node_config_details = attributes[:'node_config_details'] if attributes[:'node_config_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#cluster_id ⇒ String
[Required] The OCID of the cluster to which this node pool is attached.
16 17 18 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 16 def cluster_id @cluster_id end |
#compartment_id ⇒ String
[Required] The OCID of the compartment in which the node pool exists.
12 13 14 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 12 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
90 91 92 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 90 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
83 84 85 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 83 def @freeform_tags end |
#initial_node_labels ⇒ Array<OCI::ContainerEngine::Models::KeyValue>
A list of key/value pairs to add to nodes after they join the Kubernetes cluster.
53 54 55 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 53 def initial_node_labels @initial_node_labels end |
#kubernetes_version ⇒ String
[Required] The version of Kubernetes to install on the nodes in the node pool.
24 25 26 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 24 def kubernetes_version @kubernetes_version end |
#name ⇒ String
[Required] The name of the node pool. Avoid entering confidential information.
20 21 22 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 20 def name @name end |
#node_config_details ⇒ OCI::ContainerEngine::Models::CreateNodePoolNodeConfigDetails
The configuration of nodes in the node pool. Exactly one of the subnetIds or nodeConfigDetails properties must be specified.
76 77 78 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 76 def node_config_details @node_config_details end |
#node_image_name ⇒ String
Deprecated. Use nodeSourceDetails instead. If you specify values for both, this value is ignored. The name of the image running on the nodes in the node pool.
35 36 37 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 35 def node_image_name @node_image_name end |
#node_metadata ⇒ Hash<String, String>
A list of key/value pairs to add to each underlying OCI instance in the node pool on launch.
28 29 30 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 28 def @node_metadata end |
#node_shape ⇒ String
[Required] The name of the node shape of the nodes in the node pool.
44 45 46 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 44 def node_shape @node_shape end |
#node_shape_config ⇒ OCI::ContainerEngine::Models::CreateNodeShapeConfigDetails
Specify the configuration of the shape to launch nodes in the node pool.
49 50 51 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 49 def node_shape_config @node_shape_config end |
#node_source_details ⇒ OCI::ContainerEngine::Models::NodeSourceDetails
Specify the source to use to launch nodes in the node pool. Currently, image is the only supported source.
40 41 42 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 40 def node_source_details @node_source_details end |
#quantity_per_subnet ⇒ Integer
Optional, default to 1. The number of nodes to create in each subnet specified in subnetIds property. When used, subnetIds is required. This property is deprecated, use nodeConfigDetails instead.
63 64 65 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 63 def quantity_per_subnet @quantity_per_subnet end |
#ssh_public_key ⇒ String
The SSH public key on each node in the node pool on launch.
57 58 59 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 57 def ssh_public_key @ssh_public_key end |
#subnet_ids ⇒ Array<String>
The OCIDs of the subnets in which to place nodes for this node pool. When used, quantityPerSubnet can be provided. This property is deprecated, use nodeConfigDetails. Exactly one of the subnetIds or nodeConfigDetails properties must be specified.
70 71 72 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 70 def subnet_ids @subnet_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 93 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'cluster_id': :'clusterId', 'name': :'name', 'kubernetes_version': :'kubernetesVersion', 'node_metadata': :'nodeMetadata', 'node_image_name': :'nodeImageName', 'node_source_details': :'nodeSourceDetails', 'node_shape': :'nodeShape', 'node_shape_config': :'nodeShapeConfig', 'initial_node_labels': :'initialNodeLabels', 'ssh_public_key': :'sshPublicKey', 'quantity_per_subnet': :'quantityPerSubnet', 'subnet_ids': :'subnetIds', 'node_config_details': :'nodeConfigDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 117 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'cluster_id': :'String', 'name': :'String', 'kubernetes_version': :'String', 'node_metadata': :'Hash<String, String>', 'node_image_name': :'String', 'node_source_details': :'OCI::ContainerEngine::Models::NodeSourceDetails', 'node_shape': :'String', 'node_shape_config': :'OCI::ContainerEngine::Models::CreateNodeShapeConfigDetails', 'initial_node_labels': :'Array<OCI::ContainerEngine::Models::KeyValue>', 'ssh_public_key': :'String', 'quantity_per_subnet': :'Integer', 'subnet_ids': :'Array<String>', 'node_config_details': :'OCI::ContainerEngine::Models::CreateNodePoolNodeConfigDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 270 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && cluster_id == other.cluster_id && name == other.name && kubernetes_version == other.kubernetes_version && == other. && node_image_name == other.node_image_name && node_source_details == other.node_source_details && node_shape == other.node_shape && node_shape_config == other.node_shape_config && initial_node_labels == other.initial_node_labels && ssh_public_key == other.ssh_public_key && quantity_per_subnet == other.quantity_per_subnet && subnet_ids == other.subnet_ids && node_config_details == other.node_config_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 315 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
295 296 297 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 295 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
304 305 306 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 304 def hash [compartment_id, cluster_id, name, kubernetes_version, , node_image_name, node_source_details, node_shape, node_shape_config, initial_node_labels, ssh_public_key, quantity_per_subnet, subnet_ids, node_config_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 357 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
342 343 344 |
# File 'lib/oci/container_engine/models/create_node_pool_details.rb', line 342 def to_s to_hash.to_s end |