Class: OCI::ContainerEngine::Models::CreateNodePoolNodeConfigDetails
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::CreateNodePoolNodeConfigDetails
- Defined in:
- lib/oci/container_engine/models/create_node_pool_node_config_details.rb
Overview
The size and placement configuration of nodes in the node pool.
Instance Attribute Summary collapse
-
#nsg_ids ⇒ Array<String>
The OCIDs of the Network Security Group(s) to associate nodes for this node pool with.
-
#placement_configs ⇒ Array<OCI::ContainerEngine::Models::NodePoolPlacementConfigDetails>
[Required] The placement configurations for the node pool.
-
#size ⇒ Integer
[Required] The number of nodes that should be in the node pool.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateNodePoolNodeConfigDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateNodePoolNodeConfigDetails
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 61 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.size = attributes[:'size'] if attributes[:'size'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.placement_configs = attributes[:'placementConfigs'] if attributes[:'placementConfigs'] raise 'You cannot provide both :placementConfigs and :placement_configs' if attributes.key?(:'placementConfigs') && attributes.key?(:'placement_configs') self.placement_configs = attributes[:'placement_configs'] if attributes[:'placement_configs'] end |
Instance Attribute Details
#nsg_ids ⇒ Array<String>
The OCIDs of the Network Security Group(s) to associate nodes for this node pool with. For more information about NSGs, see NetworkSecurityGroup.
18 19 20 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 18 def nsg_ids @nsg_ids end |
#placement_configs ⇒ Array<OCI::ContainerEngine::Models::NodePoolPlacementConfigDetails>
[Required] The placement configurations for the node pool. Provide one placement configuration for each availability domain in which you intend to launch a node.
To use the node pool with a regional subnet, provide a placement configuration for each availability domain, and include the regional subnet in each placement configuration.
28 29 30 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 28 def placement_configs @placement_configs end |
#size ⇒ Integer
[Required] The number of nodes that should be in the node pool.
13 14 15 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 13 def size @size end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'size': :'size', 'nsg_ids': :'nsgIds', 'placement_configs': :'placementConfigs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 42 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'size': :'Integer', 'nsg_ids': :'Array<String>', 'placement_configs': :'Array<OCI::ContainerEngine::Models::NodePoolPlacementConfigDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
89 90 91 92 93 94 95 96 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 89 def ==(other) return true if equal?(other) self.class == other.class && size == other.size && nsg_ids == other.nsg_ids && placement_configs == other.placement_configs end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 121 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
101 102 103 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 101 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
110 111 112 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 110 def hash [size, nsg_ids, placement_configs].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 154 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
148 149 150 |
# File 'lib/oci/container_engine/models/create_node_pool_node_config_details.rb', line 148 def to_s to_hash.to_s end |