Class: OCI::ContainerEngine::Models::NodePool
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::NodePool
- Defined in:
- lib/oci/container_engine/models/node_pool.rb
Overview
A pool of compute nodes attached to a cluster. Avoid entering confidential information.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
The OCID of the cluster to which this node pool is attached.
-
#compartment_id ⇒ String
The OCID of the compartment in which the node pool exists.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
The OCID of the node pool.
-
#initial_node_labels ⇒ Array<OCI::ContainerEngine::Models::KeyValue>
A list of key/value pairs to add to nodes after they join the Kubernetes cluster.
-
#kubernetes_version ⇒ String
The version of Kubernetes running on the nodes in the node pool.
-
#lifecycle_details ⇒ String
Details about the state of the nodepool.
-
#lifecycle_state ⇒ String
The state of the nodepool.
-
#name ⇒ String
The name of the node pool.
-
#node_config_details ⇒ OCI::ContainerEngine::Models::NodePoolNodeConfigDetails
The configuration of nodes in the node pool.
- #node_eviction_node_pool_settings ⇒ OCI::ContainerEngine::Models::NodeEvictionNodePoolSettings
-
#node_image_id ⇒ String
Deprecated.
-
#node_image_name ⇒ String
Deprecated.
-
#node_metadata ⇒ Hash<String, String>
A list of key/value pairs to add to each underlying OCI instance in the node pool on launch.
-
#node_shape ⇒ String
The name of the node shape of the nodes in the node pool.
-
#node_shape_config ⇒ OCI::ContainerEngine::Models::NodeShapeConfig
The shape configuration of the nodes.
-
#node_source ⇒ OCI::ContainerEngine::Models::NodeSourceOption
Deprecated.
-
#node_source_details ⇒ OCI::ContainerEngine::Models::NodeSourceDetails
Source running on the nodes in the node pool.
-
#nodes ⇒ Array<OCI::ContainerEngine::Models::Node>
The nodes in the node pool.
-
#quantity_per_subnet ⇒ Integer
The number of nodes in each subnet.
-
#ssh_public_key ⇒ String
The SSH public key on each node in the node pool on launch.
-
#subnet_ids ⇒ Array<String>
The OCIDs of the subnets in which to place nodes for this node pool.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NodePool
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NodePool
Initializes the object
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 222 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.cluster_id = attributes[:'clusterId'] if attributes[:'clusterId'] raise 'You cannot provide both :clusterId and :cluster_id' if attributes.key?(:'clusterId') && attributes.key?(:'cluster_id') self.cluster_id = attributes[:'cluster_id'] if attributes[:'cluster_id'] self.name = attributes[:'name'] if attributes[:'name'] self.kubernetes_version = attributes[:'kubernetesVersion'] if attributes[:'kubernetesVersion'] raise 'You cannot provide both :kubernetesVersion and :kubernetes_version' if attributes.key?(:'kubernetesVersion') && attributes.key?(:'kubernetes_version') self.kubernetes_version = attributes[:'kubernetes_version'] if attributes[:'kubernetes_version'] self. = attributes[:'nodeMetadata'] if attributes[:'nodeMetadata'] raise 'You cannot provide both :nodeMetadata and :node_metadata' if attributes.key?(:'nodeMetadata') && attributes.key?(:'node_metadata') self. = attributes[:'node_metadata'] if attributes[:'node_metadata'] self.node_image_id = attributes[:'nodeImageId'] if attributes[:'nodeImageId'] raise 'You cannot provide both :nodeImageId and :node_image_id' if attributes.key?(:'nodeImageId') && attributes.key?(:'node_image_id') self.node_image_id = attributes[:'node_image_id'] if attributes[:'node_image_id'] self.node_image_name = attributes[:'nodeImageName'] if attributes[:'nodeImageName'] raise 'You cannot provide both :nodeImageName and :node_image_name' if attributes.key?(:'nodeImageName') && attributes.key?(:'node_image_name') self.node_image_name = attributes[:'node_image_name'] if attributes[:'node_image_name'] self.node_shape_config = attributes[:'nodeShapeConfig'] if attributes[:'nodeShapeConfig'] raise 'You cannot provide both :nodeShapeConfig and :node_shape_config' if attributes.key?(:'nodeShapeConfig') && attributes.key?(:'node_shape_config') self.node_shape_config = attributes[:'node_shape_config'] if attributes[:'node_shape_config'] self.node_source = attributes[:'nodeSource'] if attributes[:'nodeSource'] raise 'You cannot provide both :nodeSource and :node_source' if attributes.key?(:'nodeSource') && attributes.key?(:'node_source') self.node_source = attributes[:'node_source'] if attributes[:'node_source'] self.node_source_details = attributes[:'nodeSourceDetails'] if attributes[:'nodeSourceDetails'] raise 'You cannot provide both :nodeSourceDetails and :node_source_details' if attributes.key?(:'nodeSourceDetails') && attributes.key?(:'node_source_details') self.node_source_details = attributes[:'node_source_details'] if attributes[:'node_source_details'] self.node_shape = attributes[:'nodeShape'] if attributes[:'nodeShape'] raise 'You cannot provide both :nodeShape and :node_shape' if attributes.key?(:'nodeShape') && attributes.key?(:'node_shape') self.node_shape = attributes[:'node_shape'] if attributes[:'node_shape'] self.initial_node_labels = attributes[:'initialNodeLabels'] if attributes[:'initialNodeLabels'] raise 'You cannot provide both :initialNodeLabels and :initial_node_labels' if attributes.key?(:'initialNodeLabels') && attributes.key?(:'initial_node_labels') self.initial_node_labels = attributes[:'initial_node_labels'] if attributes[:'initial_node_labels'] self.ssh_public_key = attributes[:'sshPublicKey'] if attributes[:'sshPublicKey'] raise 'You cannot provide both :sshPublicKey and :ssh_public_key' if attributes.key?(:'sshPublicKey') && attributes.key?(:'ssh_public_key') self.ssh_public_key = attributes[:'ssh_public_key'] if attributes[:'ssh_public_key'] self.quantity_per_subnet = attributes[:'quantityPerSubnet'] if attributes[:'quantityPerSubnet'] raise 'You cannot provide both :quantityPerSubnet and :quantity_per_subnet' if attributes.key?(:'quantityPerSubnet') && attributes.key?(:'quantity_per_subnet') self.quantity_per_subnet = attributes[:'quantity_per_subnet'] if attributes[:'quantity_per_subnet'] self.subnet_ids = attributes[:'subnetIds'] if attributes[:'subnetIds'] raise 'You cannot provide both :subnetIds and :subnet_ids' if attributes.key?(:'subnetIds') && attributes.key?(:'subnet_ids') self.subnet_ids = attributes[:'subnet_ids'] if attributes[:'subnet_ids'] self.nodes = attributes[:'nodes'] if attributes[:'nodes'] self.node_config_details = attributes[:'nodeConfigDetails'] if attributes[:'nodeConfigDetails'] raise 'You cannot provide both :nodeConfigDetails and :node_config_details' if attributes.key?(:'nodeConfigDetails') && attributes.key?(:'node_config_details') self.node_config_details = attributes[:'node_config_details'] if attributes[:'node_config_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.node_eviction_node_pool_settings = attributes[:'nodeEvictionNodePoolSettings'] if attributes[:'nodeEvictionNodePoolSettings'] raise 'You cannot provide both :nodeEvictionNodePoolSettings and :node_eviction_node_pool_settings' if attributes.key?(:'nodeEvictionNodePoolSettings') && attributes.key?(:'node_eviction_node_pool_settings') self.node_eviction_node_pool_settings = attributes[:'node_eviction_node_pool_settings'] if attributes[:'node_eviction_node_pool_settings'] end |
Instance Attribute Details
#cluster_id ⇒ String
The OCID of the cluster to which this node pool is attached.
41 42 43 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 41 def cluster_id @cluster_id end |
#compartment_id ⇒ String
The OCID of the compartment in which the node pool exists.
37 38 39 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 37 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
117 118 119 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 117 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
110 111 112 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 110 def @freeform_tags end |
#id ⇒ String
The OCID of the node pool.
25 26 27 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 25 def id @id end |
#initial_node_labels ⇒ Array<OCI::ContainerEngine::Models::KeyValue>
A list of key/value pairs to add to nodes after they join the Kubernetes cluster.
83 84 85 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 83 def initial_node_labels @initial_node_labels end |
#kubernetes_version ⇒ String
The version of Kubernetes running on the nodes in the node pool.
49 50 51 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 49 def kubernetes_version @kubernetes_version end |
#lifecycle_details ⇒ String
Details about the state of the nodepool.
33 34 35 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 33 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The state of the nodepool.
29 30 31 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 29 def lifecycle_state @lifecycle_state end |
#name ⇒ String
The name of the node pool.
45 46 47 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 45 def name @name end |
#node_config_details ⇒ OCI::ContainerEngine::Models::NodePoolNodeConfigDetails
The configuration of nodes in the node pool.
103 104 105 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 103 def node_config_details @node_config_details end |
#node_eviction_node_pool_settings ⇒ OCI::ContainerEngine::Models::NodeEvictionNodePoolSettings
126 127 128 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 126 def node_eviction_node_pool_settings @node_eviction_node_pool_settings end |
#node_image_id ⇒ String
Deprecated. see `nodeSource`. The OCID of the image running on the nodes in the node pool.
58 59 60 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 58 def node_image_id @node_image_id end |
#node_image_name ⇒ String
Deprecated. see `nodeSource`. The name of the image running on the nodes in the node pool.
63 64 65 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 63 def node_image_name @node_image_name end |
#node_metadata ⇒ Hash<String, String>
A list of key/value pairs to add to each underlying OCI instance in the node pool on launch.
53 54 55 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 53 def @node_metadata end |
#node_shape ⇒ String
The name of the node shape of the nodes in the node pool.
79 80 81 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 79 def node_shape @node_shape end |
#node_shape_config ⇒ OCI::ContainerEngine::Models::NodeShapeConfig
The shape configuration of the nodes.
67 68 69 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 67 def node_shape_config @node_shape_config end |
#node_source ⇒ OCI::ContainerEngine::Models::NodeSourceOption
Deprecated. see `nodeSourceDetails`. Source running on the nodes in the node pool.
71 72 73 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 71 def node_source @node_source end |
#node_source_details ⇒ OCI::ContainerEngine::Models::NodeSourceDetails
Source running on the nodes in the node pool.
75 76 77 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 75 def node_source_details @node_source_details end |
#nodes ⇒ Array<OCI::ContainerEngine::Models::Node>
The nodes in the node pool.
99 100 101 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 99 def nodes @nodes end |
#quantity_per_subnet ⇒ Integer
The number of nodes in each subnet.
91 92 93 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 91 def quantity_per_subnet @quantity_per_subnet end |
#ssh_public_key ⇒ String
The SSH public key on each node in the node pool on launch.
87 88 89 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 87 def ssh_public_key @ssh_public_key end |
#subnet_ids ⇒ Array<String>
The OCIDs of the subnets in which to place nodes for this node pool.
95 96 97 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 95 def subnet_ids @subnet_ids end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
123 124 125 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 123 def @system_tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 129 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'compartment_id': :'compartmentId', 'cluster_id': :'clusterId', 'name': :'name', 'kubernetes_version': :'kubernetesVersion', 'node_metadata': :'nodeMetadata', 'node_image_id': :'nodeImageId', 'node_image_name': :'nodeImageName', 'node_shape_config': :'nodeShapeConfig', 'node_source': :'nodeSource', 'node_source_details': :'nodeSourceDetails', 'node_shape': :'nodeShape', 'initial_node_labels': :'initialNodeLabels', 'ssh_public_key': :'sshPublicKey', 'quantity_per_subnet': :'quantityPerSubnet', 'subnet_ids': :'subnetIds', 'nodes': :'nodes', 'node_config_details': :'nodeConfigDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'node_eviction_node_pool_settings': :'nodeEvictionNodePoolSettings' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 161 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'compartment_id': :'String', 'cluster_id': :'String', 'name': :'String', 'kubernetes_version': :'String', 'node_metadata': :'Hash<String, String>', 'node_image_id': :'String', 'node_image_name': :'String', 'node_shape_config': :'OCI::ContainerEngine::Models::NodeShapeConfig', 'node_source': :'OCI::ContainerEngine::Models::NodeSourceOption', 'node_source_details': :'OCI::ContainerEngine::Models::NodeSourceDetails', 'node_shape': :'String', 'initial_node_labels': :'Array<OCI::ContainerEngine::Models::KeyValue>', 'ssh_public_key': :'String', 'quantity_per_subnet': :'Integer', 'subnet_ids': :'Array<String>', 'nodes': :'Array<OCI::ContainerEngine::Models::Node>', 'node_config_details': :'OCI::ContainerEngine::Models::NodePoolNodeConfigDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'node_eviction_node_pool_settings': :'OCI::ContainerEngine::Models::NodeEvictionNodePoolSettings' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 381 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && compartment_id == other.compartment_id && cluster_id == other.cluster_id && name == other.name && kubernetes_version == other.kubernetes_version && == other. && node_image_id == other.node_image_id && node_image_name == other.node_image_name && node_shape_config == other.node_shape_config && node_source == other.node_source && node_source_details == other.node_source_details && node_shape == other.node_shape && initial_node_labels == other.initial_node_labels && ssh_public_key == other.ssh_public_key && quantity_per_subnet == other.quantity_per_subnet && subnet_ids == other.subnet_ids && nodes == other.nodes && node_config_details == other.node_config_details && == other. && == other. && == other. && node_eviction_node_pool_settings == other.node_eviction_node_pool_settings end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 434 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
414 415 416 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 414 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
423 424 425 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 423 def hash [id, lifecycle_state, lifecycle_details, compartment_id, cluster_id, name, kubernetes_version, , node_image_id, node_image_name, node_shape_config, node_source, node_source_details, node_shape, initial_node_labels, ssh_public_key, quantity_per_subnet, subnet_ids, nodes, node_config_details, , , , node_eviction_node_pool_settings].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
467 468 469 470 471 472 473 474 475 476 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 467 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
461 462 463 |
# File 'lib/oci/container_engine/models/node_pool.rb', line 461 def to_s to_hash.to_s end |