Class: OCI::ContainerEngine::Models::NodePoolPlacementConfigDetails
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::NodePoolPlacementConfigDetails
- Defined in:
- lib/oci/container_engine/models/node_pool_placement_config_details.rb
Overview
The location where a node pool will place nodes.
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
**[Required]** The availability domain in which to place nodes.
-
#capacity_reservation_id ⇒ String
The OCID of the compute capacity reservation in which to place the compute instance.
-
#fault_domains ⇒ Array<String>
A list of fault domains in which to place nodes.
-
#subnet_id ⇒ String
**[Required]** The OCID of the subnet in which to place nodes.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NodePoolPlacementConfigDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NodePoolPlacementConfigDetails
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.capacity_reservation_id = attributes[:'capacityReservationId'] if attributes[:'capacityReservationId'] raise 'You cannot provide both :capacityReservationId and :capacity_reservation_id' if attributes.key?(:'capacityReservationId') && attributes.key?(:'capacity_reservation_id') self.capacity_reservation_id = attributes[:'capacity_reservation_id'] if attributes[:'capacity_reservation_id'] self.fault_domains = attributes[:'faultDomains'] if attributes[:'faultDomains'] raise 'You cannot provide both :faultDomains and :fault_domains' if attributes.key?(:'faultDomains') && attributes.key?(:'fault_domains') self.fault_domains = attributes[:'fault_domains'] if attributes[:'fault_domains'] end |
Instance Attribute Details
#availability_domain ⇒ String
**[Required]** The availability domain in which to place nodes. Example: `Uocm:PHX-AD-1`
14 15 16 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 14 def availability_domain @availability_domain end |
#capacity_reservation_id ⇒ String
The OCID of the compute capacity reservation in which to place the compute instance.
22 23 24 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 22 def capacity_reservation_id @capacity_reservation_id end |
#fault_domains ⇒ Array<String>
A list of fault domains in which to place nodes.
27 28 29 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 27 def fault_domains @fault_domains end |
#subnet_id ⇒ String
**[Required]** The OCID of the subnet in which to place nodes.
18 19 20 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 18 def subnet_id @subnet_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'subnet_id': :'subnetId', 'capacity_reservation_id': :'capacityReservationId', 'fault_domains': :'faultDomains' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 42 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'subnet_id': :'String', 'capacity_reservation_id': :'String', 'fault_domains': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 101 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && subnet_id == other.subnet_id && capacity_reservation_id == other.capacity_reservation_id && fault_domains == other.fault_domains end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 134 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
114 115 116 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 114 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
123 124 125 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 123 def hash [availability_domain, subnet_id, capacity_reservation_id, fault_domains].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 167 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
161 162 163 |
# File 'lib/oci/container_engine/models/node_pool_placement_config_details.rb', line 161 def to_s to_hash.to_s end |