Class: OCI::ContainerEngine::Models::UpdateClusterDetails
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::UpdateClusterDetails
- Defined in:
- lib/oci/container_engine/models/update_cluster_details.rb
Overview
The properties that define a request to update a cluster.
Instance Attribute Summary collapse
-
#image_policy_config ⇒ OCI::ContainerEngine::Models::UpdateImagePolicyConfigDetails
The image verification policy for signature validation.
-
#kubernetes_version ⇒ String
The version of Kubernetes to which the cluster masters should be upgraded.
-
#name ⇒ String
The new name for the cluster.
- #options ⇒ OCI::ContainerEngine::Models::UpdateClusterOptionsDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateClusterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateClusterDetails
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.kubernetes_version = attributes[:'kubernetesVersion'] if attributes[:'kubernetesVersion'] raise 'You cannot provide both :kubernetesVersion and :kubernetes_version' if attributes.key?(:'kubernetesVersion') && attributes.key?(:'kubernetes_version') self.kubernetes_version = attributes[:'kubernetes_version'] if attributes[:'kubernetes_version'] self. = attributes[:'options'] if attributes[:'options'] self.image_policy_config = attributes[:'imagePolicyConfig'] if attributes[:'imagePolicyConfig'] raise 'You cannot provide both :imagePolicyConfig and :image_policy_config' if attributes.key?(:'imagePolicyConfig') && attributes.key?(:'image_policy_config') self.image_policy_config = attributes[:'image_policy_config'] if attributes[:'image_policy_config'] end |
Instance Attribute Details
#image_policy_config ⇒ OCI::ContainerEngine::Models::UpdateImagePolicyConfigDetails
The image verification policy for signature validation. Once a policy is created and enabled with one or more kms keys, the policy will ensure all images deployed has been signed with the key(s) attached to the policy.
26 27 28 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 26 def image_policy_config @image_policy_config end |
#kubernetes_version ⇒ String
The version of Kubernetes to which the cluster masters should be upgraded.
16 17 18 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 16 def kubernetes_version @kubernetes_version end |
#name ⇒ String
The new name for the cluster. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 12 def name @name end |
#options ⇒ OCI::ContainerEngine::Models::UpdateClusterOptionsDetails
19 20 21 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 19 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'kubernetes_version': :'kubernetesVersion', 'options': :'options', 'image_policy_config': :'imagePolicyConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'kubernetes_version': :'String', 'options': :'OCI::ContainerEngine::Models::UpdateClusterOptionsDetails', 'image_policy_config': :'OCI::ContainerEngine::Models::UpdateImagePolicyConfigDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 92 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && kubernetes_version == other.kubernetes_version && == other. && image_policy_config == other.image_policy_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 125 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
105 106 107 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 105 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
114 115 116 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 114 def hash [name, kubernetes_version, , image_policy_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 158 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
152 153 154 |
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 152 def to_s to_hash.to_s end |