Class: OCI::ContainerEngine::Models::UpdateClusterDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/container_engine/models/update_cluster_details.rb

Overview

The properties that define a request to update a cluster.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateClusterDetails

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 62

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.kubernetes_version = attributes[:'kubernetesVersion'] if attributes[:'kubernetesVersion']

  raise 'You cannot provide both :kubernetesVersion and :kubernetes_version' if attributes.key?(:'kubernetesVersion') && attributes.key?(:'kubernetes_version')

  self.kubernetes_version = attributes[:'kubernetes_version'] if attributes[:'kubernetes_version']

  self.options = attributes[:'options'] if attributes[:'options']

  self.image_policy_config = attributes[:'imagePolicyConfig'] if attributes[:'imagePolicyConfig']

  raise 'You cannot provide both :imagePolicyConfig and :image_policy_config' if attributes.key?(:'imagePolicyConfig') && attributes.key?(:'image_policy_config')

  self.image_policy_config = attributes[:'image_policy_config'] if attributes[:'image_policy_config']
end

Instance Attribute Details

#image_policy_configOCI::ContainerEngine::Models::UpdateImagePolicyConfigDetails

The image verification policy for signature validation. Once a policy is created and enabled with one or more kms keys, the policy will ensure all images deployed has been signed with the key(s) attached to the policy.

Returns:



26
27
28
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 26

def image_policy_config
  @image_policy_config
end

#kubernetes_versionString

The version of Kubernetes to which the cluster masters should be upgraded.

Returns:



16
17
18
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 16

def kubernetes_version
  @kubernetes_version
end

#nameString

The new name for the cluster. Avoid entering confidential information.

Returns:



12
13
14
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 12

def name
  @name
end

#optionsOCI::ContainerEngine::Models::UpdateClusterOptionsDetails

Returns:



19
20
21
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 19

def options
  @options
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
38
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 29

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'kubernetes_version': :'kubernetesVersion',
    'options': :'options',
    'image_policy_config': :'imagePolicyConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



41
42
43
44
45
46
47
48
49
50
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 41

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'kubernetes_version': :'String',
    'options': :'OCI::ContainerEngine::Models::UpdateClusterOptionsDetails',
    'image_policy_config': :'OCI::ContainerEngine::Models::UpdateImagePolicyConfigDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



92
93
94
95
96
97
98
99
100
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 92

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    kubernetes_version == other.kubernetes_version &&
    options == other.options &&
    image_policy_config == other.image_policy_config
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 125

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


105
106
107
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 105

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



114
115
116
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 114

def hash
  [name, kubernetes_version, options, image_policy_config].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 158

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



152
153
154
# File 'lib/oci/container_engine/models/update_cluster_details.rb', line 152

def to_s
  to_hash.to_s
end