Class: OCI::ContainerEngine::Models::UpdateNodePoolDetails
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::UpdateNodePoolDetails
- Defined in:
- lib/oci/container_engine/models/update_node_pool_details.rb
Overview
The properties that define a request to update a node pool.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#initial_node_labels ⇒ Array<OCI::ContainerEngine::Models::KeyValue>
A list of key/value pairs to add to nodes after they join the Kubernetes cluster.
-
#kubernetes_version ⇒ String
The version of Kubernetes to which the nodes in the node pool should be upgraded.
-
#name ⇒ String
The new name for the cluster.
-
#node_config_details ⇒ OCI::ContainerEngine::Models::UpdateNodePoolNodeConfigDetails
The configuration of nodes in the node pool.
-
#node_metadata ⇒ Hash<String, String>
A list of key/value pairs to add to each underlying OCI instance in the node pool on launch.
-
#node_shape ⇒ String
The name of the node shape of the nodes in the node pool used on launch.
-
#node_shape_config ⇒ OCI::ContainerEngine::Models::UpdateNodeShapeConfigDetails
Specify the configuration of the shape to launch nodes in the node pool.
-
#node_source_details ⇒ OCI::ContainerEngine::Models::NodeSourceDetails
Specify the source to use to launch nodes in the node pool.
-
#quantity_per_subnet ⇒ Integer
The number of nodes to have in each subnet specified in the subnetIds property.
-
#ssh_public_key ⇒ String
The SSH public key to add to each node in the node pool on launch.
-
#subnet_ids ⇒ Array<String>
The OCIDs of the subnets in which to place nodes for this node pool.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateNodePoolDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateNodePoolDetails
Initializes the object
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 143 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.kubernetes_version = attributes[:'kubernetesVersion'] if attributes[:'kubernetesVersion'] raise 'You cannot provide both :kubernetesVersion and :kubernetes_version' if attributes.key?(:'kubernetesVersion') && attributes.key?(:'kubernetes_version') self.kubernetes_version = attributes[:'kubernetes_version'] if attributes[:'kubernetes_version'] self.initial_node_labels = attributes[:'initialNodeLabels'] if attributes[:'initialNodeLabels'] raise 'You cannot provide both :initialNodeLabels and :initial_node_labels' if attributes.key?(:'initialNodeLabels') && attributes.key?(:'initial_node_labels') self.initial_node_labels = attributes[:'initial_node_labels'] if attributes[:'initial_node_labels'] self.quantity_per_subnet = attributes[:'quantityPerSubnet'] if attributes[:'quantityPerSubnet'] raise 'You cannot provide both :quantityPerSubnet and :quantity_per_subnet' if attributes.key?(:'quantityPerSubnet') && attributes.key?(:'quantity_per_subnet') self.quantity_per_subnet = attributes[:'quantity_per_subnet'] if attributes[:'quantity_per_subnet'] self.subnet_ids = attributes[:'subnetIds'] if attributes[:'subnetIds'] raise 'You cannot provide both :subnetIds and :subnet_ids' if attributes.key?(:'subnetIds') && attributes.key?(:'subnet_ids') self.subnet_ids = attributes[:'subnet_ids'] if attributes[:'subnet_ids'] self.node_config_details = attributes[:'nodeConfigDetails'] if attributes[:'nodeConfigDetails'] raise 'You cannot provide both :nodeConfigDetails and :node_config_details' if attributes.key?(:'nodeConfigDetails') && attributes.key?(:'node_config_details') self.node_config_details = attributes[:'node_config_details'] if attributes[:'node_config_details'] self. = attributes[:'nodeMetadata'] if attributes[:'nodeMetadata'] raise 'You cannot provide both :nodeMetadata and :node_metadata' if attributes.key?(:'nodeMetadata') && attributes.key?(:'node_metadata') self. = attributes[:'node_metadata'] if attributes[:'node_metadata'] self.node_source_details = attributes[:'nodeSourceDetails'] if attributes[:'nodeSourceDetails'] raise 'You cannot provide both :nodeSourceDetails and :node_source_details' if attributes.key?(:'nodeSourceDetails') && attributes.key?(:'node_source_details') self.node_source_details = attributes[:'node_source_details'] if attributes[:'node_source_details'] self.ssh_public_key = attributes[:'sshPublicKey'] if attributes[:'sshPublicKey'] raise 'You cannot provide both :sshPublicKey and :ssh_public_key' if attributes.key?(:'sshPublicKey') && attributes.key?(:'ssh_public_key') self.ssh_public_key = attributes[:'ssh_public_key'] if attributes[:'ssh_public_key'] self.node_shape = attributes[:'nodeShape'] if attributes[:'nodeShape'] raise 'You cannot provide both :nodeShape and :node_shape' if attributes.key?(:'nodeShape') && attributes.key?(:'node_shape') self.node_shape = attributes[:'node_shape'] if attributes[:'node_shape'] self.node_shape_config = attributes[:'nodeShapeConfig'] if attributes[:'nodeShapeConfig'] raise 'You cannot provide both :nodeShapeConfig and :node_shape_config' if attributes.key?(:'nodeShapeConfig') && attributes.key?(:'node_shape_config') self.node_shape_config = attributes[:'node_shape_config'] if attributes[:'node_shape_config'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
80 81 82 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 80 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
73 74 75 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 73 def @freeform_tags end |
#initial_node_labels ⇒ Array<OCI::ContainerEngine::Models::KeyValue>
A list of key/value pairs to add to nodes after they join the Kubernetes cluster.
20 21 22 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 20 def initial_node_labels @initial_node_labels end |
#kubernetes_version ⇒ String
The version of Kubernetes to which the nodes in the node pool should be upgraded.
16 17 18 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 16 def kubernetes_version @kubernetes_version end |
#name ⇒ String
The new name for the cluster. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 12 def name @name end |
#node_config_details ⇒ OCI::ContainerEngine::Models::UpdateNodePoolNodeConfigDetails
The configuration of nodes in the node pool. Only one of the subnetIds or nodeConfigDetails properties should be specified. If the current value of quantityPerSubnet is greater than 0, the node pool may still be scaled using quantityPerSubnet. Before you can use nodeConfigDetails, you must first scale the node pool to 0 nodes using quantityPerSubnet.
44 45 46 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 44 def node_config_details @node_config_details end |
#node_metadata ⇒ Hash<String, String>
A list of key/value pairs to add to each underlying OCI instance in the node pool on launch.
48 49 50 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 48 def @node_metadata end |
#node_shape ⇒ String
The name of the node shape of the nodes in the node pool used on launch.
61 62 63 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 61 def node_shape @node_shape end |
#node_shape_config ⇒ OCI::ContainerEngine::Models::UpdateNodeShapeConfigDetails
Specify the configuration of the shape to launch nodes in the node pool.
66 67 68 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 66 def node_shape_config @node_shape_config end |
#node_source_details ⇒ OCI::ContainerEngine::Models::NodeSourceDetails
Specify the source to use to launch nodes in the node pool. Currently, image is the only supported source.
53 54 55 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 53 def node_source_details @node_source_details end |
#quantity_per_subnet ⇒ Integer
The number of nodes to have in each subnet specified in the subnetIds property. This property is deprecated, use nodeConfigDetails instead. If the current value of quantityPerSubnet is greater than 0, you can only use quantityPerSubnet to scale the node pool. If the current value of quantityPerSubnet is equal to 0 and the current value of size in nodeConfigDetails is greater than 0, before you can use quantityPerSubnet, you must first scale the node pool to 0 nodes using nodeConfigDetails.
29 30 31 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 29 def quantity_per_subnet @quantity_per_subnet end |
#ssh_public_key ⇒ String
The SSH public key to add to each node in the node pool on launch.
57 58 59 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 57 def ssh_public_key @ssh_public_key end |
#subnet_ids ⇒ Array<String>
The OCIDs of the subnets in which to place nodes for this node pool. This property is deprecated, use nodeConfigDetails instead. Only one of the subnetIds or nodeConfigDetails properties can be specified.
36 37 38 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 36 def subnet_ids @subnet_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 83 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'kubernetes_version': :'kubernetesVersion', 'initial_node_labels': :'initialNodeLabels', 'quantity_per_subnet': :'quantityPerSubnet', 'subnet_ids': :'subnetIds', 'node_config_details': :'nodeConfigDetails', 'node_metadata': :'nodeMetadata', 'node_source_details': :'nodeSourceDetails', 'ssh_public_key': :'sshPublicKey', 'node_shape': :'nodeShape', 'node_shape_config': :'nodeShapeConfig', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 104 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'kubernetes_version': :'String', 'initial_node_labels': :'Array<OCI::ContainerEngine::Models::KeyValue>', 'quantity_per_subnet': :'Integer', 'subnet_ids': :'Array<String>', 'node_config_details': :'OCI::ContainerEngine::Models::UpdateNodePoolNodeConfigDetails', 'node_metadata': :'Hash<String, String>', 'node_source_details': :'OCI::ContainerEngine::Models::NodeSourceDetails', 'ssh_public_key': :'String', 'node_shape': :'String', 'node_shape_config': :'OCI::ContainerEngine::Models::UpdateNodeShapeConfigDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 231 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && kubernetes_version == other.kubernetes_version && initial_node_labels == other.initial_node_labels && quantity_per_subnet == other.quantity_per_subnet && subnet_ids == other.subnet_ids && node_config_details == other.node_config_details && == other. && node_source_details == other.node_source_details && ssh_public_key == other.ssh_public_key && node_shape == other.node_shape && node_shape_config == other.node_shape_config && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 273 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
253 254 255 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 253 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
262 263 264 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 262 def hash [name, kubernetes_version, initial_node_labels, quantity_per_subnet, subnet_ids, node_config_details, , node_source_details, ssh_public_key, node_shape, node_shape_config, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
306 307 308 309 310 311 312 313 314 315 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 306 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
300 301 302 |
# File 'lib/oci/container_engine/models/update_node_pool_details.rb', line 300 def to_s to_hash.to_s end |