Class: OCI::ContainerEngine::Models::WorkRequest
- Inherits:
-
Object
- Object
- OCI::ContainerEngine::Models::WorkRequest
- Defined in:
- lib/oci/container_engine/models/work_request.rb
Overview
An asynchronous work request.
Constant Summary collapse
- OPERATION_TYPE_ENUM =
[ OPERATION_TYPE_CLUSTER_CREATE = 'CLUSTER_CREATE'.freeze, OPERATION_TYPE_CLUSTER_UPDATE = 'CLUSTER_UPDATE'.freeze, OPERATION_TYPE_CLUSTER_DELETE = 'CLUSTER_DELETE'.freeze, OPERATION_TYPE_NODEPOOL_CREATE = 'NODEPOOL_CREATE'.freeze, OPERATION_TYPE_NODEPOOL_UPDATE = 'NODEPOOL_UPDATE'.freeze, OPERATION_TYPE_NODEPOOL_DELETE = 'NODEPOOL_DELETE'.freeze, OPERATION_TYPE_NODEPOOL_RECONCILE = 'NODEPOOL_RECONCILE'.freeze, OPERATION_TYPE_WORKREQUEST_CANCEL = 'WORKREQUEST_CANCEL'.freeze, OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_ACCEPTED = 'ACCEPTED'.freeze, STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze, STATUS_FAILED = 'FAILED'.freeze, STATUS_SUCCEEDED = 'SUCCEEDED'.freeze, STATUS_CANCELING = 'CANCELING'.freeze, STATUS_CANCELED = 'CANCELED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the compartment in which the work request exists.
-
#id ⇒ String
The OCID of the work request.
-
#operation_type ⇒ String
The type of work the work request is doing.
-
#resources ⇒ Array<OCI::ContainerEngine::Models::WorkRequestResource>
The resources this work request affects.
-
#status ⇒ String
The current status of the work request.
-
#time_accepted ⇒ DateTime
The time the work request was accepted.
-
#time_finished ⇒ DateTime
The time the work request was finished.
-
#time_started ⇒ DateTime
The time the work request was started.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequest
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequest
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/container_engine/models/work_request.rb', line 111 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.operation_type = attributes[:'operationType'] if attributes[:'operationType'] raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type'] self.status = attributes[:'status'] if attributes[:'status'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.resources = attributes[:'resources'] if attributes[:'resources'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the compartment in which the work request exists.
47 48 49 |
# File 'lib/oci/container_engine/models/work_request.rb', line 47 def compartment_id @compartment_id end |
#id ⇒ String
The OCID of the work request.
35 36 37 |
# File 'lib/oci/container_engine/models/work_request.rb', line 35 def id @id end |
#operation_type ⇒ String
The type of work the work request is doing.
39 40 41 |
# File 'lib/oci/container_engine/models/work_request.rb', line 39 def operation_type @operation_type end |
#resources ⇒ Array<OCI::ContainerEngine::Models::WorkRequestResource>
The resources this work request affects.
51 52 53 |
# File 'lib/oci/container_engine/models/work_request.rb', line 51 def resources @resources end |
#status ⇒ String
The current status of the work request.
43 44 45 |
# File 'lib/oci/container_engine/models/work_request.rb', line 43 def status @status end |
#time_accepted ⇒ DateTime
The time the work request was accepted.
55 56 57 |
# File 'lib/oci/container_engine/models/work_request.rb', line 55 def time_accepted @time_accepted end |
#time_finished ⇒ DateTime
The time the work request was finished.
63 64 65 |
# File 'lib/oci/container_engine/models/work_request.rb', line 63 def time_finished @time_finished end |
#time_started ⇒ DateTime
The time the work request was started.
59 60 61 |
# File 'lib/oci/container_engine/models/work_request.rb', line 59 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/container_engine/models/work_request.rb', line 66 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'operation_type': :'operationType', 'status': :'status', 'compartment_id': :'compartmentId', 'resources': :'resources', 'time_accepted': :'timeAccepted', 'time_started': :'timeStarted', 'time_finished': :'timeFinished' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/container_engine/models/work_request.rb', line 82 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'operation_type': :'String', 'status': :'String', 'compartment_id': :'String', 'resources': :'Array<OCI::ContainerEngine::Models::WorkRequestResource>', 'time_accepted': :'DateTime', 'time_started': :'DateTime', 'time_finished': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/container_engine/models/work_request.rb', line 187 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && operation_type == other.operation_type && status == other.status && compartment_id == other.compartment_id && resources == other.resources && time_accepted == other.time_accepted && time_started == other.time_started && time_finished == other.time_finished end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/oci/container_engine/models/work_request.rb', line 224 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
204 205 206 |
# File 'lib/oci/container_engine/models/work_request.rb', line 204 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/oci/container_engine/models/work_request.rb', line 213 def hash [id, operation_type, status, compartment_id, resources, time_accepted, time_started, time_finished].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/container_engine/models/work_request.rb', line 257 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
251 252 253 |
# File 'lib/oci/container_engine/models/work_request.rb', line 251 def to_s to_hash.to_s end |