Method: OCI::Core::ComputeClient#initialize
- Defined in:
- lib/oci/core/compute_client.rb
#initialize(config: nil, region: nil) ⇒ ComputeClient
Creates a new ComputeClient. If a config is not specified, then the global OCI.config will be used.
A region must be specified in either the config or the region parameter. If specified in both, then the region parameter will be used.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/core/compute_client.rb', line 32 def initialize(config:nil, region:nil) config ||= OCI.config config.validate signer = Signer.new(config.user, config.fingerprint, config.tenancy, config.key_file, pass_phrase: config.pass_phrase, private_key_content: config.key_content, signing_strategy: Signer::STANDARD) @api_client = ApiClient.new(config, signer) region ||= config.region self.region = region end |