Method: OCI::Core::ComputeClient#list_images
- Defined in:
- lib/oci/core/compute_client.rb
#list_images(compartment_id, opts = {}) ⇒ Response
Lists the available images in the specified compartment, including both [Oracle-provided images](docs.cloud.oracle.com/Content/Compute/References/images.htm) and [custom images](docs.cloud.oracle.com/Content/Compute/Tasks/managingcustomimages.htm) that have been created. The list of images returned is ordered to first show all Oracle-provided images, then all custom images.
The order of images returned may change when new images are released.
2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 2475 |
# File 'lib/oci/core/compute_client.rb', line 2419 def list_images(compartment_id, opts = {}) logger.debug 'Calling operation ComputeClient#list_images.' if logger raise "Missing the required parameter 'compartment_id' when calling list_images." if compartment_id.nil? if opts[:sort_by] && !%w[TIMECREATED DISPLAYNAME].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of TIMECREATED, DISPLAYNAME.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:lifecycle_state] && !OCI::Core::Models::Image::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::Core::Models::Image::LIFECYCLE_STATE_ENUM.' end path = '/images' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:operatingSystem] = opts[:operating_system] if opts[:operating_system] query_params[:operatingSystemVersion] = opts[:operating_system_version] if opts[:operating_system_version] query_params[:shape] = opts[:shape] if opts[:shape] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'ComputeClient#list_images') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'Array<OCI::Core::Models::Image>' ) end # rubocop:enable Metrics/BlockLength end |