Class: OCI::Core::Models::AddSecurityRuleDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::AddSecurityRuleDetails
- Defined in:
- lib/oci/core/models/add_security_rule_details.rb
Overview
A rule for allowing inbound (INGRESS) or outbound (EGRESS) IP packets.
Constant Summary collapse
- DESTINATION_TYPE_ENUM =
[ DESTINATION_TYPE_CIDR_BLOCK = 'CIDR_BLOCK'.freeze, DESTINATION_TYPE_SERVICE_CIDR_BLOCK = 'SERVICE_CIDR_BLOCK'.freeze, DESTINATION_TYPE_NETWORK_SECURITY_GROUP = 'NETWORK_SECURITY_GROUP'.freeze ].freeze
- DIRECTION_ENUM =
[ DIRECTION_EGRESS = 'EGRESS'.freeze, DIRECTION_INGRESS = 'INGRESS'.freeze ].freeze
- SOURCE_TYPE_ENUM =
[ SOURCE_TYPE_CIDR_BLOCK = 'CIDR_BLOCK'.freeze, SOURCE_TYPE_SERVICE_CIDR_BLOCK = 'SERVICE_CIDR_BLOCK'.freeze, SOURCE_TYPE_NETWORK_SECURITY_GROUP = 'NETWORK_SECURITY_GROUP'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of your choice for the rule.
-
#destination ⇒ String
Conceptually, this is the range of IP addresses that a packet originating from the instance can go to.
-
#destination_type ⇒ String
Type of destination for the rule.
-
#direction ⇒ String
[Required] Direction of the security rule.
-
#icmp_options ⇒ OCI::Core::Models::IcmpOptions
Optional and valid only for ICMP and ICMPv6.
-
#is_stateless ⇒ BOOLEAN
A stateless rule allows traffic in one direction.
-
#protocol ⇒ String
[Required] The transport protocol.
-
#source ⇒ String
Conceptually, this is the range of IP addresses that a packet coming into the instance can come from.
-
#source_type ⇒ String
Type of source for the rule.
-
#tcp_options ⇒ OCI::Core::Models::TcpOptions
Optional and valid only for TCP.
-
#udp_options ⇒ OCI::Core::Models::UdpOptions
Optional and valid only for UDP.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddSecurityRuleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AddSecurityRuleDetails
Initializes the object
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 203 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.destination = attributes[:'destination'] if attributes[:'destination'] self.destination_type = attributes[:'destinationType'] if attributes[:'destinationType'] raise 'You cannot provide both :destinationType and :destination_type' if attributes.key?(:'destinationType') && attributes.key?(:'destination_type') self.destination_type = attributes[:'destination_type'] if attributes[:'destination_type'] self.direction = attributes[:'direction'] if attributes[:'direction'] self. = attributes[:'icmpOptions'] if attributes[:'icmpOptions'] raise 'You cannot provide both :icmpOptions and :icmp_options' if attributes.key?(:'icmpOptions') && attributes.key?(:'icmp_options') self. = attributes[:'icmp_options'] if attributes[:'icmp_options'] self.is_stateless = attributes[:'isStateless'] unless attributes[:'isStateless'].nil? raise 'You cannot provide both :isStateless and :is_stateless' if attributes.key?(:'isStateless') && attributes.key?(:'is_stateless') self.is_stateless = attributes[:'is_stateless'] unless attributes[:'is_stateless'].nil? self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.source = attributes[:'source'] if attributes[:'source'] self.source_type = attributes[:'sourceType'] if attributes[:'sourceType'] raise 'You cannot provide both :sourceType and :source_type' if attributes.key?(:'sourceType') && attributes.key?(:'source_type') self.source_type = attributes[:'source_type'] if attributes[:'source_type'] self. = attributes[:'tcpOptions'] if attributes[:'tcpOptions'] raise 'You cannot provide both :tcpOptions and :tcp_options' if attributes.key?(:'tcpOptions') && attributes.key?(:'tcp_options') self. = attributes[:'tcp_options'] if attributes[:'tcp_options'] self. = attributes[:'udpOptions'] if attributes[:'udpOptions'] raise 'You cannot provide both :udpOptions and :udp_options' if attributes.key?(:'udpOptions') && attributes.key?(:'udp_options') self. = attributes[:'udp_options'] if attributes[:'udp_options'] end |
Instance Attribute Details
#description ⇒ String
An optional description of your choice for the rule. Avoid entering confidential information.
29 30 31 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 29 def description @description end |
#destination ⇒ String
Conceptually, this is the range of IP addresses that a packet originating from the instance can go to.
Allowed values:
* An IP address range in CIDR notation. For example: `192.168.1.0/24` or `2001:0db8:0123:45::/56`
Note that IPv6 addressing is currently supported only in certain regions. See
[IPv6 Addresses](https://docs.cloud.oracle.com/Content/Network/Concepts/ipv6.htm).
* The `cidrBlock` value for a {Service}, if you're
setting up a security rule for traffic destined for a particular `Service` through
a service gateway. For example: `oci-phx-objectstorage`.
* The OCID of a {NetworkSecurityGroup} in the same
VCN. The value can be the NSG that the rule belongs to if the rule's intent is to control
traffic between VNICs in the same NSG.
49 50 51 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 49 def destination @destination end |
#destination_type ⇒ String
Type of destination for the rule. Required if direction = EGRESS.
Allowed values:
* `CIDR_BLOCK`: If the rule's `destination` is an IP address range in CIDR notation.
* `SERVICE_CIDR_BLOCK`: If the rule's `destination` is the `cidrBlock` value for a
{Service} (the rule is for traffic destined for a
particular `Service` through a service gateway).
* `NETWORK_SECURITY_GROUP`: If the rule's `destination` is the OCID of a
{NetworkSecurityGroup}.
65 66 67 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 65 def destination_type @destination_type end |
#direction ⇒ String
[Required] Direction of the security rule. Set to EGRESS for rules to allow outbound IP packets, or INGRESS for rules to allow inbound IP packets.
69 70 71 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 69 def direction @direction end |
#icmp_options ⇒ OCI::Core::Models::IcmpOptions
Optional and valid only for ICMP and ICMPv6. Use to specify a particular ICMP type and code as defined in:
-
[ICMP Parameters](www.iana.org/assignments/icmp-parameters/icmp-parameters.xhtml)
-
[ICMPv6 Parameters](www.iana.org/assignments/icmpv6-parameters/icmpv6-parameters.xhtml)
If you specify ICMP or ICMPv6 as the protocol but omit this object, then all ICMP types and codes are allowed. If you do provide this object, the type is required and the code is optional. To enable MTU negotiation for ingress internet traffic via IPv4, make sure to allow type 3 ("Destination Unreachable") code 4 ("Fragmentation Needed and Don’t Fragment was Set"). If you need to specify multiple codes for a single type, create a separate security list rule for each.
83 84 85 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 83 def end |
#is_stateless ⇒ BOOLEAN
A stateless rule allows traffic in one direction. Remember to add a corresponding stateless rule in the other direction if you need to support bidirectional traffic. For example, if egress traffic allows TCP destination port 80, there should be an ingress rule to allow TCP source port 80. Defaults to false, which means the rule is stateful and a corresponding rule is not necessary for bidirectional traffic.
92 93 94 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 92 def is_stateless @is_stateless end |
#protocol ⇒ String
[Required] The transport protocol. Specify either all or an IPv4 protocol number as defined in [Protocol Numbers](www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml). Options are supported only for ICMP ("1"), TCP ("6"), UDP ("17"), and ICMPv6 ("58").
100 101 102 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 100 def protocol @protocol end |
#source ⇒ String
Conceptually, this is the range of IP addresses that a packet coming into the instance can come from.
Allowed values:
* An IP address range in CIDR notation. For example: `192.168.1.0/24` or `2001:0db8:0123:45::/56`
Note that IPv6 addressing is currently supported only in certain regions. See
[IPv6 Addresses](https://docs.cloud.oracle.com/Content/Network/Concepts/ipv6.htm).
* The `cidrBlock` value for a {Service}, if you're
setting up a security rule for traffic coming from a particular `Service` through
a service gateway. For example: `oci-phx-objectstorage`.
* The OCID of a {NetworkSecurityGroup} in the same
VCN. The value can be the NSG that the rule belongs to if the rule's intent is to control
traffic between VNICs in the same NSG.
120 121 122 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 120 def source @source end |
#source_type ⇒ String
Type of source for the rule. Required if direction = INGRESS.
* `CIDR_BLOCK`: If the rule's `source` is an IP address range in CIDR notation.
* `SERVICE_CIDR_BLOCK`: If the rule's `source` is the `cidrBlock` value for a
{Service} (the rule is for traffic coming from a
particular `Service` through a service gateway).
* `NETWORK_SECURITY_GROUP`: If the rule's `source` is the OCID of a
{NetworkSecurityGroup}.
134 135 136 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 134 def source_type @source_type end |
#tcp_options ⇒ OCI::Core::Models::TcpOptions
Optional and valid only for TCP. Use to specify particular destination ports for TCP rules. If you specify TCP as the protocol but omit this object, then all destination ports are allowed.
140 141 142 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 140 def end |
#udp_options ⇒ OCI::Core::Models::UdpOptions
Optional and valid only for UDP. Use to specify particular destination ports for UDP rules. If you specify UDP as the protocol but omit this object, then all destination ports are allowed.
146 147 148 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 146 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 149 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'destination': :'destination', 'destination_type': :'destinationType', 'direction': :'direction', 'icmp_options': :'icmpOptions', 'is_stateless': :'isStateless', 'protocol': :'protocol', 'source': :'source', 'source_type': :'sourceType', 'tcp_options': :'tcpOptions', 'udp_options': :'udpOptions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 168 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'destination': :'String', 'destination_type': :'String', 'direction': :'String', 'icmp_options': :'OCI::Core::Models::IcmpOptions', 'is_stateless': :'BOOLEAN', 'protocol': :'String', 'source': :'String', 'source_type': :'String', 'tcp_options': :'OCI::Core::Models::TcpOptions', 'udp_options': :'OCI::Core::Models::UdpOptions' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 287 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && destination == other.destination && destination_type == other.destination_type && direction == other.direction && == other. && is_stateless == other.is_stateless && protocol == other.protocol && source == other.source && source_type == other.source_type && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 327 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
307 308 309 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 307 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
316 317 318 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 316 def hash [description, destination, destination_type, direction, , is_stateless, protocol, source, source_type, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
360 361 362 363 364 365 366 367 368 369 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 360 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
354 355 356 |
# File 'lib/oci/core/models/add_security_rule_details.rb', line 354 def to_s to_hash.to_s end |