Class: OCI::Core::Models::AttachIScsiVolumeDetails
- Inherits:
-
AttachVolumeDetails
- Object
- AttachVolumeDetails
- OCI::Core::Models::AttachIScsiVolumeDetails
- Defined in:
- lib/oci/core/models/attach_i_scsi_volume_details.rb
Overview
AttachIScsiVolumeDetails model.
Constant Summary collapse
- ENCRYPTION_IN_TRANSIT_TYPE_ENUM =
[ ENCRYPTION_IN_TRANSIT_TYPE_NONE = 'NONE'.freeze, ENCRYPTION_IN_TRANSIT_TYPE_BM_ENCRYPTION_IN_TRANSIT = 'BM_ENCRYPTION_IN_TRANSIT'.freeze ].freeze
Instance Attribute Summary collapse
-
#encryption_in_transit_type ⇒ String
Refer the top-level definition of encryptionInTransitType.
-
#use_chap ⇒ BOOLEAN
Whether to use CHAP authentication for the volume attachment.
Attributes inherited from AttachVolumeDetails
#device, #display_name, #instance_id, #is_read_only, #is_shareable, #type, #volume_id
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AttachIScsiVolumeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AttachVolumeDetails
Constructor Details
#initialize(attributes = {}) ⇒ AttachIScsiVolumeDetails
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 75 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'iscsi' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.use_chap = attributes[:'useChap'] unless attributes[:'useChap'].nil? raise 'You cannot provide both :useChap and :use_chap' if attributes.key?(:'useChap') && attributes.key?(:'use_chap') self.use_chap = attributes[:'use_chap'] unless attributes[:'use_chap'].nil? self.encryption_in_transit_type = attributes[:'encryptionInTransitType'] if attributes[:'encryptionInTransitType'] self.encryption_in_transit_type = "NONE" if encryption_in_transit_type.nil? && !attributes.key?(:'encryptionInTransitType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :encryptionInTransitType and :encryption_in_transit_type' if attributes.key?(:'encryptionInTransitType') && attributes.key?(:'encryption_in_transit_type') self.encryption_in_transit_type = attributes[:'encryption_in_transit_type'] if attributes[:'encryption_in_transit_type'] self.encryption_in_transit_type = "NONE" if encryption_in_transit_type.nil? && !attributes.key?(:'encryptionInTransitType') && !attributes.key?(:'encryption_in_transit_type') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#encryption_in_transit_type ⇒ String
Refer the top-level definition of encryptionInTransitType. The default value is NONE.
25 26 27 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 25 def encryption_in_transit_type @encryption_in_transit_type end |
#use_chap ⇒ BOOLEAN
Whether to use CHAP authentication for the volume attachment. Defaults to false.
19 20 21 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 19 def use_chap @use_chap end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'device': :'device', 'display_name': :'displayName', 'instance_id': :'instanceId', 'is_read_only': :'isReadOnly', 'is_shareable': :'isShareable', 'type': :'type', 'volume_id': :'volumeId', 'use_chap': :'useChap', 'encryption_in_transit_type': :'encryptionInTransitType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 45 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'device': :'String', 'display_name': :'String', 'instance_id': :'String', 'is_read_only': :'BOOLEAN', 'is_shareable': :'BOOLEAN', 'type': :'String', 'volume_id': :'String', 'use_chap': :'BOOLEAN', 'encryption_in_transit_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 115 def ==(other) return true if equal?(other) self.class == other.class && device == other.device && display_name == other.display_name && instance_id == other.instance_id && is_read_only == other.is_read_only && is_shareable == other.is_shareable && type == other.type && volume_id == other.volume_id && use_chap == other.use_chap && encryption_in_transit_type == other.encryption_in_transit_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 153 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
133 134 135 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 133 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 142 def hash [device, display_name, instance_id, is_read_only, is_shareable, type, volume_id, use_chap, encryption_in_transit_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
180 181 182 |
# File 'lib/oci/core/models/attach_i_scsi_volume_details.rb', line 180 def to_s to_hash.to_s end |