Class: OCI::Core::Models::BlockVolumeReplica
- Inherits:
-
Object
- Object
- OCI::Core::Models::BlockVolumeReplica
- Defined in:
- lib/oci/core/models/block_volume_replica.rb
Overview
An asynchronous replica of a block volume that can then be used to create a new block volume or recover a block volume. For more information, see [Overview of Cross-Region Volume Replication](docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumereplication.htm) To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_ACTIVATING = 'ACTIVATING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAULTY = 'FAULTY'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The availability domain of the block volume replica.
-
#block_volume_id ⇒ String
[Required] The OCID of the source block volume.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the block volume replica.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The block volume replica’s Oracle ID (OCID).
-
#lifecycle_state ⇒ String
[Required] The current state of a block volume replica.
-
#size_in_gbs ⇒ Integer
[Required] The size of the source block volume, in GBs.
-
#time_created ⇒ DateTime
[Required] The date and time the block volume replica was created.
-
#time_last_synced ⇒ DateTime
[Required] The date and time the block volume replica was last synced from the source block volume.
-
#total_data_transferred_in_gbs ⇒ Integer
The total size of the data transferred from the source block volume to the block volume replica, in GBs.
-
#volume_group_replica_id ⇒ String
The OCID of the volume group replica.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BlockVolumeReplica
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BlockVolumeReplica
Initializes the object
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 164 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs'] raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs') self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_last_synced = attributes[:'timeLastSynced'] if attributes[:'timeLastSynced'] raise 'You cannot provide both :timeLastSynced and :time_last_synced' if attributes.key?(:'timeLastSynced') && attributes.key?(:'time_last_synced') self.time_last_synced = attributes[:'time_last_synced'] if attributes[:'time_last_synced'] self.block_volume_id = attributes[:'blockVolumeId'] if attributes[:'blockVolumeId'] raise 'You cannot provide both :blockVolumeId and :block_volume_id' if attributes.key?(:'blockVolumeId') && attributes.key?(:'block_volume_id') self.block_volume_id = attributes[:'block_volume_id'] if attributes[:'block_volume_id'] self.total_data_transferred_in_gbs = attributes[:'totalDataTransferredInGBs'] if attributes[:'totalDataTransferredInGBs'] raise 'You cannot provide both :totalDataTransferredInGBs and :total_data_transferred_in_gbs' if attributes.key?(:'totalDataTransferredInGBs') && attributes.key?(:'total_data_transferred_in_gbs') self.total_data_transferred_in_gbs = attributes[:'total_data_transferred_in_gbs'] if attributes[:'total_data_transferred_in_gbs'] self.volume_group_replica_id = attributes[:'volumeGroupReplicaId'] if attributes[:'volumeGroupReplicaId'] raise 'You cannot provide both :volumeGroupReplicaId and :volume_group_replica_id' if attributes.key?(:'volumeGroupReplicaId') && attributes.key?(:'volume_group_replica_id') self.volume_group_replica_id = attributes[:'volume_group_replica_id'] if attributes[:'volume_group_replica_id'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The availability domain of the block volume replica.
Example: Uocm:PHX-AD-1
36 37 38 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 36 def availability_domain @availability_domain end |
#block_volume_id ⇒ String
[Required] The OCID of the source block volume.
91 92 93 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 91 def block_volume_id @block_volume_id end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the block volume replica.
40 41 42 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 40 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
48 49 50 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 48 def end |
#display_name ⇒ String
[Required] A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
54 55 56 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 54 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
62 63 64 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 62 def end |
#id ⇒ String
[Required] The block volume replica’s Oracle ID (OCID).
66 67 68 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 66 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of a block volume replica.
70 71 72 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 70 def lifecycle_state @lifecycle_state end |
#size_in_gbs ⇒ Integer
[Required] The size of the source block volume, in GBs.
75 76 77 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 75 def size_in_gbs @size_in_gbs end |
#time_created ⇒ DateTime
[Required] The date and time the block volume replica was created. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).
81 82 83 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 81 def time_created @time_created end |
#time_last_synced ⇒ DateTime
[Required] The date and time the block volume replica was last synced from the source block volume. Format defined by [RFC3339](tools.ietf.org/html/rfc3339).
87 88 89 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 87 def time_last_synced @time_last_synced end |
#total_data_transferred_in_gbs ⇒ Integer
The total size of the data transferred from the source block volume to the block volume replica, in GBs.
96 97 98 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 96 def total_data_transferred_in_gbs @total_data_transferred_in_gbs end |
#volume_group_replica_id ⇒ String
The OCID of the volume group replica.
101 102 103 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 101 def volume_group_replica_id @volume_group_replica_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 104 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'size_in_gbs': :'sizeInGBs', 'time_created': :'timeCreated', 'time_last_synced': :'timeLastSynced', 'block_volume_id': :'blockVolumeId', 'total_data_transferred_in_gbs': :'totalDataTransferredInGBs', 'volume_group_replica_id': :'volumeGroupReplicaId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 125 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'size_in_gbs': :'Integer', 'time_created': :'DateTime', 'time_last_synced': :'DateTime', 'block_volume_id': :'String', 'total_data_transferred_in_gbs': :'Integer', 'volume_group_replica_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 265 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_state == other.lifecycle_state && size_in_gbs == other.size_in_gbs && time_created == other.time_created && time_last_synced == other.time_last_synced && block_volume_id == other.block_volume_id && total_data_transferred_in_gbs == other.total_data_transferred_in_gbs && volume_group_replica_id == other.volume_group_replica_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 307 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
287 288 289 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 287 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
296 297 298 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 296 def hash [availability_domain, compartment_id, , display_name, , id, lifecycle_state, size_in_gbs, time_created, time_last_synced, block_volume_id, total_data_transferred_in_gbs, volume_group_replica_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
340 341 342 343 344 345 346 347 348 349 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 340 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
334 335 336 |
# File 'lib/oci/core/models/block_volume_replica.rb', line 334 def to_s to_hash.to_s end |