Class: OCI::Core::Models::CreateBootVolumeDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/create_boot_volume_details.rb

Overview

CreateBootVolumeDetails model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateBootVolumeDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 129

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.backup_policy_id = attributes[:'backupPolicyId'] if attributes[:'backupPolicyId']

  raise 'You cannot provide both :backupPolicyId and :backup_policy_id' if attributes.key?(:'backupPolicyId') && attributes.key?(:'backup_policy_id')

  self.backup_policy_id = attributes[:'backup_policy_id'] if attributes[:'backup_policy_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs']

  raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs')

  self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs']

  self.vpus_per_gb = attributes[:'vpusPerGB'] if attributes[:'vpusPerGB']

  raise 'You cannot provide both :vpusPerGB and :vpus_per_gb' if attributes.key?(:'vpusPerGB') && attributes.key?(:'vpus_per_gb')

  self.vpus_per_gb = attributes[:'vpus_per_gb'] if attributes[:'vpus_per_gb']

  self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails']

  raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details')

  self.source_details = attributes[:'source_details'] if attributes[:'source_details']
end

Instance Attribute Details

#availability_domainString

[Required] The availability domain of the boot volume.

Example: Uocm:PHX-AD-1

Returns:

  • (String)


14
15
16
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 14

def availability_domain
  @availability_domain
end

#backup_policy_idString

If provided, specifies the ID of the boot volume backup policy to assign to the newly created boot volume. If omitted, no policy will be assigned.

Returns:

  • (String)


20
21
22
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 20

def backup_policy_id
  @backup_policy_id
end

#compartment_idString

[Required] The OCID of the compartment that contains the boot volume.

Returns:

  • (String)


24
25
26
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 24

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


32
33
34
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 32

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


38
39
40
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 38

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


46
47
48
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 46

def freeform_tags
  @freeform_tags
end

#kms_key_idString

The OCID of the Key Management key to assign as the master encryption key for the boot volume.

Returns:

  • (String)


52
53
54
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 52

def kms_key_id
  @kms_key_id
end

#size_in_gbsInteger

The size of the volume in GBs.

Returns:

  • (Integer)


56
57
58
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 56

def size_in_gbs
  @size_in_gbs
end

#source_detailsOCI::Core::Models::BootVolumeSourceDetails

[Required] Specifies the boot volume source details for a new boot volume. The volume source is either another boot volume in the same availability domain or a boot volume backup. This is a mandatory field for a boot volume.



75
76
77
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 75

def source_details
  @source_details
end

#vpus_per_gbInteger

The number of volume performance units (VPUs) that will be applied to this volume per GB, representing the Block Volume service’s elastic performance options. See [Block Volume Elastic Performance](docs.cloud.oracle.com/Content/Block/Concepts/blockvolumeelasticperformance.htm) for more information.

Allowed values:

* `10`: Represents Balanced option.

* `20`: Represents Higher Performance option.

Returns:

  • (Integer)


69
70
71
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 69

def vpus_per_gb
  @vpus_per_gb
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 78

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'availabilityDomain',
    'backup_policy_id': :'backupPolicyId',
    'compartment_id': :'compartmentId',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'kms_key_id': :'kmsKeyId',
    'size_in_gbs': :'sizeInGBs',
    'vpus_per_gb': :'vpusPerGB',
    'source_details': :'sourceDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 96

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'String',
    'backup_policy_id': :'String',
    'compartment_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'kms_key_id': :'String',
    'size_in_gbs': :'Integer',
    'vpus_per_gb': :'Integer',
    'source_details': :'OCI::Core::Models::BootVolumeSourceDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 203

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    availability_domain == other.availability_domain &&
    backup_policy_id == other.backup_policy_id &&
    compartment_id == other.compartment_id &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    kms_key_id == other.kms_key_id &&
    size_in_gbs == other.size_in_gbs &&
    vpus_per_gb == other.vpus_per_gb &&
    source_details == other.source_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 242

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 222

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



231
232
233
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 231

def hash
  [availability_domain, backup_policy_id, compartment_id, defined_tags, display_name, freeform_tags, kms_key_id, size_in_gbs, vpus_per_gb, source_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



269
270
271
# File 'lib/oci/core/models/create_boot_volume_details.rb', line 269

def to_s
  to_hash.to_s
end