Class: OCI::Core::Models::CreateIPSecConnectionDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::CreateIPSecConnectionDetails
- Defined in:
- lib/oci/core/models/create_ip_sec_connection_details.rb
Overview
CreateIPSecConnectionDetails model.
Constant Summary collapse
- CPE_LOCAL_IDENTIFIER_TYPE_ENUM =
rubocop:disable Metrics/LineLength
[ CPE_LOCAL_IDENTIFIER_TYPE_IP_ADDRESS = 'IP_ADDRESS'.freeze, CPE_LOCAL_IDENTIFIER_TYPE_HOSTNAME = 'HOSTNAME'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment to contain the IPSec connection.
-
#cpe_id ⇒ String
[Required] The OCID of the Cpe object.
-
#cpe_local_identifier ⇒ String
Your identifier for your CPE device.
-
#cpe_local_identifier_type ⇒ String
The type of identifier for your CPE device.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#drg_id ⇒ String
[Required] The OCID of the DRG.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#static_routes ⇒ Array<String>
[Required] Static routes to the CPE.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateIPSecConnectionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateIPSecConnectionDetails
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 124 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.cpe_id = attributes[:'cpeId'] if attributes[:'cpeId'] raise 'You cannot provide both :cpeId and :cpe_id' if attributes.key?(:'cpeId') && attributes.key?(:'cpe_id') self.cpe_id = attributes[:'cpe_id'] if attributes[:'cpe_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.drg_id = attributes[:'drgId'] if attributes[:'drgId'] raise 'You cannot provide both :drgId and :drg_id' if attributes.key?(:'drgId') && attributes.key?(:'drg_id') self.drg_id = attributes[:'drg_id'] if attributes[:'drg_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.cpe_local_identifier = attributes[:'cpeLocalIdentifier'] if attributes[:'cpeLocalIdentifier'] raise 'You cannot provide both :cpeLocalIdentifier and :cpe_local_identifier' if attributes.key?(:'cpeLocalIdentifier') && attributes.key?(:'cpe_local_identifier') self.cpe_local_identifier = attributes[:'cpe_local_identifier'] if attributes[:'cpe_local_identifier'] self.cpe_local_identifier_type = attributes[:'cpeLocalIdentifierType'] if attributes[:'cpeLocalIdentifierType'] raise 'You cannot provide both :cpeLocalIdentifierType and :cpe_local_identifier_type' if attributes.key?(:'cpeLocalIdentifierType') && attributes.key?(:'cpe_local_identifier_type') self.cpe_local_identifier_type = attributes[:'cpe_local_identifier_type'] if attributes[:'cpe_local_identifier_type'] self.static_routes = attributes[:'staticRoutes'] if attributes[:'staticRoutes'] raise 'You cannot provide both :staticRoutes and :static_routes' if attributes.key?(:'staticRoutes') && attributes.key?(:'static_routes') self.static_routes = attributes[:'static_routes'] if attributes[:'static_routes'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment to contain the IPSec connection.
16 17 18 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 16 def compartment_id @compartment_id end |
#cpe_id ⇒ String
[Required] The OCID of the OCI::Core::Models::Cpe object.
20 21 22 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 20 def cpe_id @cpe_id end |
#cpe_local_identifier ⇒ String
Your identifier for your CPE device. Can be either an IP address or a hostname (specifically, the fully qualified domain name (FQDN)). The type of identifier you provide here must correspond to the value for cpeLocalIdentifierType.
If you don’t provide a value, the ipAddress attribute for the OCI::Core::Models::Cpe object specified by cpeId is used as the cpeLocalIdentifier.
Example IP address: 10.0.3.3
Example hostname: cpe.example.com
59 60 61 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 59 def cpe_local_identifier @cpe_local_identifier end |
#cpe_local_identifier_type ⇒ String
The type of identifier for your CPE device. The value you provide here must correspond to the value for cpeLocalIdentifier.
65 66 67 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 65 def cpe_local_identifier_type @cpe_local_identifier_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
28 29 30 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 28 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
32 33 34 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 32 def display_name @display_name end |
#drg_id ⇒ String
[Required] The OCID of the DRG.
36 37 38 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 36 def drg_id @drg_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
45 46 47 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 45 def @freeform_tags end |
#static_routes ⇒ Array<String>
[Required] Static routes to the CPE. At least one route must be included. A static route’s CIDR must not be a multicast address or class E address.
Example: 10.0.1.0/24
73 74 75 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 73 def static_routes @static_routes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'cpe_id': :'cpeId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'drg_id': :'drgId', 'freeform_tags': :'freeformTags', 'cpe_local_identifier': :'cpeLocalIdentifier', 'cpe_local_identifier_type': :'cpeLocalIdentifierType', 'static_routes': :'staticRoutes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 93 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'cpe_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'drg_id': :'String', 'freeform_tags': :'Hash<String, String>', 'cpe_local_identifier': :'String', 'cpe_local_identifier_type': :'String', 'static_routes': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 202 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && cpe_id == other.cpe_id && == other. && display_name == other.display_name && drg_id == other.drg_id && == other. && cpe_local_identifier == other.cpe_local_identifier && cpe_local_identifier_type == other.cpe_local_identifier_type && static_routes == other.static_routes end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 240 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
220 221 222 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 220 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 229 def hash [compartment_id, cpe_id, , display_name, drg_id, , cpe_local_identifier, cpe_local_identifier_type, static_routes].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 273 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
267 268 269 |
# File 'lib/oci/core/models/create_ip_sec_connection_details.rb', line 267 def to_s to_hash.to_s end |