Class: OCI::Core::Models::CreateIPSecConnectionTunnelDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb

Overview

CreateIPSecConnectionTunnelDetails model.

Constant Summary collapse

ROUTING_ENUM =
[
  ROUTING_BGP = 'BGP'.freeze,
  ROUTING_STATIC = 'STATIC'.freeze,
  ROUTING_POLICY = 'POLICY'.freeze
].freeze
IKE_VERSION_ENUM =
[
  IKE_VERSION_V1 = 'V1'.freeze,
  IKE_VERSION_V2 = 'V2'.freeze
].freeze
ORACLE_INITIATION_ENUM =
[
  ORACLE_INITIATION_INITIATOR_OR_RESPONDER = 'INITIATOR_OR_RESPONDER'.freeze,
  ORACLE_INITIATION_RESPONDER_ONLY = 'RESPONDER_ONLY'.freeze
].freeze
NAT_TRANSLATION_ENABLED_ENUM =
[
  NAT_TRANSLATION_ENABLED_ENABLED = 'ENABLED'.freeze,
  NAT_TRANSLATION_ENABLED_DISABLED = 'DISABLED'.freeze,
  NAT_TRANSLATION_ENABLED_AUTO = 'AUTO'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateIPSecConnectionTunnelDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 134

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.routing = attributes[:'routing'] if attributes[:'routing']

  self.ike_version = attributes[:'ikeVersion'] if attributes[:'ikeVersion']

  raise 'You cannot provide both :ikeVersion and :ike_version' if attributes.key?(:'ikeVersion') && attributes.key?(:'ike_version')

  self.ike_version = attributes[:'ike_version'] if attributes[:'ike_version']

  self.shared_secret = attributes[:'sharedSecret'] if attributes[:'sharedSecret']

  raise 'You cannot provide both :sharedSecret and :shared_secret' if attributes.key?(:'sharedSecret') && attributes.key?(:'shared_secret')

  self.shared_secret = attributes[:'shared_secret'] if attributes[:'shared_secret']

  self.bgp_session_config = attributes[:'bgpSessionConfig'] if attributes[:'bgpSessionConfig']

  raise 'You cannot provide both :bgpSessionConfig and :bgp_session_config' if attributes.key?(:'bgpSessionConfig') && attributes.key?(:'bgp_session_config')

  self.bgp_session_config = attributes[:'bgp_session_config'] if attributes[:'bgp_session_config']

  self.oracle_initiation = attributes[:'oracleInitiation'] if attributes[:'oracleInitiation']

  raise 'You cannot provide both :oracleInitiation and :oracle_initiation' if attributes.key?(:'oracleInitiation') && attributes.key?(:'oracle_initiation')

  self.oracle_initiation = attributes[:'oracle_initiation'] if attributes[:'oracle_initiation']

  self.nat_translation_enabled = attributes[:'natTranslationEnabled'] if attributes[:'natTranslationEnabled']

  raise 'You cannot provide both :natTranslationEnabled and :nat_translation_enabled' if attributes.key?(:'natTranslationEnabled') && attributes.key?(:'nat_translation_enabled')

  self.nat_translation_enabled = attributes[:'nat_translation_enabled'] if attributes[:'nat_translation_enabled']

  self.phase_one_config = attributes[:'phaseOneConfig'] if attributes[:'phaseOneConfig']

  raise 'You cannot provide both :phaseOneConfig and :phase_one_config' if attributes.key?(:'phaseOneConfig') && attributes.key?(:'phase_one_config')

  self.phase_one_config = attributes[:'phase_one_config'] if attributes[:'phase_one_config']

  self.phase_two_config = attributes[:'phaseTwoConfig'] if attributes[:'phaseTwoConfig']

  raise 'You cannot provide both :phaseTwoConfig and :phase_two_config' if attributes.key?(:'phaseTwoConfig') && attributes.key?(:'phase_two_config')

  self.phase_two_config = attributes[:'phase_two_config'] if attributes[:'phase_two_config']

  self.dpd_config = attributes[:'dpdConfig'] if attributes[:'dpdConfig']

  raise 'You cannot provide both :dpdConfig and :dpd_config' if attributes.key?(:'dpdConfig') && attributes.key?(:'dpd_config')

  self.dpd_config = attributes[:'dpd_config'] if attributes[:'dpd_config']

  self.encryption_domain_config = attributes[:'encryptionDomainConfig'] if attributes[:'encryptionDomainConfig']

  raise 'You cannot provide both :encryptionDomainConfig and :encryption_domain_config' if attributes.key?(:'encryptionDomainConfig') && attributes.key?(:'encryption_domain_config')

  self.encryption_domain_config = attributes[:'encryption_domain_config'] if attributes[:'encryption_domain_config']
end

Instance Attribute Details

#bgp_session_configOCI::Core::Models::CreateIPSecTunnelBgpSessionDetails



57
58
59
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 57

def bgp_session_config
  @bgp_session_config
end

#display_nameString

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


36
37
38
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 36

def display_name
  @display_name
end

#dpd_configOCI::Core::Models::DpdConfig



74
75
76
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 74

def dpd_config
  @dpd_config
end

#encryption_domain_configOCI::Core::Models::CreateIPSecTunnelEncryptionDomainDetails



77
78
79
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 77

def encryption_domain_config
  @encryption_domain_config
end

#ike_versionString

Internet Key Exchange protocol version.

Returns:

  • (String)


46
47
48
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 46

def ike_version
  @ike_version
end

#nat_translation_enabledString

Whether NAT-T Enabled on the tunnel

Returns:

  • (String)


65
66
67
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 65

def nat_translation_enabled
  @nat_translation_enabled
end

#oracle_initiationString

Whether Oracle side is the initiator for negotiation.

Returns:

  • (String)


61
62
63
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 61

def oracle_initiation
  @oracle_initiation
end

#phase_one_configOCI::Core::Models::PhaseOneConfigDetails



68
69
70
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 68

def phase_one_config
  @phase_one_config
end

#phase_two_configOCI::Core::Models::PhaseTwoConfigDetails



71
72
73
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 71

def phase_two_config
  @phase_two_config
end

#routingString

The type of routing to use for this tunnel (either BGP dynamic routing or static routing).

Returns:

  • (String)


41
42
43
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 41

def routing
  @routing
end

#shared_secretString

The shared secret (pre-shared key) to use for the IPSec tunnel. Only numbers, letters, and spaces are allowed. If you don’t provide a value, Oracle generates a value for you. You can specify your own shared secret later if you like with update_ip_sec_connection_tunnel_shared_secret.

Returns:

  • (String)


54
55
56
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 54

def shared_secret
  @shared_secret
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 80

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'routing': :'routing',
    'ike_version': :'ikeVersion',
    'shared_secret': :'sharedSecret',
    'bgp_session_config': :'bgpSessionConfig',
    'oracle_initiation': :'oracleInitiation',
    'nat_translation_enabled': :'natTranslationEnabled',
    'phase_one_config': :'phaseOneConfig',
    'phase_two_config': :'phaseTwoConfig',
    'dpd_config': :'dpdConfig',
    'encryption_domain_config': :'encryptionDomainConfig'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 99

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'routing': :'String',
    'ike_version': :'String',
    'shared_secret': :'String',
    'bgp_session_config': :'OCI::Core::Models::CreateIPSecTunnelBgpSessionDetails',
    'oracle_initiation': :'String',
    'nat_translation_enabled': :'String',
    'phase_one_config': :'OCI::Core::Models::PhaseOneConfigDetails',
    'phase_two_config': :'OCI::Core::Models::PhaseTwoConfigDetails',
    'dpd_config': :'OCI::Core::Models::DpdConfig',
    'encryption_domain_config': :'OCI::Core::Models::CreateIPSecTunnelEncryptionDomainDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 242

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    routing == other.routing &&
    ike_version == other.ike_version &&
    shared_secret == other.shared_secret &&
    bgp_session_config == other.bgp_session_config &&
    oracle_initiation == other.oracle_initiation &&
    nat_translation_enabled == other.nat_translation_enabled &&
    phase_one_config == other.phase_one_config &&
    phase_two_config == other.phase_two_config &&
    dpd_config == other.dpd_config &&
    encryption_domain_config == other.encryption_domain_config
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 282

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 262

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



271
272
273
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 271

def hash
  [display_name, routing, ike_version, shared_secret, bgp_session_config, oracle_initiation, nat_translation_enabled, phase_one_config, phase_two_config, dpd_config, encryption_domain_config].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



315
316
317
318
319
320
321
322
323
324
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 315

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



309
310
311
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 309

def to_s
  to_hash.to_s
end