Class: OCI::Core::Models::CreateIPSecConnectionTunnelDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::CreateIPSecConnectionTunnelDetails
- Defined in:
- lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb
Overview
CreateIPSecConnectionTunnelDetails model.
Constant Summary collapse
- ROUTING_ENUM =
[ ROUTING_BGP = 'BGP'.freeze, ROUTING_STATIC = 'STATIC'.freeze, ROUTING_POLICY = 'POLICY'.freeze ].freeze
- IKE_VERSION_ENUM =
[ IKE_VERSION_V1 = 'V1'.freeze, IKE_VERSION_V2 = 'V2'.freeze ].freeze
Instance Attribute Summary collapse
- #bgp_session_config ⇒ OCI::Core::Models::CreateIPSecTunnelBgpSessionDetails
-
#display_name ⇒ String
A user-friendly name.
- #encryption_domain_config ⇒ OCI::Core::Models::CreateIPSecTunnelEncryptionDomainDetails
-
#ike_version ⇒ String
Internet Key Exchange protocol version.
-
#routing ⇒ String
The type of routing to use for this tunnel (either BGP dynamic routing or static routing).
-
#shared_secret ⇒ String
The shared secret (pre-shared key) to use for the IPSec tunnel.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateIPSecConnectionTunnelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateIPSecConnectionTunnelDetails
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.routing = attributes[:'routing'] if attributes[:'routing'] self.ike_version = attributes[:'ikeVersion'] if attributes[:'ikeVersion'] raise 'You cannot provide both :ikeVersion and :ike_version' if attributes.key?(:'ikeVersion') && attributes.key?(:'ike_version') self.ike_version = attributes[:'ike_version'] if attributes[:'ike_version'] self.shared_secret = attributes[:'sharedSecret'] if attributes[:'sharedSecret'] raise 'You cannot provide both :sharedSecret and :shared_secret' if attributes.key?(:'sharedSecret') && attributes.key?(:'shared_secret') self.shared_secret = attributes[:'shared_secret'] if attributes[:'shared_secret'] self.bgp_session_config = attributes[:'bgpSessionConfig'] if attributes[:'bgpSessionConfig'] raise 'You cannot provide both :bgpSessionConfig and :bgp_session_config' if attributes.key?(:'bgpSessionConfig') && attributes.key?(:'bgp_session_config') self.bgp_session_config = attributes[:'bgp_session_config'] if attributes[:'bgp_session_config'] self.encryption_domain_config = attributes[:'encryptionDomainConfig'] if attributes[:'encryptionDomainConfig'] raise 'You cannot provide both :encryptionDomainConfig and :encryption_domain_config' if attributes.key?(:'encryptionDomainConfig') && attributes.key?(:'encryption_domain_config') self.encryption_domain_config = attributes[:'encryption_domain_config'] if attributes[:'encryption_domain_config'] end |
Instance Attribute Details
#bgp_session_config ⇒ OCI::Core::Models::CreateIPSecTunnelBgpSessionDetails
46 47 48 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 46 def bgp_session_config @bgp_session_config end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
25 26 27 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 25 def display_name @display_name end |
#encryption_domain_config ⇒ OCI::Core::Models::CreateIPSecTunnelEncryptionDomainDetails
49 50 51 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 49 def encryption_domain_config @encryption_domain_config end |
#ike_version ⇒ String
Internet Key Exchange protocol version.
35 36 37 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 35 def ike_version @ike_version end |
#routing ⇒ String
The type of routing to use for this tunnel (either BGP dynamic routing or static routing).
30 31 32 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 30 def routing @routing end |
#shared_secret ⇒ String
The shared secret (pre-shared key) to use for the IPSec tunnel. Only numbers, letters, and spaces are allowed. If you don’t provide a value, Oracle generates a value for you. You can specify your own shared secret later if you like with update_ip_sec_connection_tunnel_shared_secret.
43 44 45 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 43 def shared_secret @shared_secret end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'routing': :'routing', 'ike_version': :'ikeVersion', 'shared_secret': :'sharedSecret', 'bgp_session_config': :'bgpSessionConfig', 'encryption_domain_config': :'encryptionDomainConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'routing': :'String', 'ike_version': :'String', 'shared_secret': :'String', 'bgp_session_config': :'OCI::Core::Models::CreateIPSecTunnelBgpSessionDetails', 'encryption_domain_config': :'OCI::Core::Models::CreateIPSecTunnelEncryptionDomainDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 153 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && routing == other.routing && ike_version == other.ike_version && shared_secret == other.shared_secret && bgp_session_config == other.bgp_session_config && encryption_domain_config == other.encryption_domain_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 188 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
168 169 170 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 168 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 177 def hash [display_name, routing, ike_version, shared_secret, bgp_session_config, encryption_domain_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
215 216 217 |
# File 'lib/oci/core/models/create_ip_sec_connection_tunnel_details.rb', line 215 def to_s to_hash.to_s end |