Class: OCI::Core::Models::CreatePublicIpDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::CreatePublicIpDetails
- Defined in:
- lib/oci/core/models/create_public_ip_details.rb
Overview
CreatePublicIpDetails model.
Constant Summary collapse
- LIFETIME_ENUM =
[ LIFETIME_EPHEMERAL = 'EPHEMERAL'.freeze, LIFETIME_RESERVED = 'RESERVED'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment to contain the public IP.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#lifetime ⇒ String
[Required] Defines when the public IP is deleted and released back to the Oracle Cloud Infrastructure public IP pool.
-
#private_ip_id ⇒ String
The OCID of the private IP to assign the public IP to.
-
#public_ip_pool_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the public IP pool.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePublicIpDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreatePublicIpDetails
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 109 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.lifetime = attributes[:'lifetime'] if attributes[:'lifetime'] self.private_ip_id = attributes[:'privateIpId'] if attributes[:'privateIpId'] raise 'You cannot provide both :privateIpId and :private_ip_id' if attributes.key?(:'privateIpId') && attributes.key?(:'private_ip_id') self.private_ip_id = attributes[:'private_ip_id'] if attributes[:'private_ip_id'] self.public_ip_pool_id = attributes[:'publicIpPoolId'] if attributes[:'publicIpPoolId'] raise 'You cannot provide both :publicIpPoolId and :public_ip_pool_id' if attributes.key?(:'publicIpPoolId') && attributes.key?(:'public_ip_pool_id') self.public_ip_pool_id = attributes[:'public_ip_pool_id'] if attributes[:'public_ip_pool_id'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment to contain the public IP. For ephemeral public IPs, you must set this to the private IP’s compartment OCID.
19 20 21 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 19 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
27 28 29 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 27 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
33 34 35 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 33 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
41 42 43 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 41 def @freeform_tags end |
#lifetime ⇒ String
[Required] Defines when the public IP is deleted and released back to the Oracle Cloud Infrastructure public IP pool. For more information, see [Public IP Addresses](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingpublicIPs.htm).
48 49 50 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 48 def lifetime @lifetime end |
#private_ip_id ⇒ String
The OCID of the private IP to assign the public IP to.
Required for an ephemeral public IP because it must always be assigned to a private IP (specifically a primary private IP).
Optional for a reserved public IP. If you don’t provide it, the public IP is created but not assigned to a private IP. You can later assign the public IP with update_public_ip.
60 61 62 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 60 def private_ip_id @private_ip_id end |
#public_ip_pool_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the public IP pool.
64 65 66 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 64 def public_ip_pool_id @public_ip_pool_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'lifetime': :'lifetime', 'private_ip_id': :'privateIpId', 'public_ip_pool_id': :'publicIpPoolId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 82 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'lifetime': :'String', 'private_ip_id': :'String', 'public_ip_pool_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 169 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && lifetime == other.lifetime && private_ip_id == other.private_ip_id && public_ip_pool_id == other.public_ip_pool_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 205 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
185 186 187 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 185 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 194 def hash [compartment_id, , display_name, , lifetime, private_ip_id, public_ip_pool_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 238 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
232 233 234 |
# File 'lib/oci/core/models/create_public_ip_details.rb', line 232 def to_s to_hash.to_s end |