Class: OCI::Core::Models::CreateVolumeDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/create_volume_details.rb

Overview

CreateVolumeDetails model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateVolumeDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/oci/core/models/create_volume_details.rb', line 165

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.backup_policy_id = attributes[:'backupPolicyId'] if attributes[:'backupPolicyId']

  raise 'You cannot provide both :backupPolicyId and :backup_policy_id' if attributes.key?(:'backupPolicyId') && attributes.key?(:'backup_policy_id')

  self.backup_policy_id = attributes[:'backup_policy_id'] if attributes[:'backup_policy_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.vpus_per_gb = attributes[:'vpusPerGB'] if attributes[:'vpusPerGB']

  raise 'You cannot provide both :vpusPerGB and :vpus_per_gb' if attributes.key?(:'vpusPerGB') && attributes.key?(:'vpus_per_gb')

  self.vpus_per_gb = attributes[:'vpus_per_gb'] if attributes[:'vpus_per_gb']

  self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs']

  raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs')

  self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs']

  self.size_in_mbs = attributes[:'sizeInMBs'] if attributes[:'sizeInMBs']

  raise 'You cannot provide both :sizeInMBs and :size_in_mbs' if attributes.key?(:'sizeInMBs') && attributes.key?(:'size_in_mbs')

  self.size_in_mbs = attributes[:'size_in_mbs'] if attributes[:'size_in_mbs']

  self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails']

  raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details')

  self.source_details = attributes[:'source_details'] if attributes[:'source_details']

  self.volume_backup_id = attributes[:'volumeBackupId'] if attributes[:'volumeBackupId']

  raise 'You cannot provide both :volumeBackupId and :volume_backup_id' if attributes.key?(:'volumeBackupId') && attributes.key?(:'volume_backup_id')

  self.volume_backup_id = attributes[:'volume_backup_id'] if attributes[:'volume_backup_id']

  self.is_auto_tune_enabled = attributes[:'isAutoTuneEnabled'] unless attributes[:'isAutoTuneEnabled'].nil?

  raise 'You cannot provide both :isAutoTuneEnabled and :is_auto_tune_enabled' if attributes.key?(:'isAutoTuneEnabled') && attributes.key?(:'is_auto_tune_enabled')

  self.is_auto_tune_enabled = attributes[:'is_auto_tune_enabled'] unless attributes[:'is_auto_tune_enabled'].nil?

  self.block_volume_replicas = attributes[:'blockVolumeReplicas'] if attributes[:'blockVolumeReplicas']

  raise 'You cannot provide both :blockVolumeReplicas and :block_volume_replicas' if attributes.key?(:'blockVolumeReplicas') && attributes.key?(:'block_volume_replicas')

  self.block_volume_replicas = attributes[:'block_volume_replicas'] if attributes[:'block_volume_replicas']
end

Instance Attribute Details

#availability_domainString

[Required] The availability domain of the volume.

Example: Uocm:PHX-AD-1

Returns:

  • (String)


15
16
17
# File 'lib/oci/core/models/create_volume_details.rb', line 15

def availability_domain
  @availability_domain
end

#backup_policy_idString

If provided, specifies the ID of the volume backup policy to assign to the newly created volume. If omitted, no policy will be assigned.

Returns:

  • (String)


21
22
23
# File 'lib/oci/core/models/create_volume_details.rb', line 21

def backup_policy_id
  @backup_policy_id
end

#block_volume_replicasArray<OCI::Core::Models::BlockVolumeReplicaDetails>

The list of block volume replicas to be enabled for this volume in the specified destination availability domains.



99
100
101
# File 'lib/oci/core/models/create_volume_details.rb', line 99

def block_volume_replicas
  @block_volume_replicas
end

#compartment_idString

[Required] The OCID of the compartment that contains the volume.

Returns:

  • (String)


25
26
27
# File 'lib/oci/core/models/create_volume_details.rb', line 25

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


33
34
35
# File 'lib/oci/core/models/create_volume_details.rb', line 33

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


39
40
41
# File 'lib/oci/core/models/create_volume_details.rb', line 39

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


47
48
49
# File 'lib/oci/core/models/create_volume_details.rb', line 47

def freeform_tags
  @freeform_tags
end

#is_auto_tune_enabledBOOLEAN

Specifies whether the auto-tune performance is enabled for this volume.

Returns:

  • (BOOLEAN)


93
94
95
# File 'lib/oci/core/models/create_volume_details.rb', line 93

def is_auto_tune_enabled
  @is_auto_tune_enabled
end

#kms_key_idString

The OCID of the Key Management key to assign as the master encryption key for the volume.

Returns:

  • (String)


53
54
55
# File 'lib/oci/core/models/create_volume_details.rb', line 53

def kms_key_id
  @kms_key_id
end

#size_in_gbsInteger

The size of the volume in GBs.

Returns:

  • (Integer)


72
73
74
# File 'lib/oci/core/models/create_volume_details.rb', line 72

def size_in_gbs
  @size_in_gbs
end

#size_in_mbsInteger

The size of the volume in MBs. The value must be a multiple of 1024. This field is deprecated. Use sizeInGBs instead.

Returns:

  • (Integer)


78
79
80
# File 'lib/oci/core/models/create_volume_details.rb', line 78

def size_in_mbs
  @size_in_mbs
end

#source_detailsOCI::Core::Models::VolumeSourceDetails



81
82
83
# File 'lib/oci/core/models/create_volume_details.rb', line 81

def source_details
  @source_details
end

#volume_backup_idString

The OCID of the volume backup from which the data should be restored on the newly created volume. This field is deprecated. Use the sourceDetails field instead to specify the backup for the volume.

Returns:

  • (String)


88
89
90
# File 'lib/oci/core/models/create_volume_details.rb', line 88

def volume_backup_id
  @volume_backup_id
end

#vpus_per_gbInteger

The number of volume performance units (VPUs) that will be applied to this volume per GB, representing the Block Volume service’s elastic performance options. See [Block Volume Elastic Performance](docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeelasticperformance.htm) for more information.

Allowed values:

* `0`: Represents Lower Cost option.

* `10`: Represents Balanced option.

* `20`: Represents Higher Performance option.

Returns:

  • (Integer)


68
69
70
# File 'lib/oci/core/models/create_volume_details.rb', line 68

def vpus_per_gb
  @vpus_per_gb
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/core/models/create_volume_details.rb', line 102

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'availabilityDomain',
    'backup_policy_id': :'backupPolicyId',
    'compartment_id': :'compartmentId',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'kms_key_id': :'kmsKeyId',
    'vpus_per_gb': :'vpusPerGB',
    'size_in_gbs': :'sizeInGBs',
    'size_in_mbs': :'sizeInMBs',
    'source_details': :'sourceDetails',
    'volume_backup_id': :'volumeBackupId',
    'is_auto_tune_enabled': :'isAutoTuneEnabled',
    'block_volume_replicas': :'blockVolumeReplicas'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/core/models/create_volume_details.rb', line 124

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'String',
    'backup_policy_id': :'String',
    'compartment_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'kms_key_id': :'String',
    'vpus_per_gb': :'Integer',
    'size_in_gbs': :'Integer',
    'size_in_mbs': :'Integer',
    'source_details': :'OCI::Core::Models::VolumeSourceDetails',
    'volume_backup_id': :'String',
    'is_auto_tune_enabled': :'BOOLEAN',
    'block_volume_replicas': :'Array<OCI::Core::Models::BlockVolumeReplicaDetails>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/oci/core/models/create_volume_details.rb', line 263

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    availability_domain == other.availability_domain &&
    backup_policy_id == other.backup_policy_id &&
    compartment_id == other.compartment_id &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    kms_key_id == other.kms_key_id &&
    vpus_per_gb == other.vpus_per_gb &&
    size_in_gbs == other.size_in_gbs &&
    size_in_mbs == other.size_in_mbs &&
    source_details == other.source_details &&
    volume_backup_id == other.volume_backup_id &&
    is_auto_tune_enabled == other.is_auto_tune_enabled &&
    block_volume_replicas == other.block_volume_replicas
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/oci/core/models/create_volume_details.rb', line 306

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


286
287
288
# File 'lib/oci/core/models/create_volume_details.rb', line 286

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



295
296
297
# File 'lib/oci/core/models/create_volume_details.rb', line 295

def hash
  [availability_domain, backup_policy_id, compartment_id, defined_tags, display_name, freeform_tags, kms_key_id, vpus_per_gb, size_in_gbs, size_in_mbs, source_details, volume_backup_id, is_auto_tune_enabled, block_volume_replicas].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



339
340
341
342
343
344
345
346
347
348
# File 'lib/oci/core/models/create_volume_details.rb', line 339

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



333
334
335
# File 'lib/oci/core/models/create_volume_details.rb', line 333

def to_s
  to_hash.to_s
end