Class: OCI::Core::Models::CreateVolumeDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/create_volume_details.rb

Overview

CreateVolumeDetails model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateVolumeDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/oci/core/models/create_volume_details.rb', line 151

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.backup_policy_id = attributes[:'backupPolicyId'] if attributes[:'backupPolicyId']

  raise 'You cannot provide both :backupPolicyId and :backup_policy_id' if attributes.key?(:'backupPolicyId') && attributes.key?(:'backup_policy_id')

  self.backup_policy_id = attributes[:'backup_policy_id'] if attributes[:'backup_policy_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.vpus_per_gb = attributes[:'vpusPerGB'] if attributes[:'vpusPerGB']

  raise 'You cannot provide both :vpusPerGB and :vpus_per_gb' if attributes.key?(:'vpusPerGB') && attributes.key?(:'vpus_per_gb')

  self.vpus_per_gb = attributes[:'vpus_per_gb'] if attributes[:'vpus_per_gb']

  self.size_in_gbs = attributes[:'sizeInGBs'] if attributes[:'sizeInGBs']

  raise 'You cannot provide both :sizeInGBs and :size_in_gbs' if attributes.key?(:'sizeInGBs') && attributes.key?(:'size_in_gbs')

  self.size_in_gbs = attributes[:'size_in_gbs'] if attributes[:'size_in_gbs']

  self.size_in_mbs = attributes[:'sizeInMBs'] if attributes[:'sizeInMBs']

  raise 'You cannot provide both :sizeInMBs and :size_in_mbs' if attributes.key?(:'sizeInMBs') && attributes.key?(:'size_in_mbs')

  self.size_in_mbs = attributes[:'size_in_mbs'] if attributes[:'size_in_mbs']

  self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails']

  raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details')

  self.source_details = attributes[:'source_details'] if attributes[:'source_details']

  self.volume_backup_id = attributes[:'volumeBackupId'] if attributes[:'volumeBackupId']

  raise 'You cannot provide both :volumeBackupId and :volume_backup_id' if attributes.key?(:'volumeBackupId') && attributes.key?(:'volume_backup_id')

  self.volume_backup_id = attributes[:'volume_backup_id'] if attributes[:'volume_backup_id']
end

Instance Attribute Details

#availability_domainString

[Required] The availability domain of the volume.

Example: Uocm:PHX-AD-1

Returns:

  • (String)


14
15
16
# File 'lib/oci/core/models/create_volume_details.rb', line 14

def availability_domain
  @availability_domain
end

#backup_policy_idString

If provided, specifies the ID of the volume backup policy to assign to the newly created volume. If omitted, no policy will be assigned.

Returns:

  • (String)


20
21
22
# File 'lib/oci/core/models/create_volume_details.rb', line 20

def backup_policy_id
  @backup_policy_id
end

#compartment_idString

[Required] The OCID of the compartment that contains the volume.

Returns:

  • (String)


24
25
26
# File 'lib/oci/core/models/create_volume_details.rb', line 24

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


32
33
34
# File 'lib/oci/core/models/create_volume_details.rb', line 32

def defined_tags
  @defined_tags
end

#display_nameString

A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


38
39
40
# File 'lib/oci/core/models/create_volume_details.rb', line 38

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


46
47
48
# File 'lib/oci/core/models/create_volume_details.rb', line 46

def freeform_tags
  @freeform_tags
end

#kms_key_idString

The OCID of the Key Management key to assign as the master encryption key for the volume.

Returns:

  • (String)


52
53
54
# File 'lib/oci/core/models/create_volume_details.rb', line 52

def kms_key_id
  @kms_key_id
end

#size_in_gbsInteger

The size of the volume in GBs.

Returns:

  • (Integer)


71
72
73
# File 'lib/oci/core/models/create_volume_details.rb', line 71

def size_in_gbs
  @size_in_gbs
end

#size_in_mbsInteger

The size of the volume in MBs. The value must be a multiple of 1024. This field is deprecated. Use sizeInGBs instead.

Returns:

  • (Integer)


77
78
79
# File 'lib/oci/core/models/create_volume_details.rb', line 77

def size_in_mbs
  @size_in_mbs
end

#source_detailsOCI::Core::Models::VolumeSourceDetails

Specifies the volume source details for a new Block volume. The volume source is either another Block volume in the same availability domain or a Block volume backup. This is an optional field. If not specified or set to null, the new Block volume will be empty. When specified, the new Block volume will contain data from the source volume or backup.



84
85
86
# File 'lib/oci/core/models/create_volume_details.rb', line 84

def source_details
  @source_details
end

#volume_backup_idString

The OCID of the volume backup from which the data should be restored on the newly created volume. This field is deprecated. Use the sourceDetails field instead to specify the backup for the volume.

Returns:

  • (String)


91
92
93
# File 'lib/oci/core/models/create_volume_details.rb', line 91

def volume_backup_id
  @volume_backup_id
end

#vpus_per_gbInteger

The number of volume performance units (VPUs) that will be applied to this volume per GB, representing the Block Volume service’s elastic performance options. See [Block Volume Elastic Performance](docs.cloud.oracle.com/Content/Block/Concepts/blockvolumeelasticperformance.htm) for more information.

Allowed values:

* `0`: Represents Lower Cost option.

* `10`: Represents Balanced option.

* `20`: Represents Higher Performance option.

Returns:

  • (Integer)


67
68
69
# File 'lib/oci/core/models/create_volume_details.rb', line 67

def vpus_per_gb
  @vpus_per_gb
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/oci/core/models/create_volume_details.rb', line 94

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'availabilityDomain',
    'backup_policy_id': :'backupPolicyId',
    'compartment_id': :'compartmentId',
    'defined_tags': :'definedTags',
    'display_name': :'displayName',
    'freeform_tags': :'freeformTags',
    'kms_key_id': :'kmsKeyId',
    'vpus_per_gb': :'vpusPerGB',
    'size_in_gbs': :'sizeInGBs',
    'size_in_mbs': :'sizeInMBs',
    'source_details': :'sourceDetails',
    'volume_backup_id': :'volumeBackupId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/oci/core/models/create_volume_details.rb', line 114

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'availability_domain': :'String',
    'backup_policy_id': :'String',
    'compartment_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'display_name': :'String',
    'freeform_tags': :'Hash<String, String>',
    'kms_key_id': :'String',
    'vpus_per_gb': :'Integer',
    'size_in_gbs': :'Integer',
    'size_in_mbs': :'Integer',
    'source_details': :'OCI::Core::Models::VolumeSourceDetails',
    'volume_backup_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/oci/core/models/create_volume_details.rb', line 237

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    availability_domain == other.availability_domain &&
    backup_policy_id == other.backup_policy_id &&
    compartment_id == other.compartment_id &&
    defined_tags == other.defined_tags &&
    display_name == other.display_name &&
    freeform_tags == other.freeform_tags &&
    kms_key_id == other.kms_key_id &&
    vpus_per_gb == other.vpus_per_gb &&
    size_in_gbs == other.size_in_gbs &&
    size_in_mbs == other.size_in_mbs &&
    source_details == other.source_details &&
    volume_backup_id == other.volume_backup_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/oci/core/models/create_volume_details.rb', line 278

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


258
259
260
# File 'lib/oci/core/models/create_volume_details.rb', line 258

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



267
268
269
# File 'lib/oci/core/models/create_volume_details.rb', line 267

def hash
  [availability_domain, backup_policy_id, compartment_id, defined_tags, display_name, freeform_tags, kms_key_id, vpus_per_gb, size_in_gbs, size_in_mbs, source_details, volume_backup_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



311
312
313
314
315
316
317
318
319
320
# File 'lib/oci/core/models/create_volume_details.rb', line 311

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



305
306
307
# File 'lib/oci/core/models/create_volume_details.rb', line 305

def to_s
  to_hash.to_s
end