Class: OCI::Core::Models::CrossConnect
- Inherits:
-
Object
- Object
- OCI::Core::Models::CrossConnect
- Defined in:
- lib/oci/core/models/cross_connect.rb
Overview
For use with Oracle Cloud Infrastructure FastConnect. A cross-connect represents a physical connection between an existing network and Oracle. Customers who are colocated with Oracle in a FastConnect location create and use cross-connects. For more information, see [FastConnect Overview](docs.us-phoenix-1.oraclecloud.com/Content/Network/Concepts/fastconnect.htm).
Oracle recommends you create each cross-connect in a CrossConnectGroup so you can use link aggregation with the connection.
Note: If you’re a provider who is setting up a physical connection to Oracle so customers can use FastConnect over the connection, be aware that your connection is modeled the same way as a colocated customer’s (with CrossConnect and CrossConnectGroup objects, and so on).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.us-phoenix-1.oraclecloud.com/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
rubocop:disable Metrics/LineLength
[ LIFECYCLE_STATE_PENDING_CUSTOMER = 'PENDING_CUSTOMER'.freeze, LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_PROVISIONED = 'PROVISIONED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the compartment containing the cross-connect group.
-
#cross_connect_group_id ⇒ String
The OCID of the cross-connect group this cross-connect belongs to (if any).
-
#display_name ⇒ String
A user-friendly name.
-
#id ⇒ String
The cross-connect’s Oracle ID (OCID).
-
#lifecycle_state ⇒ String
The cross-connect’s current state.
-
#location_name ⇒ String
The name of the FastConnect location where this cross-connect is installed.
-
#port_name ⇒ String
A string identifying the meet-me room port for this cross-connect.
-
#port_speed_shape_name ⇒ String
The port speed for this cross-connect.
-
#time_created ⇒ DateTime
The date and time the cross-connect was created, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CrossConnect
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CrossConnect
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/core/models/cross_connect.rb', line 132 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.cross_connect_group_id = attributes[:'crossConnectGroupId'] if attributes[:'crossConnectGroupId'] raise 'You cannot provide both :crossConnectGroupId and :cross_connect_group_id' if attributes.key?(:'crossConnectGroupId') && attributes.key?(:'cross_connect_group_id') self.cross_connect_group_id = attributes[:'cross_connect_group_id'] if attributes[:'cross_connect_group_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.location_name = attributes[:'locationName'] if attributes[:'locationName'] raise 'You cannot provide both :locationName and :location_name' if attributes.key?(:'locationName') && attributes.key?(:'location_name') self.location_name = attributes[:'location_name'] if attributes[:'location_name'] self.port_name = attributes[:'portName'] if attributes[:'portName'] raise 'You cannot provide both :portName and :port_name' if attributes.key?(:'portName') && attributes.key?(:'port_name') self.port_name = attributes[:'port_name'] if attributes[:'port_name'] self.port_speed_shape_name = attributes[:'portSpeedShapeName'] if attributes[:'portSpeedShapeName'] raise 'You cannot provide both :portSpeedShapeName and :port_speed_shape_name' if attributes.key?(:'portSpeedShapeName') && attributes.key?(:'port_speed_shape_name') self.port_speed_shape_name = attributes[:'port_speed_shape_name'] if attributes[:'port_speed_shape_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the compartment containing the cross-connect group.
41 42 43 |
# File 'lib/oci/core/models/cross_connect.rb', line 41 def compartment_id @compartment_id end |
#cross_connect_group_id ⇒ String
The OCID of the cross-connect group this cross-connect belongs to (if any).
45 46 47 |
# File 'lib/oci/core/models/cross_connect.rb', line 45 def cross_connect_group_id @cross_connect_group_id end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
51 52 53 |
# File 'lib/oci/core/models/cross_connect.rb', line 51 def display_name @display_name end |
#id ⇒ String
The cross-connect’s Oracle ID (OCID).
55 56 57 |
# File 'lib/oci/core/models/cross_connect.rb', line 55 def id @id end |
#lifecycle_state ⇒ String
The cross-connect’s current state.
59 60 61 |
# File 'lib/oci/core/models/cross_connect.rb', line 59 def lifecycle_state @lifecycle_state end |
#location_name ⇒ String
The name of the FastConnect location where this cross-connect is installed.
63 64 65 |
# File 'lib/oci/core/models/cross_connect.rb', line 63 def location_name @location_name end |
#port_name ⇒ String
A string identifying the meet-me room port for this cross-connect.
67 68 69 |
# File 'lib/oci/core/models/cross_connect.rb', line 67 def port_name @port_name end |
#port_speed_shape_name ⇒ String
The port speed for this cross-connect.
Example: ‘10 Gbps`
74 75 76 |
# File 'lib/oci/core/models/cross_connect.rb', line 74 def port_speed_shape_name @port_speed_shape_name end |
#time_created ⇒ DateTime
The date and time the cross-connect was created, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
81 82 83 |
# File 'lib/oci/core/models/cross_connect.rb', line 81 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/core/models/cross_connect.rb', line 84 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'cross_connect_group_id': :'crossConnectGroupId', 'display_name': :'displayName', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'location_name': :'locationName', 'port_name': :'portName', 'port_speed_shape_name': :'portSpeedShapeName', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/core/models/cross_connect.rb', line 101 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'cross_connect_group_id': :'String', 'display_name': :'String', 'id': :'String', 'lifecycle_state': :'String', 'location_name': :'String', 'port_name': :'String', 'port_speed_shape_name': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/oci/core/models/cross_connect.rb', line 211 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && cross_connect_group_id == other.cross_connect_group_id && display_name == other.display_name && id == other.id && lifecycle_state == other.lifecycle_state && location_name == other.location_name && port_name == other.port_name && port_speed_shape_name == other.port_speed_shape_name && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/core/models/cross_connect.rb', line 249 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
229 230 231 |
# File 'lib/oci/core/models/cross_connect.rb', line 229 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
238 239 240 |
# File 'lib/oci/core/models/cross_connect.rb', line 238 def hash [compartment_id, cross_connect_group_id, display_name, id, lifecycle_state, location_name, port_name, port_speed_shape_name, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
282 283 284 285 286 287 288 289 290 291 |
# File 'lib/oci/core/models/cross_connect.rb', line 282 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
276 277 278 |
# File 'lib/oci/core/models/cross_connect.rb', line 276 def to_s to_hash.to_s end |