Class: OCI::Core::Models::CrossConnectMappingDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::CrossConnectMappingDetails
- Defined in:
- lib/oci/core/models/cross_connect_mapping_details.rb
Overview
For use with Oracle Cloud Infrastructure FastConnect. Each VirtualCircuit runs on one or more cross-connects or cross-connect groups. A CrossConnectMappingDetails contains the properties for an individual cross-connect or cross-connect group associated with a given virtual circuit.
The details includes information about the cross-connect or cross-connect group, the VLAN, and the BGP peering session.
Constant Summary collapse
- IPV4_BGP_STATUS_ENUM =
[ IPV4_BGP_STATUS_UP = 'UP'.freeze, IPV4_BGP_STATUS_DOWN = 'DOWN'.freeze, IPV4_BGP_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- IPV6_BGP_STATUS_ENUM =
[ IPV6_BGP_STATUS_UP = 'UP'.freeze, IPV6_BGP_STATUS_DOWN = 'DOWN'.freeze, IPV6_BGP_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#bgp_md5_auth_key ⇒ String
The key for BGP MD5 authentication.
-
#cross_connect_or_cross_connect_group_id ⇒ String
The OCID of the cross-connect or cross-connect group for this mapping.
-
#customer_bgp_peering_ip ⇒ String
The BGP IPv4 address for the router on the other end of the BGP session from Oracle.
-
#customer_bgp_peering_ipv6 ⇒ String
The BGP IPv6 address for the router on the other end of the BGP session from Oracle.
-
#ipv4_bgp_status ⇒ String
The state of the Ipv4 BGP session.
-
#ipv6_bgp_status ⇒ String
The state of the Ipv6 BGP session.
-
#oracle_bgp_peering_ip ⇒ String
The IPv4 address for Oracle’s end of the BGP session.
-
#oracle_bgp_peering_ipv6 ⇒ String
The IPv6 address for Oracle’s end of the BGP session.
-
#vlan ⇒ Integer
The number of the specific VLAN (on the cross-connect or cross-connect group) that is assigned to this virtual circuit.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CrossConnectMappingDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CrossConnectMappingDetails
Initializes the object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 163 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.bgp_md5_auth_key = attributes[:'bgpMd5AuthKey'] if attributes[:'bgpMd5AuthKey'] raise 'You cannot provide both :bgpMd5AuthKey and :bgp_md5_auth_key' if attributes.key?(:'bgpMd5AuthKey') && attributes.key?(:'bgp_md5_auth_key') self.bgp_md5_auth_key = attributes[:'bgp_md5_auth_key'] if attributes[:'bgp_md5_auth_key'] self.cross_connect_or_cross_connect_group_id = attributes[:'crossConnectOrCrossConnectGroupId'] if attributes[:'crossConnectOrCrossConnectGroupId'] raise 'You cannot provide both :crossConnectOrCrossConnectGroupId and :cross_connect_or_cross_connect_group_id' if attributes.key?(:'crossConnectOrCrossConnectGroupId') && attributes.key?(:'cross_connect_or_cross_connect_group_id') self.cross_connect_or_cross_connect_group_id = attributes[:'cross_connect_or_cross_connect_group_id'] if attributes[:'cross_connect_or_cross_connect_group_id'] self.customer_bgp_peering_ip = attributes[:'customerBgpPeeringIp'] if attributes[:'customerBgpPeeringIp'] raise 'You cannot provide both :customerBgpPeeringIp and :customer_bgp_peering_ip' if attributes.key?(:'customerBgpPeeringIp') && attributes.key?(:'customer_bgp_peering_ip') self.customer_bgp_peering_ip = attributes[:'customer_bgp_peering_ip'] if attributes[:'customer_bgp_peering_ip'] self.oracle_bgp_peering_ip = attributes[:'oracleBgpPeeringIp'] if attributes[:'oracleBgpPeeringIp'] raise 'You cannot provide both :oracleBgpPeeringIp and :oracle_bgp_peering_ip' if attributes.key?(:'oracleBgpPeeringIp') && attributes.key?(:'oracle_bgp_peering_ip') self.oracle_bgp_peering_ip = attributes[:'oracle_bgp_peering_ip'] if attributes[:'oracle_bgp_peering_ip'] self.customer_bgp_peering_ipv6 = attributes[:'customerBgpPeeringIpv6'] if attributes[:'customerBgpPeeringIpv6'] raise 'You cannot provide both :customerBgpPeeringIpv6 and :customer_bgp_peering_ipv6' if attributes.key?(:'customerBgpPeeringIpv6') && attributes.key?(:'customer_bgp_peering_ipv6') self.customer_bgp_peering_ipv6 = attributes[:'customer_bgp_peering_ipv6'] if attributes[:'customer_bgp_peering_ipv6'] self.oracle_bgp_peering_ipv6 = attributes[:'oracleBgpPeeringIpv6'] if attributes[:'oracleBgpPeeringIpv6'] raise 'You cannot provide both :oracleBgpPeeringIpv6 and :oracle_bgp_peering_ipv6' if attributes.key?(:'oracleBgpPeeringIpv6') && attributes.key?(:'oracle_bgp_peering_ipv6') self.oracle_bgp_peering_ipv6 = attributes[:'oracle_bgp_peering_ipv6'] if attributes[:'oracle_bgp_peering_ipv6'] self.vlan = attributes[:'vlan'] if attributes[:'vlan'] self.ipv4_bgp_status = attributes[:'ipv4BgpStatus'] if attributes[:'ipv4BgpStatus'] raise 'You cannot provide both :ipv4BgpStatus and :ipv4_bgp_status' if attributes.key?(:'ipv4BgpStatus') && attributes.key?(:'ipv4_bgp_status') self.ipv4_bgp_status = attributes[:'ipv4_bgp_status'] if attributes[:'ipv4_bgp_status'] self.ipv6_bgp_status = attributes[:'ipv6BgpStatus'] if attributes[:'ipv6BgpStatus'] raise 'You cannot provide both :ipv6BgpStatus and :ipv6_bgp_status' if attributes.key?(:'ipv6BgpStatus') && attributes.key?(:'ipv6_bgp_status') self.ipv6_bgp_status = attributes[:'ipv6_bgp_status'] if attributes[:'ipv6_bgp_status'] end |
Instance Attribute Details
#bgp_md5_auth_key ⇒ String
The key for BGP MD5 authentication. Only applicable if your system requires MD5 authentication. If empty or not set (null), that means you don’t use BGP MD5 authentication.
36 37 38 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 36 def bgp_md5_auth_key @bgp_md5_auth_key end |
#cross_connect_or_cross_connect_group_id ⇒ String
The OCID of the cross-connect or cross-connect group for this mapping. Specified by the owner of the cross-connect or cross-connect group (the customer if the customer is colocated with Oracle, or the provider if the customer is connecting via provider).
44 45 46 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 44 def cross_connect_or_cross_connect_group_id @cross_connect_or_cross_connect_group_id end |
#customer_bgp_peering_ip ⇒ String
The BGP IPv4 address for the router on the other end of the BGP session from Oracle. Specified by the owner of that router. If the session goes from Oracle to a customer, this is the BGP IPv4 address of the customer’s edge router. If the session goes from Oracle to a provider, this is the BGP IPv4 address of the provider’s edge router. Must use a /30 or /31 subnet mask.
There’s one exception: for a public virtual circuit, Oracle specifies the BGP IPv4 addresses.
Example: 10.0.0.18/31
57 58 59 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 57 def customer_bgp_peering_ip @customer_bgp_peering_ip end |
#customer_bgp_peering_ipv6 ⇒ String
The BGP IPv6 address for the router on the other end of the BGP session from Oracle. Specified by the owner of that router. If the session goes from Oracle to a customer, this is the BGP IPv6 address of the customer’s edge router. If the session goes from Oracle to a provider, this is the BGP IPv6 address of the provider’s edge router. Only subnet masks from /64 up to /127 are allowed.
There’s one exception: for a public virtual circuit, Oracle specifies the BGP IPv6 addresses.
Example: 2001:db8::1/64
82 83 84 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 82 def customer_bgp_peering_ipv6 @customer_bgp_peering_ipv6 end |
#ipv4_bgp_status ⇒ String
The state of the Ipv4 BGP session.
108 109 110 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 108 def ipv4_bgp_status @ipv4_bgp_status end |
#ipv6_bgp_status ⇒ String
The state of the Ipv6 BGP session.
112 113 114 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 112 def ipv6_bgp_status @ipv6_bgp_status end |
#oracle_bgp_peering_ip ⇒ String
The IPv4 address for Oracle’s end of the BGP session. Must use a /30 or /31 subnet mask. If the session goes from Oracle to a customer’s edge router, the customer specifies this information. If the session goes from Oracle to a provider’s edge router, the provider specifies this.
There’s one exception: for a public virtual circuit, Oracle specifies the BGP IPv4 addresses.
Example: 10.0.0.19/31
69 70 71 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 69 def oracle_bgp_peering_ip @oracle_bgp_peering_ip end |
#oracle_bgp_peering_ipv6 ⇒ String
The IPv6 address for Oracle’s end of the BGP session. Only subnet masks from /64 up to /127 are allowed. If the session goes from Oracle to a customer’s edge router, the customer specifies this information. If the session goes from Oracle to a provider’s edge router, the provider specifies this.
There’s one exception: for a public virtual circuit, Oracle specifies the BGP IPv6 addresses.
Example: 2001:db8::2/64
94 95 96 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 94 def oracle_bgp_peering_ipv6 @oracle_bgp_peering_ipv6 end |
#vlan ⇒ Integer
The number of the specific VLAN (on the cross-connect or cross-connect group) that is assigned to this virtual circuit. Specified by the owner of the cross-connect or cross-connect group (the customer if the customer is colocated with Oracle, or the provider if the customer is connecting via provider).
Example: 200
104 105 106 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 104 def vlan @vlan end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 115 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'bgp_md5_auth_key': :'bgpMd5AuthKey', 'cross_connect_or_cross_connect_group_id': :'crossConnectOrCrossConnectGroupId', 'customer_bgp_peering_ip': :'customerBgpPeeringIp', 'oracle_bgp_peering_ip': :'oracleBgpPeeringIp', 'customer_bgp_peering_ipv6': :'customerBgpPeeringIpv6', 'oracle_bgp_peering_ipv6': :'oracleBgpPeeringIpv6', 'vlan': :'vlan', 'ipv4_bgp_status': :'ipv4BgpStatus', 'ipv6_bgp_status': :'ipv6BgpStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 132 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'bgp_md5_auth_key': :'String', 'cross_connect_or_cross_connect_group_id': :'String', 'customer_bgp_peering_ip': :'String', 'oracle_bgp_peering_ip': :'String', 'customer_bgp_peering_ipv6': :'String', 'oracle_bgp_peering_ipv6': :'String', 'vlan': :'Integer', 'ipv4_bgp_status': :'String', 'ipv6_bgp_status': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 253 def ==(other) return true if equal?(other) self.class == other.class && bgp_md5_auth_key == other.bgp_md5_auth_key && cross_connect_or_cross_connect_group_id == other.cross_connect_or_cross_connect_group_id && customer_bgp_peering_ip == other.customer_bgp_peering_ip && oracle_bgp_peering_ip == other.oracle_bgp_peering_ip && customer_bgp_peering_ipv6 == other.customer_bgp_peering_ipv6 && oracle_bgp_peering_ipv6 == other.oracle_bgp_peering_ipv6 && vlan == other.vlan && ipv4_bgp_status == other.ipv4_bgp_status && ipv6_bgp_status == other.ipv6_bgp_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 291 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
271 272 273 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 271 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
280 281 282 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 280 def hash [bgp_md5_auth_key, cross_connect_or_cross_connect_group_id, customer_bgp_peering_ip, oracle_bgp_peering_ip, customer_bgp_peering_ipv6, oracle_bgp_peering_ipv6, vlan, ipv4_bgp_status, ipv6_bgp_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
324 325 326 327 328 329 330 331 332 333 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 324 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
318 319 320 |
# File 'lib/oci/core/models/cross_connect_mapping_details.rb', line 318 def to_s to_hash.to_s end |