Class: OCI::Core::Models::DedicatedVmHost
- Inherits:
-
Object
- Object
- OCI::Core::Models::DedicatedVmHost
- Defined in:
- lib/oci/core/models/dedicated_vm_host.rb
Overview
A dedicated virtual machine host lets you host multiple VM instances on a dedicated server that is not shared with other tenancies.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The availability domain the dedicated virtual machine host is running in.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the dedicated virtual machine host.
-
#dedicated_vm_host_shape ⇒ String
[Required] The dedicated virtual machine host shape.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#fault_domain ⇒ String
The fault domain for the dedicated virtual machine host’s assigned instances.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the dedicated VM host.
-
#lifecycle_state ⇒ String
[Required] The current state of the dedicated VM host.
-
#remaining_memory_in_gbs ⇒ Float
The remaining memory of the dedicated VM host, in GBs.
-
#remaining_ocpus ⇒ Float
[Required] The available OCPUs of the dedicated VM host.
-
#time_created ⇒ DateTime
[Required] The date and time the dedicated VM host was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#total_memory_in_gbs ⇒ Float
The total memory of the dedicated VM host, in GBs.
-
#total_ocpus ⇒ Float
[Required] The total OCPUs of the dedicated VM host.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DedicatedVmHost
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DedicatedVmHost
Initializes the object
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 177 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.dedicated_vm_host_shape = attributes[:'dedicatedVmHostShape'] if attributes[:'dedicatedVmHostShape'] raise 'You cannot provide both :dedicatedVmHostShape and :dedicated_vm_host_shape' if attributes.key?(:'dedicatedVmHostShape') && attributes.key?(:'dedicated_vm_host_shape') self.dedicated_vm_host_shape = attributes[:'dedicated_vm_host_shape'] if attributes[:'dedicated_vm_host_shape'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain'] raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain') self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.total_ocpus = attributes[:'totalOcpus'] if attributes[:'totalOcpus'] raise 'You cannot provide both :totalOcpus and :total_ocpus' if attributes.key?(:'totalOcpus') && attributes.key?(:'total_ocpus') self.total_ocpus = attributes[:'total_ocpus'] if attributes[:'total_ocpus'] self.remaining_ocpus = attributes[:'remainingOcpus'] if attributes[:'remainingOcpus'] raise 'You cannot provide both :remainingOcpus and :remaining_ocpus' if attributes.key?(:'remainingOcpus') && attributes.key?(:'remaining_ocpus') self.remaining_ocpus = attributes[:'remaining_ocpus'] if attributes[:'remaining_ocpus'] self.total_memory_in_gbs = attributes[:'totalMemoryInGBs'] if attributes[:'totalMemoryInGBs'] raise 'You cannot provide both :totalMemoryInGBs and :total_memory_in_gbs' if attributes.key?(:'totalMemoryInGBs') && attributes.key?(:'total_memory_in_gbs') self.total_memory_in_gbs = attributes[:'total_memory_in_gbs'] if attributes[:'total_memory_in_gbs'] self.remaining_memory_in_gbs = attributes[:'remainingMemoryInGBs'] if attributes[:'remainingMemoryInGBs'] raise 'You cannot provide both :remainingMemoryInGBs and :remaining_memory_in_gbs' if attributes.key?(:'remainingMemoryInGBs') && attributes.key?(:'remaining_memory_in_gbs') self.remaining_memory_in_gbs = attributes[:'remaining_memory_in_gbs'] if attributes[:'remaining_memory_in_gbs'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The availability domain the dedicated virtual machine host is running in.
Example: Uocm:PHX-AD-1
28 29 30 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 28 def availability_domain @availability_domain end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the dedicated virtual machine host.
32 33 34 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 32 def compartment_id @compartment_id end |
#dedicated_vm_host_shape ⇒ String
[Required] The dedicated virtual machine host shape. The shape determines the number of CPUs and other resources available for VMs.
38 39 40 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 38 def dedicated_vm_host_shape @dedicated_vm_host_shape end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
46 47 48 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 46 def end |
#display_name ⇒ String
[Required] A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
Example: ‘My Dedicated Vm Host`
54 55 56 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 54 def display_name @display_name end |
#fault_domain ⇒ String
The fault domain for the dedicated virtual machine host’s assigned instances. For more information, see [Fault Domains](docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm#fault).
If you do not specify the fault domain, the system selects one for you. To change the fault domain for a dedicated virtual machine host, delete it, and then create a new dedicated virtual machine host in the preferred fault domain.
To get a list of fault domains, use the ListFaultDomains operation in the [Identity and Access Management Service API](docs.cloud.oracle.com/iaas/api/#/en/identity/20160918/).
Example: FAULT-DOMAIN-1
67 68 69 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 67 def fault_domain @fault_domain end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
75 76 77 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 75 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the dedicated VM host.
79 80 81 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 79 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of the dedicated VM host.
84 85 86 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 84 def lifecycle_state @lifecycle_state end |
#remaining_memory_in_gbs ⇒ Float
The remaining memory of the dedicated VM host, in GBs.
111 112 113 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 111 def remaining_memory_in_gbs @remaining_memory_in_gbs end |
#remaining_ocpus ⇒ Float
[Required] The available OCPUs of the dedicated VM host.
101 102 103 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 101 def remaining_ocpus @remaining_ocpus end |
#time_created ⇒ DateTime
[Required] The date and time the dedicated VM host was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
91 92 93 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 91 def time_created @time_created end |
#total_memory_in_gbs ⇒ Float
The total memory of the dedicated VM host, in GBs.
106 107 108 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 106 def total_memory_in_gbs @total_memory_in_gbs end |
#total_ocpus ⇒ Float
[Required] The total OCPUs of the dedicated VM host.
96 97 98 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 96 def total_ocpus @total_ocpus end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 114 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'dedicated_vm_host_shape': :'dedicatedVmHostShape', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'fault_domain': :'faultDomain', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'total_ocpus': :'totalOcpus', 'remaining_ocpus': :'remainingOcpus', 'total_memory_in_gbs': :'totalMemoryInGBs', 'remaining_memory_in_gbs': :'remainingMemoryInGBs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 136 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'dedicated_vm_host_shape': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'fault_domain': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'total_ocpus': :'Float', 'remaining_ocpus': :'Float', 'total_memory_in_gbs': :'Float', 'remaining_memory_in_gbs': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 284 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && dedicated_vm_host_shape == other.dedicated_vm_host_shape && == other. && display_name == other.display_name && fault_domain == other.fault_domain && == other. && id == other.id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && total_ocpus == other.total_ocpus && remaining_ocpus == other.remaining_ocpus && total_memory_in_gbs == other.total_memory_in_gbs && remaining_memory_in_gbs == other.remaining_memory_in_gbs end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 327 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
307 308 309 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 307 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
316 317 318 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 316 def hash [availability_domain, compartment_id, dedicated_vm_host_shape, , display_name, fault_domain, , id, lifecycle_state, time_created, total_ocpus, remaining_ocpus, total_memory_in_gbs, remaining_memory_in_gbs].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
360 361 362 363 364 365 366 367 368 369 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 360 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
354 355 356 |
# File 'lib/oci/core/models/dedicated_vm_host.rb', line 354 def to_s to_hash.to_s end |