Class: OCI::Core::Models::IPSecConnectionTunnel
- Inherits:
-
Object
- Object
- OCI::Core::Models::IPSecConnectionTunnel
- Defined in:
- lib/oci/core/models/ip_sec_connection_tunnel.rb
Overview
Information about a single IPSec tunnel in an IPSec connection. This object does not include the tunnel's shared secret (pre-shared key), which is found in the IPSecConnectionTunnelSharedSecret object.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_UP = 'UP'.freeze, STATUS_DOWN = 'DOWN'.freeze, STATUS_DOWN_FOR_MAINTENANCE = 'DOWN_FOR_MAINTENANCE'.freeze, STATUS_PARTIAL_UP = 'PARTIAL_UP'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- IKE_VERSION_ENUM =
[ IKE_VERSION_V1 = 'V1'.freeze, IKE_VERSION_V2 = 'V2'.freeze, IKE_VERSION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ROUTING_ENUM =
[ ROUTING_BGP = 'BGP'.freeze, ROUTING_STATIC = 'STATIC'.freeze, ROUTING_POLICY = 'POLICY'.freeze, ROUTING_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ORACLE_CAN_INITIATE_ENUM =
[ ORACLE_CAN_INITIATE_INITIATOR_OR_RESPONDER = 'INITIATOR_OR_RESPONDER'.freeze, ORACLE_CAN_INITIATE_RESPONDER_ONLY = 'RESPONDER_ONLY'.freeze, ORACLE_CAN_INITIATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- NAT_TRANSLATION_ENABLED_ENUM =
[ NAT_TRANSLATION_ENABLED_ENABLED = 'ENABLED'.freeze, NAT_TRANSLATION_ENABLED_DISABLED = 'DISABLED'.freeze, NAT_TRANSLATION_ENABLED_AUTO = 'AUTO'.freeze, NAT_TRANSLATION_ENABLED_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DPD_MODE_ENUM =
[ DPD_MODE_INITIATE_AND_RESPOND = 'INITIATE_AND_RESPOND'.freeze, DPD_MODE_RESPOND_ONLY = 'RESPOND_ONLY'.freeze, DPD_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #bgp_session_info ⇒ OCI::Core::Models::BgpSessionInfo
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the tunnel.
-
#cpe_ip ⇒ String
The IP address of the CPE device's VPN headend.
-
#display_name ⇒ String
A user-friendly name.
-
#dpd_mode ⇒ String
Dead peer detection (DPD) mode set on the Oracle side of the connection.
-
#dpd_timeout_in_sec ⇒ Integer
DPD timeout in seconds.
- #encryption_domain_config ⇒ OCI::Core::Models::EncryptionDomainConfig
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the tunnel.
-
#ike_version ⇒ String
Internet Key Exchange protocol version.
-
#lifecycle_state ⇒ String
**[Required]** The tunnel's lifecycle state.
-
#nat_translation_enabled ⇒ String
By default (the `AUTO` setting), IKE sends packets with a source and destination port set to 500, and when it detects that the port used to forward packets has changed (most likely because a NAT device is between the CPE device and the Oracle VPN headend) it will try to negotiate the use of NAT-T.
-
#oracle_can_initiate ⇒ String
Indicates whether Oracle can only respond to a request to start an IPSec tunnel from the CPE device, or both respond to and initiate requests.
- #phase_one_details ⇒ OCI::Core::Models::TunnelPhaseOneDetails
- #phase_two_details ⇒ OCI::Core::Models::TunnelPhaseTwoDetails
-
#routing ⇒ String
The type of routing used for this tunnel (BGP dynamic routing, static routing, or policy-based routing).
-
#status ⇒ String
The status of the tunnel based on IPSec protocol characteristics.
-
#time_created ⇒ DateTime
The date and time the IPSec tunnel was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_status_updated ⇒ DateTime
When the status of the IPSec tunnel last changed, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vpn_ip ⇒ String
The IP address of the Oracle VPN headend for the connection.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IPSecConnectionTunnel
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IPSecConnectionTunnel
Initializes the object
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 245 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.id = attributes[:'id'] if attributes[:'id'] self.vpn_ip = attributes[:'vpnIp'] if attributes[:'vpnIp'] raise 'You cannot provide both :vpnIp and :vpn_ip' if attributes.key?(:'vpnIp') && attributes.key?(:'vpn_ip') self.vpn_ip = attributes[:'vpn_ip'] if attributes[:'vpn_ip'] self.cpe_ip = attributes[:'cpeIp'] if attributes[:'cpeIp'] raise 'You cannot provide both :cpeIp and :cpe_ip' if attributes.key?(:'cpeIp') && attributes.key?(:'cpe_ip') self.cpe_ip = attributes[:'cpe_ip'] if attributes[:'cpe_ip'] self.status = attributes[:'status'] if attributes[:'status'] self.ike_version = attributes[:'ikeVersion'] if attributes[:'ikeVersion'] raise 'You cannot provide both :ikeVersion and :ike_version' if attributes.key?(:'ikeVersion') && attributes.key?(:'ike_version') self.ike_version = attributes[:'ike_version'] if attributes[:'ike_version'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.bgp_session_info = attributes[:'bgpSessionInfo'] if attributes[:'bgpSessionInfo'] raise 'You cannot provide both :bgpSessionInfo and :bgp_session_info' if attributes.key?(:'bgpSessionInfo') && attributes.key?(:'bgp_session_info') self.bgp_session_info = attributes[:'bgp_session_info'] if attributes[:'bgp_session_info'] self.encryption_domain_config = attributes[:'encryptionDomainConfig'] if attributes[:'encryptionDomainConfig'] raise 'You cannot provide both :encryptionDomainConfig and :encryption_domain_config' if attributes.key?(:'encryptionDomainConfig') && attributes.key?(:'encryption_domain_config') self.encryption_domain_config = attributes[:'encryption_domain_config'] if attributes[:'encryption_domain_config'] self.routing = attributes[:'routing'] if attributes[:'routing'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_status_updated = attributes[:'timeStatusUpdated'] if attributes[:'timeStatusUpdated'] raise 'You cannot provide both :timeStatusUpdated and :time_status_updated' if attributes.key?(:'timeStatusUpdated') && attributes.key?(:'time_status_updated') self.time_status_updated = attributes[:'time_status_updated'] if attributes[:'time_status_updated'] self.oracle_can_initiate = attributes[:'oracleCanInitiate'] if attributes[:'oracleCanInitiate'] raise 'You cannot provide both :oracleCanInitiate and :oracle_can_initiate' if attributes.key?(:'oracleCanInitiate') && attributes.key?(:'oracle_can_initiate') self.oracle_can_initiate = attributes[:'oracle_can_initiate'] if attributes[:'oracle_can_initiate'] self.nat_translation_enabled = attributes[:'natTranslationEnabled'] if attributes[:'natTranslationEnabled'] raise 'You cannot provide both :natTranslationEnabled and :nat_translation_enabled' if attributes.key?(:'natTranslationEnabled') && attributes.key?(:'nat_translation_enabled') self.nat_translation_enabled = attributes[:'nat_translation_enabled'] if attributes[:'nat_translation_enabled'] self.dpd_mode = attributes[:'dpdMode'] if attributes[:'dpdMode'] raise 'You cannot provide both :dpdMode and :dpd_mode' if attributes.key?(:'dpdMode') && attributes.key?(:'dpd_mode') self.dpd_mode = attributes[:'dpd_mode'] if attributes[:'dpd_mode'] self.dpd_timeout_in_sec = attributes[:'dpdTimeoutInSec'] if attributes[:'dpdTimeoutInSec'] raise 'You cannot provide both :dpdTimeoutInSec and :dpd_timeout_in_sec' if attributes.key?(:'dpdTimeoutInSec') && attributes.key?(:'dpd_timeout_in_sec') self.dpd_timeout_in_sec = attributes[:'dpd_timeout_in_sec'] if attributes[:'dpd_timeout_in_sec'] self.phase_one_details = attributes[:'phaseOneDetails'] if attributes[:'phaseOneDetails'] raise 'You cannot provide both :phaseOneDetails and :phase_one_details' if attributes.key?(:'phaseOneDetails') && attributes.key?(:'phase_one_details') self.phase_one_details = attributes[:'phase_one_details'] if attributes[:'phase_one_details'] self.phase_two_details = attributes[:'phaseTwoDetails'] if attributes[:'phaseTwoDetails'] raise 'You cannot provide both :phaseTwoDetails and :phase_two_details' if attributes.key?(:'phaseTwoDetails') && attributes.key?(:'phase_two_details') self.phase_two_details = attributes[:'phase_two_details'] if attributes[:'phase_two_details'] end |
Instance Attribute Details
#bgp_session_info ⇒ OCI::Core::Models::BgpSessionInfo
105 106 107 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 105 def bgp_session_info @bgp_session_info end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the tunnel.
65 66 67 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 65 def compartment_id @compartment_id end |
#cpe_ip ⇒ String
The IP address of the CPE device's VPN headend.
Example: `203.0.113.22`
83 84 85 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 83 def cpe_ip @cpe_ip end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
102 103 104 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 102 def display_name @display_name end |
#dpd_mode ⇒ String
Dead peer detection (DPD) mode set on the Oracle side of the connection. This mode sets whether Oracle can only respond to a request from the CPE device to start DPD, or both respond to and initiate requests.
154 155 156 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 154 def dpd_mode @dpd_mode end |
#dpd_timeout_in_sec ⇒ Integer
DPD timeout in seconds.
158 159 160 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 158 def dpd_timeout_in_sec @dpd_timeout_in_sec end |
#encryption_domain_config ⇒ OCI::Core::Models::EncryptionDomainConfig
108 109 110 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 108 def encryption_domain_config @encryption_domain_config end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the tunnel.
69 70 71 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 69 def id @id end |
#ike_version ⇒ String
Internet Key Exchange protocol version.
92 93 94 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 92 def ike_version @ike_version end |
#lifecycle_state ⇒ String
**[Required]** The tunnel's lifecycle state.
96 97 98 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 96 def lifecycle_state @lifecycle_state end |
#nat_translation_enabled ⇒ String
By default (the `AUTO` setting), IKE sends packets with a source and destination port set to 500, and when it detects that the port used to forward packets has changed (most likely because a NAT device is between the CPE device and the Oracle VPN headend) it will try to negotiate the use of NAT-T.
The `ENABLED` option sets the IKE protocol to use port 4500 instead of 500 and forces encapsulating traffic with the ESP protocol inside UDP packets.
The `DISABLED` option directs IKE to completely refuse to negotiate NAT-T even if it senses there may be a NAT device in use.
.
147 148 149 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 147 def nat_translation_enabled @nat_translation_enabled end |
#oracle_can_initiate ⇒ String
Indicates whether Oracle can only respond to a request to start an IPSec tunnel from the CPE device, or both respond to and initiate requests.
132 133 134 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 132 def oracle_can_initiate @oracle_can_initiate end |
#phase_one_details ⇒ OCI::Core::Models::TunnelPhaseOneDetails
161 162 163 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 161 def phase_one_details @phase_one_details end |
#phase_two_details ⇒ OCI::Core::Models::TunnelPhaseTwoDetails
164 165 166 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 164 def phase_two_details @phase_two_details end |
#routing ⇒ String
The type of routing used for this tunnel (BGP dynamic routing, static routing, or policy-based routing).
113 114 115 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 113 def routing @routing end |
#status ⇒ String
The status of the tunnel based on IPSec protocol characteristics.
87 88 89 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 87 def status @status end |
#time_created ⇒ DateTime
The date and time the IPSec tunnel was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
120 121 122 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 120 def time_created @time_created end |
#time_status_updated ⇒ DateTime
When the status of the IPSec tunnel last changed, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
127 128 129 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 127 def time_status_updated @time_status_updated end |
#vpn_ip ⇒ String
The IP address of the Oracle VPN headend for the connection.
Example: `203.0.113.21`
76 77 78 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 76 def vpn_ip @vpn_ip end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 167 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'id': :'id', 'vpn_ip': :'vpnIp', 'cpe_ip': :'cpeIp', 'status': :'status', 'ike_version': :'ikeVersion', 'lifecycle_state': :'lifecycleState', 'display_name': :'displayName', 'bgp_session_info': :'bgpSessionInfo', 'encryption_domain_config': :'encryptionDomainConfig', 'routing': :'routing', 'time_created': :'timeCreated', 'time_status_updated': :'timeStatusUpdated', 'oracle_can_initiate': :'oracleCanInitiate', 'nat_translation_enabled': :'natTranslationEnabled', 'dpd_mode': :'dpdMode', 'dpd_timeout_in_sec': :'dpdTimeoutInSec', 'phase_one_details': :'phaseOneDetails', 'phase_two_details': :'phaseTwoDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 194 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'id': :'String', 'vpn_ip': :'String', 'cpe_ip': :'String', 'status': :'String', 'ike_version': :'String', 'lifecycle_state': :'String', 'display_name': :'String', 'bgp_session_info': :'OCI::Core::Models::BgpSessionInfo', 'encryption_domain_config': :'OCI::Core::Models::EncryptionDomainConfig', 'routing': :'String', 'time_created': :'DateTime', 'time_status_updated': :'DateTime', 'oracle_can_initiate': :'String', 'nat_translation_enabled': :'String', 'dpd_mode': :'String', 'dpd_timeout_in_sec': :'Integer', 'phase_one_details': :'OCI::Core::Models::TunnelPhaseOneDetails', 'phase_two_details': :'OCI::Core::Models::TunnelPhaseTwoDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 452 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && id == other.id && vpn_ip == other.vpn_ip && cpe_ip == other.cpe_ip && status == other.status && ike_version == other.ike_version && lifecycle_state == other.lifecycle_state && display_name == other.display_name && bgp_session_info == other.bgp_session_info && encryption_domain_config == other.encryption_domain_config && routing == other.routing && time_created == other.time_created && time_status_updated == other.time_status_updated && oracle_can_initiate == other.oracle_can_initiate && nat_translation_enabled == other.nat_translation_enabled && dpd_mode == other.dpd_mode && dpd_timeout_in_sec == other.dpd_timeout_in_sec && phase_one_details == other.phase_one_details && phase_two_details == other.phase_two_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 500 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
480 481 482 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 480 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
489 490 491 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 489 def hash [compartment_id, id, vpn_ip, cpe_ip, status, ike_version, lifecycle_state, display_name, bgp_session_info, encryption_domain_config, routing, time_created, time_status_updated, oracle_can_initiate, nat_translation_enabled, dpd_mode, dpd_timeout_in_sec, phase_one_details, phase_two_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
533 534 535 536 537 538 539 540 541 542 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 533 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
527 528 529 |
# File 'lib/oci/core/models/ip_sec_connection_tunnel.rb', line 527 def to_s to_hash.to_s end |