Class: OCI::Core::Models::IScsiVolumeAttachment
- Inherits:
-
VolumeAttachment
- Object
- VolumeAttachment
- OCI::Core::Models::IScsiVolumeAttachment
- Defined in:
- lib/oci/core/models/i_scsi_volume_attachment.rb
Overview
An ISCSI volume attachment.
Constant Summary
Constants inherited from VolumeAttachment
VolumeAttachment::LIFECYCLE_STATE_ENUM
Instance Attribute Summary collapse
-
#chap_secret ⇒ String
The Challenge-Handshake-Authentication-Protocol (CHAP) secret valid for the associated CHAP user name.
-
#chap_username ⇒ String
The volume’s system-generated Challenge-Handshake-Authentication-Protocol (CHAP) user name.
-
#ipv4 ⇒ String
[Required] The volume’s iSCSI IP address.
-
#iqn ⇒ String
[Required] The target volume’s iSCSI Qualified Name in the format defined by [RFC 3720](tools.ietf.org/html/rfc3720#page-32).
-
#port ⇒ Integer
[Required] The volume’s iSCSI port, usually port 860 or 3260.
Attributes inherited from VolumeAttachment
#attachment_type, #availability_domain, #compartment_id, #device, #display_name, #id, #instance_id, #is_pv_encryption_in_transit_enabled, #is_read_only, #is_shareable, #lifecycle_state, #time_created, #volume_id
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IScsiVolumeAttachment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from VolumeAttachment
Constructor Details
#initialize(attributes = {}) ⇒ IScsiVolumeAttachment
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 123 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['attachmentType'] = 'iscsi' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.chap_secret = attributes[:'chapSecret'] if attributes[:'chapSecret'] raise 'You cannot provide both :chapSecret and :chap_secret' if attributes.key?(:'chapSecret') && attributes.key?(:'chap_secret') self.chap_secret = attributes[:'chap_secret'] if attributes[:'chap_secret'] self.chap_username = attributes[:'chapUsername'] if attributes[:'chapUsername'] raise 'You cannot provide both :chapUsername and :chap_username' if attributes.key?(:'chapUsername') && attributes.key?(:'chap_username') self.chap_username = attributes[:'chap_username'] if attributes[:'chap_username'] self.ipv4 = attributes[:'ipv4'] if attributes[:'ipv4'] self.iqn = attributes[:'iqn'] if attributes[:'iqn'] self.port = attributes[:'port'] if attributes[:'port'] end |
Instance Attribute Details
#chap_secret ⇒ String
The Challenge-Handshake-Authentication-Protocol (CHAP) secret valid for the associated CHAP user name. (Also called the "CHAP password".)
16 17 18 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 16 def chap_secret @chap_secret end |
#chap_username ⇒ String
The volume’s system-generated Challenge-Handshake-Authentication-Protocol (CHAP) user name. See [RFC 1994](tools.ietf.org/html/rfc1994) for more on CHAP.
Example: ‘ocid1.volume.oc1.phx.<unique_ID>`
24 25 26 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 24 def chap_username @chap_username end |
#ipv4 ⇒ String
[Required] The volume’s iSCSI IP address.
Example: 169.254.0.2
31 32 33 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 31 def ipv4 @ipv4 end |
#iqn ⇒ String
[Required] The target volume’s iSCSI Qualified Name in the format defined by [RFC 3720](tools.ietf.org/html/rfc3720#page-32).
Example: ‘iqn.2015-12.us.oracle.com:<CHAP_username>`
39 40 41 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 39 def iqn @iqn end |
#port ⇒ Integer
[Required] The volume’s iSCSI port, usually port 860 or 3260.
Example: 3260
46 47 48 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 46 def port @port end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'attachment_type': :'attachmentType', 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'device': :'device', 'display_name': :'displayName', 'id': :'id', 'instance_id': :'instanceId', 'is_read_only': :'isReadOnly', 'is_shareable': :'isShareable', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'volume_id': :'volumeId', 'is_pv_encryption_in_transit_enabled': :'isPvEncryptionInTransitEnabled', 'chap_secret': :'chapSecret', 'chap_username': :'chapUsername', 'ipv4': :'ipv4', 'iqn': :'iqn', 'port': :'port' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'attachment_type': :'String', 'availability_domain': :'String', 'compartment_id': :'String', 'device': :'String', 'display_name': :'String', 'id': :'String', 'instance_id': :'String', 'is_read_only': :'BOOLEAN', 'is_shareable': :'BOOLEAN', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'volume_id': :'String', 'is_pv_encryption_in_transit_enabled': :'BOOLEAN', 'chap_secret': :'String', 'chap_username': :'String', 'ipv4': :'String', 'iqn': :'String', 'port': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 159 def ==(other) return true if equal?(other) self.class == other.class && == other. && availability_domain == other.availability_domain && compartment_id == other.compartment_id && device == other.device && display_name == other.display_name && id == other.id && instance_id == other.instance_id && is_read_only == other.is_read_only && is_shareable == other.is_shareable && lifecycle_state == other.lifecycle_state && time_created == other.time_created && volume_id == other.volume_id && is_pv_encryption_in_transit_enabled == other.is_pv_encryption_in_transit_enabled && chap_secret == other.chap_secret && chap_username == other.chap_username && ipv4 == other.ipv4 && iqn == other.iqn && port == other.port end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 206 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
186 187 188 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 186 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
195 196 197 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 195 def hash [, availability_domain, compartment_id, device, display_name, id, instance_id, is_read_only, is_shareable, lifecycle_state, time_created, volume_id, is_pv_encryption_in_transit_enabled, chap_secret, chap_username, ipv4, iqn, port].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
239 240 241 242 243 244 245 246 247 248 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 239 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
233 234 235 |
# File 'lib/oci/core/models/i_scsi_volume_attachment.rb', line 233 def to_s to_hash.to_s end |