Class: OCI::Core::Models::Image
- Inherits:
-
Object
- Object
- OCI::Core::Models::Image
- Defined in:
- lib/oci/core/models/image.rb
Overview
A boot disk image for launching an instance. For more information, see [Overview of the Compute Service](docs.cloud.oracle.com/iaas/Content/Compute/Concepts/computeoverview.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LAUNCH_MODE_ENUM =
[ LAUNCH_MODE_NATIVE = 'NATIVE'.freeze, LAUNCH_MODE_EMULATED = 'EMULATED'.freeze, LAUNCH_MODE_PARAVIRTUALIZED = 'PARAVIRTUALIZED'.freeze, LAUNCH_MODE_CUSTOM = 'CUSTOM'.freeze, LAUNCH_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_IMPORTING = 'IMPORTING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_EXPORTING = 'EXPORTING'.freeze, LIFECYCLE_STATE_DISABLED = 'DISABLED'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LISTING_TYPE_ENUM =
[ LISTING_TYPE_COMMUNITY = 'COMMUNITY'.freeze, LISTING_TYPE_NONE = 'NONE'.freeze, LISTING_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #agent_features ⇒ OCI::Core::Models::InstanceAgentFeatures
-
#base_image_id ⇒ String
The OCID of the image originally used to launch the instance.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the instance you want to use as the basis for the image.
-
#create_image_allowed ⇒ BOOLEAN
[Required] Whether instances launched with this image can be used to create new images.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name for the image.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the image.
-
#launch_mode ⇒ String
Specifies the configuration mode for launching virtual machine (VM) instances.
- #launch_options ⇒ OCI::Core::Models::LaunchOptions
-
#lifecycle_state ⇒ String
This attribute is required.
-
#listing_type ⇒ String
The listing type of the image.
-
#operating_system ⇒ String
[Required] The image’s operating system.
-
#operating_system_version ⇒ String
[Required] The image’s operating system version.
-
#size_in_mbs ⇒ Integer
The boot volume size for an instance launched from this image (1 MB = 1,048,576 bytes).
-
#time_created ⇒ DateTime
[Required] The date and time the image was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Image
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Image
Initializes the object
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/oci/core/models/image.rb', line 213 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.base_image_id = attributes[:'baseImageId'] if attributes[:'baseImageId'] raise 'You cannot provide both :baseImageId and :base_image_id' if attributes.key?(:'baseImageId') && attributes.key?(:'base_image_id') self.base_image_id = attributes[:'base_image_id'] if attributes[:'base_image_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.create_image_allowed = attributes[:'createImageAllowed'] unless attributes[:'createImageAllowed'].nil? raise 'You cannot provide both :createImageAllowed and :create_image_allowed' if attributes.key?(:'createImageAllowed') && attributes.key?(:'create_image_allowed') self.create_image_allowed = attributes[:'create_image_allowed'] unless attributes[:'create_image_allowed'].nil? self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.launch_mode = attributes[:'launchMode'] if attributes[:'launchMode'] raise 'You cannot provide both :launchMode and :launch_mode' if attributes.key?(:'launchMode') && attributes.key?(:'launch_mode') self.launch_mode = attributes[:'launch_mode'] if attributes[:'launch_mode'] self. = attributes[:'launchOptions'] if attributes[:'launchOptions'] raise 'You cannot provide both :launchOptions and :launch_options' if attributes.key?(:'launchOptions') && attributes.key?(:'launch_options') self. = attributes[:'launch_options'] if attributes[:'launch_options'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'operatingSystem'] if attributes[:'operatingSystem'] raise 'You cannot provide both :operatingSystem and :operating_system' if attributes.key?(:'operatingSystem') && attributes.key?(:'operating_system') self. = attributes[:'operating_system'] if attributes[:'operating_system'] self. = attributes[:'operatingSystemVersion'] if attributes[:'operatingSystemVersion'] raise 'You cannot provide both :operatingSystemVersion and :operating_system_version' if attributes.key?(:'operatingSystemVersion') && attributes.key?(:'operating_system_version') self. = attributes[:'operating_system_version'] if attributes[:'operating_system_version'] self.agent_features = attributes[:'agentFeatures'] if attributes[:'agentFeatures'] raise 'You cannot provide both :agentFeatures and :agent_features' if attributes.key?(:'agentFeatures') && attributes.key?(:'agent_features') self.agent_features = attributes[:'agent_features'] if attributes[:'agent_features'] self.listing_type = attributes[:'listingType'] if attributes[:'listingType'] raise 'You cannot provide both :listingType and :listing_type' if attributes.key?(:'listingType') && attributes.key?(:'listing_type') self.listing_type = attributes[:'listing_type'] if attributes[:'listing_type'] self.size_in_mbs = attributes[:'sizeInMBs'] if attributes[:'sizeInMBs'] raise 'You cannot provide both :sizeInMBs and :size_in_mbs' if attributes.key?(:'sizeInMBs') && attributes.key?(:'size_in_mbs') self.size_in_mbs = attributes[:'size_in_mbs'] if attributes[:'size_in_mbs'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#agent_features ⇒ OCI::Core::Models::InstanceAgentFeatures
122 123 124 |
# File 'lib/oci/core/models/image.rb', line 122 def agent_features @agent_features end |
#base_image_id ⇒ String
The OCID of the image originally used to launch the instance.
46 47 48 |
# File 'lib/oci/core/models/image.rb', line 46 def base_image_id @base_image_id end |
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the instance you want to use as the basis for the image.
51 52 53 |
# File 'lib/oci/core/models/image.rb', line 51 def compartment_id @compartment_id end |
#create_image_allowed ⇒ BOOLEAN
[Required] Whether instances launched with this image can be used to create new images. For example, you cannot create an image of an Oracle Database instance.
Example: true
59 60 61 |
# File 'lib/oci/core/models/image.rb', line 59 def create_image_allowed @create_image_allowed end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
67 68 69 |
# File 'lib/oci/core/models/image.rb', line 67 def end |
#display_name ⇒ String
A user-friendly name for the image. It does not have to be unique, and it’s changeable. Avoid entering confidential information.
You cannot use a platform image name as a custom image name.
Example: ‘My custom Oracle Linux image`
77 78 79 |
# File 'lib/oci/core/models/image.rb', line 77 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
85 86 87 |
# File 'lib/oci/core/models/image.rb', line 85 def end |
#id ⇒ String
[Required] The OCID of the image.
89 90 91 |
# File 'lib/oci/core/models/image.rb', line 89 def id @id end |
#launch_mode ⇒ String
Specifies the configuration mode for launching virtual machine (VM) instances. The configuration modes are:
-
NATIVE- VM instances launch with iSCSI boot and VFIO devices. The default value for platform images. -
EMULATED- VM instances launch with emulated devices, such as the E1000 network driver and emulated SCSI disk controller. -
PARAVIRTUALIZED- VM instances launch with paravirtualized devices using VirtIO drivers. -
CUSTOM- VM instances launch with custom configuration settings specified in theLaunchOptionsparameter.
98 99 100 |
# File 'lib/oci/core/models/image.rb', line 98 def launch_mode @launch_mode end |
#launch_options ⇒ OCI::Core::Models::LaunchOptions
101 102 103 |
# File 'lib/oci/core/models/image.rb', line 101 def end |
#lifecycle_state ⇒ String
This attribute is required.
105 106 107 |
# File 'lib/oci/core/models/image.rb', line 105 def lifecycle_state @lifecycle_state end |
#listing_type ⇒ String
The listing type of the image. The default value is "NONE".
126 127 128 |
# File 'lib/oci/core/models/image.rb', line 126 def listing_type @listing_type end |
#operating_system ⇒ String
[Required] The image’s operating system.
Example: ‘Oracle Linux`
112 113 114 |
# File 'lib/oci/core/models/image.rb', line 112 def end |
#operating_system_version ⇒ String
[Required] The image’s operating system version.
Example: 7.2
119 120 121 |
# File 'lib/oci/core/models/image.rb', line 119 def end |
#size_in_mbs ⇒ Integer
The boot volume size for an instance launched from this image (1 MB = 1,048,576 bytes). Note this is not the same as the size of the image when it was exported or the actual size of the image.
Example: 47694
134 135 136 |
# File 'lib/oci/core/models/image.rb', line 134 def size_in_mbs @size_in_mbs end |
#time_created ⇒ DateTime
[Required] The date and time the image was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: 2016-08-25T21:10:29.600Z
141 142 143 |
# File 'lib/oci/core/models/image.rb', line 141 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/core/models/image.rb', line 144 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'base_image_id': :'baseImageId', 'compartment_id': :'compartmentId', 'create_image_allowed': :'createImageAllowed', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'launch_mode': :'launchMode', 'launch_options': :'launchOptions', 'lifecycle_state': :'lifecycleState', 'operating_system': :'operatingSystem', 'operating_system_version': :'operatingSystemVersion', 'agent_features': :'agentFeatures', 'listing_type': :'listingType', 'size_in_mbs': :'sizeInMBs', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/core/models/image.rb', line 168 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'base_image_id': :'String', 'compartment_id': :'String', 'create_image_allowed': :'BOOLEAN', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'launch_mode': :'String', 'launch_options': :'OCI::Core::Models::LaunchOptions', 'lifecycle_state': :'String', 'operating_system': :'String', 'operating_system_version': :'String', 'agent_features': :'OCI::Core::Models::InstanceAgentFeatures', 'listing_type': :'String', 'size_in_mbs': :'Integer', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/oci/core/models/image.rb', line 358 def ==(other) return true if equal?(other) self.class == other.class && base_image_id == other.base_image_id && compartment_id == other.compartment_id && create_image_allowed == other.create_image_allowed && == other. && display_name == other.display_name && == other. && id == other.id && launch_mode == other.launch_mode && == other. && lifecycle_state == other.lifecycle_state && == other. && == other. && agent_features == other.agent_features && listing_type == other.listing_type && size_in_mbs == other.size_in_mbs && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/oci/core/models/image.rb', line 403 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
383 384 385 |
# File 'lib/oci/core/models/image.rb', line 383 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
392 393 394 |
# File 'lib/oci/core/models/image.rb', line 392 def hash [base_image_id, compartment_id, create_image_allowed, , display_name, , id, launch_mode, , lifecycle_state, , , agent_features, listing_type, size_in_mbs, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
436 437 438 439 440 441 442 443 444 445 |
# File 'lib/oci/core/models/image.rb', line 436 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
430 431 432 |
# File 'lib/oci/core/models/image.rb', line 430 def to_s to_hash.to_s end |