Class: OCI::Core::Models::InstanceConfigurationCreateVnicDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/instance_configuration_create_vnic_details.rb

Overview

Contains the properties of the VNIC for an instance configuration. See CreateVnicDetails and [Instance Configurations](docs.cloud.oracle.com/Content/Compute/Concepts/instancemanagement.htm#config) for more information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InstanceConfigurationCreateVnicDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :assign_public_ip (BOOLEAN)

    The value to assign to the #assign_public_ip property

  • :display_name (String)

    The value to assign to the #display_name property

  • :hostname_label (String)

    The value to assign to the #hostname_label property

  • :private_ip (String)

    The value to assign to the #private_ip property

  • :skip_source_dest_check (BOOLEAN)

    The value to assign to the #skip_source_dest_check property

  • :subnet_id (String)

    The value to assign to the #subnet_id property



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 87

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.assign_public_ip = attributes[:'assignPublicIp'] unless attributes[:'assignPublicIp'].nil?

  raise 'You cannot provide both :assignPublicIp and :assign_public_ip' if attributes.key?(:'assignPublicIp') && attributes.key?(:'assign_public_ip')

  self.assign_public_ip = attributes[:'assign_public_ip'] unless attributes[:'assign_public_ip'].nil?

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel']

  raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label')

  self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label']

  self.private_ip = attributes[:'privateIp'] if attributes[:'privateIp']

  raise 'You cannot provide both :privateIp and :private_ip' if attributes.key?(:'privateIp') && attributes.key?(:'private_ip')

  self.private_ip = attributes[:'private_ip'] if attributes[:'private_ip']

  self.skip_source_dest_check = attributes[:'skipSourceDestCheck'] unless attributes[:'skipSourceDestCheck'].nil?

  raise 'You cannot provide both :skipSourceDestCheck and :skip_source_dest_check' if attributes.key?(:'skipSourceDestCheck') && attributes.key?(:'skip_source_dest_check')

  self.skip_source_dest_check = attributes[:'skip_source_dest_check'] unless attributes[:'skip_source_dest_check'].nil?

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']
end

Instance Attribute Details

#assign_public_ipBOOLEAN

Whether the VNIC should be assigned a public IP address. See the assignPublicIp attribute of CreateVnicDetails for more information.

Returns:

  • (BOOLEAN)


15
16
17
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 15

def assign_public_ip
  @assign_public_ip
end

#display_nameString

A user-friendly name for the VNIC. Does not have to be unique. Avoid entering confidential information.

Returns:

  • (String)


21
22
23
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 21

def display_name
  @display_name
end

#hostname_labelString

The hostname for the VNIC’s primary private IP. See the hostnameLabel attribute of CreateVnicDetails for more information.

Returns:

  • (String)


27
28
29
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 27

def hostname_label
  @hostname_label
end

#private_ipString

A private IP address of your choice to assign to the VNIC. See the privateIp attribute of CreateVnicDetails for more information.

Returns:

  • (String)


33
34
35
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 33

def private_ip
  @private_ip
end

#skip_source_dest_checkBOOLEAN

Whether the source/destination check is disabled on the VNIC. See the skipSourceDestCheck attribute of CreateVnicDetails for more information.

Returns:

  • (BOOLEAN)


39
40
41
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 39

def skip_source_dest_check
  @skip_source_dest_check
end

#subnet_idString

The OCID of the subnet to create the VNIC in. See the subnetId attribute of CreateVnicDetails for more information.

Returns:

  • (String)


45
46
47
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 45

def subnet_id
  @subnet_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 48

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'assign_public_ip': :'assignPublicIp',
    'display_name': :'displayName',
    'hostname_label': :'hostnameLabel',
    'private_ip': :'privateIp',
    'skip_source_dest_check': :'skipSourceDestCheck',
    'subnet_id': :'subnetId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 62

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'assign_public_ip': :'BOOLEAN',
    'display_name': :'String',
    'hostname_label': :'String',
    'private_ip': :'String',
    'skip_source_dest_check': :'BOOLEAN',
    'subnet_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



137
138
139
140
141
142
143
144
145
146
147
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 137

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    assign_public_ip == other.assign_public_ip &&
    display_name == other.display_name &&
    hostname_label == other.hostname_label &&
    private_ip == other.private_ip &&
    skip_source_dest_check == other.skip_source_dest_check &&
    subnet_id == other.subnet_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 172

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 152

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



161
162
163
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 161

def hash
  [assign_public_ip, display_name, hostname_label, private_ip, skip_source_dest_check, subnet_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



199
200
201
# File 'lib/oci/core/models/instance_configuration_create_vnic_details.rb', line 199

def to_s
  to_hash.to_s
end