Class: OCI::Core::Models::InstancePoolInstance
- Inherits:
-
Object
- Object
- OCI::Core::Models::InstancePoolInstance
- Defined in:
- lib/oci/core/models/instance_pool_instance.rb
Overview
Information about an instance that belongs to an instance pool.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ATTACHING = 'ATTACHING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DETACHING = 'DETACHING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The availability domain the instance is running in.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the instance.
-
#display_name ⇒ String
The user-friendly name.
-
#fault_domain ⇒ String
The fault domain the instance is running in.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance.
-
#instance_configuration_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance configuration used to create the instance.
-
#instance_pool_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance pool.
-
#lifecycle_state ⇒ String
[Required] The attachment state of the instance in relation to the instance pool.
-
#load_balancer_backends ⇒ Array<OCI::Core::Models::InstancePoolInstanceLoadBalancerBackend>
The load balancer backends that are configured for the instance.
-
#region ⇒ String
[Required] The region that contains the availability domain the instance is running in.
-
#shape ⇒ String
[Required] The shape of the instance.
-
#state ⇒ String
[Required] The lifecycle state of the instance.
-
#time_created ⇒ DateTime
[Required] The date and time the instance pool instance was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InstancePoolInstance
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ InstancePoolInstance
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 140 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.instance_pool_id = attributes[:'instancePoolId'] if attributes[:'instancePoolId'] raise 'You cannot provide both :instancePoolId and :instance_pool_id' if attributes.key?(:'instancePoolId') && attributes.key?(:'instance_pool_id') self.instance_pool_id = attributes[:'instance_pool_id'] if attributes[:'instance_pool_id'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain'] raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain') self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain'] self.instance_configuration_id = attributes[:'instanceConfigurationId'] if attributes[:'instanceConfigurationId'] raise 'You cannot provide both :instanceConfigurationId and :instance_configuration_id' if attributes.key?(:'instanceConfigurationId') && attributes.key?(:'instance_configuration_id') self.instance_configuration_id = attributes[:'instance_configuration_id'] if attributes[:'instance_configuration_id'] self.region = attributes[:'region'] if attributes[:'region'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.state = attributes[:'state'] if attributes[:'state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.load_balancer_backends = attributes[:'loadBalancerBackends'] if attributes[:'loadBalancerBackends'] raise 'You cannot provide both :loadBalancerBackends and :load_balancer_backends' if attributes.key?(:'loadBalancerBackends') && attributes.key?(:'load_balancer_backends') self.load_balancer_backends = attributes[:'load_balancer_backends'] if attributes[:'load_balancer_backends'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The availability domain the instance is running in.
28 29 30 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 28 def availability_domain @availability_domain end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the instance.
38 39 40 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 38 def compartment_id @compartment_id end |
#display_name ⇒ String
The user-friendly name. Does not have to be unique.
42 43 44 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 42 def display_name @display_name end |
#fault_domain ⇒ String
The fault domain the instance is running in.
46 47 48 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 46 def fault_domain @fault_domain end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance.
20 21 22 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 20 def id @id end |
#instance_configuration_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance configuration used to create the instance.
52 53 54 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 52 def instance_configuration_id @instance_configuration_id end |
#instance_pool_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance pool.
24 25 26 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 24 def instance_pool_id @instance_pool_id end |
#lifecycle_state ⇒ String
[Required] The attachment state of the instance in relation to the instance pool.
32 33 34 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 32 def lifecycle_state @lifecycle_state end |
#load_balancer_backends ⇒ Array<OCI::Core::Models::InstancePoolInstanceLoadBalancerBackend>
The load balancer backends that are configured for the instance.
77 78 79 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 77 def load_balancer_backends @load_balancer_backends end |
#region ⇒ String
[Required] The region that contains the availability domain the instance is running in.
56 57 58 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 56 def region @region end |
#shape ⇒ String
[Required] The shape of the instance. The shape determines the number of CPUs, amount of memory, and other resources allocated to the instance.
62 63 64 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 62 def shape @shape end |
#state ⇒ String
[Required] The lifecycle state of the instance. Refer to lifecycleState in the OCI::Core::Models::Instance resource.
66 67 68 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 66 def state @state end |
#time_created ⇒ DateTime
[Required] The date and time the instance pool instance was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2016-08-25T21:10:29.600Z
72 73 74 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 72 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 80 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'instance_pool_id': :'instancePoolId', 'availability_domain': :'availabilityDomain', 'lifecycle_state': :'lifecycleState', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'fault_domain': :'faultDomain', 'instance_configuration_id': :'instanceConfigurationId', 'region': :'region', 'shape': :'shape', 'state': :'state', 'time_created': :'timeCreated', 'load_balancer_backends': :'loadBalancerBackends' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 101 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'instance_pool_id': :'String', 'availability_domain': :'String', 'lifecycle_state': :'String', 'compartment_id': :'String', 'display_name': :'String', 'fault_domain': :'String', 'instance_configuration_id': :'String', 'region': :'String', 'shape': :'String', 'state': :'String', 'time_created': :'DateTime', 'load_balancer_backends': :'Array<OCI::Core::Models::InstancePoolInstanceLoadBalancerBackend>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 229 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && instance_pool_id == other.instance_pool_id && availability_domain == other.availability_domain && lifecycle_state == other.lifecycle_state && compartment_id == other.compartment_id && display_name == other.display_name && fault_domain == other.fault_domain && instance_configuration_id == other.instance_configuration_id && region == other.region && shape == other.shape && state == other.state && time_created == other.time_created && load_balancer_backends == other.load_balancer_backends end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 271 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
251 252 253 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 251 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
260 261 262 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 260 def hash [id, instance_pool_id, availability_domain, lifecycle_state, compartment_id, display_name, fault_domain, instance_configuration_id, region, shape, state, time_created, load_balancer_backends].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
298 299 300 |
# File 'lib/oci/core/models/instance_pool_instance.rb', line 298 def to_s to_hash.to_s end |