Class: OCI::Core::Models::InstanceSummary
- Inherits:
-
Object
- Object
- OCI::Core::Models::InstanceSummary
- Defined in:
- lib/oci/core/models/instance_summary.rb
Overview
Condensed instance data when listing instances in an instance pool.
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The availability domain the instance is running in.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the instance.
-
#display_name ⇒ String
A user-friendly name.
-
#fault_domain ⇒ String
The fault domain the instance is running in.
-
#id ⇒ String
[Required] The OCID of the instance.
-
#instance_configuration_id ⇒ String
[Required] The OCID of the instance confgiuration used to create the instance.
-
#load_balancer_backends ⇒ Array<OCI::Core::Models::InstancePoolInstanceLoadBalancerBackend>
The load balancer backends that are configured for the instance pool instance.
-
#region ⇒ String
[Required] The region that contains the availability domain the instance is running in.
-
#shape ⇒ String
The shape of an instance.
-
#state ⇒ String
[Required] The current state of the instance pool instance.
-
#time_created ⇒ DateTime
[Required] The date and time the instance pool instance was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InstanceSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ InstanceSummary
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/core/models/instance_summary.rb', line 118 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain'] raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain') self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain'] self.instance_configuration_id = attributes[:'instanceConfigurationId'] if attributes[:'instanceConfigurationId'] raise 'You cannot provide both :instanceConfigurationId and :instance_configuration_id' if attributes.key?(:'instanceConfigurationId') && attributes.key?(:'instance_configuration_id') self.instance_configuration_id = attributes[:'instance_configuration_id'] if attributes[:'instance_configuration_id'] self.region = attributes[:'region'] if attributes[:'region'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.state = attributes[:'state'] if attributes[:'state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.load_balancer_backends = attributes[:'loadBalancerBackends'] if attributes[:'loadBalancerBackends'] raise 'You cannot provide both :loadBalancerBackends and :load_balancer_backends' if attributes.key?(:'loadBalancerBackends') && attributes.key?(:'load_balancer_backends') self.load_balancer_backends = attributes[:'load_balancer_backends'] if attributes[:'load_balancer_backends'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The availability domain the instance is running in.
16 17 18 |
# File 'lib/oci/core/models/instance_summary.rb', line 16 def availability_domain @availability_domain end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the instance.
20 21 22 |
# File 'lib/oci/core/models/instance_summary.rb', line 20 def compartment_id @compartment_id end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
26 27 28 |
# File 'lib/oci/core/models/instance_summary.rb', line 26 def display_name @display_name end |
#fault_domain ⇒ String
The fault domain the instance is running in.
30 31 32 |
# File 'lib/oci/core/models/instance_summary.rb', line 30 def fault_domain @fault_domain end |
#id ⇒ String
[Required] The OCID of the instance.
12 13 14 |
# File 'lib/oci/core/models/instance_summary.rb', line 12 def id @id end |
#instance_configuration_id ⇒ String
[Required] The OCID of the instance confgiuration used to create the instance.
34 35 36 |
# File 'lib/oci/core/models/instance_summary.rb', line 34 def instance_configuration_id @instance_configuration_id end |
#load_balancer_backends ⇒ Array<OCI::Core::Models::InstancePoolInstanceLoadBalancerBackend>
The load balancer backends that are configured for the instance pool instance.
61 62 63 |
# File 'lib/oci/core/models/instance_summary.rb', line 61 def load_balancer_backends @load_balancer_backends end |
#region ⇒ String
[Required] The region that contains the availability domain the instance is running in.
38 39 40 |
# File 'lib/oci/core/models/instance_summary.rb', line 38 def region @region end |
#shape ⇒ String
The shape of an instance. The shape determines the number of CPUs, amount of memory, and other resources allocated to the instance.
You can enumerate all available shapes by calling list_shapes.
46 47 48 |
# File 'lib/oci/core/models/instance_summary.rb', line 46 def shape @shape end |
#state ⇒ String
[Required] The current state of the instance pool instance.
50 51 52 |
# File 'lib/oci/core/models/instance_summary.rb', line 50 def state @state end |
#time_created ⇒ DateTime
[Required] The date and time the instance pool instance was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2016-08-25T21:10:29.600Z
56 57 58 |
# File 'lib/oci/core/models/instance_summary.rb', line 56 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/core/models/instance_summary.rb', line 64 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'fault_domain': :'faultDomain', 'instance_configuration_id': :'instanceConfigurationId', 'region': :'region', 'shape': :'shape', 'state': :'state', 'time_created': :'timeCreated', 'load_balancer_backends': :'loadBalancerBackends' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/core/models/instance_summary.rb', line 83 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'availability_domain': :'String', 'compartment_id': :'String', 'display_name': :'String', 'fault_domain': :'String', 'instance_configuration_id': :'String', 'region': :'String', 'shape': :'String', 'state': :'String', 'time_created': :'DateTime', 'load_balancer_backends': :'Array<OCI::Core::Models::InstancePoolInstanceLoadBalancerBackend>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/core/models/instance_summary.rb', line 182 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && availability_domain == other.availability_domain && compartment_id == other.compartment_id && display_name == other.display_name && fault_domain == other.fault_domain && instance_configuration_id == other.instance_configuration_id && region == other.region && shape == other.shape && state == other.state && time_created == other.time_created && load_balancer_backends == other.load_balancer_backends end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/core/models/instance_summary.rb', line 222 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
202 203 204 |
# File 'lib/oci/core/models/instance_summary.rb', line 202 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/oci/core/models/instance_summary.rb', line 211 def hash [id, availability_domain, compartment_id, display_name, fault_domain, instance_configuration_id, region, shape, state, time_created, load_balancer_backends].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/core/models/instance_summary.rb', line 255 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
249 250 251 |
# File 'lib/oci/core/models/instance_summary.rb', line 249 def to_s to_hash.to_s end |