Class: OCI::Core::Models::InstanceSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/instance_summary.rb

Overview

Condensed instance data when listing instances in an instance pool.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InstanceSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :availability_domain (String)

    The value to assign to the #availability_domain property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :fault_domain (String)

    The value to assign to the #fault_domain property

  • :instance_configuration_id (String)

    The value to assign to the #instance_configuration_id property

  • :region (String)

    The value to assign to the #region property

  • :shape (String)

    The value to assign to the #shape property

  • :state (String)

    The value to assign to the #state property

  • :time_created (DateTime)

    The value to assign to the #time_created property



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/core/models/instance_summary.rb', line 107

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain']

  raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain')

  self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain']

  self.instance_configuration_id = attributes[:'instanceConfigurationId'] if attributes[:'instanceConfigurationId']

  raise 'You cannot provide both :instanceConfigurationId and :instance_configuration_id' if attributes.key?(:'instanceConfigurationId') && attributes.key?(:'instance_configuration_id')

  self.instance_configuration_id = attributes[:'instance_configuration_id'] if attributes[:'instance_configuration_id']

  self.region = attributes[:'region'] if attributes[:'region']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.state = attributes[:'state'] if attributes[:'state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']
end

Instance Attribute Details

#availability_domainString

[Required] The availability domain the instance is running in.

Returns:

  • (String)


15
16
17
# File 'lib/oci/core/models/instance_summary.rb', line 15

def availability_domain
  @availability_domain
end

#compartment_idString

[Required] The OCID of the compartment that contains the instance.

Returns:

  • (String)


19
20
21
# File 'lib/oci/core/models/instance_summary.rb', line 19

def compartment_id
  @compartment_id
end

#display_nameString

The user-friendly name. Does not have to be unique.

Returns:

  • (String)


23
24
25
# File 'lib/oci/core/models/instance_summary.rb', line 23

def display_name
  @display_name
end

#fault_domainString

The name of the Fault Domain the instance is running in.

Returns:

  • (String)


27
28
29
# File 'lib/oci/core/models/instance_summary.rb', line 27

def fault_domain
  @fault_domain
end

#idString

[Required] The OCID of the instance

Returns:

  • (String)


11
12
13
# File 'lib/oci/core/models/instance_summary.rb', line 11

def id
  @id
end

#instance_configuration_idString

[Required] The OCID of the instance confgiuration used to create the instance.

Returns:

  • (String)


31
32
33
# File 'lib/oci/core/models/instance_summary.rb', line 31

def instance_configuration_id
  @instance_configuration_id
end

#regionString

[Required] The region that contains the availability domain the instance is running in.

Returns:

  • (String)


35
36
37
# File 'lib/oci/core/models/instance_summary.rb', line 35

def region
  @region
end

#shapeString

The shape of an instance. The shape determines the number of CPUs, amount of memory, and other resources allocated to the instance.

You can enumerate all available shapes by calling list_shapes.

Returns:

  • (String)


43
44
45
# File 'lib/oci/core/models/instance_summary.rb', line 43

def shape
  @shape
end

#stateString

[Required] The current state of the instance pool instance.

Returns:

  • (String)


47
48
49
# File 'lib/oci/core/models/instance_summary.rb', line 47

def state
  @state
end

#time_createdDateTime

[Required] The date and time the instance pool instance was created, in the format defined by RFC3339. Example: 2016-08-25T21:10:29.600Z

Returns:

  • (DateTime)


53
54
55
# File 'lib/oci/core/models/instance_summary.rb', line 53

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/oci/core/models/instance_summary.rb', line 56

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'availability_domain': :'availabilityDomain',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'fault_domain': :'faultDomain',
    'instance_configuration_id': :'instanceConfigurationId',
    'region': :'region',
    'shape': :'shape',
    'state': :'state',
    'time_created': :'timeCreated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/core/models/instance_summary.rb', line 74

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'availability_domain': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'fault_domain': :'String',
    'instance_configuration_id': :'String',
    'region': :'String',
    'shape': :'String',
    'state': :'String',
    'time_created': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/oci/core/models/instance_summary.rb', line 165

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    availability_domain == other.availability_domain &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    fault_domain == other.fault_domain &&
    instance_configuration_id == other.instance_configuration_id &&
    region == other.region &&
    shape == other.shape &&
    state == other.state &&
    time_created == other.time_created
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/oci/core/models/instance_summary.rb', line 204

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/oci/core/models/instance_summary.rb', line 184

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



193
194
195
# File 'lib/oci/core/models/instance_summary.rb', line 193

def hash
  [id, availability_domain, compartment_id, display_name, fault_domain, instance_configuration_id, region, shape, state, time_created].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
# File 'lib/oci/core/models/instance_summary.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



231
232
233
# File 'lib/oci/core/models/instance_summary.rb', line 231

def to_s
  to_hash.to_s
end