Class: OCI::Core::Models::LaunchInstancePlatformConfig
- Inherits:
-
Object
- Object
- OCI::Core::Models::LaunchInstancePlatformConfig
- Defined in:
- lib/oci/core/models/launch_instance_platform_config.rb
Overview
The platform configuration requested for the instance.
If you provide the parameter, the instance is created with the platform configuration that you specify. For any values that you omit, the instance uses the default configuration values for the shape that you specify. If you don’t provide the parameter, the default values for the shape are used.
Each shape only supports certain configurable values. If the values that you provide are not valid for the specified shape, an error is returned.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_AMD_MILAN_BM = 'AMD_MILAN_BM'.freeze ].freeze
Instance Attribute Summary collapse
-
#type ⇒ String
[Required] The type of platform being configured.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LaunchInstancePlatformConfig
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LaunchInstancePlatformConfig
Initializes the object
69 70 71 72 73 74 75 76 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] end |
Instance Attribute Details
#type ⇒ String
[Required] The type of platform being configured. The only supported type is AMD_MILAN_BM
27 28 29 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 27 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
52 53 54 55 56 57 58 59 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 52 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::Core::Models::AmdMilanBmLaunchInstancePlatformConfig' if type == 'AMD_MILAN_BM' # TODO: Log a warning when the subtype is not found. 'OCI::Core::Models::LaunchInstancePlatformConfig' end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
93 94 95 96 97 98 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 93 def ==(other) return true if equal?(other) self.class == other.class && type == other.type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 123 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
103 104 105 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 103 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
112 113 114 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 112 def hash [type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 156 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
150 151 152 |
# File 'lib/oci/core/models/launch_instance_platform_config.rb', line 150 def to_s to_hash.to_s end |