Class: OCI::Core::Models::PlatformConfig
- Inherits:
-
Object
- Object
- OCI::Core::Models::PlatformConfig
- Defined in:
- lib/oci/core/models/platform_config.rb
Overview
The platform configuration for the instance.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
AmdMilanBmPlatformConfig, AmdRomeBmPlatformConfig, AmdVmPlatformConfig, IntelSkylakeBmPlatformConfig, IntelVmPlatformConfig
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_AMD_MILAN_BM = 'AMD_MILAN_BM'.freeze, TYPE_AMD_ROME_BM = 'AMD_ROME_BM'.freeze, TYPE_INTEL_SKYLAKE_BM = 'INTEL_SKYLAKE_BM'.freeze, TYPE_AMD_VM = 'AMD_VM'.freeze, TYPE_INTEL_VM = 'INTEL_VM'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#is_measured_boot_enabled ⇒ BOOLEAN
Whether the Measured Boot feature is enabled on the instance.
-
#is_secure_boot_enabled ⇒ BOOLEAN
Whether Secure Boot is enabled on the instance.
-
#is_trusted_platform_module_enabled ⇒ BOOLEAN
Whether the Trusted Platform Module (TPM) is enabled on the instance.
-
#type ⇒ String
[Required] The type of platform being configured.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PlatformConfig
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PlatformConfig
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/core/models/platform_config.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.is_secure_boot_enabled = attributes[:'isSecureBootEnabled'] unless attributes[:'isSecureBootEnabled'].nil? self.is_secure_boot_enabled = false if is_secure_boot_enabled.nil? && !attributes.key?(:'isSecureBootEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isSecureBootEnabled and :is_secure_boot_enabled' if attributes.key?(:'isSecureBootEnabled') && attributes.key?(:'is_secure_boot_enabled') self.is_secure_boot_enabled = attributes[:'is_secure_boot_enabled'] unless attributes[:'is_secure_boot_enabled'].nil? self.is_secure_boot_enabled = false if is_secure_boot_enabled.nil? && !attributes.key?(:'isSecureBootEnabled') && !attributes.key?(:'is_secure_boot_enabled') # rubocop:disable Style/StringLiterals self.is_trusted_platform_module_enabled = attributes[:'isTrustedPlatformModuleEnabled'] unless attributes[:'isTrustedPlatformModuleEnabled'].nil? self.is_trusted_platform_module_enabled = false if is_trusted_platform_module_enabled.nil? && !attributes.key?(:'isTrustedPlatformModuleEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isTrustedPlatformModuleEnabled and :is_trusted_platform_module_enabled' if attributes.key?(:'isTrustedPlatformModuleEnabled') && attributes.key?(:'is_trusted_platform_module_enabled') self.is_trusted_platform_module_enabled = attributes[:'is_trusted_platform_module_enabled'] unless attributes[:'is_trusted_platform_module_enabled'].nil? self.is_trusted_platform_module_enabled = false if is_trusted_platform_module_enabled.nil? && !attributes.key?(:'isTrustedPlatformModuleEnabled') && !attributes.key?(:'is_trusted_platform_module_enabled') # rubocop:disable Style/StringLiterals self.is_measured_boot_enabled = attributes[:'isMeasuredBootEnabled'] unless attributes[:'isMeasuredBootEnabled'].nil? self.is_measured_boot_enabled = false if is_measured_boot_enabled.nil? && !attributes.key?(:'isMeasuredBootEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isMeasuredBootEnabled and :is_measured_boot_enabled' if attributes.key?(:'isMeasuredBootEnabled') && attributes.key?(:'is_measured_boot_enabled') self.is_measured_boot_enabled = attributes[:'is_measured_boot_enabled'] unless attributes[:'is_measured_boot_enabled'].nil? self.is_measured_boot_enabled = false if is_measured_boot_enabled.nil? && !attributes.key?(:'isMeasuredBootEnabled') && !attributes.key?(:'is_measured_boot_enabled') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#is_measured_boot_enabled ⇒ BOOLEAN
Whether the Measured Boot feature is enabled on the instance.
40 41 42 |
# File 'lib/oci/core/models/platform_config.rb', line 40 def is_measured_boot_enabled @is_measured_boot_enabled end |
#is_secure_boot_enabled ⇒ BOOLEAN
Whether Secure Boot is enabled on the instance.
30 31 32 |
# File 'lib/oci/core/models/platform_config.rb', line 30 def is_secure_boot_enabled @is_secure_boot_enabled end |
#is_trusted_platform_module_enabled ⇒ BOOLEAN
Whether the Trusted Platform Module (TPM) is enabled on the instance.
35 36 37 |
# File 'lib/oci/core/models/platform_config.rb', line 35 def is_trusted_platform_module_enabled @is_trusted_platform_module_enabled end |
#type ⇒ String
[Required] The type of platform being configured.
25 26 27 |
# File 'lib/oci/core/models/platform_config.rb', line 25 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/core/models/platform_config.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'is_secure_boot_enabled': :'isSecureBootEnabled', 'is_trusted_platform_module_enabled': :'isTrustedPlatformModuleEnabled', 'is_measured_boot_enabled': :'isMeasuredBootEnabled' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/core/models/platform_config.rb', line 71 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::Core::Models::AmdMilanBmPlatformConfig' if type == 'AMD_MILAN_BM' return 'OCI::Core::Models::AmdRomeBmPlatformConfig' if type == 'AMD_ROME_BM' return 'OCI::Core::Models::IntelSkylakeBmPlatformConfig' if type == 'INTEL_SKYLAKE_BM' return 'OCI::Core::Models::AmdVmPlatformConfig' if type == 'AMD_VM' return 'OCI::Core::Models::IntelVmPlatformConfig' if type == 'INTEL_VM' # TODO: Log a warning when the subtype is not found. 'OCI::Core::Models::PlatformConfig' end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/core/models/platform_config.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'is_secure_boot_enabled': :'BOOLEAN', 'is_trusted_platform_module_enabled': :'BOOLEAN', 'is_measured_boot_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/core/models/platform_config.rb', line 148 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && is_secure_boot_enabled == other.is_secure_boot_enabled && is_trusted_platform_module_enabled == other.is_trusted_platform_module_enabled && is_measured_boot_enabled == other.is_measured_boot_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/core/models/platform_config.rb', line 181 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
161 162 163 |
# File 'lib/oci/core/models/platform_config.rb', line 161 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/oci/core/models/platform_config.rb', line 170 def hash [type, is_secure_boot_enabled, is_trusted_platform_module_enabled, is_measured_boot_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/core/models/platform_config.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
208 209 210 |
# File 'lib/oci/core/models/platform_config.rb', line 208 def to_s to_hash.to_s end |