Class: OCI::Core::Models::RebootMigrateActionDetails
- Inherits:
-
InstancePowerActionDetails
- Object
- InstancePowerActionDetails
- OCI::Core::Models::RebootMigrateActionDetails
- Defined in:
- lib/oci/core/models/reboot_migrate_action_details.rb
Overview
Parameters for the rebootMigrate instance_action.
Instance Attribute Summary collapse
-
#delete_local_storage ⇒ BOOLEAN
For bare metal instances that have local storage, this must be set to true to verify that the local storage will be deleted during the migration.
-
#time_scheduled ⇒ DateTime
If present, this parameter will set (or re-set) the scheduled time that the instance will be reboot migrated in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Attributes inherited from InstancePowerActionDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RebootMigrateActionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from InstancePowerActionDetails
Constructor Details
#initialize(attributes = {}) ⇒ RebootMigrateActionDetails
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 56 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['actionType'] = 'rebootMigrate' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.delete_local_storage = attributes[:'deleteLocalStorage'] unless attributes[:'deleteLocalStorage'].nil? self.delete_local_storage = false if delete_local_storage.nil? && !attributes.key?(:'deleteLocalStorage') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :deleteLocalStorage and :delete_local_storage' if attributes.key?(:'deleteLocalStorage') && attributes.key?(:'delete_local_storage') self.delete_local_storage = attributes[:'delete_local_storage'] unless attributes[:'delete_local_storage'].nil? self.delete_local_storage = false if delete_local_storage.nil? && !attributes.key?(:'deleteLocalStorage') && !attributes.key?(:'delete_local_storage') # rubocop:disable Style/StringLiterals self.time_scheduled = attributes[:'timeScheduled'] if attributes[:'timeScheduled'] raise 'You cannot provide both :timeScheduled and :time_scheduled' if attributes.key?(:'timeScheduled') && attributes.key?(:'time_scheduled') self.time_scheduled = attributes[:'time_scheduled'] if attributes[:'time_scheduled'] end |
Instance Attribute Details
#delete_local_storage ⇒ BOOLEAN
For bare metal instances that have local storage, this must be set to true to verify that the local storage will be deleted during the migration. For instances without, this parameter has no effect.
16 17 18 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 16 def delete_local_storage @delete_local_storage end |
#time_scheduled ⇒ DateTime
If present, this parameter will set (or re-set) the scheduled time that the instance will be reboot migrated in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). This will also change the timeRebootMigrationDue field on the instance. If not present, the reboot migration will be triggered immediately.
24 25 26 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 24 def time_scheduled @time_scheduled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'action_type': :'actionType', 'delete_local_storage': :'deleteLocalStorage', 'time_scheduled': :'timeScheduled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'action_type': :'String', 'delete_local_storage': :'BOOLEAN', 'time_scheduled': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
88 89 90 91 92 93 94 95 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 88 def ==(other) return true if equal?(other) self.class == other.class && action_type == other.action_type && delete_local_storage == other.delete_local_storage && time_scheduled == other.time_scheduled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 120 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
100 101 102 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 100 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
109 110 111 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 109 def hash [action_type, delete_local_storage, time_scheduled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 153 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
147 148 149 |
# File 'lib/oci/core/models/reboot_migrate_action_details.rb', line 147 def to_s to_hash.to_s end |