Method: OCI::Core::Models::SecurityRule#destination
- Defined in:
- lib/oci/core/models/security_rule.rb
#destination ⇒ String
Conceptually, this is the range of IP addresses that a packet originating from the instance can go to.
Allowed values:
* An IP address range in CIDR notation. For example: `192.168.1.0/24`
* The `cidrBlock` value for a {Service}, if you're
setting up a security rule for traffic destined for a particular `Service` through
a service gateway. For example: `oci-phx-objectstorage`.
* The OCID of a {NetworkSecurityGroup} in the same
VCN. The value can be the NSG that the rule belongs to if the rule's intent is to control
traffic between VNICs in the same NSG.
54 55 56 |
# File 'lib/oci/core/models/security_rule.rb', line 54 def destination @destination end |