Class: OCI::Core::Models::Shape
- Inherits:
-
Object
- Object
- OCI::Core::Models::Shape
- Defined in:
- lib/oci/core/models/shape.rb
Overview
A compute instance shape that can be used in launch_instance. For more information, see [Overview of the Compute Service](docs.cloud.oracle.com/iaas/Content/Compute/Concepts/computeoverview.htm) and [Compute Shapes](docs.cloud.oracle.com/iaas/Content/Compute/References/computeshapes.htm).
Constant Summary collapse
- BASELINE_OCPU_UTILIZATIONS_ENUM =
[ BASELINE_OCPU_UTILIZATIONS_BASELINE_1_8 = 'BASELINE_1_8'.freeze, BASELINE_OCPU_UTILIZATIONS_BASELINE_1_2 = 'BASELINE_1_2'.freeze, BASELINE_OCPU_UTILIZATIONS_BASELINE_1_1 = 'BASELINE_1_1'.freeze, BASELINE_OCPU_UTILIZATIONS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#baseline_ocpu_utilizations ⇒ Array<String>
For a subcore burstable VM, the supported baseline OCPU utilization for instances that use this shape.
-
#gpu_description ⇒ String
A short description of the graphics processing unit (GPU) available for this shape.
-
#gpus ⇒ Integer
The number of GPUs available for this shape.
-
#is_live_migration_supported ⇒ BOOLEAN
Whether live migration is supported for this shape.
-
#local_disk_description ⇒ String
A short description of the local disks available for this shape.
-
#local_disks ⇒ Integer
The number of local disks available for this shape.
-
#local_disks_total_size_in_gbs ⇒ Float
The aggregate size of the local disks available for this shape, in gigabytes.
- #max_vnic_attachment_options ⇒ OCI::Core::Models::ShapeMaxVnicAttachmentOptions
-
#max_vnic_attachments ⇒ Integer
The maximum number of VNIC attachments available for this shape.
-
#memory_in_gbs ⇒ Float
The default amount of memory available for this shape, in gigabytes.
- #memory_options ⇒ OCI::Core::Models::ShapeMemoryOptions
-
#min_total_baseline_ocpus_required ⇒ Float
For a subcore burstable VM, the minimum total baseline OCPUs required.
-
#networking_bandwidth_in_gbps ⇒ Float
The networking bandwidth available for this shape, in gigabits per second.
- #networking_bandwidth_options ⇒ OCI::Core::Models::ShapeNetworkingBandwidthOptions
- #ocpu_options ⇒ OCI::Core::Models::ShapeOcpuOptions
-
#ocpus ⇒ Float
The default number of OCPUs available for this shape.
-
#processor_description ⇒ String
A short description of the shape’s processor (CPU).
-
#shape ⇒ String
[Required] The name of the shape.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Shape
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Shape
Initializes the object
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/oci/core/models/shape.rb', line 187 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.baseline_ocpu_utilizations = attributes[:'baselineOcpuUtilizations'] if attributes[:'baselineOcpuUtilizations'] raise 'You cannot provide both :baselineOcpuUtilizations and :baseline_ocpu_utilizations' if attributes.key?(:'baselineOcpuUtilizations') && attributes.key?(:'baseline_ocpu_utilizations') self.baseline_ocpu_utilizations = attributes[:'baseline_ocpu_utilizations'] if attributes[:'baseline_ocpu_utilizations'] self.min_total_baseline_ocpus_required = attributes[:'minTotalBaselineOcpusRequired'] if attributes[:'minTotalBaselineOcpusRequired'] raise 'You cannot provide both :minTotalBaselineOcpusRequired and :min_total_baseline_ocpus_required' if attributes.key?(:'minTotalBaselineOcpusRequired') && attributes.key?(:'min_total_baseline_ocpus_required') self.min_total_baseline_ocpus_required = attributes[:'min_total_baseline_ocpus_required'] if attributes[:'min_total_baseline_ocpus_required'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.processor_description = attributes[:'processorDescription'] if attributes[:'processorDescription'] raise 'You cannot provide both :processorDescription and :processor_description' if attributes.key?(:'processorDescription') && attributes.key?(:'processor_description') self.processor_description = attributes[:'processor_description'] if attributes[:'processor_description'] self.ocpus = attributes[:'ocpus'] if attributes[:'ocpus'] self.memory_in_gbs = attributes[:'memoryInGBs'] if attributes[:'memoryInGBs'] raise 'You cannot provide both :memoryInGBs and :memory_in_gbs' if attributes.key?(:'memoryInGBs') && attributes.key?(:'memory_in_gbs') self.memory_in_gbs = attributes[:'memory_in_gbs'] if attributes[:'memory_in_gbs'] self.networking_bandwidth_in_gbps = attributes[:'networkingBandwidthInGbps'] if attributes[:'networkingBandwidthInGbps'] raise 'You cannot provide both :networkingBandwidthInGbps and :networking_bandwidth_in_gbps' if attributes.key?(:'networkingBandwidthInGbps') && attributes.key?(:'networking_bandwidth_in_gbps') self.networking_bandwidth_in_gbps = attributes[:'networking_bandwidth_in_gbps'] if attributes[:'networking_bandwidth_in_gbps'] self. = attributes[:'maxVnicAttachments'] if attributes[:'maxVnicAttachments'] raise 'You cannot provide both :maxVnicAttachments and :max_vnic_attachments' if attributes.key?(:'maxVnicAttachments') && attributes.key?(:'max_vnic_attachments') self. = attributes[:'max_vnic_attachments'] if attributes[:'max_vnic_attachments'] self.gpus = attributes[:'gpus'] if attributes[:'gpus'] self.gpu_description = attributes[:'gpuDescription'] if attributes[:'gpuDescription'] raise 'You cannot provide both :gpuDescription and :gpu_description' if attributes.key?(:'gpuDescription') && attributes.key?(:'gpu_description') self.gpu_description = attributes[:'gpu_description'] if attributes[:'gpu_description'] self.local_disks = attributes[:'localDisks'] if attributes[:'localDisks'] raise 'You cannot provide both :localDisks and :local_disks' if attributes.key?(:'localDisks') && attributes.key?(:'local_disks') self.local_disks = attributes[:'local_disks'] if attributes[:'local_disks'] self.local_disks_total_size_in_gbs = attributes[:'localDisksTotalSizeInGBs'] if attributes[:'localDisksTotalSizeInGBs'] raise 'You cannot provide both :localDisksTotalSizeInGBs and :local_disks_total_size_in_gbs' if attributes.key?(:'localDisksTotalSizeInGBs') && attributes.key?(:'local_disks_total_size_in_gbs') self.local_disks_total_size_in_gbs = attributes[:'local_disks_total_size_in_gbs'] if attributes[:'local_disks_total_size_in_gbs'] self.local_disk_description = attributes[:'localDiskDescription'] if attributes[:'localDiskDescription'] raise 'You cannot provide both :localDiskDescription and :local_disk_description' if attributes.key?(:'localDiskDescription') && attributes.key?(:'local_disk_description') self.local_disk_description = attributes[:'local_disk_description'] if attributes[:'local_disk_description'] self.is_live_migration_supported = attributes[:'isLiveMigrationSupported'] unless attributes[:'isLiveMigrationSupported'].nil? raise 'You cannot provide both :isLiveMigrationSupported and :is_live_migration_supported' if attributes.key?(:'isLiveMigrationSupported') && attributes.key?(:'is_live_migration_supported') self.is_live_migration_supported = attributes[:'is_live_migration_supported'] unless attributes[:'is_live_migration_supported'].nil? self. = attributes[:'ocpuOptions'] if attributes[:'ocpuOptions'] raise 'You cannot provide both :ocpuOptions and :ocpu_options' if attributes.key?(:'ocpuOptions') && attributes.key?(:'ocpu_options') self. = attributes[:'ocpu_options'] if attributes[:'ocpu_options'] self. = attributes[:'memoryOptions'] if attributes[:'memoryOptions'] raise 'You cannot provide both :memoryOptions and :memory_options' if attributes.key?(:'memoryOptions') && attributes.key?(:'memory_options') self. = attributes[:'memory_options'] if attributes[:'memory_options'] self. = attributes[:'networkingBandwidthOptions'] if attributes[:'networkingBandwidthOptions'] raise 'You cannot provide both :networkingBandwidthOptions and :networking_bandwidth_options' if attributes.key?(:'networkingBandwidthOptions') && attributes.key?(:'networking_bandwidth_options') self. = attributes[:'networking_bandwidth_options'] if attributes[:'networking_bandwidth_options'] self. = attributes[:'maxVnicAttachmentOptions'] if attributes[:'maxVnicAttachmentOptions'] raise 'You cannot provide both :maxVnicAttachmentOptions and :max_vnic_attachment_options' if attributes.key?(:'maxVnicAttachmentOptions') && attributes.key?(:'max_vnic_attachment_options') self. = attributes[:'max_vnic_attachment_options'] if attributes[:'max_vnic_attachment_options'] end |
Instance Attribute Details
#baseline_ocpu_utilizations ⇒ Array<String>
For a subcore burstable VM, the supported baseline OCPU utilization for instances that use this shape.
24 25 26 |
# File 'lib/oci/core/models/shape.rb', line 24 def baseline_ocpu_utilizations @baseline_ocpu_utilizations end |
#gpu_description ⇒ String
A short description of the graphics processing unit (GPU) available for this shape.
If the shape does not have any GPUs, this field is null.
73 74 75 |
# File 'lib/oci/core/models/shape.rb', line 73 def gpu_description @gpu_description end |
#gpus ⇒ Integer
The number of GPUs available for this shape.
66 67 68 |
# File 'lib/oci/core/models/shape.rb', line 66 def gpus @gpus end |
#is_live_migration_supported ⇒ BOOLEAN
Whether live migration is supported for this shape.
97 98 99 |
# File 'lib/oci/core/models/shape.rb', line 97 def is_live_migration_supported @is_live_migration_supported end |
#local_disk_description ⇒ String
A short description of the local disks available for this shape.
If the shape does not have any local disks, this field is null.
92 93 94 |
# File 'lib/oci/core/models/shape.rb', line 92 def local_disk_description @local_disk_description end |
#local_disks ⇒ Integer
The number of local disks available for this shape.
78 79 80 |
# File 'lib/oci/core/models/shape.rb', line 78 def local_disks @local_disks end |
#local_disks_total_size_in_gbs ⇒ Float
The aggregate size of the local disks available for this shape, in gigabytes.
If the shape does not have any local disks, this field is null.
85 86 87 |
# File 'lib/oci/core/models/shape.rb', line 85 def local_disks_total_size_in_gbs @local_disks_total_size_in_gbs end |
#max_vnic_attachment_options ⇒ OCI::Core::Models::ShapeMaxVnicAttachmentOptions
109 110 111 |
# File 'lib/oci/core/models/shape.rb', line 109 def end |
#max_vnic_attachments ⇒ Integer
The maximum number of VNIC attachments available for this shape.
61 62 63 |
# File 'lib/oci/core/models/shape.rb', line 61 def end |
#memory_in_gbs ⇒ Float
The default amount of memory available for this shape, in gigabytes.
51 52 53 |
# File 'lib/oci/core/models/shape.rb', line 51 def memory_in_gbs @memory_in_gbs end |
#memory_options ⇒ OCI::Core::Models::ShapeMemoryOptions
103 104 105 |
# File 'lib/oci/core/models/shape.rb', line 103 def end |
#min_total_baseline_ocpus_required ⇒ Float
For a subcore burstable VM, the minimum total baseline OCPUs required. The total baseline OCPUs is equal to baselineOcpuUtilization chosen multiplied by the number of OCPUs chosen.
30 31 32 |
# File 'lib/oci/core/models/shape.rb', line 30 def min_total_baseline_ocpus_required @min_total_baseline_ocpus_required end |
#networking_bandwidth_in_gbps ⇒ Float
The networking bandwidth available for this shape, in gigabits per second.
56 57 58 |
# File 'lib/oci/core/models/shape.rb', line 56 def networking_bandwidth_in_gbps @networking_bandwidth_in_gbps end |
#networking_bandwidth_options ⇒ OCI::Core::Models::ShapeNetworkingBandwidthOptions
106 107 108 |
# File 'lib/oci/core/models/shape.rb', line 106 def end |
#ocpu_options ⇒ OCI::Core::Models::ShapeOcpuOptions
100 101 102 |
# File 'lib/oci/core/models/shape.rb', line 100 def end |
#ocpus ⇒ Float
The default number of OCPUs available for this shape.
46 47 48 |
# File 'lib/oci/core/models/shape.rb', line 46 def ocpus @ocpus end |
#processor_description ⇒ String
A short description of the shape’s processor (CPU).
41 42 43 |
# File 'lib/oci/core/models/shape.rb', line 41 def processor_description @processor_description end |
#shape ⇒ String
[Required] The name of the shape. You can enumerate all available shapes by calling list_shapes.
36 37 38 |
# File 'lib/oci/core/models/shape.rb', line 36 def shape @shape end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/core/models/shape.rb', line 112 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'baseline_ocpu_utilizations': :'baselineOcpuUtilizations', 'min_total_baseline_ocpus_required': :'minTotalBaselineOcpusRequired', 'shape': :'shape', 'processor_description': :'processorDescription', 'ocpus': :'ocpus', 'memory_in_gbs': :'memoryInGBs', 'networking_bandwidth_in_gbps': :'networkingBandwidthInGbps', 'max_vnic_attachments': :'maxVnicAttachments', 'gpus': :'gpus', 'gpu_description': :'gpuDescription', 'local_disks': :'localDisks', 'local_disks_total_size_in_gbs': :'localDisksTotalSizeInGBs', 'local_disk_description': :'localDiskDescription', 'is_live_migration_supported': :'isLiveMigrationSupported', 'ocpu_options': :'ocpuOptions', 'memory_options': :'memoryOptions', 'networking_bandwidth_options': :'networkingBandwidthOptions', 'max_vnic_attachment_options': :'maxVnicAttachmentOptions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/core/models/shape.rb', line 138 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'baseline_ocpu_utilizations': :'Array<String>', 'min_total_baseline_ocpus_required': :'Float', 'shape': :'String', 'processor_description': :'String', 'ocpus': :'Float', 'memory_in_gbs': :'Float', 'networking_bandwidth_in_gbps': :'Float', 'max_vnic_attachments': :'Integer', 'gpus': :'Integer', 'gpu_description': :'String', 'local_disks': :'Integer', 'local_disks_total_size_in_gbs': :'Float', 'local_disk_description': :'String', 'is_live_migration_supported': :'BOOLEAN', 'ocpu_options': :'OCI::Core::Models::ShapeOcpuOptions', 'memory_options': :'OCI::Core::Models::ShapeMemoryOptions', 'networking_bandwidth_options': :'OCI::Core::Models::ShapeNetworkingBandwidthOptions', 'max_vnic_attachment_options': :'OCI::Core::Models::ShapeMaxVnicAttachmentOptions' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/oci/core/models/shape.rb', line 317 def ==(other) return true if equal?(other) self.class == other.class && baseline_ocpu_utilizations == other.baseline_ocpu_utilizations && min_total_baseline_ocpus_required == other.min_total_baseline_ocpus_required && shape == other.shape && processor_description == other.processor_description && ocpus == other.ocpus && memory_in_gbs == other.memory_in_gbs && networking_bandwidth_in_gbps == other.networking_bandwidth_in_gbps && == other. && gpus == other.gpus && gpu_description == other.gpu_description && local_disks == other.local_disks && local_disks_total_size_in_gbs == other.local_disks_total_size_in_gbs && local_disk_description == other.local_disk_description && is_live_migration_supported == other.is_live_migration_supported && == other. && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/oci/core/models/shape.rb', line 364 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
344 345 346 |
# File 'lib/oci/core/models/shape.rb', line 344 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
353 354 355 |
# File 'lib/oci/core/models/shape.rb', line 353 def hash [baseline_ocpu_utilizations, min_total_baseline_ocpus_required, shape, processor_description, ocpus, memory_in_gbs, networking_bandwidth_in_gbps, , gpus, gpu_description, local_disks, local_disks_total_size_in_gbs, local_disk_description, is_live_migration_supported, , , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
397 398 399 400 401 402 403 404 405 406 |
# File 'lib/oci/core/models/shape.rb', line 397 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
391 392 393 |
# File 'lib/oci/core/models/shape.rb', line 391 def to_s to_hash.to_s end |