Class: OCI::Core::Models::ShapePlatformConfigOptions
- Inherits:
-
Object
- Object
- OCI::Core::Models::ShapePlatformConfigOptions
- Defined in:
- lib/oci/core/models/shape_platform_config_options.rb
Overview
The list of supported platform configuration options for this shape.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_AMD_MILAN_BM = 'AMD_MILAN_BM'.freeze, TYPE_AMD_ROME_BM = 'AMD_ROME_BM'.freeze, TYPE_AMD_ROME_BM_GPU = 'AMD_ROME_BM_GPU'.freeze, TYPE_INTEL_ICELAKE_BM = 'INTEL_ICELAKE_BM'.freeze, TYPE_INTEL_SKYLAKE_BM = 'INTEL_SKYLAKE_BM'.freeze, TYPE_AMD_VM = 'AMD_VM'.freeze, TYPE_INTEL_VM = 'INTEL_VM'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #access_control_service_options ⇒ OCI::Core::Models::ShapeAccessControlServiceEnabledPlatformOptions
- #input_output_memory_management_unit_options ⇒ OCI::Core::Models::ShapeInputOutputMemoryManagementUnitEnabledPlatformOptions
- #measured_boot_options ⇒ OCI::Core::Models::ShapeMeasuredBootOptions
- #numa_nodes_per_socket_platform_options ⇒ OCI::Core::Models::ShapeNumaNodesPerSocketPlatformOptions
- #percentage_of_cores_enabled_options ⇒ OCI::Core::Models::PercentageOfCoresEnabledOptions
- #secure_boot_options ⇒ OCI::Core::Models::ShapeSecureBootOptions
- #symmetric_multi_threading_options ⇒ OCI::Core::Models::ShapeSymmetricMultiThreadingEnabledPlatformOptions
- #trusted_platform_module_options ⇒ OCI::Core::Models::ShapeTrustedPlatformModuleOptions
-
#type ⇒ String
The type of platform being configured.
- #virtual_instructions_options ⇒ OCI::Core::Models::ShapeVirtualInstructionsEnabledPlatformOptions
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ShapePlatformConfigOptions
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ShapePlatformConfigOptions
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 107 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self. = attributes[:'secureBootOptions'] if attributes[:'secureBootOptions'] raise 'You cannot provide both :secureBootOptions and :secure_boot_options' if attributes.key?(:'secureBootOptions') && attributes.key?(:'secure_boot_options') self. = attributes[:'secure_boot_options'] if attributes[:'secure_boot_options'] self. = attributes[:'measuredBootOptions'] if attributes[:'measuredBootOptions'] raise 'You cannot provide both :measuredBootOptions and :measured_boot_options' if attributes.key?(:'measuredBootOptions') && attributes.key?(:'measured_boot_options') self. = attributes[:'measured_boot_options'] if attributes[:'measured_boot_options'] self. = attributes[:'trustedPlatformModuleOptions'] if attributes[:'trustedPlatformModuleOptions'] raise 'You cannot provide both :trustedPlatformModuleOptions and :trusted_platform_module_options' if attributes.key?(:'trustedPlatformModuleOptions') && attributes.key?(:'trusted_platform_module_options') self. = attributes[:'trusted_platform_module_options'] if attributes[:'trusted_platform_module_options'] self. = attributes[:'numaNodesPerSocketPlatformOptions'] if attributes[:'numaNodesPerSocketPlatformOptions'] raise 'You cannot provide both :numaNodesPerSocketPlatformOptions and :numa_nodes_per_socket_platform_options' if attributes.key?(:'numaNodesPerSocketPlatformOptions') && attributes.key?(:'numa_nodes_per_socket_platform_options') self. = attributes[:'numa_nodes_per_socket_platform_options'] if attributes[:'numa_nodes_per_socket_platform_options'] self. = attributes[:'symmetricMultiThreadingOptions'] if attributes[:'symmetricMultiThreadingOptions'] raise 'You cannot provide both :symmetricMultiThreadingOptions and :symmetric_multi_threading_options' if attributes.key?(:'symmetricMultiThreadingOptions') && attributes.key?(:'symmetric_multi_threading_options') self. = attributes[:'symmetric_multi_threading_options'] if attributes[:'symmetric_multi_threading_options'] self. = attributes[:'accessControlServiceOptions'] if attributes[:'accessControlServiceOptions'] raise 'You cannot provide both :accessControlServiceOptions and :access_control_service_options' if attributes.key?(:'accessControlServiceOptions') && attributes.key?(:'access_control_service_options') self. = attributes[:'access_control_service_options'] if attributes[:'access_control_service_options'] self. = attributes[:'virtualInstructionsOptions'] if attributes[:'virtualInstructionsOptions'] raise 'You cannot provide both :virtualInstructionsOptions and :virtual_instructions_options' if attributes.key?(:'virtualInstructionsOptions') && attributes.key?(:'virtual_instructions_options') self. = attributes[:'virtual_instructions_options'] if attributes[:'virtual_instructions_options'] self. = attributes[:'inputOutputMemoryManagementUnitOptions'] if attributes[:'inputOutputMemoryManagementUnitOptions'] raise 'You cannot provide both :inputOutputMemoryManagementUnitOptions and :input_output_memory_management_unit_options' if attributes.key?(:'inputOutputMemoryManagementUnitOptions') && attributes.key?(:'input_output_memory_management_unit_options') self. = attributes[:'input_output_memory_management_unit_options'] if attributes[:'input_output_memory_management_unit_options'] self. = attributes[:'percentageOfCoresEnabledOptions'] if attributes[:'percentageOfCoresEnabledOptions'] raise 'You cannot provide both :percentageOfCoresEnabledOptions and :percentage_of_cores_enabled_options' if attributes.key?(:'percentageOfCoresEnabledOptions') && attributes.key?(:'percentage_of_cores_enabled_options') self. = attributes[:'percentage_of_cores_enabled_options'] if attributes[:'percentage_of_cores_enabled_options'] end |
Instance Attribute Details
#access_control_service_options ⇒ OCI::Core::Models::ShapeAccessControlServiceEnabledPlatformOptions
44 45 46 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 44 def @access_control_service_options end |
#input_output_memory_management_unit_options ⇒ OCI::Core::Models::ShapeInputOutputMemoryManagementUnitEnabledPlatformOptions
50 51 52 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 50 def @input_output_memory_management_unit_options end |
#measured_boot_options ⇒ OCI::Core::Models::ShapeMeasuredBootOptions
32 33 34 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 32 def @measured_boot_options end |
#numa_nodes_per_socket_platform_options ⇒ OCI::Core::Models::ShapeNumaNodesPerSocketPlatformOptions
38 39 40 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 38 def @numa_nodes_per_socket_platform_options end |
#percentage_of_cores_enabled_options ⇒ OCI::Core::Models::PercentageOfCoresEnabledOptions
53 54 55 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 53 def @percentage_of_cores_enabled_options end |
#secure_boot_options ⇒ OCI::Core::Models::ShapeSecureBootOptions
29 30 31 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 29 def @secure_boot_options end |
#symmetric_multi_threading_options ⇒ OCI::Core::Models::ShapeSymmetricMultiThreadingEnabledPlatformOptions
41 42 43 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 41 def @symmetric_multi_threading_options end |
#trusted_platform_module_options ⇒ OCI::Core::Models::ShapeTrustedPlatformModuleOptions
35 36 37 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 35 def @trusted_platform_module_options end |
#type ⇒ String
The type of platform being configured.
26 27 28 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 26 def type @type end |
#virtual_instructions_options ⇒ OCI::Core::Models::ShapeVirtualInstructionsEnabledPlatformOptions
47 48 49 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 47 def @virtual_instructions_options end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 56 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'secure_boot_options': :'secureBootOptions', 'measured_boot_options': :'measuredBootOptions', 'trusted_platform_module_options': :'trustedPlatformModuleOptions', 'numa_nodes_per_socket_platform_options': :'numaNodesPerSocketPlatformOptions', 'symmetric_multi_threading_options': :'symmetricMultiThreadingOptions', 'access_control_service_options': :'accessControlServiceOptions', 'virtual_instructions_options': :'virtualInstructionsOptions', 'input_output_memory_management_unit_options': :'inputOutputMemoryManagementUnitOptions', 'percentage_of_cores_enabled_options': :'percentageOfCoresEnabledOptions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 74 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'secure_boot_options': :'OCI::Core::Models::ShapeSecureBootOptions', 'measured_boot_options': :'OCI::Core::Models::ShapeMeasuredBootOptions', 'trusted_platform_module_options': :'OCI::Core::Models::ShapeTrustedPlatformModuleOptions', 'numa_nodes_per_socket_platform_options': :'OCI::Core::Models::ShapeNumaNodesPerSocketPlatformOptions', 'symmetric_multi_threading_options': :'OCI::Core::Models::ShapeSymmetricMultiThreadingEnabledPlatformOptions', 'access_control_service_options': :'OCI::Core::Models::ShapeAccessControlServiceEnabledPlatformOptions', 'virtual_instructions_options': :'OCI::Core::Models::ShapeVirtualInstructionsEnabledPlatformOptions', 'input_output_memory_management_unit_options': :'OCI::Core::Models::ShapeInputOutputMemoryManagementUnitEnabledPlatformOptions', 'percentage_of_cores_enabled_options': :'OCI::Core::Models::PercentageOfCoresEnabledOptions' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 190 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && == other. && == other. && == other. && == other. && == other. && == other. && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 229 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
209 210 211 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 209 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 218 def hash [type, , , , , , , , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 262 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
256 257 258 |
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 256 def to_s to_hash.to_s end |