Class: OCI::Core::Models::ShapePlatformConfigOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/core/models/shape_platform_config_options.rb

Overview

The list of supported platform configuration options for this shape.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_AMD_MILAN_BM = 'AMD_MILAN_BM'.freeze,
  TYPE_AMD_ROME_BM = 'AMD_ROME_BM'.freeze,
  TYPE_INTEL_SKYLAKE_BM = 'INTEL_SKYLAKE_BM'.freeze,
  TYPE_AMD_VM = 'AMD_VM'.freeze,
  TYPE_INTEL_VM = 'INTEL_VM'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ShapePlatformConfigOptions

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 75

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.type = attributes[:'type'] if attributes[:'type']

  self.secure_boot_options = attributes[:'secureBootOptions'] if attributes[:'secureBootOptions']

  raise 'You cannot provide both :secureBootOptions and :secure_boot_options' if attributes.key?(:'secureBootOptions') && attributes.key?(:'secure_boot_options')

  self.secure_boot_options = attributes[:'secure_boot_options'] if attributes[:'secure_boot_options']

  self.measured_boot_options = attributes[:'measuredBootOptions'] if attributes[:'measuredBootOptions']

  raise 'You cannot provide both :measuredBootOptions and :measured_boot_options' if attributes.key?(:'measuredBootOptions') && attributes.key?(:'measured_boot_options')

  self.measured_boot_options = attributes[:'measured_boot_options'] if attributes[:'measured_boot_options']

  self.trusted_platform_module_options = attributes[:'trustedPlatformModuleOptions'] if attributes[:'trustedPlatformModuleOptions']

  raise 'You cannot provide both :trustedPlatformModuleOptions and :trusted_platform_module_options' if attributes.key?(:'trustedPlatformModuleOptions') && attributes.key?(:'trusted_platform_module_options')

  self.trusted_platform_module_options = attributes[:'trusted_platform_module_options'] if attributes[:'trusted_platform_module_options']

  self.numa_nodes_per_socket_platform_options = attributes[:'numaNodesPerSocketPlatformOptions'] if attributes[:'numaNodesPerSocketPlatformOptions']

  raise 'You cannot provide both :numaNodesPerSocketPlatformOptions and :numa_nodes_per_socket_platform_options' if attributes.key?(:'numaNodesPerSocketPlatformOptions') && attributes.key?(:'numa_nodes_per_socket_platform_options')

  self.numa_nodes_per_socket_platform_options = attributes[:'numa_nodes_per_socket_platform_options'] if attributes[:'numa_nodes_per_socket_platform_options']
end

Instance Attribute Details

#measured_boot_optionsOCI::Core::Models::ShapeMeasuredBootOptions

Returns:



30
31
32
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 30

def measured_boot_options
  @measured_boot_options
end

#numa_nodes_per_socket_platform_optionsOCI::Core::Models::ShapeNumaNodesPerSocketPlatformOptions

Returns:



36
37
38
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 36

def numa_nodes_per_socket_platform_options
  @numa_nodes_per_socket_platform_options
end

#secure_boot_optionsOCI::Core::Models::ShapeSecureBootOptions

Returns:



27
28
29
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 27

def secure_boot_options
  @secure_boot_options
end

#trusted_platform_module_optionsOCI::Core::Models::ShapeTrustedPlatformModuleOptions

Returns:



33
34
35
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 33

def trusted_platform_module_options
  @trusted_platform_module_options
end

#typeString

The type of platform being configured.

Returns:



24
25
26
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 24

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 39

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'secure_boot_options': :'secureBootOptions',
    'measured_boot_options': :'measuredBootOptions',
    'trusted_platform_module_options': :'trustedPlatformModuleOptions',
    'numa_nodes_per_socket_platform_options': :'numaNodesPerSocketPlatformOptions'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 52

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'secure_boot_options': :'OCI::Core::Models::ShapeSecureBootOptions',
    'measured_boot_options': :'OCI::Core::Models::ShapeMeasuredBootOptions',
    'trusted_platform_module_options': :'OCI::Core::Models::ShapeTrustedPlatformModuleOptions',
    'numa_nodes_per_socket_platform_options': :'OCI::Core::Models::ShapeNumaNodesPerSocketPlatformOptions'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



128
129
130
131
132
133
134
135
136
137
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 128

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    secure_boot_options == other.secure_boot_options &&
    measured_boot_options == other.measured_boot_options &&
    trusted_platform_module_options == other.trusted_platform_module_options &&
    numa_nodes_per_socket_platform_options == other.numa_nodes_per_socket_platform_options
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 162

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



142
143
144
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 142

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



151
152
153
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 151

def hash
  [type, secure_boot_options, measured_boot_options, trusted_platform_module_options, numa_nodes_per_socket_platform_options].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



189
190
191
# File 'lib/oci/core/models/shape_platform_config_options.rb', line 189

def to_s
  to_hash.to_s
end