Class: OCI::Core::Models::TunnelSecurityAssociationSummary
- Inherits:
-
Object
- Object
- OCI::Core::Models::TunnelSecurityAssociationSummary
- Defined in:
- lib/oci/core/models/tunnel_security_association_summary.rb
Overview
A summary of the IPSec tunnel security association details.
Constant Summary collapse
- TUNNEL_SA_STATUS_ENUM =
[ TUNNEL_SA_STATUS_INITIATING = 'INITIATING'.freeze, TUNNEL_SA_STATUS_LISTENING = 'LISTENING'.freeze, TUNNEL_SA_STATUS_UP = 'UP'.freeze, TUNNEL_SA_STATUS_DOWN = 'DOWN'.freeze, TUNNEL_SA_STATUS_ERROR = 'ERROR'.freeze, TUNNEL_SA_STATUS_UNKNOWN = 'UNKNOWN'.freeze, TUNNEL_SA_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cpe_subnet ⇒ String
The IP address and mask of the partner subnet used in policy based VPNs or static routes.
-
#oracle_subnet ⇒ String
The IP address and mask of the local subnet used in policy based VPNs or static routes.
-
#time ⇒ String
Time in the current state, in seconds.
-
#tunnel_sa_error_info ⇒ String
Current state if the IPSec tunnel status is not `UP`, including phase one and phase two details and a possible reason the tunnel is not `UP`.
-
#tunnel_sa_status ⇒ String
The IPSec tunnel's phase one status.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TunnelSecurityAssociationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TunnelSecurityAssociationSummary
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cpe_subnet = attributes[:'cpeSubnet'] if attributes[:'cpeSubnet'] raise 'You cannot provide both :cpeSubnet and :cpe_subnet' if attributes.key?(:'cpeSubnet') && attributes.key?(:'cpe_subnet') self.cpe_subnet = attributes[:'cpe_subnet'] if attributes[:'cpe_subnet'] self.oracle_subnet = attributes[:'oracleSubnet'] if attributes[:'oracleSubnet'] raise 'You cannot provide both :oracleSubnet and :oracle_subnet' if attributes.key?(:'oracleSubnet') && attributes.key?(:'oracle_subnet') self.oracle_subnet = attributes[:'oracle_subnet'] if attributes[:'oracle_subnet'] self.tunnel_sa_status = attributes[:'tunnelSaStatus'] if attributes[:'tunnelSaStatus'] raise 'You cannot provide both :tunnelSaStatus and :tunnel_sa_status' if attributes.key?(:'tunnelSaStatus') && attributes.key?(:'tunnel_sa_status') self.tunnel_sa_status = attributes[:'tunnel_sa_status'] if attributes[:'tunnel_sa_status'] self.tunnel_sa_error_info = attributes[:'tunnelSaErrorInfo'] if attributes[:'tunnelSaErrorInfo'] raise 'You cannot provide both :tunnelSaErrorInfo and :tunnel_sa_error_info' if attributes.key?(:'tunnelSaErrorInfo') && attributes.key?(:'tunnel_sa_error_info') self.tunnel_sa_error_info = attributes[:'tunnel_sa_error_info'] if attributes[:'tunnel_sa_error_info'] self.time = attributes[:'time'] if attributes[:'time'] end |
Instance Attribute Details
#cpe_subnet ⇒ String
The IP address and mask of the partner subnet used in policy based VPNs or static routes.
24 25 26 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 24 def cpe_subnet @cpe_subnet end |
#oracle_subnet ⇒ String
The IP address and mask of the local subnet used in policy based VPNs or static routes.
28 29 30 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 28 def oracle_subnet @oracle_subnet end |
#time ⇒ String
Time in the current state, in seconds.
41 42 43 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 41 def time @time end |
#tunnel_sa_error_info ⇒ String
Current state if the IPSec tunnel status is not `UP`, including phase one and phase two details and a possible reason the tunnel is not `UP`.
37 38 39 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 37 def tunnel_sa_error_info @tunnel_sa_error_info end |
#tunnel_sa_status ⇒ String
The IPSec tunnel's phase one status.
32 33 34 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 32 def tunnel_sa_status @tunnel_sa_status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cpe_subnet': :'cpeSubnet', 'oracle_subnet': :'oracleSubnet', 'tunnel_sa_status': :'tunnelSaStatus', 'tunnel_sa_error_info': :'tunnelSaErrorInfo', 'time': :'time' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cpe_subnet': :'String', 'oracle_subnet': :'String', 'tunnel_sa_status': :'String', 'tunnel_sa_error_info': :'String', 'time': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 133 def ==(other) return true if equal?(other) self.class == other.class && cpe_subnet == other.cpe_subnet && oracle_subnet == other.oracle_subnet && tunnel_sa_status == other.tunnel_sa_status && tunnel_sa_error_info == other.tunnel_sa_error_info && time == other.time end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 167 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
147 148 149 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 147 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 156 def hash [cpe_subnet, oracle_subnet, tunnel_sa_status, tunnel_sa_error_info, time].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
194 195 196 |
# File 'lib/oci/core/models/tunnel_security_association_summary.rb', line 194 def to_s to_hash.to_s end |