Class: OCI::Core::Models::UpdateIPSecConnectionTunnelDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateIPSecConnectionTunnelDetails
- Defined in:
- lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb
Overview
UpdateIPSecConnectionTunnelDetails model.
Constant Summary collapse
- ROUTING_ENUM =
[ ROUTING_BGP = 'BGP'.freeze, ROUTING_STATIC = 'STATIC'.freeze, ROUTING_POLICY = 'POLICY'.freeze ].freeze
- IKE_VERSION_ENUM =
[ IKE_VERSION_V1 = 'V1'.freeze, IKE_VERSION_V2 = 'V2'.freeze ].freeze
- ORACLE_INITIATION_ENUM =
[ ORACLE_INITIATION_INITIATOR_OR_RESPONDER = 'INITIATOR_OR_RESPONDER'.freeze, ORACLE_INITIATION_RESPONDER_ONLY = 'RESPONDER_ONLY'.freeze ].freeze
- NAT_TRANSLATION_ENABLED_ENUM =
[ NAT_TRANSLATION_ENABLED_ENABLED = 'ENABLED'.freeze, NAT_TRANSLATION_ENABLED_DISABLED = 'DISABLED'.freeze, NAT_TRANSLATION_ENABLED_AUTO = 'AUTO'.freeze ].freeze
Instance Attribute Summary collapse
- #bgp_session_config ⇒ OCI::Core::Models::UpdateIPSecTunnelBgpSessionDetails
-
#display_name ⇒ String
A user-friendly name.
- #dpd_config ⇒ OCI::Core::Models::DpdConfig
- #encryption_domain_config ⇒ OCI::Core::Models::UpdateIPSecTunnelEncryptionDomainDetails
-
#ike_version ⇒ String
Internet Key Exchange protocol version.
-
#nat_translation_enabled ⇒ String
Whether NAT-T Enabled on the tunnel.
-
#oracle_initiation ⇒ String
Whether Oracle side is the initiator for negotiation.
- #phase_one_config ⇒ OCI::Core::Models::PhaseOneConfigDetails
- #phase_two_config ⇒ OCI::Core::Models::PhaseTwoConfigDetails
-
#routing ⇒ String
The type of routing to use for this tunnel (either BGP dynamic routing or static routing).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateIPSecConnectionTunnelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateIPSecConnectionTunnelDetails
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 123 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.routing = attributes[:'routing'] if attributes[:'routing'] self.ike_version = attributes[:'ikeVersion'] if attributes[:'ikeVersion'] raise 'You cannot provide both :ikeVersion and :ike_version' if attributes.key?(:'ikeVersion') && attributes.key?(:'ike_version') self.ike_version = attributes[:'ike_version'] if attributes[:'ike_version'] self.bgp_session_config = attributes[:'bgpSessionConfig'] if attributes[:'bgpSessionConfig'] raise 'You cannot provide both :bgpSessionConfig and :bgp_session_config' if attributes.key?(:'bgpSessionConfig') && attributes.key?(:'bgp_session_config') self.bgp_session_config = attributes[:'bgp_session_config'] if attributes[:'bgp_session_config'] self.oracle_initiation = attributes[:'oracleInitiation'] if attributes[:'oracleInitiation'] raise 'You cannot provide both :oracleInitiation and :oracle_initiation' if attributes.key?(:'oracleInitiation') && attributes.key?(:'oracle_initiation') self.oracle_initiation = attributes[:'oracle_initiation'] if attributes[:'oracle_initiation'] self.nat_translation_enabled = attributes[:'natTranslationEnabled'] if attributes[:'natTranslationEnabled'] raise 'You cannot provide both :natTranslationEnabled and :nat_translation_enabled' if attributes.key?(:'natTranslationEnabled') && attributes.key?(:'nat_translation_enabled') self.nat_translation_enabled = attributes[:'nat_translation_enabled'] if attributes[:'nat_translation_enabled'] self.phase_one_config = attributes[:'phaseOneConfig'] if attributes[:'phaseOneConfig'] raise 'You cannot provide both :phaseOneConfig and :phase_one_config' if attributes.key?(:'phaseOneConfig') && attributes.key?(:'phase_one_config') self.phase_one_config = attributes[:'phase_one_config'] if attributes[:'phase_one_config'] self.phase_two_config = attributes[:'phaseTwoConfig'] if attributes[:'phaseTwoConfig'] raise 'You cannot provide both :phaseTwoConfig and :phase_two_config' if attributes.key?(:'phaseTwoConfig') && attributes.key?(:'phase_two_config') self.phase_two_config = attributes[:'phase_two_config'] if attributes[:'phase_two_config'] self.dpd_config = attributes[:'dpdConfig'] if attributes[:'dpdConfig'] raise 'You cannot provide both :dpdConfig and :dpd_config' if attributes.key?(:'dpdConfig') && attributes.key?(:'dpd_config') self.dpd_config = attributes[:'dpd_config'] if attributes[:'dpd_config'] self.encryption_domain_config = attributes[:'encryptionDomainConfig'] if attributes[:'encryptionDomainConfig'] raise 'You cannot provide both :encryptionDomainConfig and :encryption_domain_config' if attributes.key?(:'encryptionDomainConfig') && attributes.key?(:'encryption_domain_config') self.encryption_domain_config = attributes[:'encryption_domain_config'] if attributes[:'encryption_domain_config'] end |
Instance Attribute Details
#bgp_session_config ⇒ OCI::Core::Models::UpdateIPSecTunnelBgpSessionDetails
49 50 51 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 49 def bgp_session_config @bgp_session_config end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
36 37 38 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 36 def display_name @display_name end |
#dpd_config ⇒ OCI::Core::Models::DpdConfig
66 67 68 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 66 def dpd_config @dpd_config end |
#encryption_domain_config ⇒ OCI::Core::Models::UpdateIPSecTunnelEncryptionDomainDetails
69 70 71 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 69 def encryption_domain_config @encryption_domain_config end |
#ike_version ⇒ String
Internet Key Exchange protocol version.
46 47 48 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 46 def ike_version @ike_version end |
#nat_translation_enabled ⇒ String
Whether NAT-T Enabled on the tunnel
57 58 59 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 57 def nat_translation_enabled @nat_translation_enabled end |
#oracle_initiation ⇒ String
Whether Oracle side is the initiator for negotiation.
53 54 55 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 53 def oracle_initiation @oracle_initiation end |
#phase_one_config ⇒ OCI::Core::Models::PhaseOneConfigDetails
60 61 62 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 60 def phase_one_config @phase_one_config end |
#phase_two_config ⇒ OCI::Core::Models::PhaseTwoConfigDetails
63 64 65 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 63 def phase_two_config @phase_two_config end |
#routing ⇒ String
The type of routing to use for this tunnel (either BGP dynamic routing or static routing).
41 42 43 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 41 def routing @routing end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 72 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'routing': :'routing', 'ike_version': :'ikeVersion', 'bgp_session_config': :'bgpSessionConfig', 'oracle_initiation': :'oracleInitiation', 'nat_translation_enabled': :'natTranslationEnabled', 'phase_one_config': :'phaseOneConfig', 'phase_two_config': :'phaseTwoConfig', 'dpd_config': :'dpdConfig', 'encryption_domain_config': :'encryptionDomainConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 90 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'routing': :'String', 'ike_version': :'String', 'bgp_session_config': :'OCI::Core::Models::UpdateIPSecTunnelBgpSessionDetails', 'oracle_initiation': :'String', 'nat_translation_enabled': :'String', 'phase_one_config': :'OCI::Core::Models::PhaseOneConfigDetails', 'phase_two_config': :'OCI::Core::Models::PhaseTwoConfigDetails', 'dpd_config': :'OCI::Core::Models::DpdConfig', 'encryption_domain_config': :'OCI::Core::Models::UpdateIPSecTunnelEncryptionDomainDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 225 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && routing == other.routing && ike_version == other.ike_version && bgp_session_config == other.bgp_session_config && oracle_initiation == other.oracle_initiation && nat_translation_enabled == other.nat_translation_enabled && phase_one_config == other.phase_one_config && phase_two_config == other.phase_two_config && dpd_config == other.dpd_config && encryption_domain_config == other.encryption_domain_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 264 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
244 245 246 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 244 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
253 254 255 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 253 def hash [display_name, routing, ike_version, bgp_session_config, oracle_initiation, nat_translation_enabled, phase_one_config, phase_two_config, dpd_config, encryption_domain_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
297 298 299 300 301 302 303 304 305 306 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 297 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
291 292 293 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 291 def to_s to_hash.to_s end |