Class: OCI::Core::Models::UpdateIPSecConnectionTunnelDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateIPSecConnectionTunnelDetails
- Defined in:
- lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb
Overview
UpdateIPSecConnectionTunnelDetails model.
Constant Summary collapse
- ROUTING_ENUM =
[ ROUTING_BGP = 'BGP'.freeze, ROUTING_STATIC = 'STATIC'.freeze, ROUTING_POLICY = 'POLICY'.freeze ].freeze
- IKE_VERSION_ENUM =
[ IKE_VERSION_V1 = 'V1'.freeze, IKE_VERSION_V2 = 'V2'.freeze ].freeze
Instance Attribute Summary collapse
- #bgp_session_config ⇒ OCI::Core::Models::UpdateIPSecTunnelBgpSessionDetails
-
#display_name ⇒ String
A user-friendly name.
- #encryption_domain_config ⇒ OCI::Core::Models::UpdateIPSecTunnelEncryptionDomainDetails
-
#ike_version ⇒ String
Internet Key Exchange protocol version.
-
#routing ⇒ String
The type of routing to use for this tunnel (either BGP dynamic routing or static routing).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateIPSecConnectionTunnelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateIPSecConnectionTunnelDetails
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.routing = attributes[:'routing'] if attributes[:'routing'] self.ike_version = attributes[:'ikeVersion'] if attributes[:'ikeVersion'] raise 'You cannot provide both :ikeVersion and :ike_version' if attributes.key?(:'ikeVersion') && attributes.key?(:'ike_version') self.ike_version = attributes[:'ike_version'] if attributes[:'ike_version'] self.bgp_session_config = attributes[:'bgpSessionConfig'] if attributes[:'bgpSessionConfig'] raise 'You cannot provide both :bgpSessionConfig and :bgp_session_config' if attributes.key?(:'bgpSessionConfig') && attributes.key?(:'bgp_session_config') self.bgp_session_config = attributes[:'bgp_session_config'] if attributes[:'bgp_session_config'] self.encryption_domain_config = attributes[:'encryptionDomainConfig'] if attributes[:'encryptionDomainConfig'] raise 'You cannot provide both :encryptionDomainConfig and :encryption_domain_config' if attributes.key?(:'encryptionDomainConfig') && attributes.key?(:'encryption_domain_config') self.encryption_domain_config = attributes[:'encryption_domain_config'] if attributes[:'encryption_domain_config'] end |
Instance Attribute Details
#bgp_session_config ⇒ OCI::Core::Models::UpdateIPSecTunnelBgpSessionDetails
38 39 40 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 38 def bgp_session_config @bgp_session_config end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
25 26 27 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 25 def display_name @display_name end |
#encryption_domain_config ⇒ OCI::Core::Models::UpdateIPSecTunnelEncryptionDomainDetails
41 42 43 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 41 def encryption_domain_config @encryption_domain_config end |
#ike_version ⇒ String
Internet Key Exchange protocol version.
35 36 37 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 35 def ike_version @ike_version end |
#routing ⇒ String
The type of routing to use for this tunnel (either BGP dynamic routing or static routing).
30 31 32 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 30 def routing @routing end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'routing': :'routing', 'ike_version': :'ikeVersion', 'bgp_session_config': :'bgpSessionConfig', 'encryption_domain_config': :'encryptionDomainConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'routing': :'String', 'ike_version': :'String', 'bgp_session_config': :'OCI::Core::Models::UpdateIPSecTunnelBgpSessionDetails', 'encryption_domain_config': :'OCI::Core::Models::UpdateIPSecTunnelEncryptionDomainDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 136 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && routing == other.routing && ike_version == other.ike_version && bgp_session_config == other.bgp_session_config && encryption_domain_config == other.encryption_domain_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 170 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
150 151 152 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 150 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 159 def hash [display_name, routing, ike_version, bgp_session_config, encryption_domain_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
197 198 199 |
# File 'lib/oci/core/models/update_ip_sec_connection_tunnel_details.rb', line 197 def to_s to_hash.to_s end |