Class: OCI::Core::Models::UpdateIPSecTunnelBgpSessionDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateIPSecTunnelBgpSessionDetails
- Defined in:
- lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb
Overview
UpdateIPSecTunnelBgpSessionDetails model.
Instance Attribute Summary collapse
-
#customer_bgp_asn ⇒ String
The BGP ASN of the network on the CPE end of the BGP session.
-
#customer_interface_ip ⇒ String
The IP address for the CPE end of the inside tunnel interface.
-
#oracle_interface_ip ⇒ String
The IP address for the Oracle end of the inside tunnel interface.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateIPSecTunnelBgpSessionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateIPSecTunnelBgpSessionDetails
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.oracle_interface_ip = attributes[:'oracleInterfaceIp'] if attributes[:'oracleInterfaceIp'] raise 'You cannot provide both :oracleInterfaceIp and :oracle_interface_ip' if attributes.key?(:'oracleInterfaceIp') && attributes.key?(:'oracle_interface_ip') self.oracle_interface_ip = attributes[:'oracle_interface_ip'] if attributes[:'oracle_interface_ip'] self.customer_interface_ip = attributes[:'customerInterfaceIp'] if attributes[:'customerInterfaceIp'] raise 'You cannot provide both :customerInterfaceIp and :customer_interface_ip' if attributes.key?(:'customerInterfaceIp') && attributes.key?(:'customer_interface_ip') self.customer_interface_ip = attributes[:'customer_interface_ip'] if attributes[:'customer_interface_ip'] self.customer_bgp_asn = attributes[:'customerBgpAsn'] if attributes[:'customerBgpAsn'] raise 'You cannot provide both :customerBgpAsn and :customer_bgp_asn' if attributes.key?(:'customerBgpAsn') && attributes.key?(:'customer_bgp_asn') self.customer_bgp_asn = attributes[:'customer_bgp_asn'] if attributes[:'customer_bgp_asn'] end |
Instance Attribute Details
#customer_bgp_asn ⇒ String
The BGP ASN of the network on the CPE end of the BGP session. Can be a 2-byte or 4-byte ASN. Uses "asplain" format.
If you are switching the tunnel from using BGP dynamic routing to static routing, the customerBgpAsn must be null.
Example: 12345 (2-byte) or 1587232876 (4-byte)
57 58 59 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 57 def customer_bgp_asn @customer_bgp_asn end |
#customer_interface_ip ⇒ String
The IP address for the CPE end of the inside tunnel interface.
If the tunnel’s routing attribute is set to BGP (see update_ip_sec_connection_tunnel_details), this IP address is used for the tunnel’s BGP session.
If routing is instead set to STATIC, you can set this IP address to troubleshoot or monitor the tunnel.
The value must be a /30 or /31.
If you are switching the tunnel from using BGP dynamic routing to static routing and want to remove the value for customerInterfaceIp, you can set the value to an empty string.
Example: 10.0.0.5/31
46 47 48 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 46 def customer_interface_ip @customer_interface_ip end |
#oracle_interface_ip ⇒ String
The IP address for the Oracle end of the inside tunnel interface.
If the tunnel’s routing attribute is set to BGP (see update_ip_sec_connection_tunnel_details), this IP address is used for the tunnel’s BGP session.
If routing is instead set to STATIC, you can set this IP address to troubleshoot or monitor the tunnel.
The value must be a /30 or /31.
If you are switching the tunnel from using BGP dynamic routing to static routing and want to remove the value for oracleInterfaceIp, you can set the value to an empty string.
Example: 10.0.0.4/31
27 28 29 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 27 def oracle_interface_ip @oracle_interface_ip end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 60 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'oracle_interface_ip': :'oracleInterfaceIp', 'customer_interface_ip': :'customerInterfaceIp', 'customer_bgp_asn': :'customerBgpAsn' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 71 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'oracle_interface_ip': :'String', 'customer_interface_ip': :'String', 'customer_bgp_asn': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 122 def ==(other) return true if equal?(other) self.class == other.class && oracle_interface_ip == other.oracle_interface_ip && customer_interface_ip == other.customer_interface_ip && customer_bgp_asn == other.customer_bgp_asn end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 143 def hash [oracle_interface_ip, customer_interface_ip, customer_bgp_asn].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/core/models/update_ip_sec_tunnel_bgp_session_details.rb', line 181 def to_s to_hash.to_s end |