Class: OCI::Core::Models::UpdateInstanceShapeConfigDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateInstanceShapeConfigDetails
- Defined in:
- lib/oci/core/models/update_instance_shape_config_details.rb
Overview
The shape configuration requested for the instance. If provided, the instance will be updated with the resources specified. In the case where some properties are missing, the missing values will be set to the default for the provided shape.
Each shape only supports certain configurable values. If the shape is provided and the configuration values are invalid for that new shape, an error will be returned. If no shape is provided and the configuration values are invalid for the instance’s existing shape, an error will be returned.
Constant Summary collapse
- BASELINE_OCPU_UTILIZATION_ENUM =
[ BASELINE_OCPU_UTILIZATION_BASELINE_1_8 = 'BASELINE_1_8'.freeze, BASELINE_OCPU_UTILIZATION_BASELINE_1_2 = 'BASELINE_1_2'.freeze, BASELINE_OCPU_UTILIZATION_BASELINE_1_1 = 'BASELINE_1_1'.freeze ].freeze
Instance Attribute Summary collapse
-
#baseline_ocpu_utilization ⇒ String
The baseline OCPU utilization for a subcore burstable VM instance.
-
#memory_in_gbs ⇒ Float
The total amount of memory available to the instance, in gigabytes.
-
#ocpus ⇒ Float
The total number of OCPUs available to the instance.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateInstanceShapeConfigDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateInstanceShapeConfigDetails
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.ocpus = attributes[:'ocpus'] if attributes[:'ocpus'] self.memory_in_gbs = attributes[:'memoryInGBs'] if attributes[:'memoryInGBs'] raise 'You cannot provide both :memoryInGBs and :memory_in_gbs' if attributes.key?(:'memoryInGBs') && attributes.key?(:'memory_in_gbs') self.memory_in_gbs = attributes[:'memory_in_gbs'] if attributes[:'memory_in_gbs'] self.baseline_ocpu_utilization = attributes[:'baselineOcpuUtilization'] if attributes[:'baselineOcpuUtilization'] raise 'You cannot provide both :baselineOcpuUtilization and :baseline_ocpu_utilization' if attributes.key?(:'baselineOcpuUtilization') && attributes.key?(:'baseline_ocpu_utilization') self.baseline_ocpu_utilization = attributes[:'baseline_ocpu_utilization'] if attributes[:'baseline_ocpu_utilization'] end |
Instance Attribute Details
#baseline_ocpu_utilization ⇒ String
The baseline OCPU utilization for a subcore burstable VM instance. Leave this attribute blank for a non-burstable instance, or explicitly specify non-burstable with BASELINE_1_1.
The following values are supported:
-
BASELINE_1_8- baseline usage is 1/8 of an OCPU. -
BASELINE_1_2- baseline usage is 1/2 of an OCPU. -
BASELINE_1_1- baseline usage is an entire OCPU. This represents a non-burstable instance.
43 44 45 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 43 def baseline_ocpu_utilization @baseline_ocpu_utilization end |
#memory_in_gbs ⇒ Float
The total amount of memory available to the instance, in gigabytes.
32 33 34 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 32 def memory_in_gbs @memory_in_gbs end |
#ocpus ⇒ Float
The total number of OCPUs available to the instance.
27 28 29 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 27 def ocpus @ocpus end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'ocpus': :'ocpus', 'memory_in_gbs': :'memoryInGBs', 'baseline_ocpu_utilization': :'baselineOcpuUtilization' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'ocpus': :'Float', 'memory_in_gbs': :'Float', 'baseline_ocpu_utilization': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 119 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 112 def ==(other) return true if equal?(other) self.class == other.class && ocpus == other.ocpus && memory_in_gbs == other.memory_in_gbs && baseline_ocpu_utilization == other.baseline_ocpu_utilization end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 144 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
124 125 126 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 124 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
133 134 135 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 133 def hash [ocpus, memory_in_gbs, baseline_ocpu_utilization].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
171 172 173 |
# File 'lib/oci/core/models/update_instance_shape_config_details.rb', line 171 def to_s to_hash.to_s end |