Class: OCI::Core::Models::UpdateVirtualCircuitDetails
- Inherits:
-
Object
- Object
- OCI::Core::Models::UpdateVirtualCircuitDetails
- Defined in:
- lib/oci/core/models/update_virtual_circuit_details.rb
Overview
UpdateVirtualCircuitDetails model.
Constant Summary collapse
- ROUTING_POLICY_ENUM =
[ ROUTING_POLICY_ORACLE_SERVICE_NETWORK = 'ORACLE_SERVICE_NETWORK'.freeze, ROUTING_POLICY_REGIONAL = 'REGIONAL'.freeze, ROUTING_POLICY_MARKET_LEVEL = 'MARKET_LEVEL'.freeze, ROUTING_POLICY_GLOBAL = 'GLOBAL'.freeze ].freeze
- PROVIDER_STATE_ENUM =
[ PROVIDER_STATE_ACTIVE = 'ACTIVE'.freeze, PROVIDER_STATE_INACTIVE = 'INACTIVE'.freeze ].freeze
Instance Attribute Summary collapse
-
#bandwidth_shape_name ⇒ String
The provisioned data rate of the connection.
-
#cross_connect_mappings ⇒ Array<OCI::Core::Models::CrossConnectMapping>
An array of mappings, each containing properties for a cross-connect or cross-connect group associated with this virtual circuit.
-
#customer_asn ⇒ Integer
The BGP ASN of the network at the other end of the BGP session from Oracle.
-
#customer_bgp_asn ⇒ Integer
Deprecated.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#gateway_id ⇒ String
The OCID of the Drg that this private virtual circuit uses.
-
#provider_service_key_name ⇒ String
The service key name offered by the provider (if the customer is connecting via a provider).
-
#provider_state ⇒ String
The provider’s state in relation to this virtual circuit.
-
#reference_comment ⇒ String
Provider-supplied reference information about this virtual circuit.
-
#routing_policy ⇒ Array<String>
The routing policy sets how routing information about the Oracle cloud is shared over a public virtual circuit.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateVirtualCircuitDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateVirtualCircuitDetails
Initializes the object
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 184 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.bandwidth_shape_name = attributes[:'bandwidthShapeName'] if attributes[:'bandwidthShapeName'] raise 'You cannot provide both :bandwidthShapeName and :bandwidth_shape_name' if attributes.key?(:'bandwidthShapeName') && attributes.key?(:'bandwidth_shape_name') self.bandwidth_shape_name = attributes[:'bandwidth_shape_name'] if attributes[:'bandwidth_shape_name'] self.cross_connect_mappings = attributes[:'crossConnectMappings'] if attributes[:'crossConnectMappings'] raise 'You cannot provide both :crossConnectMappings and :cross_connect_mappings' if attributes.key?(:'crossConnectMappings') && attributes.key?(:'cross_connect_mappings') self.cross_connect_mappings = attributes[:'cross_connect_mappings'] if attributes[:'cross_connect_mappings'] self.routing_policy = attributes[:'routingPolicy'] if attributes[:'routingPolicy'] raise 'You cannot provide both :routingPolicy and :routing_policy' if attributes.key?(:'routingPolicy') && attributes.key?(:'routing_policy') self.routing_policy = attributes[:'routing_policy'] if attributes[:'routing_policy'] self.customer_bgp_asn = attributes[:'customerBgpAsn'] if attributes[:'customerBgpAsn'] raise 'You cannot provide both :customerBgpAsn and :customer_bgp_asn' if attributes.key?(:'customerBgpAsn') && attributes.key?(:'customer_bgp_asn') self.customer_bgp_asn = attributes[:'customer_bgp_asn'] if attributes[:'customer_bgp_asn'] self.customer_asn = attributes[:'customerAsn'] if attributes[:'customerAsn'] raise 'You cannot provide both :customerAsn and :customer_asn' if attributes.key?(:'customerAsn') && attributes.key?(:'customer_asn') self.customer_asn = attributes[:'customer_asn'] if attributes[:'customer_asn'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.gateway_id = attributes[:'gatewayId'] if attributes[:'gatewayId'] raise 'You cannot provide both :gatewayId and :gateway_id' if attributes.key?(:'gatewayId') && attributes.key?(:'gateway_id') self.gateway_id = attributes[:'gateway_id'] if attributes[:'gateway_id'] self.provider_state = attributes[:'providerState'] if attributes[:'providerState'] raise 'You cannot provide both :providerState and :provider_state' if attributes.key?(:'providerState') && attributes.key?(:'provider_state') self.provider_state = attributes[:'provider_state'] if attributes[:'provider_state'] self.provider_service_key_name = attributes[:'providerServiceKeyName'] if attributes[:'providerServiceKeyName'] raise 'You cannot provide both :providerServiceKeyName and :provider_service_key_name' if attributes.key?(:'providerServiceKeyName') && attributes.key?(:'provider_service_key_name') self.provider_service_key_name = attributes[:'provider_service_key_name'] if attributes[:'provider_service_key_name'] self.reference_comment = attributes[:'referenceComment'] if attributes[:'referenceComment'] raise 'You cannot provide both :referenceComment and :reference_comment' if attributes.key?(:'referenceComment') && attributes.key?(:'reference_comment') self.reference_comment = attributes[:'reference_comment'] if attributes[:'reference_comment'] end |
Instance Attribute Details
#bandwidth_shape_name ⇒ String
The provisioned data rate of the connection. To get a list of the available bandwidth levels (that is, shapes), see list_fast_connect_provider_virtual_circuit_bandwidth_shapes. To be updated only by the customer who owns the virtual circuit.
28 29 30 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 28 def bandwidth_shape_name @bandwidth_shape_name end |
#cross_connect_mappings ⇒ Array<OCI::Core::Models::CrossConnectMapping>
An array of mappings, each containing properties for a cross-connect or cross-connect group associated with this virtual circuit.
The customer and provider can update different properties in the mapping depending on the situation. See the description of the CrossConnectMapping.
38 39 40 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 38 def cross_connect_mappings @cross_connect_mappings end |
#customer_asn ⇒ Integer
The BGP ASN of the network at the other end of the BGP session from Oracle.
If the BGP session is from the customer’s edge router to Oracle, the required value is the customer’s ASN, and it can be updated only by the customer.
If the BGP session is from the provider’s edge router to Oracle, the required value is the provider’s ASN, and it can be updated only by the provider.
Can be a 2-byte or 4-byte ASN. Uses "asplain" format.
68 69 70 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 68 def customer_asn @customer_asn end |
#customer_bgp_asn ⇒ Integer
Deprecated. Instead use customerAsn. If you specify values for both, the request will be rejected.
52 53 54 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 52 def customer_bgp_asn @customer_bgp_asn end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
76 77 78 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 76 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique. Avoid entering confidential information.
To be updated only by the customer who owns the virtual circuit.
84 85 86 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 84 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
92 93 94 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 92 def @freeform_tags end |
#gateway_id ⇒ String
The OCID of the Drg that this private virtual circuit uses.
To be updated only by the customer who owns the virtual circuit.
100 101 102 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 100 def gateway_id @gateway_id end |
#provider_service_key_name ⇒ String
The service key name offered by the provider (if the customer is connecting via a provider).
116 117 118 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 116 def provider_service_key_name @provider_service_key_name end |
#provider_state ⇒ String
The provider’s state in relation to this virtual circuit. Relevant only if the customer is using FastConnect via a provider. ACTIVE means the provider has provisioned the virtual circuit from their end. INACTIVE means the provider has not yet provisioned the virtual circuit, or has de-provisioned it.
To be updated only by the provider.
111 112 113 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 111 def provider_state @provider_state end |
#reference_comment ⇒ String
Provider-supplied reference information about this virtual circuit. Relevant only if the customer is using FastConnect via a provider.
To be updated only by the provider.
124 125 126 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 124 def reference_comment @reference_comment end |
#routing_policy ⇒ Array<String>
The routing policy sets how routing information about the Oracle cloud is shared over a public virtual circuit. Policies available are: ORACLE_SERVICE_NETWORK, REGIONAL, MARKET_LEVEL, and GLOBAL. See [Route Filtering](docs.cloud.oracle.com/iaas/Content/Network/Concepts/routingonprem.htm#route_filtering) for details. By default, routing information is shared for all routes in the same market.
46 47 48 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 46 def routing_policy @routing_policy end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 127 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'bandwidth_shape_name': :'bandwidthShapeName', 'cross_connect_mappings': :'crossConnectMappings', 'routing_policy': :'routingPolicy', 'customer_bgp_asn': :'customerBgpAsn', 'customer_asn': :'customerAsn', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'gateway_id': :'gatewayId', 'provider_state': :'providerState', 'provider_service_key_name': :'providerServiceKeyName', 'reference_comment': :'referenceComment' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 147 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'bandwidth_shape_name': :'String', 'cross_connect_mappings': :'Array<OCI::Core::Models::CrossConnectMapping>', 'routing_policy': :'Array<String>', 'customer_bgp_asn': :'Integer', 'customer_asn': :'Integer', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'gateway_id': :'String', 'provider_state': :'String', 'provider_service_key_name': :'String', 'reference_comment': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 293 def ==(other) return true if equal?(other) self.class == other.class && bandwidth_shape_name == other.bandwidth_shape_name && cross_connect_mappings == other.cross_connect_mappings && routing_policy == other.routing_policy && customer_bgp_asn == other.customer_bgp_asn && customer_asn == other.customer_asn && == other. && display_name == other.display_name && == other. && gateway_id == other.gateway_id && provider_state == other.provider_state && provider_service_key_name == other.provider_service_key_name && reference_comment == other.reference_comment end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 334 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
314 315 316 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 314 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
323 324 325 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 323 def hash [bandwidth_shape_name, cross_connect_mappings, routing_policy, customer_bgp_asn, customer_asn, , display_name, , gateway_id, provider_state, provider_service_key_name, reference_comment].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
367 368 369 370 371 372 373 374 375 376 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 367 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
361 362 363 |
# File 'lib/oci/core/models/update_virtual_circuit_details.rb', line 361 def to_s to_hash.to_s end |