Class: OCI::Core::Models::VirtualCircuit
- Inherits:
-
Object
- Object
- OCI::Core::Models::VirtualCircuit
- Defined in:
- lib/oci/core/models/virtual_circuit.rb
Overview
For use with Oracle Cloud Infrastructure FastConnect.
A virtual circuit is an isolated network path that runs over one or more physical network connections to provide a single, logical connection between the edge router on the customer’s existing network and Oracle Cloud Infrastructure. Private virtual circuits support private peering, and public virtual circuits support public peering. For more information, see [FastConnect Overview](docs.cloud.oracle.com/Content/Network/Concepts/fastconnect.htm).
Each virtual circuit is made up of information shared between a customer, Oracle, and a provider (if the customer is using FastConnect via a provider). Who fills in a given property of a virtual circuit depends on whether the BGP session related to that virtual circuit goes from the customer’s edge router to Oracle, or from the provider’s edge router to Oracle. Also, in the case where the customer is using a provider, values for some of the properties may not be present immediately, but may get filled in as the provider and Oracle each do their part to provision the virtual circuit.
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- BGP_MANAGEMENT_ENUM =
rubocop:disable Metrics/LineLength
[ BGP_MANAGEMENT_CUSTOMER_MANAGED = 'CUSTOMER_MANAGED'.freeze, BGP_MANAGEMENT_PROVIDER_MANAGED = 'PROVIDER_MANAGED'.freeze, BGP_MANAGEMENT_ORACLE_MANAGED = 'ORACLE_MANAGED'.freeze, BGP_MANAGEMENT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- BGP_SESSION_STATE_ENUM =
[ BGP_SESSION_STATE_UP = 'UP'.freeze, BGP_SESSION_STATE_DOWN = 'DOWN'.freeze, BGP_SESSION_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PENDING_PROVIDER = 'PENDING_PROVIDER'.freeze, LIFECYCLE_STATE_VERIFYING = 'VERIFYING'.freeze, LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_PROVISIONED = 'PROVISIONED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- PROVIDER_STATE_ENUM =
[ PROVIDER_STATE_ACTIVE = 'ACTIVE'.freeze, PROVIDER_STATE_INACTIVE = 'INACTIVE'.freeze, PROVIDER_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SERVICE_TYPE_ENUM =
[ SERVICE_TYPE_COLOCATED = 'COLOCATED'.freeze, SERVICE_TYPE_LAYER2 = 'LAYER2'.freeze, SERVICE_TYPE_LAYER3 = 'LAYER3'.freeze, SERVICE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TYPE_ENUM =
[ TYPE_PUBLIC = 'PUBLIC'.freeze, TYPE_PRIVATE = 'PRIVATE'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#bandwidth_shape_name ⇒ String
The provisioned data rate of the connection.
-
#bgp_management ⇒ String
BGP management option.
-
#bgp_session_state ⇒ String
The state of the BGP session associated with the virtual circuit.
-
#compartment_id ⇒ String
The OCID of the compartment containing the virtual circuit.
-
#cross_connect_mappings ⇒ Array<OCI::Core::Models::CrossConnectMapping>
An array of mappings, each containing properties for a cross-connect or cross-connect group that is associated with this virtual circuit.
-
#customer_bgp_asn ⇒ Integer
The BGP ASN of the network at the other end of the BGP session from Oracle.
-
#display_name ⇒ String
A user-friendly name.
-
#gateway_id ⇒ String
The OCID of the customer’s Drg that this virtual circuit uses.
-
#id ⇒ String
The virtual circuit’s Oracle ID (OCID).
-
#lifecycle_state ⇒ String
The virtual circuit’s current state.
-
#oracle_bgp_asn ⇒ Integer
The Oracle BGP ASN.
-
#provider_name ⇒ String
Deprecated.
-
#provider_service_id ⇒ String
The OCID of the service offered by the provider (if the customer is connecting via a provider).
-
#provider_service_name ⇒ String
Deprecated.
-
#provider_state ⇒ String
The provider’s state in relation to this virtual circuit (if the customer is connecting via a provider).
-
#public_prefixes ⇒ Array<String>
For a public virtual circuit.
-
#reference_comment ⇒ String
Provider-supplied reference information about this virtual circuit (if the customer is connecting via a provider).
-
#region ⇒ String
The Oracle Cloud Infrastructure region where this virtual circuit is located.
-
#service_type ⇒ String
Provider service type.
-
#time_created ⇒ DateTime
The date and time the virtual circuit was created, in the format defined by RFC3339.
-
#type ⇒ String
Whether the virtual circuit supports private or public peering.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VirtualCircuit
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ VirtualCircuit
Initializes the object
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 287 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.bandwidth_shape_name = attributes[:'bandwidthShapeName'] if attributes[:'bandwidthShapeName'] raise 'You cannot provide both :bandwidthShapeName and :bandwidth_shape_name' if attributes.key?(:'bandwidthShapeName') && attributes.key?(:'bandwidth_shape_name') self.bandwidth_shape_name = attributes[:'bandwidth_shape_name'] if attributes[:'bandwidth_shape_name'] self.bgp_management = attributes[:'bgpManagement'] if attributes[:'bgpManagement'] raise 'You cannot provide both :bgpManagement and :bgp_management' if attributes.key?(:'bgpManagement') && attributes.key?(:'bgp_management') self.bgp_management = attributes[:'bgp_management'] if attributes[:'bgp_management'] self.bgp_session_state = attributes[:'bgpSessionState'] if attributes[:'bgpSessionState'] raise 'You cannot provide both :bgpSessionState and :bgp_session_state' if attributes.key?(:'bgpSessionState') && attributes.key?(:'bgp_session_state') self.bgp_session_state = attributes[:'bgp_session_state'] if attributes[:'bgp_session_state'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.cross_connect_mappings = attributes[:'crossConnectMappings'] if attributes[:'crossConnectMappings'] raise 'You cannot provide both :crossConnectMappings and :cross_connect_mappings' if attributes.key?(:'crossConnectMappings') && attributes.key?(:'cross_connect_mappings') self.cross_connect_mappings = attributes[:'cross_connect_mappings'] if attributes[:'cross_connect_mappings'] self.customer_bgp_asn = attributes[:'customerBgpAsn'] if attributes[:'customerBgpAsn'] raise 'You cannot provide both :customerBgpAsn and :customer_bgp_asn' if attributes.key?(:'customerBgpAsn') && attributes.key?(:'customer_bgp_asn') self.customer_bgp_asn = attributes[:'customer_bgp_asn'] if attributes[:'customer_bgp_asn'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.gateway_id = attributes[:'gatewayId'] if attributes[:'gatewayId'] raise 'You cannot provide both :gatewayId and :gateway_id' if attributes.key?(:'gatewayId') && attributes.key?(:'gateway_id') self.gateway_id = attributes[:'gateway_id'] if attributes[:'gateway_id'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.oracle_bgp_asn = attributes[:'oracleBgpAsn'] if attributes[:'oracleBgpAsn'] raise 'You cannot provide both :oracleBgpAsn and :oracle_bgp_asn' if attributes.key?(:'oracleBgpAsn') && attributes.key?(:'oracle_bgp_asn') self.oracle_bgp_asn = attributes[:'oracle_bgp_asn'] if attributes[:'oracle_bgp_asn'] self.provider_name = attributes[:'providerName'] if attributes[:'providerName'] raise 'You cannot provide both :providerName and :provider_name' if attributes.key?(:'providerName') && attributes.key?(:'provider_name') self.provider_name = attributes[:'provider_name'] if attributes[:'provider_name'] self.provider_service_id = attributes[:'providerServiceId'] if attributes[:'providerServiceId'] raise 'You cannot provide both :providerServiceId and :provider_service_id' if attributes.key?(:'providerServiceId') && attributes.key?(:'provider_service_id') self.provider_service_id = attributes[:'provider_service_id'] if attributes[:'provider_service_id'] self.provider_service_name = attributes[:'providerServiceName'] if attributes[:'providerServiceName'] raise 'You cannot provide both :providerServiceName and :provider_service_name' if attributes.key?(:'providerServiceName') && attributes.key?(:'provider_service_name') self.provider_service_name = attributes[:'provider_service_name'] if attributes[:'provider_service_name'] self.provider_state = attributes[:'providerState'] if attributes[:'providerState'] raise 'You cannot provide both :providerState and :provider_state' if attributes.key?(:'providerState') && attributes.key?(:'provider_state') self.provider_state = attributes[:'provider_state'] if attributes[:'provider_state'] self.public_prefixes = attributes[:'publicPrefixes'] if attributes[:'publicPrefixes'] raise 'You cannot provide both :publicPrefixes and :public_prefixes' if attributes.key?(:'publicPrefixes') && attributes.key?(:'public_prefixes') self.public_prefixes = attributes[:'public_prefixes'] if attributes[:'public_prefixes'] self.reference_comment = attributes[:'referenceComment'] if attributes[:'referenceComment'] raise 'You cannot provide both :referenceComment and :reference_comment' if attributes.key?(:'referenceComment') && attributes.key?(:'reference_comment') self.reference_comment = attributes[:'reference_comment'] if attributes[:'reference_comment'] self.region = attributes[:'region'] if attributes[:'region'] self.service_type = attributes[:'serviceType'] if attributes[:'serviceType'] raise 'You cannot provide both :serviceType and :service_type' if attributes.key?(:'serviceType') && attributes.key?(:'service_type') self.service_type = attributes[:'service_type'] if attributes[:'service_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.type = attributes[:'type'] if attributes[:'type'] end |
Instance Attribute Details
#bandwidth_shape_name ⇒ String
The provisioned data rate of the connection. To get a list of the available bandwidth levels (that is, shapes), see list_fast_connect_provider_virtual_circuit_bandwidth_shapes.
Example: ‘10 Gbps`
83 84 85 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 83 def bandwidth_shape_name @bandwidth_shape_name end |
#bgp_management ⇒ String
BGP management option.
88 89 90 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 88 def bgp_management @bgp_management end |
#bgp_session_state ⇒ String
The state of the BGP session associated with the virtual circuit.
92 93 94 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 92 def bgp_session_state @bgp_session_state end |
#compartment_id ⇒ String
The OCID of the compartment containing the virtual circuit.
96 97 98 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 96 def compartment_id @compartment_id end |
#cross_connect_mappings ⇒ Array<OCI::Core::Models::CrossConnectMapping>
An array of mappings, each containing properties for a cross-connect or cross-connect group that is associated with this virtual circuit.
103 104 105 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 103 def cross_connect_mappings @cross_connect_mappings end |
#customer_bgp_asn ⇒ Integer
The BGP ASN of the network at the other end of the BGP session from Oracle. If the session is between the customer’s edge router and Oracle, the value is the customer’s ASN. If the BGP session is between the provider’s edge router and Oracle, the value is the provider’s ASN.
112 113 114 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 112 def customer_bgp_asn @customer_bgp_asn end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
118 119 120 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 118 def display_name @display_name end |
#gateway_id ⇒ String
The OCID of the customer’s Drg that this virtual circuit uses. Applicable only to private virtual circuits.
124 125 126 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 124 def gateway_id @gateway_id end |
#id ⇒ String
The virtual circuit’s Oracle ID (OCID).
128 129 130 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 128 def id @id end |
#lifecycle_state ⇒ String
The virtual circuit’s current state. For information about the different states, see [FastConnect Overview](docs.cloud.oracle.com/Content/Network/Concepts/fastconnect.htm).
135 136 137 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 135 def lifecycle_state @lifecycle_state end |
#oracle_bgp_asn ⇒ Integer
The Oracle BGP ASN.
139 140 141 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 139 def oracle_bgp_asn @oracle_bgp_asn end |
#provider_name ⇒ String
Deprecated. Instead use providerServiceId.
144 145 146 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 144 def provider_name @provider_name end |
#provider_service_id ⇒ String
The OCID of the service offered by the provider (if the customer is connecting via a provider).
149 150 151 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 149 def provider_service_id @provider_service_id end |
#provider_service_name ⇒ String
Deprecated. Instead use providerServiceId.
154 155 156 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 154 def provider_service_name @provider_service_name end |
#provider_state ⇒ String
The provider’s state in relation to this virtual circuit (if the customer is connecting via a provider). ACTIVE means the provider has provisioned the virtual circuit from their end. INACTIVE means the provider has not yet provisioned the virtual circuit, or has de-provisioned it.
163 164 165 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 163 def provider_state @provider_state end |
#public_prefixes ⇒ Array<String>
For a public virtual circuit. The public IP prefixes (CIDRs) the customer wants to advertise across the connection. Each prefix must be /31 or less specific.
169 170 171 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 169 def public_prefixes @public_prefixes end |
#reference_comment ⇒ String
Provider-supplied reference information about this virtual circuit (if the customer is connecting via a provider).
175 176 177 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 175 def reference_comment @reference_comment end |
#region ⇒ String
The Oracle Cloud Infrastructure region where this virtual circuit is located.
181 182 183 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 181 def region @region end |
#service_type ⇒ String
Provider service type.
186 187 188 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 186 def service_type @service_type end |
#time_created ⇒ DateTime
The date and time the virtual circuit was created, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
194 195 196 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 194 def time_created @time_created end |
#type ⇒ String
Whether the virtual circuit supports private or public peering. For more information, see [FastConnect Overview](docs.cloud.oracle.com/Content/Network/Concepts/fastconnect.htm).
200 201 202 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 200 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 203 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'bandwidth_shape_name': :'bandwidthShapeName', 'bgp_management': :'bgpManagement', 'bgp_session_state': :'bgpSessionState', 'compartment_id': :'compartmentId', 'cross_connect_mappings': :'crossConnectMappings', 'customer_bgp_asn': :'customerBgpAsn', 'display_name': :'displayName', 'gateway_id': :'gatewayId', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'oracle_bgp_asn': :'oracleBgpAsn', 'provider_name': :'providerName', 'provider_service_id': :'providerServiceId', 'provider_service_name': :'providerServiceName', 'provider_state': :'providerState', 'public_prefixes': :'publicPrefixes', 'reference_comment': :'referenceComment', 'region': :'region', 'service_type': :'serviceType', 'time_created': :'timeCreated', 'type': :'type' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 232 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'bandwidth_shape_name': :'String', 'bgp_management': :'String', 'bgp_session_state': :'String', 'compartment_id': :'String', 'cross_connect_mappings': :'Array<OCI::Core::Models::CrossConnectMapping>', 'customer_bgp_asn': :'Integer', 'display_name': :'String', 'gateway_id': :'String', 'id': :'String', 'lifecycle_state': :'String', 'oracle_bgp_asn': :'Integer', 'provider_name': :'String', 'provider_service_id': :'String', 'provider_service_name': :'String', 'provider_state': :'String', 'public_prefixes': :'Array<String>', 'reference_comment': :'String', 'region': :'String', 'service_type': :'String', 'time_created': :'DateTime', 'type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 505 def ==(other) return true if equal?(other) self.class == other.class && bandwidth_shape_name == other.bandwidth_shape_name && bgp_management == other.bgp_management && bgp_session_state == other.bgp_session_state && compartment_id == other.compartment_id && cross_connect_mappings == other.cross_connect_mappings && customer_bgp_asn == other.customer_bgp_asn && display_name == other.display_name && gateway_id == other.gateway_id && id == other.id && lifecycle_state == other.lifecycle_state && oracle_bgp_asn == other.oracle_bgp_asn && provider_name == other.provider_name && provider_service_id == other.provider_service_id && provider_service_name == other.provider_service_name && provider_state == other.provider_state && public_prefixes == other.public_prefixes && reference_comment == other.reference_comment && region == other.region && service_type == other.service_type && time_created == other.time_created && type == other.type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 555 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
535 536 537 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 535 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
544 545 546 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 544 def hash [bandwidth_shape_name, bgp_management, bgp_session_state, compartment_id, cross_connect_mappings, customer_bgp_asn, display_name, gateway_id, id, lifecycle_state, oracle_bgp_asn, provider_name, provider_service_id, provider_service_name, provider_state, public_prefixes, reference_comment, region, service_type, time_created, type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
588 589 590 591 592 593 594 595 596 597 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 588 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
582 583 584 |
# File 'lib/oci/core/models/virtual_circuit.rb', line 582 def to_s to_hash.to_s end |