Class: OCI::DataCatalog::Models::Attribute
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::Attribute
- Defined in:
- lib/oci/data_catalog/models/attribute.rb
Overview
Details of an entity attribute. An attribute of a data entity describing an item of data, with a name and data type. Synonymous with ‘column’ in a database.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ASSOCIATED_RULE_TYPES_ENUM =
[ ASSOCIATED_RULE_TYPES_PRIMARYKEY = 'PRIMARYKEY'.freeze, ASSOCIATED_RULE_TYPES_FOREIGNKEY = 'FOREIGNKEY'.freeze, ASSOCIATED_RULE_TYPES_UNIQUEKEY = 'UNIQUEKEY'.freeze, ASSOCIATED_RULE_TYPES_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#associated_rule_types ⇒ Array<String>
Rule types associated with attribute.
-
#business_name ⇒ String
Optional user friendly business name of the attribute.
-
#created_by_id ⇒ String
OCID of the user who created this attribute in the data catalog.
-
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertyGetUsage>
The list of customized properties along with the values for this object.
-
#datatype_entity_key ⇒ String
Entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.
-
#description ⇒ String
Detailed description of the attribute.
-
#display_name ⇒ String
A user-friendly display name.
-
#entity_key ⇒ String
The unique key of the parent entity.
-
#external_data_type ⇒ String
Data type of the attribute as defined in the external system.
-
#external_datatype_entity_key ⇒ String
External entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.
-
#external_key ⇒ String
Unique external key of this attribute in the external source system.
-
#external_parent_attribute_key ⇒ String
External attribute key that represents the parent attribute of this attribute , applicable if the parent attribute is of complex type.
-
#is_incremental_data ⇒ BOOLEAN
Property that identifies if this attribute can be used as a watermark to extract incremental data.
-
#is_nullable ⇒ BOOLEAN
Property that identifies if this attribute can be assigned null values.
-
#key ⇒ String
[Required] Unique attribute key that is immutable.
-
#length ⇒ Integer
Max allowed length of the attribute value.
-
#lifecycle_state ⇒ String
State of the attribute.
-
#max_collection_count ⇒ Integer
The maximum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.
-
#min_collection_count ⇒ Integer
The minimum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.
-
#parent_attribute_key ⇒ String
Attribute key that represents the parent attribute of this attribute , applicable if the parent attribute is of complex datatype.
-
#path ⇒ String
Full path of the attribute.
-
#position ⇒ Integer
Position of the attribute in the record definition.
-
#precision ⇒ Integer
Precision of the attribute value usually applies to float data type.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the attribute type.
-
#scale ⇒ Integer
Scale of the attribute value usually applies to float data type.
-
#time_created ⇒ DateTime
The date and time the attribute was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_external ⇒ DateTime
Last modified timestamp of this object in the external system.
-
#time_updated ⇒ DateTime
The last time that any change was made to the attribute.
-
#updated_by_id ⇒ String
OCID of the user who modified this attribute in the data catalog.
-
#uri ⇒ String
URI to the attribute instance in the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Attribute
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Attribute
Initializes the object
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 281 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.business_name = attributes[:'businessName'] if attributes[:'businessName'] raise 'You cannot provide both :businessName and :business_name' if attributes.key?(:'businessName') && attributes.key?(:'business_name') self.business_name = attributes[:'business_name'] if attributes[:'business_name'] self.description = attributes[:'description'] if attributes[:'description'] self.entity_key = attributes[:'entityKey'] if attributes[:'entityKey'] raise 'You cannot provide both :entityKey and :entity_key' if attributes.key?(:'entityKey') && attributes.key?(:'entity_key') self.entity_key = attributes[:'entity_key'] if attributes[:'entity_key'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.created_by_id = attributes[:'createdById'] if attributes[:'createdById'] raise 'You cannot provide both :createdById and :created_by_id' if attributes.key?(:'createdById') && attributes.key?(:'created_by_id') self.created_by_id = attributes[:'created_by_id'] if attributes[:'created_by_id'] self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById'] raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id') self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id'] self.external_data_type = attributes[:'externalDataType'] if attributes[:'externalDataType'] raise 'You cannot provide both :externalDataType and :external_data_type' if attributes.key?(:'externalDataType') && attributes.key?(:'external_data_type') self.external_data_type = attributes[:'external_data_type'] if attributes[:'external_data_type'] self.external_key = attributes[:'externalKey'] if attributes[:'externalKey'] raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key') self.external_key = attributes[:'external_key'] if attributes[:'external_key'] self.is_incremental_data = attributes[:'isIncrementalData'] unless attributes[:'isIncrementalData'].nil? raise 'You cannot provide both :isIncrementalData and :is_incremental_data' if attributes.key?(:'isIncrementalData') && attributes.key?(:'is_incremental_data') self.is_incremental_data = attributes[:'is_incremental_data'] unless attributes[:'is_incremental_data'].nil? self.is_nullable = attributes[:'isNullable'] unless attributes[:'isNullable'].nil? raise 'You cannot provide both :isNullable and :is_nullable' if attributes.key?(:'isNullable') && attributes.key?(:'is_nullable') self.is_nullable = attributes[:'is_nullable'] unless attributes[:'is_nullable'].nil? self.min_collection_count = attributes[:'minCollectionCount'] if attributes[:'minCollectionCount'] raise 'You cannot provide both :minCollectionCount and :min_collection_count' if attributes.key?(:'minCollectionCount') && attributes.key?(:'min_collection_count') self.min_collection_count = attributes[:'min_collection_count'] if attributes[:'min_collection_count'] self.max_collection_count = attributes[:'maxCollectionCount'] if attributes[:'maxCollectionCount'] raise 'You cannot provide both :maxCollectionCount and :max_collection_count' if attributes.key?(:'maxCollectionCount') && attributes.key?(:'max_collection_count') self.max_collection_count = attributes[:'max_collection_count'] if attributes[:'max_collection_count'] self.datatype_entity_key = attributes[:'datatypeEntityKey'] if attributes[:'datatypeEntityKey'] raise 'You cannot provide both :datatypeEntityKey and :datatype_entity_key' if attributes.key?(:'datatypeEntityKey') && attributes.key?(:'datatype_entity_key') self.datatype_entity_key = attributes[:'datatype_entity_key'] if attributes[:'datatype_entity_key'] self.external_datatype_entity_key = attributes[:'externalDatatypeEntityKey'] if attributes[:'externalDatatypeEntityKey'] raise 'You cannot provide both :externalDatatypeEntityKey and :external_datatype_entity_key' if attributes.key?(:'externalDatatypeEntityKey') && attributes.key?(:'external_datatype_entity_key') self.external_datatype_entity_key = attributes[:'external_datatype_entity_key'] if attributes[:'external_datatype_entity_key'] self.parent_attribute_key = attributes[:'parentAttributeKey'] if attributes[:'parentAttributeKey'] raise 'You cannot provide both :parentAttributeKey and :parent_attribute_key' if attributes.key?(:'parentAttributeKey') && attributes.key?(:'parent_attribute_key') self.parent_attribute_key = attributes[:'parent_attribute_key'] if attributes[:'parent_attribute_key'] self.external_parent_attribute_key = attributes[:'externalParentAttributeKey'] if attributes[:'externalParentAttributeKey'] raise 'You cannot provide both :externalParentAttributeKey and :external_parent_attribute_key' if attributes.key?(:'externalParentAttributeKey') && attributes.key?(:'external_parent_attribute_key') self.external_parent_attribute_key = attributes[:'external_parent_attribute_key'] if attributes[:'external_parent_attribute_key'] self.length = attributes[:'length'] if attributes[:'length'] self.position = attributes[:'position'] if attributes[:'position'] self.precision = attributes[:'precision'] if attributes[:'precision'] self.scale = attributes[:'scale'] if attributes[:'scale'] self.time_external = attributes[:'timeExternal'] if attributes[:'timeExternal'] raise 'You cannot provide both :timeExternal and :time_external' if attributes.key?(:'timeExternal') && attributes.key?(:'time_external') self.time_external = attributes[:'time_external'] if attributes[:'time_external'] self.uri = attributes[:'uri'] if attributes[:'uri'] self.path = attributes[:'path'] if attributes[:'path'] self.custom_property_members = attributes[:'customPropertyMembers'] if attributes[:'customPropertyMembers'] raise 'You cannot provide both :customPropertyMembers and :custom_property_members' if attributes.key?(:'customPropertyMembers') && attributes.key?(:'custom_property_members') self.custom_property_members = attributes[:'custom_property_members'] if attributes[:'custom_property_members'] self.properties = attributes[:'properties'] if attributes[:'properties'] self.associated_rule_types = attributes[:'associatedRuleTypes'] if attributes[:'associatedRuleTypes'] raise 'You cannot provide both :associatedRuleTypes and :associated_rule_types' if attributes.key?(:'associatedRuleTypes') && attributes.key?(:'associated_rule_types') self.associated_rule_types = attributes[:'associated_rule_types'] if attributes[:'associated_rule_types'] end |
Instance Attribute Details
#associated_rule_types ⇒ Array<String>
Rule types associated with attribute.
167 168 169 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 167 def associated_rule_types @associated_rule_types end |
#business_name ⇒ String
Optional user friendly business name of the attribute. If set, this supplements the harvested display name of the object.
44 45 46 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 44 def business_name @business_name end |
#created_by_id ⇒ String
OCID of the user who created this attribute in the data catalog.
71 72 73 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 71 def created_by_id @created_by_id end |
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertyGetUsage>
The list of customized properties along with the values for this object
154 155 156 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 154 def custom_property_members @custom_property_members end |
#datatype_entity_key ⇒ String
Entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.
110 111 112 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 110 def datatype_entity_key @datatype_entity_key end |
#description ⇒ String
Detailed description of the attribute.
48 49 50 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 48 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
40 41 42 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 40 def display_name @display_name end |
#entity_key ⇒ String
The unique key of the parent entity.
52 53 54 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 52 def entity_key @entity_key end |
#external_data_type ⇒ String
Data type of the attribute as defined in the external system. Type mapping across systems can be achieved through term associations across domains in the ontology. The attribute can also be tagged to the datatype in the domain ontology to resolve any ambiguity arising from type name similarity that can occur with user defined types.
83 84 85 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 83 def external_data_type @external_data_type end |
#external_datatype_entity_key ⇒ String
External entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.
114 115 116 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 114 def external_datatype_entity_key @external_datatype_entity_key end |
#external_key ⇒ String
Unique external key of this attribute in the external source system.
87 88 89 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 87 def external_key @external_key end |
#external_parent_attribute_key ⇒ String
External attribute key that represents the parent attribute of this attribute , applicable if the parent attribute is of complex type.
122 123 124 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 122 def external_parent_attribute_key @external_parent_attribute_key end |
#is_incremental_data ⇒ BOOLEAN
Property that identifies if this attribute can be used as a watermark to extract incremental data.
91 92 93 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 91 def is_incremental_data @is_incremental_data end |
#is_nullable ⇒ BOOLEAN
Property that identifies if this attribute can be assigned null values.
95 96 97 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 95 def is_nullable @is_nullable end |
#key ⇒ String
[Required] Unique attribute key that is immutable.
34 35 36 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 34 def key @key end |
#length ⇒ Integer
Max allowed length of the attribute value.
126 127 128 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 126 def length @length end |
#lifecycle_state ⇒ String
State of the attribute.
56 57 58 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 56 def lifecycle_state @lifecycle_state end |
#max_collection_count ⇒ Integer
The maximum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type. For type specifications in systems that specify only "capacity" without upper or lower bound , this property can also be used to just mean "capacity". Some examples are Varray size in Oracle , Occurs Clause in Cobol , capacity in XmlSchemaObjectCollection , maxOccurs in Xml , maxItems in Json
106 107 108 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 106 def max_collection_count @max_collection_count end |
#min_collection_count ⇒ Integer
The minimum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.
99 100 101 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 99 def min_collection_count @min_collection_count end |
#parent_attribute_key ⇒ String
Attribute key that represents the parent attribute of this attribute , applicable if the parent attribute is of complex datatype.
118 119 120 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 118 def parent_attribute_key @parent_attribute_key end |
#path ⇒ String
Full path of the attribute.
150 151 152 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 150 def path @path end |
#position ⇒ Integer
Position of the attribute in the record definition.
130 131 132 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 130 def position @position end |
#precision ⇒ Integer
Precision of the attribute value usually applies to float data type.
134 135 136 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 134 def precision @precision end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the attribute type. Each attribute type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most attributes have required properties within the "default" category. Example: ‘{ "default": { "key1": "value1"}}`
163 164 165 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 163 def properties @properties end |
#scale ⇒ Integer
Scale of the attribute value usually applies to float data type.
138 139 140 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 138 def scale @scale end |
#time_created ⇒ DateTime
The date and time the attribute was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
62 63 64 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 62 def time_created @time_created end |
#time_external ⇒ DateTime
Last modified timestamp of this object in the external system.
142 143 144 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 142 def time_external @time_external end |
#time_updated ⇒ DateTime
The last time that any change was made to the attribute. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
67 68 69 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 67 def time_updated @time_updated end |
#updated_by_id ⇒ String
OCID of the user who modified this attribute in the data catalog.
75 76 77 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 75 def updated_by_id @updated_by_id end |
#uri ⇒ String
URI to the attribute instance in the API.
146 147 148 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 146 def uri @uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 170 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'business_name': :'businessName', 'description': :'description', 'entity_key': :'entityKey', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'created_by_id': :'createdById', 'updated_by_id': :'updatedById', 'external_data_type': :'externalDataType', 'external_key': :'externalKey', 'is_incremental_data': :'isIncrementalData', 'is_nullable': :'isNullable', 'min_collection_count': :'minCollectionCount', 'max_collection_count': :'maxCollectionCount', 'datatype_entity_key': :'datatypeEntityKey', 'external_datatype_entity_key': :'externalDatatypeEntityKey', 'parent_attribute_key': :'parentAttributeKey', 'external_parent_attribute_key': :'externalParentAttributeKey', 'length': :'length', 'position': :'position', 'precision': :'precision', 'scale': :'scale', 'time_external': :'timeExternal', 'uri': :'uri', 'path': :'path', 'custom_property_members': :'customPropertyMembers', 'properties': :'properties', 'associated_rule_types': :'associatedRuleTypes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 208 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'business_name': :'String', 'description': :'String', 'entity_key': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'created_by_id': :'String', 'updated_by_id': :'String', 'external_data_type': :'String', 'external_key': :'String', 'is_incremental_data': :'BOOLEAN', 'is_nullable': :'BOOLEAN', 'min_collection_count': :'Integer', 'max_collection_count': :'Integer', 'datatype_entity_key': :'String', 'external_datatype_entity_key': :'String', 'parent_attribute_key': :'String', 'external_parent_attribute_key': :'String', 'length': :'Integer', 'position': :'Integer', 'precision': :'Integer', 'scale': :'Integer', 'time_external': :'DateTime', 'uri': :'String', 'path': :'String', 'custom_property_members': :'Array<OCI::DataCatalog::Models::CustomPropertyGetUsage>', 'properties': :'Hash<String, Hash<String, String>>', 'associated_rule_types': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 472 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && business_name == other.business_name && description == other.description && entity_key == other.entity_key && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated && created_by_id == other.created_by_id && updated_by_id == other.updated_by_id && external_data_type == other.external_data_type && external_key == other.external_key && is_incremental_data == other.is_incremental_data && is_nullable == other.is_nullable && min_collection_count == other.min_collection_count && max_collection_count == other.max_collection_count && datatype_entity_key == other.datatype_entity_key && external_datatype_entity_key == other.external_datatype_entity_key && parent_attribute_key == other.parent_attribute_key && external_parent_attribute_key == other.external_parent_attribute_key && length == other.length && position == other.position && precision == other.precision && scale == other.scale && time_external == other.time_external && uri == other.uri && path == other.path && custom_property_members == other.custom_property_members && properties == other.properties && associated_rule_types == other.associated_rule_types end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 531 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
511 512 513 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 511 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
520 521 522 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 520 def hash [key, display_name, business_name, description, entity_key, lifecycle_state, time_created, time_updated, created_by_id, updated_by_id, external_data_type, external_key, is_incremental_data, is_nullable, min_collection_count, max_collection_count, datatype_entity_key, external_datatype_entity_key, parent_attribute_key, external_parent_attribute_key, length, position, precision, scale, time_external, uri, path, custom_property_members, properties, associated_rule_types].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
564 565 566 567 568 569 570 571 572 573 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 564 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
558 559 560 |
# File 'lib/oci/data_catalog/models/attribute.rb', line 558 def to_s to_hash.to_s end |