Class: OCI::DataCatalog::Models::CreateFolderDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::CreateFolderDetails
- Defined in:
- lib/oci/data_catalog/models/create_folder_details.rb
Overview
Properties used in folder create operations.
Constant Summary collapse
- HARVEST_STATUS_ENUM =
[ HARVEST_STATUS_COMPLETE = 'COMPLETE'.freeze, HARVEST_STATUS_ERROR = 'ERROR'.freeze, HARVEST_STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze, HARVEST_STATUS_DEFERRED = 'DEFERRED'.freeze ].freeze
Instance Attribute Summary collapse
-
#business_name ⇒ String
Optional user friendly business name of the folder.
-
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertySetUsage>
The list of customized properties along with the values for this object.
-
#description ⇒ String
Detailed description of a folder.
-
#display_name ⇒ String
[Required] A user-friendly display name.
-
#harvest_status ⇒ String
Folder harvesting status.
-
#last_job_key ⇒ String
The job key of the harvest process that updated the folder definition from the source system.
-
#parent_folder_key ⇒ String
The key of the containing folder or null if there isn’t a parent folder.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the folder type.
-
#time_external ⇒ DateTime
[Required] Last modified timestamp of this object in the external system.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateFolderDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateFolderDetails
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 112 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.business_name = attributes[:'businessName'] if attributes[:'businessName'] raise 'You cannot provide both :businessName and :business_name' if attributes.key?(:'businessName') && attributes.key?(:'business_name') self.business_name = attributes[:'business_name'] if attributes[:'business_name'] self.description = attributes[:'description'] if attributes[:'description'] self.custom_property_members = attributes[:'customPropertyMembers'] if attributes[:'customPropertyMembers'] raise 'You cannot provide both :customPropertyMembers and :custom_property_members' if attributes.key?(:'customPropertyMembers') && attributes.key?(:'custom_property_members') self.custom_property_members = attributes[:'custom_property_members'] if attributes[:'custom_property_members'] self.properties = attributes[:'properties'] if attributes[:'properties'] self.parent_folder_key = attributes[:'parentFolderKey'] if attributes[:'parentFolderKey'] raise 'You cannot provide both :parentFolderKey and :parent_folder_key' if attributes.key?(:'parentFolderKey') && attributes.key?(:'parent_folder_key') self.parent_folder_key = attributes[:'parent_folder_key'] if attributes[:'parent_folder_key'] self.time_external = attributes[:'timeExternal'] if attributes[:'timeExternal'] raise 'You cannot provide both :timeExternal and :time_external' if attributes.key?(:'timeExternal') && attributes.key?(:'time_external') self.time_external = attributes[:'time_external'] if attributes[:'time_external'] self.last_job_key = attributes[:'lastJobKey'] if attributes[:'lastJobKey'] raise 'You cannot provide both :lastJobKey and :last_job_key' if attributes.key?(:'lastJobKey') && attributes.key?(:'last_job_key') self.last_job_key = attributes[:'last_job_key'] if attributes[:'last_job_key'] self.harvest_status = attributes[:'harvestStatus'] if attributes[:'harvestStatus'] raise 'You cannot provide both :harvestStatus and :harvest_status' if attributes.key?(:'harvestStatus') && attributes.key?(:'harvest_status') self.harvest_status = attributes[:'harvest_status'] if attributes[:'harvest_status'] end |
Instance Attribute Details
#business_name ⇒ String
Optional user friendly business name of the folder. If set, this supplements the harvested display name of the object.
25 26 27 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 25 def business_name @business_name end |
#custom_property_members ⇒ Array<OCI::DataCatalog::Models::CustomPropertySetUsage>
The list of customized properties along with the values for this object
33 34 35 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 33 def custom_property_members @custom_property_members end |
#description ⇒ String
Detailed description of a folder.
29 30 31 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 29 def description @description end |
#display_name ⇒ String
[Required] A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
21 22 23 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 21 def display_name @display_name end |
#harvest_status ⇒ String
Folder harvesting status.
61 62 63 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 61 def harvest_status @harvest_status end |
#last_job_key ⇒ String
The job key of the harvest process that updated the folder definition from the source system.
57 58 59 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 57 def last_job_key @last_job_key end |
#parent_folder_key ⇒ String
The key of the containing folder or null if there isn’t a parent folder.
49 50 51 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 49 def parent_folder_key @parent_folder_key end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the folder type. Each folder type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most folders have required properties within the "default" category. To determine the set of optional and required properties for a folder type, a query can be done on ‘/types?type=folder’ that returns a collection of all folder types. The appropriate folder type, which includes definitions of all of it’s properties, can be identified from this collection. Example: ‘{ "default": { "key1": "value1"}}`
45 46 47 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 45 def properties @properties end |
#time_external ⇒ DateTime
[Required] Last modified timestamp of this object in the external system.
53 54 55 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 53 def time_external @time_external end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 64 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'business_name': :'businessName', 'description': :'description', 'custom_property_members': :'customPropertyMembers', 'properties': :'properties', 'parent_folder_key': :'parentFolderKey', 'time_external': :'timeExternal', 'last_job_key': :'lastJobKey', 'harvest_status': :'harvestStatus' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'business_name': :'String', 'description': :'String', 'custom_property_members': :'Array<OCI::DataCatalog::Models::CustomPropertySetUsage>', 'properties': :'Hash<String, Hash<String, String>>', 'parent_folder_key': :'String', 'time_external': :'DateTime', 'last_job_key': :'String', 'harvest_status': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 180 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && business_name == other.business_name && description == other.description && custom_property_members == other.custom_property_members && properties == other.properties && parent_folder_key == other.parent_folder_key && time_external == other.time_external && last_job_key == other.last_job_key && harvest_status == other.harvest_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 218 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
198 199 200 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 198 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 207 def hash [display_name, business_name, description, custom_property_members, properties, parent_folder_key, time_external, last_job_key, harvest_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 251 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
245 246 247 |
# File 'lib/oci/data_catalog/models/create_folder_details.rb', line 245 def to_s to_hash.to_s end |