Class: OCI::DataCatalog::Models::CreateJobDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::CreateJobDetails
- Defined in:
- lib/oci/data_catalog/models/create_job_details.rb
Overview
Properties used to create a job.
Instance Attribute Summary collapse
-
#connection_key ⇒ String
The key of the connection used by the job.
-
#description ⇒ String
Detailed description of the job.
-
#display_name ⇒ String
**[Required]** A user-friendly display name.
-
#job_definition_key ⇒ String
**[Required]** The unique key of the job definition that defined the scope of this job.
-
#schedule_cron_expression ⇒ String
Interval on which the job will be run.
-
#time_schedule_begin ⇒ DateTime
Date that the schedule should be operational.
-
#time_schedule_end ⇒ DateTime
Date that the schedule should end from being operational.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateJobDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateJobDetails
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 87 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.schedule_cron_expression = attributes[:'scheduleCronExpression'] if attributes[:'scheduleCronExpression'] raise 'You cannot provide both :scheduleCronExpression and :schedule_cron_expression' if attributes.key?(:'scheduleCronExpression') && attributes.key?(:'schedule_cron_expression') self.schedule_cron_expression = attributes[:'schedule_cron_expression'] if attributes[:'schedule_cron_expression'] self.time_schedule_begin = attributes[:'timeScheduleBegin'] if attributes[:'timeScheduleBegin'] raise 'You cannot provide both :timeScheduleBegin and :time_schedule_begin' if attributes.key?(:'timeScheduleBegin') && attributes.key?(:'time_schedule_begin') self.time_schedule_begin = attributes[:'time_schedule_begin'] if attributes[:'time_schedule_begin'] self.time_schedule_end = attributes[:'timeScheduleEnd'] if attributes[:'timeScheduleEnd'] raise 'You cannot provide both :timeScheduleEnd and :time_schedule_end' if attributes.key?(:'timeScheduleEnd') && attributes.key?(:'time_schedule_end') self.time_schedule_end = attributes[:'time_schedule_end'] if attributes[:'time_schedule_end'] self.connection_key = attributes[:'connectionKey'] if attributes[:'connectionKey'] raise 'You cannot provide both :connectionKey and :connection_key' if attributes.key?(:'connectionKey') && attributes.key?(:'connection_key') self.connection_key = attributes[:'connection_key'] if attributes[:'connection_key'] self.job_definition_key = attributes[:'jobDefinitionKey'] if attributes[:'jobDefinitionKey'] raise 'You cannot provide both :jobDefinitionKey and :job_definition_key' if attributes.key?(:'jobDefinitionKey') && attributes.key?(:'job_definition_key') self.job_definition_key = attributes[:'job_definition_key'] if attributes[:'job_definition_key'] end |
Instance Attribute Details
#connection_key ⇒ String
The key of the connection used by the job. This connection will override the default connection specified in the associated job definition. All executions will use this connection.
38 39 40 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 38 def connection_key @connection_key end |
#description ⇒ String
Detailed description of the job.
18 19 20 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 18 def description @description end |
#display_name ⇒ String
**[Required]** A user-friendly display name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
14 15 16 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 14 def display_name @display_name end |
#job_definition_key ⇒ String
**[Required]** The unique key of the job definition that defined the scope of this job.
42 43 44 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 42 def job_definition_key @job_definition_key end |
#schedule_cron_expression ⇒ String
Interval on which the job will be run. Value is specified as a cron-supported time specification "nickname". The following subset of those is supported: @monthly, @weekly, @daily, @hourly.
24 25 26 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 24 def schedule_cron_expression @schedule_cron_expression end |
#time_schedule_begin ⇒ DateTime
Date that the schedule should be operational. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
28 29 30 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 28 def time_schedule_begin @time_schedule_begin end |
#time_schedule_end ⇒ DateTime
Date that the schedule should end from being operational. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
32 33 34 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 32 def time_schedule_end @time_schedule_end end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'schedule_cron_expression': :'scheduleCronExpression', 'time_schedule_begin': :'timeScheduleBegin', 'time_schedule_end': :'timeScheduleEnd', 'connection_key': :'connectionKey', 'job_definition_key': :'jobDefinitionKey' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 60 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'schedule_cron_expression': :'String', 'time_schedule_begin': :'DateTime', 'time_schedule_end': :'DateTime', 'connection_key': :'String', 'job_definition_key': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 139 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && schedule_cron_expression == other.schedule_cron_expression && time_schedule_begin == other.time_schedule_begin && time_schedule_end == other.time_schedule_end && connection_key == other.connection_key && job_definition_key == other.job_definition_key end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 175 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
155 156 157 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 155 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 164 def hash [display_name, description, schedule_cron_expression, time_schedule_begin, time_schedule_end, connection_key, job_definition_key].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
202 203 204 |
# File 'lib/oci/data_catalog/models/create_job_details.rb', line 202 def to_s to_hash.to_s end |