Class: OCI::DataCatalog::Models::CreateJobExecutionDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::CreateJobExecutionDetails
- Defined in:
- lib/oci/data_catalog/models/create_job_execution_details.rb
Overview
Properties for creating a new job execution.
Constant Summary collapse
- JOB_TYPE_ENUM =
[ JOB_TYPE_HARVEST = 'HARVEST'.freeze, JOB_TYPE_PROFILING = 'PROFILING'.freeze, JOB_TYPE_SAMPLING = 'SAMPLING'.freeze, JOB_TYPE_PREVIEW = 'PREVIEW'.freeze, JOB_TYPE_IMPORT = 'IMPORT'.freeze, JOB_TYPE_EXPORT = 'EXPORT'.freeze, JOB_TYPE_IMPORT_GLOSSARY = 'IMPORT_GLOSSARY'.freeze, JOB_TYPE_EXPORT_GLOSSARY = 'EXPORT_GLOSSARY'.freeze, JOB_TYPE_INTERNAL = 'INTERNAL'.freeze, JOB_TYPE_PURGE = 'PURGE'.freeze, JOB_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze, JOB_TYPE_SCHEDULED = 'SCHEDULED'.freeze, JOB_TYPE_IMMEDIATE_EXECUTION = 'IMMEDIATE_EXECUTION'.freeze, JOB_TYPE_SCHEDULED_EXECUTION = 'SCHEDULED_EXECUTION'.freeze, JOB_TYPE_SCHEDULED_EXECUTION_INSTANCE = 'SCHEDULED_EXECUTION_INSTANCE'.freeze, JOB_TYPE_ASYNC_DELETE = 'ASYNC_DELETE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATED = 'CREATED'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_SUCCEEDED_WITH_WARNINGS = 'SUCCEEDED_WITH_WARNINGS'.freeze ].freeze
Instance Attribute Summary collapse
-
#data_entity_key ⇒ String
The key of the associated data entity resource.
-
#error_code ⇒ String
Error code returned from the job execution or null if job is still running or didn’t return an error.
-
#error_message ⇒ String
Error message returned from the job execution or null if job is still running or didn’t return an error.
-
#event_key ⇒ String
An identifier used for log message correlation.
-
#external_url ⇒ String
If the job is an external process, then a URL of the job for accessing this resource and its status.
-
#job_type ⇒ String
Type of the job execution.
-
#lifecycle_state ⇒ String
Status of the job execution, such as running, paused, or completed.
-
#parent_key ⇒ String
The unique key of the parent execution or null if this job execution has no parent.
-
#process_key ⇒ String
Process identifier related to the job execution if the job is an external job.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the execution context properties which are specific to a job execution.
-
#schedule_instance_key ⇒ String
The unique key of the triggering external scheduler resource or null if this job execution is not externally triggered.
-
#sub_type ⇒ String
Sub-type of this job execution.
-
#time_ended ⇒ DateTime
Time that the job execution ended or null if it hasn’t yet completed.
-
#time_started ⇒ DateTime
Time that job execution started.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateJobExecutionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateJobExecutionDetails
Initializes the object
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 170 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.sub_type = attributes[:'subType'] if attributes[:'subType'] raise 'You cannot provide both :subType and :sub_type' if attributes.key?(:'subType') && attributes.key?(:'sub_type') self.sub_type = attributes[:'sub_type'] if attributes[:'sub_type'] self.job_type = attributes[:'jobType'] if attributes[:'jobType'] raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type') self.job_type = attributes[:'job_type'] if attributes[:'job_type'] self.parent_key = attributes[:'parentKey'] if attributes[:'parentKey'] raise 'You cannot provide both :parentKey and :parent_key' if attributes.key?(:'parentKey') && attributes.key?(:'parent_key') self.parent_key = attributes[:'parent_key'] if attributes[:'parent_key'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded'] raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended') self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.error_code = attributes[:'errorCode'] if attributes[:'errorCode'] raise 'You cannot provide both :errorCode and :error_code' if attributes.key?(:'errorCode') && attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] if attributes[:'error_code'] self. = attributes[:'errorMessage'] if attributes[:'errorMessage'] raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message') self. = attributes[:'error_message'] if attributes[:'error_message'] self.schedule_instance_key = attributes[:'scheduleInstanceKey'] if attributes[:'scheduleInstanceKey'] raise 'You cannot provide both :scheduleInstanceKey and :schedule_instance_key' if attributes.key?(:'scheduleInstanceKey') && attributes.key?(:'schedule_instance_key') self.schedule_instance_key = attributes[:'schedule_instance_key'] if attributes[:'schedule_instance_key'] self.process_key = attributes[:'processKey'] if attributes[:'processKey'] raise 'You cannot provide both :processKey and :process_key' if attributes.key?(:'processKey') && attributes.key?(:'process_key') self.process_key = attributes[:'process_key'] if attributes[:'process_key'] self.external_url = attributes[:'externalUrl'] if attributes[:'externalUrl'] raise 'You cannot provide both :externalUrl and :external_url' if attributes.key?(:'externalUrl') && attributes.key?(:'external_url') self.external_url = attributes[:'external_url'] if attributes[:'external_url'] self.event_key = attributes[:'eventKey'] if attributes[:'eventKey'] raise 'You cannot provide both :eventKey and :event_key' if attributes.key?(:'eventKey') && attributes.key?(:'event_key') self.event_key = attributes[:'event_key'] if attributes[:'event_key'] self.data_entity_key = attributes[:'dataEntityKey'] if attributes[:'dataEntityKey'] raise 'You cannot provide both :dataEntityKey and :data_entity_key' if attributes.key?(:'dataEntityKey') && attributes.key?(:'data_entity_key') self.data_entity_key = attributes[:'data_entity_key'] if attributes[:'data_entity_key'] self.properties = attributes[:'properties'] if attributes[:'properties'] end |
Instance Attribute Details
#data_entity_key ⇒ String
The key of the associated data entity resource.
95 96 97 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 95 def data_entity_key @data_entity_key end |
#error_code ⇒ String
Error code returned from the job execution or null if job is still running or didn’t return an error.
68 69 70 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 68 def error_code @error_code end |
#error_message ⇒ String
Error message returned from the job execution or null if job is still running or didn’t return an error.
73 74 75 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 73 def end |
#event_key ⇒ String
An identifier used for log message correlation.
91 92 93 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 91 def event_key @event_key end |
#external_url ⇒ String
If the job is an external process, then a URL of the job for accessing this resource and its status.
86 87 88 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 86 def external_url @external_url end |
#job_type ⇒ String
Type of the job execution.
45 46 47 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 45 def job_type @job_type end |
#lifecycle_state ⇒ String
Status of the job execution, such as running, paused, or completed.
63 64 65 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 63 def lifecycle_state @lifecycle_state end |
#parent_key ⇒ String
The unique key of the parent execution or null if this job execution has no parent.
49 50 51 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 49 def parent_key @parent_key end |
#process_key ⇒ String
Process identifier related to the job execution if the job is an external job.
81 82 83 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 81 def process_key @process_key end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the execution context properties which are specific to a job execution. Each job execution may define it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most job executions have required properties within the "default" category. Example: ‘{ "default": { "host": "host1", "port": "1521", "database": "orcl"}}`
104 105 106 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 104 def properties @properties end |
#schedule_instance_key ⇒ String
The unique key of the triggering external scheduler resource or null if this job execution is not externally triggered.
77 78 79 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 77 def schedule_instance_key @schedule_instance_key end |
#sub_type ⇒ String
Sub-type of this job execution.
41 42 43 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 41 def sub_type @sub_type end |
#time_ended ⇒ DateTime
Time that the job execution ended or null if it hasn’t yet completed. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
59 60 61 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 59 def time_ended @time_ended end |
#time_started ⇒ DateTime
Time that job execution started. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
53 54 55 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 53 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 107 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'sub_type': :'subType', 'job_type': :'jobType', 'parent_key': :'parentKey', 'time_started': :'timeStarted', 'time_ended': :'timeEnded', 'lifecycle_state': :'lifecycleState', 'error_code': :'errorCode', 'error_message': :'errorMessage', 'schedule_instance_key': :'scheduleInstanceKey', 'process_key': :'processKey', 'external_url': :'externalUrl', 'event_key': :'eventKey', 'data_entity_key': :'dataEntityKey', 'properties': :'properties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 129 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'sub_type': :'String', 'job_type': :'String', 'parent_key': :'String', 'time_started': :'DateTime', 'time_ended': :'DateTime', 'lifecycle_state': :'String', 'error_code': :'String', 'error_message': :'String', 'schedule_instance_key': :'String', 'process_key': :'String', 'external_url': :'String', 'event_key': :'String', 'data_entity_key': :'String', 'properties': :'Hash<String, Hash<String, String>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 280 def ==(other) return true if equal?(other) self.class == other.class && sub_type == other.sub_type && job_type == other.job_type && parent_key == other.parent_key && time_started == other.time_started && time_ended == other.time_ended && lifecycle_state == other.lifecycle_state && error_code == other.error_code && == other. && schedule_instance_key == other.schedule_instance_key && process_key == other.process_key && external_url == other.external_url && event_key == other.event_key && data_entity_key == other.data_entity_key && properties == other.properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 323 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
303 304 305 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 303 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
312 313 314 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 312 def hash [sub_type, job_type, parent_key, time_started, time_ended, lifecycle_state, error_code, , schedule_instance_key, process_key, external_url, event_key, data_entity_key, properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 365 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
350 351 352 |
# File 'lib/oci/data_catalog/models/create_job_execution_details.rb', line 350 def to_s to_hash.to_s end |