Class: OCI::DataCatalog::Models::EntitySummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/entity_summary.rb

Overview

Summary of an data entity. A representation of data with a set of attributes, normally representing a single business entity. Synonymous with ‘table’ or ‘view’ in a database, or a single logical file structure that one or many files may match.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MOVING = 'MOVING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EntitySummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key property

  • :display_name (String)

    The value to assign to the #display_name property

  • :business_name (String)

    The value to assign to the #business_name property

  • :description (String)

    The value to assign to the #description property

  • :is_logical (BOOLEAN)

    The value to assign to the #is_logical property

  • :is_partition (BOOLEAN)

    The value to assign to the #is_partition property

  • :data_asset_key (String)

    The value to assign to the #data_asset_key property

  • :folder_key (String)

    The value to assign to the #folder_key property

  • :folder_name (String)

    The value to assign to the #folder_name property

  • :external_key (String)

    The value to assign to the #external_key property

  • :pattern_key (String)

    The value to assign to the #pattern_key property

  • :type_key (String)

    The value to assign to the #type_key property

  • :realized_expression (String)

    The value to assign to the #realized_expression property

  • :path (String)

    The value to assign to the #path property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :updated_by_id (String)

    The value to assign to the #updated_by_id property

  • :uri (String)

    The value to assign to the #uri property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :properties (Hash<String, Hash<String, String>>)

    The value to assign to the #properties property



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 200

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.business_name = attributes[:'businessName'] if attributes[:'businessName']

  raise 'You cannot provide both :businessName and :business_name' if attributes.key?(:'businessName') && attributes.key?(:'business_name')

  self.business_name = attributes[:'business_name'] if attributes[:'business_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.is_logical = attributes[:'isLogical'] unless attributes[:'isLogical'].nil?

  raise 'You cannot provide both :isLogical and :is_logical' if attributes.key?(:'isLogical') && attributes.key?(:'is_logical')

  self.is_logical = attributes[:'is_logical'] unless attributes[:'is_logical'].nil?

  self.is_partition = attributes[:'isPartition'] unless attributes[:'isPartition'].nil?

  raise 'You cannot provide both :isPartition and :is_partition' if attributes.key?(:'isPartition') && attributes.key?(:'is_partition')

  self.is_partition = attributes[:'is_partition'] unless attributes[:'is_partition'].nil?

  self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey']

  raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key')

  self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key']

  self.folder_key = attributes[:'folderKey'] if attributes[:'folderKey']

  raise 'You cannot provide both :folderKey and :folder_key' if attributes.key?(:'folderKey') && attributes.key?(:'folder_key')

  self.folder_key = attributes[:'folder_key'] if attributes[:'folder_key']

  self.folder_name = attributes[:'folderName'] if attributes[:'folderName']

  raise 'You cannot provide both :folderName and :folder_name' if attributes.key?(:'folderName') && attributes.key?(:'folder_name')

  self.folder_name = attributes[:'folder_name'] if attributes[:'folder_name']

  self.external_key = attributes[:'externalKey'] if attributes[:'externalKey']

  raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key')

  self.external_key = attributes[:'external_key'] if attributes[:'external_key']

  self.pattern_key = attributes[:'patternKey'] if attributes[:'patternKey']

  raise 'You cannot provide both :patternKey and :pattern_key' if attributes.key?(:'patternKey') && attributes.key?(:'pattern_key')

  self.pattern_key = attributes[:'pattern_key'] if attributes[:'pattern_key']

  self.type_key = attributes[:'typeKey'] if attributes[:'typeKey']

  raise 'You cannot provide both :typeKey and :type_key' if attributes.key?(:'typeKey') && attributes.key?(:'type_key')

  self.type_key = attributes[:'type_key'] if attributes[:'type_key']

  self.realized_expression = attributes[:'realizedExpression'] if attributes[:'realizedExpression']

  raise 'You cannot provide both :realizedExpression and :realized_expression' if attributes.key?(:'realizedExpression') && attributes.key?(:'realized_expression')

  self.realized_expression = attributes[:'realized_expression'] if attributes[:'realized_expression']

  self.path = attributes[:'path'] if attributes[:'path']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById']

  raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id')

  self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id']

  self.uri = attributes[:'uri'] if attributes[:'uri']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.properties = attributes[:'properties'] if attributes[:'properties']
end

Instance Attribute Details

#business_nameString

Optional user friendly business name of the data entity. If set, this supplements the harvested display name of the object.

Returns:

  • (String)


38
39
40
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 38

def business_name
  @business_name
end

#data_asset_keyString

Unique key of the parent data asset.

Returns:

  • (String)


56
57
58
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 56

def data_asset_key
  @data_asset_key
end

#descriptionString

Detailed description of a data entity.

Returns:

  • (String)


42
43
44
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 42

def description
  @description
end

#display_nameString

A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


34
35
36
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 34

def display_name
  @display_name
end

#external_keyString

Unique external key of this object in the source system.

Returns:

  • (String)


68
69
70
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 68

def external_key
  @external_key
end

#folder_keyString

Key of the associated folder.

Returns:

  • (String)


60
61
62
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 60

def folder_key
  @folder_key
end

#folder_nameString

Name of the associated folder. This name is harvested from the source data asset when the parent folder for the entiy is harvested.

Returns:

  • (String)


64
65
66
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 64

def folder_name
  @folder_name
end

#is_logicalBOOLEAN

Property that identifies if the object is a physical object (materialized) or virtual/logical object defined on other objects.

Returns:

  • (BOOLEAN)


48
49
50
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 48

def is_logical
  @is_logical
end

#is_partitionBOOLEAN

Property that identifies if an object is a sub object of a physical or materialized parent object.

Returns:

  • (BOOLEAN)


52
53
54
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 52

def is_partition
  @is_partition
end

#keyString

[Required] Unique data entity key that is immutable.

Returns:

  • (String)


28
29
30
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 28

def key
  @key
end

#lifecycle_stateString

State of the data entity.

Returns:

  • (String)


107
108
109
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 107

def lifecycle_state
  @lifecycle_state
end

#pathString

Full path of the data entity.

Returns:

  • (String)


84
85
86
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 84

def path
  @path
end

#pattern_keyString

Key of the associated pattern if this is a logical entity.

Returns:

  • (String)


72
73
74
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 72

def pattern_key
  @pattern_key
end

#propertiesHash<String, Hash<String, String>>

A map of maps that contains the properties which are specific to the entity type. Each entity type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most data entities have required properties within the "default" category. Example: ‘{ "default": { "key1": "value1"}}`

Returns:

  • (Hash<String, Hash<String, String>>)


116
117
118
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 116

def properties
  @properties
end

#realized_expressionString

The expression realized after resolving qualifiers . Used in deriving this logical entity

Returns:

  • (String)


80
81
82
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 80

def realized_expression
  @realized_expression
end

#time_createdDateTime

The date and time the data entity was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z

Returns:

  • (DateTime)


90
91
92
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 90

def time_created
  @time_created
end

#time_updatedDateTime

The last time that any change was made to the data entity. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


95
96
97
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 95

def time_updated
  @time_updated
end

#type_keyString

The type of data entity object. Type keys can be found via the ‘/types’ endpoint.

Returns:

  • (String)


76
77
78
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 76

def type_key
  @type_key
end

#updated_by_idString

OCID of the user who updated this object in the data catalog.

Returns:

  • (String)


99
100
101
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 99

def updated_by_id
  @updated_by_id
end

#uriString

URI to the data entity instance in the API.

Returns:

  • (String)


103
104
105
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 103

def uri
  @uri
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 119

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'display_name': :'displayName',
    'business_name': :'businessName',
    'description': :'description',
    'is_logical': :'isLogical',
    'is_partition': :'isPartition',
    'data_asset_key': :'dataAssetKey',
    'folder_key': :'folderKey',
    'folder_name': :'folderName',
    'external_key': :'externalKey',
    'pattern_key': :'patternKey',
    'type_key': :'typeKey',
    'realized_expression': :'realizedExpression',
    'path': :'path',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'updated_by_id': :'updatedById',
    'uri': :'uri',
    'lifecycle_state': :'lifecycleState',
    'properties': :'properties'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 147

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'display_name': :'String',
    'business_name': :'String',
    'description': :'String',
    'is_logical': :'BOOLEAN',
    'is_partition': :'BOOLEAN',
    'data_asset_key': :'String',
    'folder_key': :'String',
    'folder_name': :'String',
    'external_key': :'String',
    'pattern_key': :'String',
    'type_key': :'String',
    'realized_expression': :'String',
    'path': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'updated_by_id': :'String',
    'uri': :'String',
    'lifecycle_state': :'String',
    'properties': :'Hash<String, Hash<String, String>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 327

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    display_name == other.display_name &&
    business_name == other.business_name &&
    description == other.description &&
    is_logical == other.is_logical &&
    is_partition == other.is_partition &&
    data_asset_key == other.data_asset_key &&
    folder_key == other.folder_key &&
    folder_name == other.folder_name &&
    external_key == other.external_key &&
    pattern_key == other.pattern_key &&
    type_key == other.type_key &&
    realized_expression == other.realized_expression &&
    path == other.path &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    updated_by_id == other.updated_by_id &&
    uri == other.uri &&
    lifecycle_state == other.lifecycle_state &&
    properties == other.properties
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 376

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


356
357
358
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 356

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



365
366
367
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 365

def hash
  [key, display_name, business_name, description, is_logical, is_partition, data_asset_key, folder_key, folder_name, external_key, pattern_key, type_key, realized_expression, path, time_created, time_updated, updated_by_id, uri, lifecycle_state, properties].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



409
410
411
412
413
414
415
416
417
418
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 409

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



403
404
405
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 403

def to_s
  to_hash.to_s
end