Class: OCI::DataCatalog::Models::EntitySummary
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::EntitySummary
- Defined in:
- lib/oci/data_catalog/models/entity_summary.rb
Overview
Summary of an data entity. A representation of data with a set of attributes, normally representing a single business entity. Synonymous with ‘table’ or ‘view’ in a database, or a single logical file structure that one or many files may match.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#business_name ⇒ String
Optional user friendly business name of the data entity.
-
#data_asset_key ⇒ String
Unique key of the parent data asset.
-
#description ⇒ String
Detailed description of a data entity.
-
#display_name ⇒ String
A user-friendly display name.
-
#external_key ⇒ String
Unique external key of this object in the source system.
-
#folder_key ⇒ String
Key of the associated folder.
-
#folder_name ⇒ String
Name of the associated folder.
-
#key ⇒ String
[Required] Unique data entity key that is immutable.
-
#lifecycle_state ⇒ String
State of the data entity.
-
#path ⇒ String
Full path of the data entity.
-
#pattern_key ⇒ String
Key of the associated pattern if this is a logical entity.
-
#realized_expression ⇒ String
The expression realized after resolving qualifiers .
-
#time_created ⇒ DateTime
The date and time the data entity was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
The last time that any change was made to the data entity.
-
#type_key ⇒ String
The type of data entity object.
-
#updated_by_id ⇒ String
OCID of the user who updated this object in the data catalog.
-
#uri ⇒ String
URI to the data entity instance in the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EntitySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EntitySummary
Initializes the object
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 172 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.business_name = attributes[:'businessName'] if attributes[:'businessName'] raise 'You cannot provide both :businessName and :business_name' if attributes.key?(:'businessName') && attributes.key?(:'business_name') self.business_name = attributes[:'business_name'] if attributes[:'business_name'] self.description = attributes[:'description'] if attributes[:'description'] self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey'] raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key') self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key'] self.folder_key = attributes[:'folderKey'] if attributes[:'folderKey'] raise 'You cannot provide both :folderKey and :folder_key' if attributes.key?(:'folderKey') && attributes.key?(:'folder_key') self.folder_key = attributes[:'folder_key'] if attributes[:'folder_key'] self.folder_name = attributes[:'folderName'] if attributes[:'folderName'] raise 'You cannot provide both :folderName and :folder_name' if attributes.key?(:'folderName') && attributes.key?(:'folder_name') self.folder_name = attributes[:'folder_name'] if attributes[:'folder_name'] self.external_key = attributes[:'externalKey'] if attributes[:'externalKey'] raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key') self.external_key = attributes[:'external_key'] if attributes[:'external_key'] self.pattern_key = attributes[:'patternKey'] if attributes[:'patternKey'] raise 'You cannot provide both :patternKey and :pattern_key' if attributes.key?(:'patternKey') && attributes.key?(:'pattern_key') self.pattern_key = attributes[:'pattern_key'] if attributes[:'pattern_key'] self.type_key = attributes[:'typeKey'] if attributes[:'typeKey'] raise 'You cannot provide both :typeKey and :type_key' if attributes.key?(:'typeKey') && attributes.key?(:'type_key') self.type_key = attributes[:'type_key'] if attributes[:'type_key'] self.realized_expression = attributes[:'realizedExpression'] if attributes[:'realizedExpression'] raise 'You cannot provide both :realizedExpression and :realized_expression' if attributes.key?(:'realizedExpression') && attributes.key?(:'realized_expression') self.realized_expression = attributes[:'realized_expression'] if attributes[:'realized_expression'] self.path = attributes[:'path'] if attributes[:'path'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById'] raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id') self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id'] self.uri = attributes[:'uri'] if attributes[:'uri'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#business_name ⇒ String
Optional user friendly business name of the data entity. If set, this supplements the harvested display name of the object.
38 39 40 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 38 def business_name @business_name end |
#data_asset_key ⇒ String
Unique key of the parent data asset.
46 47 48 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 46 def data_asset_key @data_asset_key end |
#description ⇒ String
Detailed description of a data entity.
42 43 44 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 42 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
34 35 36 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 34 def display_name @display_name end |
#external_key ⇒ String
Unique external key of this object in the source system.
58 59 60 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 58 def external_key @external_key end |
#folder_key ⇒ String
Key of the associated folder.
50 51 52 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 50 def folder_key @folder_key end |
#folder_name ⇒ String
Name of the associated folder. This name is harvested from the source data asset when the parent folder for the entiy is harvested.
54 55 56 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 54 def folder_name @folder_name end |
#key ⇒ String
[Required] Unique data entity key that is immutable.
28 29 30 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 28 def key @key end |
#lifecycle_state ⇒ String
State of the data entity.
97 98 99 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 97 def lifecycle_state @lifecycle_state end |
#path ⇒ String
Full path of the data entity.
74 75 76 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 74 def path @path end |
#pattern_key ⇒ String
Key of the associated pattern if this is a logical entity.
62 63 64 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 62 def pattern_key @pattern_key end |
#realized_expression ⇒ String
The expression realized after resolving qualifiers . Used in deriving this logical entity
70 71 72 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 70 def realized_expression @realized_expression end |
#time_created ⇒ DateTime
The date and time the data entity was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
80 81 82 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 80 def time_created @time_created end |
#time_updated ⇒ DateTime
The last time that any change was made to the data entity. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
85 86 87 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 85 def time_updated @time_updated end |
#type_key ⇒ String
The type of data entity object. Type keys can be found via the ‘/types’ endpoint.
66 67 68 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 66 def type_key @type_key end |
#updated_by_id ⇒ String
OCID of the user who updated this object in the data catalog.
89 90 91 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 89 def updated_by_id @updated_by_id end |
#uri ⇒ String
URI to the data entity instance in the API.
93 94 95 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 93 def uri @uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 100 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'business_name': :'businessName', 'description': :'description', 'data_asset_key': :'dataAssetKey', 'folder_key': :'folderKey', 'folder_name': :'folderName', 'external_key': :'externalKey', 'pattern_key': :'patternKey', 'type_key': :'typeKey', 'realized_expression': :'realizedExpression', 'path': :'path', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'updated_by_id': :'updatedById', 'uri': :'uri', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 125 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'business_name': :'String', 'description': :'String', 'data_asset_key': :'String', 'folder_key': :'String', 'folder_name': :'String', 'external_key': :'String', 'pattern_key': :'String', 'type_key': :'String', 'realized_expression': :'String', 'path': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'updated_by_id': :'String', 'uri': :'String', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 285 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && business_name == other.business_name && description == other.description && data_asset_key == other.data_asset_key && folder_key == other.folder_key && folder_name == other.folder_name && external_key == other.external_key && pattern_key == other.pattern_key && type_key == other.type_key && realized_expression == other.realized_expression && path == other.path && time_created == other.time_created && time_updated == other.time_updated && updated_by_id == other.updated_by_id && uri == other.uri && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 331 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
311 312 313 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 311 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
320 321 322 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 320 def hash [key, display_name, business_name, description, data_asset_key, folder_key, folder_name, external_key, pattern_key, type_key, realized_expression, path, time_created, time_updated, updated_by_id, uri, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
364 365 366 367 368 369 370 371 372 373 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 364 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
358 359 360 |
# File 'lib/oci/data_catalog/models/entity_summary.rb', line 358 def to_s to_hash.to_s end |