Class: OCI::DataCatalog::Models::Folder

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/folder.rb

Overview

A generic term used in the data catalog for an external organization concept used for a collection of data entities or processes within a data asset. This term is an internal term which models multiple external types of folder, such as file directories, database schemas, and so on. Some data assets, such as Object Store containers, may contain many levels of folders.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MOVING = 'MOVING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
HARVEST_STATUS_ENUM =
[
  HARVEST_STATUS_COMPLETE = 'COMPLETE'.freeze,
  HARVEST_STATUS_ERROR = 'ERROR'.freeze,
  HARVEST_STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  HARVEST_STATUS_DEFERRED = 'DEFERRED'.freeze,
  HARVEST_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Folder

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key property

  • :display_name (String)

    The value to assign to the #display_name property

  • :business_name (String)

    The value to assign to the #business_name property

  • :description (String)

    The value to assign to the #description property

  • :parent_folder_key (String)

    The value to assign to the #parent_folder_key property

  • :path (String)

    The value to assign to the #path property

  • :data_asset_key (String)

    The value to assign to the #data_asset_key property

  • :custom_property_members (Array<OCI::DataCatalog::Models::CustomPropertyGetUsage>)

    The value to assign to the #custom_property_members property

  • :properties (Hash<String, Hash<String, String>>)

    The value to assign to the #properties property

  • :external_key (String)

    The value to assign to the #external_key property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :created_by_id (String)

    The value to assign to the #created_by_id property

  • :updated_by_id (String)

    The value to assign to the #updated_by_id property

  • :time_external (DateTime)

    The value to assign to the #time_external property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :harvest_status (String)

    The value to assign to the #harvest_status property

  • :last_job_key (String)

    The value to assign to the #last_job_key property

  • :uri (String)

    The value to assign to the #uri property



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/oci/data_catalog/models/folder.rb', line 200

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.business_name = attributes[:'businessName'] if attributes[:'businessName']

  raise 'You cannot provide both :businessName and :business_name' if attributes.key?(:'businessName') && attributes.key?(:'business_name')

  self.business_name = attributes[:'business_name'] if attributes[:'business_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.parent_folder_key = attributes[:'parentFolderKey'] if attributes[:'parentFolderKey']

  raise 'You cannot provide both :parentFolderKey and :parent_folder_key' if attributes.key?(:'parentFolderKey') && attributes.key?(:'parent_folder_key')

  self.parent_folder_key = attributes[:'parent_folder_key'] if attributes[:'parent_folder_key']

  self.path = attributes[:'path'] if attributes[:'path']

  self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey']

  raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key')

  self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key']

  self.custom_property_members = attributes[:'customPropertyMembers'] if attributes[:'customPropertyMembers']

  raise 'You cannot provide both :customPropertyMembers and :custom_property_members' if attributes.key?(:'customPropertyMembers') && attributes.key?(:'custom_property_members')

  self.custom_property_members = attributes[:'custom_property_members'] if attributes[:'custom_property_members']

  self.properties = attributes[:'properties'] if attributes[:'properties']

  self.external_key = attributes[:'externalKey'] if attributes[:'externalKey']

  raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key')

  self.external_key = attributes[:'external_key'] if attributes[:'external_key']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.created_by_id = attributes[:'createdById'] if attributes[:'createdById']

  raise 'You cannot provide both :createdById and :created_by_id' if attributes.key?(:'createdById') && attributes.key?(:'created_by_id')

  self.created_by_id = attributes[:'created_by_id'] if attributes[:'created_by_id']

  self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById']

  raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id')

  self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id']

  self.time_external = attributes[:'timeExternal'] if attributes[:'timeExternal']

  raise 'You cannot provide both :timeExternal and :time_external' if attributes.key?(:'timeExternal') && attributes.key?(:'time_external')

  self.time_external = attributes[:'time_external'] if attributes[:'time_external']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.harvest_status = attributes[:'harvestStatus'] if attributes[:'harvestStatus']

  raise 'You cannot provide both :harvestStatus and :harvest_status' if attributes.key?(:'harvestStatus') && attributes.key?(:'harvest_status')

  self.harvest_status = attributes[:'harvest_status'] if attributes[:'harvest_status']

  self.last_job_key = attributes[:'lastJobKey'] if attributes[:'lastJobKey']

  raise 'You cannot provide both :lastJobKey and :last_job_key' if attributes.key?(:'lastJobKey') && attributes.key?(:'last_job_key')

  self.last_job_key = attributes[:'last_job_key'] if attributes[:'last_job_key']

  self.uri = attributes[:'uri'] if attributes[:'uri']
end

Instance Attribute Details

#business_nameString

Optional user friendly business name of the folder. If set, this supplements the harvested display name of the object.

Returns:

  • (String)


47
48
49
# File 'lib/oci/data_catalog/models/folder.rb', line 47

def business_name
  @business_name
end

#created_by_idString

OCID of the user who created the folder.

Returns:

  • (String)


95
96
97
# File 'lib/oci/data_catalog/models/folder.rb', line 95

def created_by_id
  @created_by_id
end

#custom_property_membersArray<OCI::DataCatalog::Models::CustomPropertyGetUsage>

The list of customized properties along with the values for this object



67
68
69
# File 'lib/oci/data_catalog/models/folder.rb', line 67

def custom_property_members
  @custom_property_members
end

#data_asset_keyString

The key of the associated data asset.

Returns:

  • (String)


63
64
65
# File 'lib/oci/data_catalog/models/folder.rb', line 63

def data_asset_key
  @data_asset_key
end

#descriptionString

Detailed description of a folder.

Returns:

  • (String)


51
52
53
# File 'lib/oci/data_catalog/models/folder.rb', line 51

def description
  @description
end

#display_nameString

A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


43
44
45
# File 'lib/oci/data_catalog/models/folder.rb', line 43

def display_name
  @display_name
end

#external_keyString

Unique external key of this object in the source system.

Returns:

  • (String)


80
81
82
# File 'lib/oci/data_catalog/models/folder.rb', line 80

def external_key
  @external_key
end

#harvest_statusString

Status of the object as updated by the harvest process.

Returns:

  • (String)


111
112
113
# File 'lib/oci/data_catalog/models/folder.rb', line 111

def harvest_status
  @harvest_status
end

#keyString

[Required] Unique folder key that is immutable.

Returns:

  • (String)


37
38
39
# File 'lib/oci/data_catalog/models/folder.rb', line 37

def key
  @key
end

#last_job_keyString

The key of the last harvest process to update the metadata of this object.

Returns:

  • (String)


115
116
117
# File 'lib/oci/data_catalog/models/folder.rb', line 115

def last_job_key
  @last_job_key
end

#lifecycle_stateString

The current state of the folder.

Returns:

  • (String)


107
108
109
# File 'lib/oci/data_catalog/models/folder.rb', line 107

def lifecycle_state
  @lifecycle_state
end

#parent_folder_keyString

The unique key of the containing folder or null if there is no parent folder.

Returns:

  • (String)


55
56
57
# File 'lib/oci/data_catalog/models/folder.rb', line 55

def parent_folder_key
  @parent_folder_key
end

#pathString

Full path of the folder.

Returns:

  • (String)


59
60
61
# File 'lib/oci/data_catalog/models/folder.rb', line 59

def path
  @path
end

#propertiesHash<String, Hash<String, String>>

A map of maps that contains the properties which are specific to the folder type. Each folder type definition defines it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most folders have required properties within the "default" category. Example: ‘{ "default": { "key1": "value1"}}`

Returns:

  • (Hash<String, Hash<String, String>>)


76
77
78
# File 'lib/oci/data_catalog/models/folder.rb', line 76

def properties
  @properties
end

#time_createdDateTime

The date and time the folder was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z

Returns:

  • (DateTime)


86
87
88
# File 'lib/oci/data_catalog/models/folder.rb', line 86

def time_created
  @time_created
end

#time_externalDateTime

Last modified timestamp of this object in the external system.

Returns:

  • (DateTime)


103
104
105
# File 'lib/oci/data_catalog/models/folder.rb', line 103

def time_external
  @time_external
end

#time_updatedDateTime

The last time that any change was made to the folder. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


91
92
93
# File 'lib/oci/data_catalog/models/folder.rb', line 91

def time_updated
  @time_updated
end

#updated_by_idString

OCID of the user who modified the folder.

Returns:

  • (String)


99
100
101
# File 'lib/oci/data_catalog/models/folder.rb', line 99

def updated_by_id
  @updated_by_id
end

#uriString

URI to the folder instance in the API.

Returns:

  • (String)


119
120
121
# File 'lib/oci/data_catalog/models/folder.rb', line 119

def uri
  @uri
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/data_catalog/models/folder.rb', line 122

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'display_name': :'displayName',
    'business_name': :'businessName',
    'description': :'description',
    'parent_folder_key': :'parentFolderKey',
    'path': :'path',
    'data_asset_key': :'dataAssetKey',
    'custom_property_members': :'customPropertyMembers',
    'properties': :'properties',
    'external_key': :'externalKey',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'created_by_id': :'createdById',
    'updated_by_id': :'updatedById',
    'time_external': :'timeExternal',
    'lifecycle_state': :'lifecycleState',
    'harvest_status': :'harvestStatus',
    'last_job_key': :'lastJobKey',
    'uri': :'uri'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/oci/data_catalog/models/folder.rb', line 149

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'display_name': :'String',
    'business_name': :'String',
    'description': :'String',
    'parent_folder_key': :'String',
    'path': :'String',
    'data_asset_key': :'String',
    'custom_property_members': :'Array<OCI::DataCatalog::Models::CustomPropertyGetUsage>',
    'properties': :'Hash<String, Hash<String, String>>',
    'external_key': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'created_by_id': :'String',
    'updated_by_id': :'String',
    'time_external': :'DateTime',
    'lifecycle_state': :'String',
    'harvest_status': :'String',
    'last_job_key': :'String',
    'uri': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/oci/data_catalog/models/folder.rb', line 334

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    display_name == other.display_name &&
    business_name == other.business_name &&
    description == other.description &&
    parent_folder_key == other.parent_folder_key &&
    path == other.path &&
    data_asset_key == other.data_asset_key &&
    custom_property_members == other.custom_property_members &&
    properties == other.properties &&
    external_key == other.external_key &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    created_by_id == other.created_by_id &&
    updated_by_id == other.updated_by_id &&
    time_external == other.time_external &&
    lifecycle_state == other.lifecycle_state &&
    harvest_status == other.harvest_status &&
    last_job_key == other.last_job_key &&
    uri == other.uri
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/oci/data_catalog/models/folder.rb', line 382

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


362
363
364
# File 'lib/oci/data_catalog/models/folder.rb', line 362

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



371
372
373
# File 'lib/oci/data_catalog/models/folder.rb', line 371

def hash
  [key, display_name, business_name, description, parent_folder_key, path, data_asset_key, custom_property_members, properties, external_key, time_created, time_updated, created_by_id, updated_by_id, time_external, lifecycle_state, harvest_status, last_job_key, uri].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



415
416
417
418
419
420
421
422
423
424
# File 'lib/oci/data_catalog/models/folder.rb', line 415

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



409
410
411
# File 'lib/oci/data_catalog/models/folder.rb', line 409

def to_s
  to_hash.to_s
end