Class: OCI::DataCatalog::Models::FolderSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/folder_summary.rb

Overview

Summary of a folder. A generic term used in the data catalog for an external organization concept used for a collection of data entities or processes within a data asset. This term is an internal term which models multiple external types of folder, such as file directories, database schemas, and so on. Some data assets, such as Object Store containers, may contain many levels of folders.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MOVING = 'MOVING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FolderSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key property

  • :display_name (String)

    The value to assign to the #display_name property

  • :business_name (String)

    The value to assign to the #business_name property

  • :description (String)

    The value to assign to the #description property

  • :data_asset_key (String)

    The value to assign to the #data_asset_key property

  • :parent_folder_key (String)

    The value to assign to the #parent_folder_key property

  • :path (String)

    The value to assign to the #path property

  • :external_key (String)

    The value to assign to the #external_key property

  • :time_external (DateTime)

    The value to assign to the #time_external property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :uri (String)

    The value to assign to the #uri property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 138

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.business_name = attributes[:'businessName'] if attributes[:'businessName']

  raise 'You cannot provide both :businessName and :business_name' if attributes.key?(:'businessName') && attributes.key?(:'business_name')

  self.business_name = attributes[:'business_name'] if attributes[:'business_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey']

  raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key')

  self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key']

  self.parent_folder_key = attributes[:'parentFolderKey'] if attributes[:'parentFolderKey']

  raise 'You cannot provide both :parentFolderKey and :parent_folder_key' if attributes.key?(:'parentFolderKey') && attributes.key?(:'parent_folder_key')

  self.parent_folder_key = attributes[:'parent_folder_key'] if attributes[:'parent_folder_key']

  self.path = attributes[:'path'] if attributes[:'path']

  self.external_key = attributes[:'externalKey'] if attributes[:'externalKey']

  raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key')

  self.external_key = attributes[:'external_key'] if attributes[:'external_key']

  self.time_external = attributes[:'timeExternal'] if attributes[:'timeExternal']

  raise 'You cannot provide both :timeExternal and :time_external' if attributes.key?(:'timeExternal') && attributes.key?(:'time_external')

  self.time_external = attributes[:'time_external'] if attributes[:'time_external']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.uri = attributes[:'uri'] if attributes[:'uri']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']
end

Instance Attribute Details

#business_nameString

Optional user friendly business name of the folder. If set, this supplements the harvested display name of the object.

Returns:

  • (String)


40
41
42
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 40

def business_name
  @business_name
end

#data_asset_keyString

The unique key of the parent data asset.

Returns:

  • (String)


48
49
50
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 48

def data_asset_key
  @data_asset_key
end

#descriptionString

Detailed description of a folder.

Returns:

  • (String)


44
45
46
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 44

def description
  @description
end

#display_nameString

A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


36
37
38
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 36

def display_name
  @display_name
end

#external_keyString

Unique external key of this object from the source systems.

Returns:

  • (String)


60
61
62
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 60

def external_key
  @external_key
end

#keyString

[Required] Unique folder key that is immutable.

Returns:

  • (String)


30
31
32
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 30

def key
  @key
end

#lifecycle_stateString

State of the folder.

Returns:

  • (String)


78
79
80
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 78

def lifecycle_state
  @lifecycle_state
end

#parent_folder_keyString

The key of the containing folder or null if there is no parent.

Returns:

  • (String)


52
53
54
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 52

def parent_folder_key
  @parent_folder_key
end

#pathString

Full path of the folder.

Returns:

  • (String)


56
57
58
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 56

def path
  @path
end

#time_createdDateTime

The date and time the folder was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z

Returns:

  • (DateTime)


70
71
72
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 70

def time_created
  @time_created
end

#time_externalDateTime

Last modified timestamp of this object in the external system.

Returns:

  • (DateTime)


64
65
66
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 64

def time_external
  @time_external
end

#uriString

URI of the folder resource within the data catalog API.

Returns:

  • (String)


74
75
76
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 74

def uri
  @uri
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 81

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'display_name': :'displayName',
    'business_name': :'businessName',
    'description': :'description',
    'data_asset_key': :'dataAssetKey',
    'parent_folder_key': :'parentFolderKey',
    'path': :'path',
    'external_key': :'externalKey',
    'time_external': :'timeExternal',
    'time_created': :'timeCreated',
    'uri': :'uri',
    'lifecycle_state': :'lifecycleState'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 101

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'display_name': :'String',
    'business_name': :'String',
    'description': :'String',
    'data_asset_key': :'String',
    'parent_folder_key': :'String',
    'path': :'String',
    'external_key': :'String',
    'time_external': :'DateTime',
    'time_created': :'DateTime',
    'uri': :'String',
    'lifecycle_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 221

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    display_name == other.display_name &&
    business_name == other.business_name &&
    description == other.description &&
    data_asset_key == other.data_asset_key &&
    parent_folder_key == other.parent_folder_key &&
    path == other.path &&
    external_key == other.external_key &&
    time_external == other.time_external &&
    time_created == other.time_created &&
    uri == other.uri &&
    lifecycle_state == other.lifecycle_state
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 262

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


242
243
244
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 242

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



251
252
253
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 251

def hash
  [key, display_name, business_name, description, data_asset_key, parent_folder_key, path, external_key, time_external, time_created, uri, lifecycle_state].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
298
299
300
301
302
303
304
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 295

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



289
290
291
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 289

def to_s
  to_hash.to_s
end