Class: OCI::DataCatalog::Models::FolderSummary
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::FolderSummary
- Defined in:
- lib/oci/data_catalog/models/folder_summary.rb
Overview
Summary of a folder. A generic term used in the data catalog for an external organization concept used for a collection of data entities or processes within a data asset. This term is an internal term which models multiple external types of folder, such as file directories, database schemas, and so on. Some data assets, such as Object Store containers, may contain many levels of folders.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#business_name ⇒ String
Optional user friendly business name of the folder.
-
#data_asset_key ⇒ String
The unique key of the parent data asset.
-
#description ⇒ String
Detailed description of a folder.
-
#display_name ⇒ String
A user-friendly display name.
-
#external_key ⇒ String
Unique external key of this object from the source systems.
-
#key ⇒ String
[Required] Unique folder key that is immutable.
-
#lifecycle_state ⇒ String
State of the folder.
-
#parent_folder_key ⇒ String
The key of the containing folder or null if there is no parent.
-
#path ⇒ String
Full path of the folder.
-
#time_created ⇒ DateTime
The date and time the folder was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_external ⇒ DateTime
Last modified timestamp of this object in the external system.
-
#uri ⇒ String
URI of the folder resource within the data catalog API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FolderSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ FolderSummary
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 138 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.business_name = attributes[:'businessName'] if attributes[:'businessName'] raise 'You cannot provide both :businessName and :business_name' if attributes.key?(:'businessName') && attributes.key?(:'business_name') self.business_name = attributes[:'business_name'] if attributes[:'business_name'] self.description = attributes[:'description'] if attributes[:'description'] self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey'] raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key') self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key'] self.parent_folder_key = attributes[:'parentFolderKey'] if attributes[:'parentFolderKey'] raise 'You cannot provide both :parentFolderKey and :parent_folder_key' if attributes.key?(:'parentFolderKey') && attributes.key?(:'parent_folder_key') self.parent_folder_key = attributes[:'parent_folder_key'] if attributes[:'parent_folder_key'] self.path = attributes[:'path'] if attributes[:'path'] self.external_key = attributes[:'externalKey'] if attributes[:'externalKey'] raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key') self.external_key = attributes[:'external_key'] if attributes[:'external_key'] self.time_external = attributes[:'timeExternal'] if attributes[:'timeExternal'] raise 'You cannot provide both :timeExternal and :time_external' if attributes.key?(:'timeExternal') && attributes.key?(:'time_external') self.time_external = attributes[:'time_external'] if attributes[:'time_external'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.uri = attributes[:'uri'] if attributes[:'uri'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#business_name ⇒ String
Optional user friendly business name of the folder. If set, this supplements the harvested display name of the object.
40 41 42 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 40 def business_name @business_name end |
#data_asset_key ⇒ String
The unique key of the parent data asset.
48 49 50 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 48 def data_asset_key @data_asset_key end |
#description ⇒ String
Detailed description of a folder.
44 45 46 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 44 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
36 37 38 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 36 def display_name @display_name end |
#external_key ⇒ String
Unique external key of this object from the source systems.
60 61 62 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 60 def external_key @external_key end |
#key ⇒ String
[Required] Unique folder key that is immutable.
30 31 32 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 30 def key @key end |
#lifecycle_state ⇒ String
State of the folder.
78 79 80 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 78 def lifecycle_state @lifecycle_state end |
#parent_folder_key ⇒ String
The key of the containing folder or null if there is no parent.
52 53 54 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 52 def parent_folder_key @parent_folder_key end |
#path ⇒ String
Full path of the folder.
56 57 58 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 56 def path @path end |
#time_created ⇒ DateTime
The date and time the folder was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
70 71 72 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 70 def time_created @time_created end |
#time_external ⇒ DateTime
Last modified timestamp of this object in the external system.
64 65 66 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 64 def time_external @time_external end |
#uri ⇒ String
URI of the folder resource within the data catalog API.
74 75 76 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 74 def uri @uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 81 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'business_name': :'businessName', 'description': :'description', 'data_asset_key': :'dataAssetKey', 'parent_folder_key': :'parentFolderKey', 'path': :'path', 'external_key': :'externalKey', 'time_external': :'timeExternal', 'time_created': :'timeCreated', 'uri': :'uri', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 101 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'business_name': :'String', 'description': :'String', 'data_asset_key': :'String', 'parent_folder_key': :'String', 'path': :'String', 'external_key': :'String', 'time_external': :'DateTime', 'time_created': :'DateTime', 'uri': :'String', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 221 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && business_name == other.business_name && description == other.description && data_asset_key == other.data_asset_key && parent_folder_key == other.parent_folder_key && path == other.path && external_key == other.external_key && time_external == other.time_external && time_created == other.time_created && uri == other.uri && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 262 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
242 243 244 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 242 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
251 252 253 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 251 def hash [key, display_name, business_name, description, data_asset_key, parent_folder_key, path, external_key, time_external, time_created, uri, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 304 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
289 290 291 |
# File 'lib/oci/data_catalog/models/folder_summary.rb', line 289 def to_s to_hash.to_s end |