Class: OCI::DataCatalog::Models::JobDefinition

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/job_definition.rb

Overview

Representation of a job definition resource. Job definitions define the harvest scope and includes the list of objects to be harvested along with a schedule. The list of objects is usually specified through a combination of object type, regular expressions, or specific names of objects and a sample size for the data harvested.

Constant Summary collapse

JOB_TYPE_ENUM =
[
  JOB_TYPE_HARVEST = 'HARVEST'.freeze,
  JOB_TYPE_PROFILING = 'PROFILING'.freeze,
  JOB_TYPE_SAMPLING = 'SAMPLING'.freeze,
  JOB_TYPE_PREVIEW = 'PREVIEW'.freeze,
  JOB_TYPE_IMPORT = 'IMPORT'.freeze,
  JOB_TYPE_EXPORT = 'EXPORT'.freeze,
  JOB_TYPE_IMPORT_GLOSSARY = 'IMPORT_GLOSSARY'.freeze,
  JOB_TYPE_EXPORT_GLOSSARY = 'EXPORT_GLOSSARY'.freeze,
  JOB_TYPE_INTERNAL = 'INTERNAL'.freeze,
  JOB_TYPE_PURGE = 'PURGE'.freeze,
  JOB_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze,
  JOB_TYPE_SCHEDULED = 'SCHEDULED'.freeze,
  JOB_TYPE_IMMEDIATE_EXECUTION = 'IMMEDIATE_EXECUTION'.freeze,
  JOB_TYPE_SCHEDULED_EXECUTION = 'SCHEDULED_EXECUTION'.freeze,
  JOB_TYPE_SCHEDULED_EXECUTION_INSTANCE = 'SCHEDULED_EXECUTION_INSTANCE'.freeze,
  JOB_TYPE_ASYNC_DELETE = 'ASYNC_DELETE'.freeze,
  JOB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MOVING = 'MOVING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
JOB_EXECUTION_STATE_ENUM =
[
  JOB_EXECUTION_STATE_CREATED = 'CREATED'.freeze,
  JOB_EXECUTION_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  JOB_EXECUTION_STATE_INACTIVE = 'INACTIVE'.freeze,
  JOB_EXECUTION_STATE_FAILED = 'FAILED'.freeze,
  JOB_EXECUTION_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  JOB_EXECUTION_STATE_CANCELED = 'CANCELED'.freeze,
  JOB_EXECUTION_STATE_SUCCEEDED_WITH_WARNINGS = 'SUCCEEDED_WITH_WARNINGS'.freeze,
  JOB_EXECUTION_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
SCHEDULE_TYPE_ENUM =
[
  SCHEDULE_TYPE_SCHEDULED = 'SCHEDULED'.freeze,
  SCHEDULE_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze,
  SCHEDULE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JobDefinition

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :key (String)

    The value to assign to the #key property

  • :display_name (String)

    The value to assign to the #display_name property

  • :catalog_id (String)

    The value to assign to the #catalog_id property

  • :job_type (String)

    The value to assign to the #job_type property

  • :is_incremental (BOOLEAN)

    The value to assign to the #is_incremental property

  • :data_asset_key (String)

    The value to assign to the #data_asset_key property

  • :description (String)

    The value to assign to the #description property

  • :connection_key (String)

    The value to assign to the #connection_key property

  • :internal_version (String)

    The value to assign to the #internal_version property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :created_by_id (String)

    The value to assign to the #created_by_id property

  • :updated_by_id (String)

    The value to assign to the #updated_by_id property

  • :uri (String)

    The value to assign to the #uri property

  • :is_sample_data_extracted (BOOLEAN)

    The value to assign to the #is_sample_data_extracted property

  • :sample_data_size_in_mbs (Integer)

    The value to assign to the #sample_data_size_in_mbs property

  • :time_latest_execution_started (DateTime)

    The value to assign to the #time_latest_execution_started property

  • :time_latest_execution_ended (DateTime)

    The value to assign to the #time_latest_execution_ended property

  • :job_execution_state (String)

    The value to assign to the #job_execution_state property

  • :schedule_type (String)

    The value to assign to the #schedule_type property

  • :properties (Hash<String, Hash<String, String>>)

    The value to assign to the #properties property



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/oci/data_catalog/models/job_definition.rb', line 252

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.catalog_id = attributes[:'catalogId'] if attributes[:'catalogId']

  raise 'You cannot provide both :catalogId and :catalog_id' if attributes.key?(:'catalogId') && attributes.key?(:'catalog_id')

  self.catalog_id = attributes[:'catalog_id'] if attributes[:'catalog_id']

  self.job_type = attributes[:'jobType'] if attributes[:'jobType']

  raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type')

  self.job_type = attributes[:'job_type'] if attributes[:'job_type']

  self.is_incremental = attributes[:'isIncremental'] unless attributes[:'isIncremental'].nil?

  raise 'You cannot provide both :isIncremental and :is_incremental' if attributes.key?(:'isIncremental') && attributes.key?(:'is_incremental')

  self.is_incremental = attributes[:'is_incremental'] unless attributes[:'is_incremental'].nil?

  self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey']

  raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key')

  self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key']

  self.description = attributes[:'description'] if attributes[:'description']

  self.connection_key = attributes[:'connectionKey'] if attributes[:'connectionKey']

  raise 'You cannot provide both :connectionKey and :connection_key' if attributes.key?(:'connectionKey') && attributes.key?(:'connection_key')

  self.connection_key = attributes[:'connection_key'] if attributes[:'connection_key']

  self.internal_version = attributes[:'internalVersion'] if attributes[:'internalVersion']

  raise 'You cannot provide both :internalVersion and :internal_version' if attributes.key?(:'internalVersion') && attributes.key?(:'internal_version')

  self.internal_version = attributes[:'internal_version'] if attributes[:'internal_version']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.created_by_id = attributes[:'createdById'] if attributes[:'createdById']

  raise 'You cannot provide both :createdById and :created_by_id' if attributes.key?(:'createdById') && attributes.key?(:'created_by_id')

  self.created_by_id = attributes[:'created_by_id'] if attributes[:'created_by_id']

  self.updated_by_id = attributes[:'updatedById'] if attributes[:'updatedById']

  raise 'You cannot provide both :updatedById and :updated_by_id' if attributes.key?(:'updatedById') && attributes.key?(:'updated_by_id')

  self.updated_by_id = attributes[:'updated_by_id'] if attributes[:'updated_by_id']

  self.uri = attributes[:'uri'] if attributes[:'uri']

  self.is_sample_data_extracted = attributes[:'isSampleDataExtracted'] unless attributes[:'isSampleDataExtracted'].nil?
  self.is_sample_data_extracted = true if is_sample_data_extracted.nil? && !attributes.key?(:'isSampleDataExtracted') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isSampleDataExtracted and :is_sample_data_extracted' if attributes.key?(:'isSampleDataExtracted') && attributes.key?(:'is_sample_data_extracted')

  self.is_sample_data_extracted = attributes[:'is_sample_data_extracted'] unless attributes[:'is_sample_data_extracted'].nil?
  self.is_sample_data_extracted = true if is_sample_data_extracted.nil? && !attributes.key?(:'isSampleDataExtracted') && !attributes.key?(:'is_sample_data_extracted') # rubocop:disable Style/StringLiterals

  self.sample_data_size_in_mbs = attributes[:'sampleDataSizeInMBs'] if attributes[:'sampleDataSizeInMBs']

  raise 'You cannot provide both :sampleDataSizeInMBs and :sample_data_size_in_mbs' if attributes.key?(:'sampleDataSizeInMBs') && attributes.key?(:'sample_data_size_in_mbs')

  self.sample_data_size_in_mbs = attributes[:'sample_data_size_in_mbs'] if attributes[:'sample_data_size_in_mbs']

  self.time_latest_execution_started = attributes[:'timeLatestExecutionStarted'] if attributes[:'timeLatestExecutionStarted']

  raise 'You cannot provide both :timeLatestExecutionStarted and :time_latest_execution_started' if attributes.key?(:'timeLatestExecutionStarted') && attributes.key?(:'time_latest_execution_started')

  self.time_latest_execution_started = attributes[:'time_latest_execution_started'] if attributes[:'time_latest_execution_started']

  self.time_latest_execution_ended = attributes[:'timeLatestExecutionEnded'] if attributes[:'timeLatestExecutionEnded']

  raise 'You cannot provide both :timeLatestExecutionEnded and :time_latest_execution_ended' if attributes.key?(:'timeLatestExecutionEnded') && attributes.key?(:'time_latest_execution_ended')

  self.time_latest_execution_ended = attributes[:'time_latest_execution_ended'] if attributes[:'time_latest_execution_ended']

  self.job_execution_state = attributes[:'jobExecutionState'] if attributes[:'jobExecutionState']

  raise 'You cannot provide both :jobExecutionState and :job_execution_state' if attributes.key?(:'jobExecutionState') && attributes.key?(:'job_execution_state')

  self.job_execution_state = attributes[:'job_execution_state'] if attributes[:'job_execution_state']

  self.schedule_type = attributes[:'scheduleType'] if attributes[:'scheduleType']

  raise 'You cannot provide both :scheduleType and :schedule_type' if attributes.key?(:'scheduleType') && attributes.key?(:'schedule_type')

  self.schedule_type = attributes[:'schedule_type'] if attributes[:'schedule_type']

  self.properties = attributes[:'properties'] if attributes[:'properties']
end

Instance Attribute Details

#catalog_idString

The data catalog’s OCID.

Returns:

  • (String)


75
76
77
# File 'lib/oci/data_catalog/models/job_definition.rb', line 75

def catalog_id
  @catalog_id
end

#connection_keyString

The key of the default connection resource to be used for harvest, sampling, profiling jobs. This may be overridden in each job instance.

Returns:

  • (String)


97
98
99
# File 'lib/oci/data_catalog/models/job_definition.rb', line 97

def connection_key
  @connection_key
end

#created_by_idString

OCID of the user who created this job definition.

Returns:

  • (String)


119
120
121
# File 'lib/oci/data_catalog/models/job_definition.rb', line 119

def created_by_id
  @created_by_id
end

#data_asset_keyString

The key of the data asset for which the job is defined.

Returns:

  • (String)


87
88
89
# File 'lib/oci/data_catalog/models/job_definition.rb', line 87

def data_asset_key
  @data_asset_key
end

#descriptionString

Detailed description of the job definition.

Returns:

  • (String)


91
92
93
# File 'lib/oci/data_catalog/models/job_definition.rb', line 91

def description
  @description
end

#display_nameString

A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.

Returns:

  • (String)


71
72
73
# File 'lib/oci/data_catalog/models/job_definition.rb', line 71

def display_name
  @display_name
end

#internal_versionString

Version of the job definition object. Used internally but can be visible to users.

Returns:

  • (String)


101
102
103
# File 'lib/oci/data_catalog/models/job_definition.rb', line 101

def internal_version
  @internal_version
end

#is_incrementalBOOLEAN

Specifies if the job definition is incremental or full.

Returns:

  • (BOOLEAN)


83
84
85
# File 'lib/oci/data_catalog/models/job_definition.rb', line 83

def is_incremental
  @is_incremental
end

#is_sample_data_extractedBOOLEAN

Specify if sample data to be extracted as part of this harvest.

Returns:

  • (BOOLEAN)


131
132
133
# File 'lib/oci/data_catalog/models/job_definition.rb', line 131

def is_sample_data_extracted
  @is_sample_data_extracted
end

#job_execution_stateString

Status of the latest job execution, such as running, paused, or completed.

Returns:

  • (String)


149
150
151
# File 'lib/oci/data_catalog/models/job_definition.rb', line 149

def job_execution_state
  @job_execution_state
end

#job_typeString

Type of the job definition.

Returns:

  • (String)


79
80
81
# File 'lib/oci/data_catalog/models/job_definition.rb', line 79

def job_type
  @job_type
end

#keyString

[Required] Unique key of the job definition resource that is immutable.

Returns:

  • (String)


65
66
67
# File 'lib/oci/data_catalog/models/job_definition.rb', line 65

def key
  @key
end

#lifecycle_stateString

Lifecycle state of the job definition.

Returns:

  • (String)


105
106
107
# File 'lib/oci/data_catalog/models/job_definition.rb', line 105

def lifecycle_state
  @lifecycle_state
end

#propertiesHash<String, Hash<String, String>>

A map of maps that contains the properties which are specific to the job type. Each job type definition may define it’s set of required and optional properties. The map keys are category names and the values are maps of property name to property value. Every property is contained inside of a category. Most job definitions have required properties within the "default" category. Example: ‘{ "default": { "host": "host1", "port": "1521", "database": "orcl"}}`

Returns:

  • (Hash<String, Hash<String, String>>)


162
163
164
# File 'lib/oci/data_catalog/models/job_definition.rb', line 162

def properties
  @properties
end

#sample_data_size_in_mbsInteger

Specify the sample data size in MB, specified as number of rows, for this metadata harvest.

Returns:

  • (Integer)


135
136
137
# File 'lib/oci/data_catalog/models/job_definition.rb', line 135

def sample_data_size_in_mbs
  @sample_data_size_in_mbs
end

#schedule_typeString

Type of job schedule for the latest job executed.

Returns:

  • (String)


153
154
155
# File 'lib/oci/data_catalog/models/job_definition.rb', line 153

def schedule_type
  @schedule_type
end

#time_createdDateTime

The date and time the job definition was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z

Returns:

  • (DateTime)


111
112
113
# File 'lib/oci/data_catalog/models/job_definition.rb', line 111

def time_created
  @time_created
end

#time_latest_execution_endedDateTime

Time that the latest job execution ended or null if it hasn’t yet completed. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


145
146
147
# File 'lib/oci/data_catalog/models/job_definition.rb', line 145

def time_latest_execution_ended
  @time_latest_execution_ended
end

#time_latest_execution_startedDateTime

Time that the latest job execution started. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


139
140
141
# File 'lib/oci/data_catalog/models/job_definition.rb', line 139

def time_latest_execution_started
  @time_latest_execution_started
end

#time_updatedDateTime

The last time that any change was made to the data asset. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.

Returns:

  • (DateTime)


115
116
117
# File 'lib/oci/data_catalog/models/job_definition.rb', line 115

def time_updated
  @time_updated
end

#updated_by_idString

OCID of the user who updated this job definition.

Returns:

  • (String)


123
124
125
# File 'lib/oci/data_catalog/models/job_definition.rb', line 123

def updated_by_id
  @updated_by_id
end

#uriString

URI to the job definition instance in the API.

Returns:

  • (String)


127
128
129
# File 'lib/oci/data_catalog/models/job_definition.rb', line 127

def uri
  @uri
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/oci/data_catalog/models/job_definition.rb', line 165

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'display_name': :'displayName',
    'catalog_id': :'catalogId',
    'job_type': :'jobType',
    'is_incremental': :'isIncremental',
    'data_asset_key': :'dataAssetKey',
    'description': :'description',
    'connection_key': :'connectionKey',
    'internal_version': :'internalVersion',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'created_by_id': :'createdById',
    'updated_by_id': :'updatedById',
    'uri': :'uri',
    'is_sample_data_extracted': :'isSampleDataExtracted',
    'sample_data_size_in_mbs': :'sampleDataSizeInMBs',
    'time_latest_execution_started': :'timeLatestExecutionStarted',
    'time_latest_execution_ended': :'timeLatestExecutionEnded',
    'job_execution_state': :'jobExecutionState',
    'schedule_type': :'scheduleType',
    'properties': :'properties'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/oci/data_catalog/models/job_definition.rb', line 195

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'display_name': :'String',
    'catalog_id': :'String',
    'job_type': :'String',
    'is_incremental': :'BOOLEAN',
    'data_asset_key': :'String',
    'description': :'String',
    'connection_key': :'String',
    'internal_version': :'String',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'created_by_id': :'String',
    'updated_by_id': :'String',
    'uri': :'String',
    'is_sample_data_extracted': :'BOOLEAN',
    'sample_data_size_in_mbs': :'Integer',
    'time_latest_execution_started': :'DateTime',
    'time_latest_execution_ended': :'DateTime',
    'job_execution_state': :'String',
    'schedule_type': :'String',
    'properties': :'Hash<String, Hash<String, String>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/oci/data_catalog/models/job_definition.rb', line 436

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    display_name == other.display_name &&
    catalog_id == other.catalog_id &&
    job_type == other.job_type &&
    is_incremental == other.is_incremental &&
    data_asset_key == other.data_asset_key &&
    description == other.description &&
    connection_key == other.connection_key &&
    internal_version == other.internal_version &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    created_by_id == other.created_by_id &&
    updated_by_id == other.updated_by_id &&
    uri == other.uri &&
    is_sample_data_extracted == other.is_sample_data_extracted &&
    sample_data_size_in_mbs == other.sample_data_size_in_mbs &&
    time_latest_execution_started == other.time_latest_execution_started &&
    time_latest_execution_ended == other.time_latest_execution_ended &&
    job_execution_state == other.job_execution_state &&
    schedule_type == other.schedule_type &&
    properties == other.properties
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
# File 'lib/oci/data_catalog/models/job_definition.rb', line 487

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


467
468
469
# File 'lib/oci/data_catalog/models/job_definition.rb', line 467

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



476
477
478
# File 'lib/oci/data_catalog/models/job_definition.rb', line 476

def hash
  [key, display_name, catalog_id, job_type, is_incremental, data_asset_key, description, connection_key, internal_version, lifecycle_state, time_created, time_updated, created_by_id, updated_by_id, uri, is_sample_data_extracted, sample_data_size_in_mbs, time_latest_execution_started, time_latest_execution_ended, job_execution_state, schedule_type, properties].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



520
521
522
523
524
525
526
527
528
529
# File 'lib/oci/data_catalog/models/job_definition.rb', line 520

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



514
515
516
# File 'lib/oci/data_catalog/models/job_definition.rb', line 514

def to_s
  to_hash.to_s
end