Class: OCI::DataCatalog::Models::JobDefinitionSummary
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::JobDefinitionSummary
- Defined in:
- lib/oci/data_catalog/models/job_definition_summary.rb
Overview
A list of job definition resources. Job definitions define the harvest scope and includes the list of objects to be harvested along with a schedule. The list of objects is usually specified through a combination of object type, regular expressions, or specific names of objects and a sample size for the data harvested.
Constant Summary collapse
- JOB_TYPE_ENUM =
[ JOB_TYPE_HARVEST = 'HARVEST'.freeze, JOB_TYPE_PROFILING = 'PROFILING'.freeze, JOB_TYPE_SAMPLING = 'SAMPLING'.freeze, JOB_TYPE_PREVIEW = 'PREVIEW'.freeze, JOB_TYPE_IMPORT = 'IMPORT'.freeze, JOB_TYPE_EXPORT = 'EXPORT'.freeze, JOB_TYPE_IMPORT_GLOSSARY = 'IMPORT_GLOSSARY'.freeze, JOB_TYPE_EXPORT_GLOSSARY = 'EXPORT_GLOSSARY'.freeze, JOB_TYPE_INTERNAL = 'INTERNAL'.freeze, JOB_TYPE_PURGE = 'PURGE'.freeze, JOB_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze, JOB_TYPE_SCHEDULED = 'SCHEDULED'.freeze, JOB_TYPE_IMMEDIATE_EXECUTION = 'IMMEDIATE_EXECUTION'.freeze, JOB_TYPE_SCHEDULED_EXECUTION = 'SCHEDULED_EXECUTION'.freeze, JOB_TYPE_SCHEDULED_EXECUTION_INSTANCE = 'SCHEDULED_EXECUTION_INSTANCE'.freeze, JOB_TYPE_ASYNC_DELETE = 'ASYNC_DELETE'.freeze, JOB_TYPE_IMPORT_DATA_ASSET = 'IMPORT_DATA_ASSET'.freeze, JOB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- JOB_EXECUTION_STATE_ENUM =
[ JOB_EXECUTION_STATE_CREATED = 'CREATED'.freeze, JOB_EXECUTION_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, JOB_EXECUTION_STATE_INACTIVE = 'INACTIVE'.freeze, JOB_EXECUTION_STATE_FAILED = 'FAILED'.freeze, JOB_EXECUTION_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, JOB_EXECUTION_STATE_CANCELED = 'CANCELED'.freeze, JOB_EXECUTION_STATE_SUCCEEDED_WITH_WARNINGS = 'SUCCEEDED_WITH_WARNINGS'.freeze, JOB_EXECUTION_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SCHEDULE_TYPE_ENUM =
[ SCHEDULE_TYPE_SCHEDULED = 'SCHEDULED'.freeze, SCHEDULE_TYPE_IMMEDIATE = 'IMMEDIATE'.freeze, SCHEDULE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#catalog_id ⇒ String
The data catalog’s OCID.
-
#connection_key ⇒ String
The key of the connection resource used in harvest, sampling, profiling jobs.
-
#data_asset_key ⇒ String
Unique key of the data asset to which this job applies, if the job involves a data asset.
-
#description ⇒ String
Detailed description of the job definition.
-
#display_name ⇒ String
A user-friendly display name.
-
#is_sample_data_extracted ⇒ BOOLEAN
Specify if sample data to be extracted as part of this harvest.
-
#job_execution_state ⇒ String
Status of the latest job execution, such as running, paused, or completed.
-
#job_type ⇒ String
Type of the job definition.
-
#key ⇒ String
[Required] Unique key of the job definition resource that is immutable.
-
#lifecycle_state ⇒ String
Lifecycle state of the job definition.
-
#schedule_type ⇒ String
Type of job schedule for the latest job executed.
-
#time_created ⇒ DateTime
The date and time the job definition was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_latest_execution_ended ⇒ DateTime
Time that the latest job execution ended or null if it hasn’t yet completed.
-
#time_latest_execution_started ⇒ DateTime
Time that the latest job execution started.
-
#uri ⇒ String
URI to the job definition instance in the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JobDefinitionSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ JobDefinitionSummary
Initializes the object
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 198 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.catalog_id = attributes[:'catalogId'] if attributes[:'catalogId'] raise 'You cannot provide both :catalogId and :catalog_id' if attributes.key?(:'catalogId') && attributes.key?(:'catalog_id') self.catalog_id = attributes[:'catalog_id'] if attributes[:'catalog_id'] self.uri = attributes[:'uri'] if attributes[:'uri'] self.job_type = attributes[:'jobType'] if attributes[:'jobType'] raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type') self.job_type = attributes[:'job_type'] if attributes[:'job_type'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.is_sample_data_extracted = attributes[:'isSampleDataExtracted'] unless attributes[:'isSampleDataExtracted'].nil? self.is_sample_data_extracted = true if is_sample_data_extracted.nil? && !attributes.key?(:'isSampleDataExtracted') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isSampleDataExtracted and :is_sample_data_extracted' if attributes.key?(:'isSampleDataExtracted') && attributes.key?(:'is_sample_data_extracted') self.is_sample_data_extracted = attributes[:'is_sample_data_extracted'] unless attributes[:'is_sample_data_extracted'].nil? self.is_sample_data_extracted = true if is_sample_data_extracted.nil? && !attributes.key?(:'isSampleDataExtracted') && !attributes.key?(:'is_sample_data_extracted') # rubocop:disable Style/StringLiterals self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.connection_key = attributes[:'connectionKey'] if attributes[:'connectionKey'] raise 'You cannot provide both :connectionKey and :connection_key' if attributes.key?(:'connectionKey') && attributes.key?(:'connection_key') self.connection_key = attributes[:'connection_key'] if attributes[:'connection_key'] self.time_latest_execution_started = attributes[:'timeLatestExecutionStarted'] if attributes[:'timeLatestExecutionStarted'] raise 'You cannot provide both :timeLatestExecutionStarted and :time_latest_execution_started' if attributes.key?(:'timeLatestExecutionStarted') && attributes.key?(:'time_latest_execution_started') self.time_latest_execution_started = attributes[:'time_latest_execution_started'] if attributes[:'time_latest_execution_started'] self.time_latest_execution_ended = attributes[:'timeLatestExecutionEnded'] if attributes[:'timeLatestExecutionEnded'] raise 'You cannot provide both :timeLatestExecutionEnded and :time_latest_execution_ended' if attributes.key?(:'timeLatestExecutionEnded') && attributes.key?(:'time_latest_execution_ended') self.time_latest_execution_ended = attributes[:'time_latest_execution_ended'] if attributes[:'time_latest_execution_ended'] self.job_execution_state = attributes[:'jobExecutionState'] if attributes[:'jobExecutionState'] raise 'You cannot provide both :jobExecutionState and :job_execution_state' if attributes.key?(:'jobExecutionState') && attributes.key?(:'job_execution_state') self.job_execution_state = attributes[:'job_execution_state'] if attributes[:'job_execution_state'] self.schedule_type = attributes[:'scheduleType'] if attributes[:'scheduleType'] raise 'You cannot provide both :scheduleType and :schedule_type' if attributes.key?(:'scheduleType') && attributes.key?(:'schedule_type') self.schedule_type = attributes[:'schedule_type'] if attributes[:'schedule_type'] self.data_asset_key = attributes[:'dataAssetKey'] if attributes[:'dataAssetKey'] raise 'You cannot provide both :dataAssetKey and :data_asset_key' if attributes.key?(:'dataAssetKey') && attributes.key?(:'data_asset_key') self.data_asset_key = attributes[:'data_asset_key'] if attributes[:'data_asset_key'] end |
Instance Attribute Details
#catalog_id ⇒ String
The data catalog’s OCID.
80 81 82 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 80 def catalog_id @catalog_id end |
#connection_key ⇒ String
The key of the connection resource used in harvest, sampling, profiling jobs.
107 108 109 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 107 def connection_key @connection_key end |
#data_asset_key ⇒ String
Unique key of the data asset to which this job applies, if the job involves a data asset.
129 130 131 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 129 def data_asset_key @data_asset_key end |
#description ⇒ String
Detailed description of the job definition.
76 77 78 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 76 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
72 73 74 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 72 def display_name @display_name end |
#is_sample_data_extracted ⇒ BOOLEAN
Specify if sample data to be extracted as part of this harvest.
96 97 98 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 96 def is_sample_data_extracted @is_sample_data_extracted end |
#job_execution_state ⇒ String
Status of the latest job execution, such as running, paused, or completed.
121 122 123 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 121 def job_execution_state @job_execution_state end |
#job_type ⇒ String
Type of the job definition.
88 89 90 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 88 def job_type @job_type end |
#key ⇒ String
[Required] Unique key of the job definition resource that is immutable.
66 67 68 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 66 def key @key end |
#lifecycle_state ⇒ String
Lifecycle state of the job definition.
92 93 94 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 92 def lifecycle_state @lifecycle_state end |
#schedule_type ⇒ String
Type of job schedule for the latest job executed.
125 126 127 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 125 def schedule_type @schedule_type end |
#time_created ⇒ DateTime
The date and time the job definition was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
102 103 104 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 102 def time_created @time_created end |
#time_latest_execution_ended ⇒ DateTime
Time that the latest job execution ended or null if it hasn’t yet completed. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
117 118 119 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 117 def time_latest_execution_ended @time_latest_execution_ended end |
#time_latest_execution_started ⇒ DateTime
Time that the latest job execution started. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
111 112 113 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 111 def time_latest_execution_started @time_latest_execution_started end |
#uri ⇒ String
URI to the job definition instance in the API.
84 85 86 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 84 def uri @uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 132 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'display_name': :'displayName', 'description': :'description', 'catalog_id': :'catalogId', 'uri': :'uri', 'job_type': :'jobType', 'lifecycle_state': :'lifecycleState', 'is_sample_data_extracted': :'isSampleDataExtracted', 'time_created': :'timeCreated', 'connection_key': :'connectionKey', 'time_latest_execution_started': :'timeLatestExecutionStarted', 'time_latest_execution_ended': :'timeLatestExecutionEnded', 'job_execution_state': :'jobExecutionState', 'schedule_type': :'scheduleType', 'data_asset_key': :'dataAssetKey' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 155 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'display_name': :'String', 'description': :'String', 'catalog_id': :'String', 'uri': :'String', 'job_type': :'String', 'lifecycle_state': :'String', 'is_sample_data_extracted': :'BOOLEAN', 'time_created': :'DateTime', 'connection_key': :'String', 'time_latest_execution_started': :'DateTime', 'time_latest_execution_ended': :'DateTime', 'job_execution_state': :'String', 'schedule_type': :'String', 'data_asset_key': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 344 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && display_name == other.display_name && description == other.description && catalog_id == other.catalog_id && uri == other.uri && job_type == other.job_type && lifecycle_state == other.lifecycle_state && is_sample_data_extracted == other.is_sample_data_extracted && time_created == other.time_created && connection_key == other.connection_key && time_latest_execution_started == other.time_latest_execution_started && time_latest_execution_ended == other.time_latest_execution_ended && job_execution_state == other.job_execution_state && schedule_type == other.schedule_type && data_asset_key == other.data_asset_key end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 388 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
368 369 370 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 368 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
377 378 379 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 377 def hash [key, display_name, description, catalog_id, uri, job_type, lifecycle_state, is_sample_data_extracted, time_created, connection_key, time_latest_execution_started, time_latest_execution_ended, job_execution_state, schedule_type, data_asset_key].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
421 422 423 424 425 426 427 428 429 430 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 421 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
415 416 417 |
# File 'lib/oci/data_catalog/models/job_definition_summary.rb', line 415 def to_s to_hash.to_s end |