Class: OCI::DataCatalog::Models::ObjectRelationship
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::ObjectRelationship
- Defined in:
- lib/oci/data_catalog/models/object_relationship.rb
Overview
Details regarding a specific object and its relationship to the referencing object.
Instance Attribute Summary collapse
-
#key ⇒ String
Unique id of the object.
-
#name ⇒ String
Name of the object.
-
#relationship_type ⇒ String
Type of relationship with the referencing object.
-
#time_created ⇒ DateTime
The date and time the relationship was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
The last time a change was made to this reference.
-
#type_key ⇒ String
Type key of the object.
-
#type_name ⇒ String
Type name of the object.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ObjectRelationship
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ObjectRelationship
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.relationship_type = attributes[:'relationshipType'] if attributes[:'relationshipType'] raise 'You cannot provide both :relationshipType and :relationship_type' if attributes.key?(:'relationshipType') && attributes.key?(:'relationship_type') self.relationship_type = attributes[:'relationship_type'] if attributes[:'relationship_type'] self.key = attributes[:'key'] if attributes[:'key'] self.name = attributes[:'name'] if attributes[:'name'] self.type_name = attributes[:'typeName'] if attributes[:'typeName'] raise 'You cannot provide both :typeName and :type_name' if attributes.key?(:'typeName') && attributes.key?(:'type_name') self.type_name = attributes[:'type_name'] if attributes[:'type_name'] self.type_key = attributes[:'typeKey'] if attributes[:'typeKey'] raise 'You cannot provide both :typeKey and :type_key' if attributes.key?(:'typeKey') && attributes.key?(:'type_key') self.type_key = attributes[:'type_key'] if attributes[:'type_key'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#key ⇒ String
Unique id of the object.
16 17 18 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 16 def key @key end |
#name ⇒ String
Name of the object.
20 21 22 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 20 def name @name end |
#relationship_type ⇒ String
Type of relationship with the referencing object.
12 13 14 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 12 def relationship_type @relationship_type end |
#time_created ⇒ DateTime
The date and time the relationship was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-03-25T21:10:29.600Z
34 35 36 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 34 def time_created @time_created end |
#time_updated ⇒ DateTime
The last time a change was made to this reference. An [RFC3339](tools.ietf.org/html/rfc3339) formatted datetime string.
39 40 41 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 39 def time_updated @time_updated end |
#type_key ⇒ String
Type key of the object. Type keys can be found via the ‘/types’ endpoint.
28 29 30 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 28 def type_key @type_key end |
#type_name ⇒ String
Type name of the object. Type names can be found via the ‘/types’ endpoint.
24 25 26 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 24 def type_name @type_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'relationship_type': :'relationshipType', 'key': :'key', 'name': :'name', 'type_name': :'typeName', 'type_key': :'typeKey', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'relationship_type': :'String', 'key': :'String', 'name': :'String', 'type_name': :'String', 'type_key': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 132 def ==(other) return true if equal?(other) self.class == other.class && relationship_type == other.relationship_type && key == other.key && name == other.name && type_name == other.type_name && type_key == other.type_key && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 157 def hash [relationship_type, key, name, type_name, type_key, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/data_catalog/models/object_relationship.rb', line 195 def to_s to_hash.to_s end |