Class: OCI::DataCatalog::Models::SuggestResults
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::SuggestResults
- Defined in:
- lib/oci/data_catalog/models/suggest_results.rb
Overview
The list of potential matches returned from the suggest operation for the given input text. The size of the list will be determined by the limit parameter.
Instance Attribute Summary collapse
-
#input_text ⇒ String
**[Required]** Input string for which the potential matches are computed.
-
#items ⇒ Array<OCI::DataCatalog::Models::SuggestListItem>
List of suggestions.
-
#search_latency_in_ms ⇒ Integer
Time taken to compute the result, in milliseconds.
-
#total_count ⇒ Integer
**[Required]** Total number of items returned.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SuggestResults
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SuggestResults
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.total_count = attributes[:'totalCount'] if attributes[:'totalCount'] raise 'You cannot provide both :totalCount and :total_count' if attributes.key?(:'totalCount') && attributes.key?(:'total_count') self.total_count = attributes[:'total_count'] if attributes[:'total_count'] self.search_latency_in_ms = attributes[:'searchLatencyInMs'] if attributes[:'searchLatencyInMs'] raise 'You cannot provide both :searchLatencyInMs and :search_latency_in_ms' if attributes.key?(:'searchLatencyInMs') && attributes.key?(:'search_latency_in_ms') self.search_latency_in_ms = attributes[:'search_latency_in_ms'] if attributes[:'search_latency_in_ms'] self.input_text = attributes[:'inputText'] if attributes[:'inputText'] raise 'You cannot provide both :inputText and :input_text' if attributes.key?(:'inputText') && attributes.key?(:'input_text') self.input_text = attributes[:'input_text'] if attributes[:'input_text'] self.items = attributes[:'items'] if attributes[:'items'] end |
Instance Attribute Details
#input_text ⇒ String
**[Required]** Input string for which the potential matches are computed.
22 23 24 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 22 def input_text @input_text end |
#items ⇒ Array<OCI::DataCatalog::Models::SuggestListItem>
List of suggestions.
26 27 28 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 26 def items @items end |
#search_latency_in_ms ⇒ Integer
Time taken to compute the result, in milliseconds.
18 19 20 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 18 def search_latency_in_ms @search_latency_in_ms end |
#total_count ⇒ Integer
**[Required]** Total number of items returned.
14 15 16 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 14 def total_count @total_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'total_count': :'totalCount', 'search_latency_in_ms': :'searchLatencyInMs', 'input_text': :'inputText', 'items': :'items' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'total_count': :'Integer', 'search_latency_in_ms': :'Integer', 'input_text': :'String', 'items': :'Array<OCI::DataCatalog::Models::SuggestListItem>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 96 def ==(other) return true if equal?(other) self.class == other.class && total_count == other.total_count && search_latency_in_ms == other.search_latency_in_ms && input_text == other.input_text && items == other.items end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 129 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
109 110 111 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 109 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
118 119 120 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 118 def hash [total_count, search_latency_in_ms, input_text, items].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
156 157 158 |
# File 'lib/oci/data_catalog/models/suggest_results.rb', line 156 def to_s to_hash.to_s end |