Class: OCI::DataCatalog::Models::UpdatePatternDetails
- Inherits:
-
Object
- Object
- OCI::DataCatalog::Models::UpdatePatternDetails
- Defined in:
- lib/oci/data_catalog/models/update_pattern_details.rb
Overview
Properties used in pattern update operations.
Instance Attribute Summary collapse
-
#check_failure_limit ⇒ Integer
The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails.
-
#check_file_path_list ⇒ Array<String>
List of file paths against which the expression can be tried, as a check.
-
#description ⇒ String
Detailed description of the Pattern.
-
#display_name ⇒ String
A user-friendly display name.
-
#expression ⇒ String
The expression used in the pattern that may include qualifiers.
-
#is_enable_check_failure_limit ⇒ BOOLEAN
Indicates whether the expression check, against the checkFilePathList, will fail the request if the count of UNMATCHED files is above the checkFailureLimit.
-
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the pattern type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdatePatternDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdatePatternDetails
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 96 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.expression = attributes[:'expression'] if attributes[:'expression'] self.check_file_path_list = attributes[:'checkFilePathList'] if attributes[:'checkFilePathList'] raise 'You cannot provide both :checkFilePathList and :check_file_path_list' if attributes.key?(:'checkFilePathList') && attributes.key?(:'check_file_path_list') self.check_file_path_list = attributes[:'check_file_path_list'] if attributes[:'check_file_path_list'] self.is_enable_check_failure_limit = attributes[:'isEnableCheckFailureLimit'] unless attributes[:'isEnableCheckFailureLimit'].nil? self.is_enable_check_failure_limit = false if is_enable_check_failure_limit.nil? && !attributes.key?(:'isEnableCheckFailureLimit') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnableCheckFailureLimit and :is_enable_check_failure_limit' if attributes.key?(:'isEnableCheckFailureLimit') && attributes.key?(:'is_enable_check_failure_limit') self.is_enable_check_failure_limit = attributes[:'is_enable_check_failure_limit'] unless attributes[:'is_enable_check_failure_limit'].nil? self.is_enable_check_failure_limit = false if is_enable_check_failure_limit.nil? && !attributes.key?(:'isEnableCheckFailureLimit') && !attributes.key?(:'is_enable_check_failure_limit') # rubocop:disable Style/StringLiterals self.check_failure_limit = attributes[:'checkFailureLimit'] if attributes[:'checkFailureLimit'] raise 'You cannot provide both :checkFailureLimit and :check_failure_limit' if attributes.key?(:'checkFailureLimit') && attributes.key?(:'check_failure_limit') self.check_failure_limit = attributes[:'check_failure_limit'] if attributes[:'check_failure_limit'] self.properties = attributes[:'properties'] if attributes[:'properties'] end |
Instance Attribute Details
#check_failure_limit ⇒ Integer
The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails. Optional, if checkFilePathList is provided - but if isEnableCheckFailureLimit is set to true it is required.
44 45 46 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 44 def check_failure_limit @check_failure_limit end |
#check_file_path_list ⇒ Array<String>
List of file paths against which the expression can be tried, as a check. This documents, for reference purposes, some example objects a pattern is meant to work with. If isEnableCheckFailureLimit is set to true, this will be run as a validation during the request, such that if the check fails the request fails. If isEnableCheckFailureLimit instead is set to (the default) false, a pattern will still be created or updated even if the check fails, with a lifecycleState of FAILED.
32 33 34 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 32 def check_file_path_list @check_file_path_list end |
#description ⇒ String
Detailed description of the Pattern.
18 19 20 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 18 def description @description end |
#display_name ⇒ String
A user-friendly display name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
14 15 16 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 14 def display_name @display_name end |
#expression ⇒ String
The expression used in the pattern that may include qualifiers. Refer to the user documentation for details of the format and examples.
23 24 25 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 23 def expression @expression end |
#is_enable_check_failure_limit ⇒ BOOLEAN
Indicates whether the expression check, against the checkFilePathList, will fail the request if the count of UNMATCHED files is above the checkFailureLimit.
38 39 40 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 38 def is_enable_check_failure_limit @is_enable_check_failure_limit end |
#properties ⇒ Hash<String, Hash<String, String>>
A map of maps that contains the properties which are specific to the pattern type. Each pattern type definition defines it’s set of required and optional properties. Example: ‘{ "default": { "tbd"}}`
51 52 53 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 51 def properties @properties end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 54 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'expression': :'expression', 'check_file_path_list': :'checkFilePathList', 'is_enable_check_failure_limit': :'isEnableCheckFailureLimit', 'check_failure_limit': :'checkFailureLimit', 'properties': :'properties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'expression': :'String', 'check_file_path_list': :'Array<String>', 'is_enable_check_failure_limit': :'BOOLEAN', 'check_failure_limit': :'Integer', 'properties': :'Hash<String, Hash<String, String>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 142 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && expression == other.expression && check_file_path_list == other.check_file_path_list && is_enable_check_failure_limit == other.is_enable_check_failure_limit && check_failure_limit == other.check_failure_limit && properties == other.properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 178 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
158 159 160 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 158 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 167 def hash [display_name, description, expression, check_file_path_list, is_enable_check_failure_limit, check_failure_limit, properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 211 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
205 206 207 |
# File 'lib/oci/data_catalog/models/update_pattern_details.rb', line 205 def to_s to_hash.to_s end |