Class: OCI::DataCatalog::Models::ValidatePatternDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_catalog/models/validate_pattern_details.rb

Overview

Validate pattern using the expression and file list.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ValidatePatternDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :expression (String)

    The value to assign to the #expression property

  • :check_file_path_list (Array<String>)

    The value to assign to the #check_file_path_list property

  • :check_failure_limit (Integer)

    The value to assign to the #check_failure_limit property



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 62

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.expression = attributes[:'expression'] if attributes[:'expression']

  self.check_file_path_list = attributes[:'checkFilePathList'] if attributes[:'checkFilePathList']

  raise 'You cannot provide both :checkFilePathList and :check_file_path_list' if attributes.key?(:'checkFilePathList') && attributes.key?(:'check_file_path_list')

  self.check_file_path_list = attributes[:'check_file_path_list'] if attributes[:'check_file_path_list']

  self.check_failure_limit = attributes[:'checkFailureLimit'] if attributes[:'checkFailureLimit']

  raise 'You cannot provide both :checkFailureLimit and :check_failure_limit' if attributes.key?(:'checkFailureLimit') && attributes.key?(:'check_failure_limit')

  self.check_failure_limit = attributes[:'check_failure_limit'] if attributes[:'check_failure_limit']
end

Instance Attribute Details

#check_failure_limitInteger

The maximum number of UNMATCHED files, in checkFilePathList, above which the check fails. Optional, if checkFilePathList is provided.

If provided with the request, this overrides the value which already exists as part of the pattern, if any.

Returns:

  • (Integer)


29
30
31
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 29

def check_failure_limit
  @check_failure_limit
end

#check_file_path_listArray<String>

List of file paths against which the expression can be tried, as a check. This documents, for reference purposes, some example objects a pattern is meant to work with.

If provided with the request,this overrides the list which already exists as part of the pattern, if any.

Returns:

  • (Array<String>)


21
22
23
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 21

def check_file_path_list
  @check_file_path_list
end

#expressionString

The expression used in the pattern that may include qualifiers. Refer to the user documentation for details of the format and examples.

Returns:

  • (String)


13
14
15
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 13

def expression
  @expression
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 32

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'expression': :'expression',
    'check_file_path_list': :'checkFilePathList',
    'check_failure_limit': :'checkFailureLimit'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
50
51
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 43

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'expression': :'String',
    'check_file_path_list': :'Array<String>',
    'check_failure_limit': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



90
91
92
93
94
95
96
97
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 90

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    expression == other.expression &&
    check_file_path_list == other.check_file_path_list &&
    check_failure_limit == other.check_failure_limit
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 122

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


102
103
104
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 102

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



111
112
113
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 111

def hash
  [expression, check_file_path_list, check_failure_limit].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



155
156
157
158
159
160
161
162
163
164
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 155

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



149
150
151
# File 'lib/oci/data_catalog/models/validate_pattern_details.rb', line 149

def to_s
  to_hash.to_s
end