Class: OCI::DataConnectivity::Models::BipCallAttribute
- Inherits:
-
AbstractCallAttribute
- Object
- AbstractCallAttribute
- OCI::DataConnectivity::Models::BipCallAttribute
- Defined in:
- lib/oci/data_connectivity/models/bip_call_attribute.rb
Overview
The call attributes impl
Constant Summary
Constants inherited from AbstractCallAttribute
AbstractCallAttribute::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#fetch_next_rows_parameter ⇒ String
Parameter to fetch next set of rows.
-
#offset_parameter ⇒ String
Parameter to set offset.
- #staging_bucket ⇒ OCI::DataConnectivity::Models::Schema
- #staging_connection ⇒ OCI::DataConnectivity::Models::Connection
- #staging_data_asset ⇒ OCI::DataConnectivity::Models::DataAsset
-
#staging_prefix ⇒ String
Prefix for the staging DataAsset.
Attributes inherited from AbstractCallAttribute
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BipCallAttribute
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractCallAttribute
Constructor Details
#initialize(attributes = {}) ⇒ BipCallAttribute
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 75 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'BIPCALLATTRIBUTE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.staging_bucket = attributes[:'stagingBucket'] if attributes[:'stagingBucket'] raise 'You cannot provide both :stagingBucket and :staging_bucket' if attributes.key?(:'stagingBucket') && attributes.key?(:'staging_bucket') self.staging_bucket = attributes[:'staging_bucket'] if attributes[:'staging_bucket'] self.offset_parameter = attributes[:'offsetParameter'] if attributes[:'offsetParameter'] raise 'You cannot provide both :offsetParameter and :offset_parameter' if attributes.key?(:'offsetParameter') && attributes.key?(:'offset_parameter') self.offset_parameter = attributes[:'offset_parameter'] if attributes[:'offset_parameter'] self.fetch_next_rows_parameter = attributes[:'fetchNextRowsParameter'] if attributes[:'fetchNextRowsParameter'] raise 'You cannot provide both :fetchNextRowsParameter and :fetch_next_rows_parameter' if attributes.key?(:'fetchNextRowsParameter') && attributes.key?(:'fetch_next_rows_parameter') self.fetch_next_rows_parameter = attributes[:'fetch_next_rows_parameter'] if attributes[:'fetch_next_rows_parameter'] self.staging_data_asset = attributes[:'stagingDataAsset'] if attributes[:'stagingDataAsset'] raise 'You cannot provide both :stagingDataAsset and :staging_data_asset' if attributes.key?(:'stagingDataAsset') && attributes.key?(:'staging_data_asset') self.staging_data_asset = attributes[:'staging_data_asset'] if attributes[:'staging_data_asset'] self.staging_connection = attributes[:'stagingConnection'] if attributes[:'stagingConnection'] raise 'You cannot provide both :stagingConnection and :staging_connection' if attributes.key?(:'stagingConnection') && attributes.key?(:'staging_connection') self.staging_connection = attributes[:'staging_connection'] if attributes[:'staging_connection'] self.staging_prefix = attributes[:'stagingPrefix'] if attributes[:'stagingPrefix'] raise 'You cannot provide both :stagingPrefix and :staging_prefix' if attributes.key?(:'stagingPrefix') && attributes.key?(:'staging_prefix') self.staging_prefix = attributes[:'staging_prefix'] if attributes[:'staging_prefix'] end |
Instance Attribute Details
#fetch_next_rows_parameter ⇒ String
Parameter to fetch next set of rows
21 22 23 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 21 def fetch_next_rows_parameter @fetch_next_rows_parameter end |
#offset_parameter ⇒ String
Parameter to set offset
17 18 19 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 17 def offset_parameter @offset_parameter end |
#staging_bucket ⇒ OCI::DataConnectivity::Models::Schema
13 14 15 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 13 def staging_bucket @staging_bucket end |
#staging_connection ⇒ OCI::DataConnectivity::Models::Connection
27 28 29 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 27 def staging_connection @staging_connection end |
#staging_data_asset ⇒ OCI::DataConnectivity::Models::DataAsset
24 25 26 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 24 def staging_data_asset @staging_data_asset end |
#staging_prefix ⇒ String
Prefix for the staging DataAsset
31 32 33 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 31 def staging_prefix @staging_prefix end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'staging_bucket': :'stagingBucket', 'offset_parameter': :'offsetParameter', 'fetch_next_rows_parameter': :'fetchNextRowsParameter', 'staging_data_asset': :'stagingDataAsset', 'staging_connection': :'stagingConnection', 'staging_prefix': :'stagingPrefix' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 49 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'staging_bucket': :'OCI::DataConnectivity::Models::Schema', 'offset_parameter': :'String', 'fetch_next_rows_parameter': :'String', 'staging_data_asset': :'OCI::DataConnectivity::Models::DataAsset', 'staging_connection': :'OCI::DataConnectivity::Models::Connection', 'staging_prefix': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 129 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && staging_bucket == other.staging_bucket && offset_parameter == other.offset_parameter && fetch_next_rows_parameter == other.fetch_next_rows_parameter && staging_data_asset == other.staging_data_asset && staging_connection == other.staging_connection && staging_prefix == other.staging_prefix end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 165 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
145 146 147 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 145 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
154 155 156 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 154 def hash [model_type, staging_bucket, offset_parameter, fetch_next_rows_parameter, staging_data_asset, staging_connection, staging_prefix].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 198 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
192 193 194 |
# File 'lib/oci/data_connectivity/models/bip_call_attribute.rb', line 192 def to_s to_hash.to_s end |