Class: OCI::DataConnectivity::Models::CreateConnectionDetails
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::CreateConnectionDetails
- Defined in:
- lib/oci/data_connectivity/models/create_connection_details.rb
Overview
Properties used in connection create operations.
Instance Attribute Summary collapse
-
#connection_properties ⇒ Array<OCI::DataConnectivity::Models::ConnectionProperty>
The properties for the connection.
-
#description ⇒ String
User-defined description for the connection.
-
#identifier ⇒ String
**[Required]** Value can only contain upper case letters, underscore, and numbers.
-
#is_default ⇒ BOOLEAN
The default property for the connection.
-
#key ⇒ String
Generated key that can be used in API calls to identify connection.
- #metadata ⇒ OCI::DataConnectivity::Models::ObjectMetadata
-
#model_type ⇒ String
The type of the object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
**[Required]** Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #primary_schema ⇒ OCI::DataConnectivity::Models::Schema
-
#properties ⇒ Hash<String, Object>
**[Required]** All the properties for the connection in a key-value map format.
- #registry_metadata ⇒ OCI::DataConnectivity::Models::RegistryMetadata
-
#type ⇒ String
**[Required]** Specific Connection Type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateConnectionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateConnectionDetails
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 134 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.primary_schema = attributes[:'primarySchema'] if attributes[:'primarySchema'] raise 'You cannot provide both :primarySchema and :primary_schema' if attributes.key?(:'primarySchema') && attributes.key?(:'primary_schema') self.primary_schema = attributes[:'primary_schema'] if attributes[:'primary_schema'] self.connection_properties = attributes[:'connectionProperties'] if attributes[:'connectionProperties'] raise 'You cannot provide both :connectionProperties and :connection_properties' if attributes.key?(:'connectionProperties') && attributes.key?(:'connection_properties') self.connection_properties = attributes[:'connection_properties'] if attributes[:'connection_properties'] self.properties = attributes[:'properties'] if attributes[:'properties'] self.type = attributes[:'type'] if attributes[:'type'] self.is_default = attributes[:'isDefault'] unless attributes[:'isDefault'].nil? self.is_default = false if is_default.nil? && !attributes.key?(:'isDefault') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isDefault and :is_default' if attributes.key?(:'isDefault') && attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] unless attributes[:'is_default'].nil? self.is_default = false if is_default.nil? && !attributes.key?(:'isDefault') && !attributes.key?(:'is_default') # rubocop:disable Style/StringLiterals self. = attributes[:'metadata'] if attributes[:'metadata'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] end |
Instance Attribute Details
#connection_properties ⇒ Array<OCI::DataConnectivity::Models::ConnectionProperty>
The properties for the connection.
47 48 49 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 47 def connection_properties @connection_properties end |
#description ⇒ String
User-defined description for the connection.
28 29 30 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 28 def description @description end |
#identifier ⇒ String
**[Required]** Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
40 41 42 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 40 def identifier @identifier end |
#is_default ⇒ BOOLEAN
The default property for the connection.
59 60 61 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 59 def is_default @is_default end |
#key ⇒ String
Generated key that can be used in API calls to identify connection. On scenarios where reference to the connection is needed, a value can be passed in create.
12 13 14 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 12 def key @key end |
#metadata ⇒ OCI::DataConnectivity::Models::ObjectMetadata
62 63 64 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 62 def @metadata end |
#model_type ⇒ String
The type of the object.
20 21 22 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 20 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
16 17 18 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 16 def model_version @model_version end |
#name ⇒ String
**[Required]** Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
24 25 26 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 24 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
36 37 38 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 36 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
32 33 34 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 32 def object_version @object_version end |
#primary_schema ⇒ OCI::DataConnectivity::Models::Schema
43 44 45 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 43 def primary_schema @primary_schema end |
#properties ⇒ Hash<String, Object>
**[Required]** All the properties for the connection in a key-value map format.
51 52 53 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 51 def properties @properties end |
#registry_metadata ⇒ OCI::DataConnectivity::Models::RegistryMetadata
65 66 67 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 65 def @registry_metadata end |
#type ⇒ String
**[Required]** Specific Connection Type
55 56 57 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 55 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 68 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_version': :'modelVersion', 'model_type': :'modelType', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'primary_schema': :'primarySchema', 'connection_properties': :'connectionProperties', 'properties': :'properties', 'type': :'type', 'is_default': :'isDefault', 'metadata': :'metadata', 'registry_metadata': :'registryMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 91 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_version': :'String', 'model_type': :'String', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'primary_schema': :'OCI::DataConnectivity::Models::Schema', 'connection_properties': :'Array<OCI::DataConnectivity::Models::ConnectionProperty>', 'properties': :'Hash<String, Object>', 'type': :'String', 'is_default': :'BOOLEAN', 'metadata': :'OCI::DataConnectivity::Models::ObjectMetadata', 'registry_metadata': :'OCI::DataConnectivity::Models::RegistryMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 212 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_version == other.model_version && model_type == other.model_type && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && primary_schema == other.primary_schema && connection_properties == other.connection_properties && properties == other.properties && type == other.type && is_default == other.is_default && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 256 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
236 237 238 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 236 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
245 246 247 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 245 def hash [key, model_version, model_type, name, description, object_version, object_status, identifier, primary_schema, connection_properties, properties, type, is_default, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
289 290 291 292 293 294 295 296 297 298 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 289 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
283 284 285 |
# File 'lib/oci/data_connectivity/models/create_connection_details.rb', line 283 def to_s to_hash.to_s end |