Class: OCI::DataConnectivity::Models::DateAttribute
- Inherits:
-
AttributeProfileResult
- Object
- AttributeProfileResult
- OCI::DataConnectivity::Models::DateAttribute
- Defined in:
- lib/oci/data_connectivity/models/date_attribute.rb
Overview
A summary of profiling results of a specefic attribute.
Instance Attribute Summary
Attributes inherited from AttributeProfileResult
#distinct_count, #duplicate_count, #max, #min, #name, #null_count, #type, #unique_count, #value_frequencies
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DateAttribute
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AttributeProfileResult
Constructor Details
#initialize(attributes = {}) ⇒ DateAttribute
Initializes the object
59 60 61 62 63 64 65 |
# File 'lib/oci/data_connectivity/models/date_attribute.rb', line 59 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'DATE_TIME' super(attributes) end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 |
# File 'lib/oci/data_connectivity/models/date_attribute.rb', line 12 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'name': :'name', 'min': :'min', 'max': :'max', 'null_count': :'nullCount', 'distinct_count': :'distinctCount', 'unique_count': :'uniqueCount', 'duplicate_count': :'duplicateCount', 'value_frequencies': :'valueFrequencies' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/data_connectivity/models/date_attribute.rb', line 29 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'Object', 'name': :'String', 'min': :'OCI::DataConnectivity::Models::ProfileStat', 'max': :'OCI::DataConnectivity::Models::ProfileStat', 'null_count': :'OCI::DataConnectivity::Models::ProfileStat', 'distinct_count': :'OCI::DataConnectivity::Models::ProfileStat', 'unique_count': :'OCI::DataConnectivity::Models::ProfileStat', 'duplicate_count': :'OCI::DataConnectivity::Models::ProfileStat', 'value_frequencies': :'Array<OCI::DataConnectivity::Models::ObjectFreqStat>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/data_connectivity/models/date_attribute.rb', line 74 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && name == other.name && min == other.min && max == other.max && null_count == other.null_count && distinct_count == other.distinct_count && unique_count == other.unique_count && duplicate_count == other.duplicate_count && value_frequencies == other.value_frequencies end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/data_connectivity/models/date_attribute.rb', line 112 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
92 93 94 |
# File 'lib/oci/data_connectivity/models/date_attribute.rb', line 92 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
101 102 103 |
# File 'lib/oci/data_connectivity/models/date_attribute.rb', line 101 def hash [type, name, min, max, null_count, distinct_count, unique_count, duplicate_count, value_frequencies].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/data_connectivity/models/date_attribute.rb', line 145 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
139 140 141 |
# File 'lib/oci/data_connectivity/models/date_attribute.rb', line 139 def to_s to_hash.to_s end |