Class: DataConnectivity::Models::Endpoint
- Inherits:
-
Object
- Object
- DataConnectivity::Models::Endpoint
- Defined in:
- lib/oci/data_connectivity/models/endpoint.rb
Overview
An Endpoint is an organizational construct to keep multiple data Connectivity Management solutions and their resources (pe-id, dnsProxyIp, dnsZones, and so on) separate from each other, helping you to stay organized. For example, you could have separate registries for development, testing, and production.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
Registry description.
-
#display_name ⇒ String
**[Required]** Data Connectivity Management Registry display name, registries can be renamed.
-
#dns_zones ⇒ Array<String>
List of DNS zones to be used by the data assets to be harvested.
-
#endpoint_size ⇒ Integer
Endpoint size for reverse connection capacity.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#lifecycle_state ⇒ String
Lifecycle states for registries in Data Connectivity Management Service CREATING - The resource is being created and may not be usable until the entire metadata is defined UPDATING - The resource is being updated and may not be usable until all changes are commited DELETING - The resource is being deleted and might require deep cleanup of children.
-
#nsg_ids ⇒ Array<String>
List of NSGs to which the Private Endpoint VNIC must be added.
-
#state_message ⇒ String
A message describing the current state in more detail.
-
#subnet_id ⇒ String
**[Required]** Subnet OCID for the customer connected network where databases for example reside.
-
#time_created ⇒ DateTime
The time the Data Connectivity Management Registry was created.
-
#time_updated ⇒ DateTime
The time the Data Connectivity Management Registry was updated.
-
#vcn_id ⇒ String
**[Required]** VCN OCID where the subnet resides.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Endpoint
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Endpoint
Initializes the object
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 164 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.dns_zones = attributes[:'dnsZones'] if attributes[:'dnsZones'] raise 'You cannot provide both :dnsZones and :dns_zones' if attributes.key?(:'dnsZones') && attributes.key?(:'dns_zones') self.dns_zones = attributes[:'dns_zones'] if attributes[:'dns_zones'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'stateMessage'] if attributes[:'stateMessage'] raise 'You cannot provide both :stateMessage and :state_message' if attributes.key?(:'stateMessage') && attributes.key?(:'state_message') self. = attributes[:'state_message'] if attributes[:'state_message'] self.id = attributes[:'id'] if attributes[:'id'] self.endpoint_size = attributes[:'endpointSize'] if attributes[:'endpointSize'] raise 'You cannot provide both :endpointSize and :endpoint_size' if attributes.key?(:'endpointSize') && attributes.key?(:'endpoint_size') self.endpoint_size = attributes[:'endpoint_size'] if attributes[:'endpoint_size'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] end |
Instance Attribute Details
#compartment_id ⇒ String
Compartment Identifier
58 59 60 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 58 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
46 47 48 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 46 def @defined_tags end |
#description ⇒ String
Registry description
50 51 52 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 50 def description @description end |
#display_name ⇒ String
**[Required]** Data Connectivity Management Registry display name, registries can be renamed
54 55 56 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 54 def display_name @display_name end |
#dns_zones ⇒ Array<String>
List of DNS zones to be used by the data assets to be harvested. Example: custpvtsubnet.oraclevcn.com for data asset: db.custpvtsubnet.oraclevcn.com
34 35 36 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 34 def dns_zones @dns_zones end |
#endpoint_size ⇒ Integer
Endpoint size for reverse connection capacity.
91 92 93 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 91 def endpoint_size @endpoint_size end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
40 41 42 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 40 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
87 88 89 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 87 def id @id end |
#lifecycle_state ⇒ String
Lifecycle states for registries in Data Connectivity Management Service CREATING - The resource is being created and may not be usable until the entire metadata is defined UPDATING - The resource is being updated and may not be usable until all changes are commited DELETING - The resource is being deleted and might require deep cleanup of children. ACTIVE - The resource is valid and available for access INACTIVE - The resource might be incomplete in its definition or might have been made unavailable for
administrative reasons
DELETED - The resource has been deleted and isn't available FAILED - The resource is in a failed state due to validation or other errors
79 80 81 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 79 def lifecycle_state @lifecycle_state end |
#nsg_ids ⇒ Array<String>
List of NSGs to which the Private Endpoint VNIC must be added.
95 96 97 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 95 def nsg_ids @nsg_ids end |
#state_message ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
83 84 85 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 83 def @state_message end |
#subnet_id ⇒ String
**[Required]** Subnet OCID for the customer connected network where databases for example reside.
28 29 30 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 28 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
The time the Data Connectivity Management Registry was created. An RFC3339 formatted datetime string
62 63 64 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 62 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the Data Connectivity Management Registry was updated. An RFC3339 formatted datetime string
66 67 68 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 66 def time_updated @time_updated end |
#vcn_id ⇒ String
**[Required]** VCN OCID where the subnet resides.
24 25 26 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 24 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 98 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'vcn_id': :'vcnId', 'subnet_id': :'subnetId', 'dns_zones': :'dnsZones', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'description': :'description', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'state_message': :'stateMessage', 'id': :'id', 'endpoint_size': :'endpointSize', 'nsg_ids': :'nsgIds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 121 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'vcn_id': :'String', 'subnet_id': :'String', 'dns_zones': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'description': :'String', 'display_name': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'state_message': :'String', 'id': :'String', 'endpoint_size': :'Integer', 'nsg_ids': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 273 def ==(other) return true if equal?(other) self.class == other.class && vcn_id == other.vcn_id && subnet_id == other.subnet_id && dns_zones == other.dns_zones && == other. && == other. && description == other.description && display_name == other.display_name && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && == other. && id == other.id && endpoint_size == other.endpoint_size && nsg_ids == other.nsg_ids end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 317 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
297 298 299 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 297 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
306 307 308 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 306 def hash [vcn_id, subnet_id, dns_zones, , , description, display_name, compartment_id, time_created, time_updated, lifecycle_state, , id, endpoint_size, nsg_ids].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
350 351 352 353 354 355 356 357 358 359 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 350 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
344 345 346 |
# File 'lib/oci/data_connectivity/models/endpoint.rb', line 344 def to_s to_hash.to_s end |