Class: DataConnectivity::Models::Registry
- Inherits:
-
Object
- Object
- DataConnectivity::Models::Registry
- Defined in:
- lib/oci/data_connectivity/models/registry.rb
Overview
A registry is an organizational construct to keep multiple data Connectivity Management solutions and their resources (data assets, data flows, tasks, and so on) separate from each other, helping you to stay organized. For example, you could have separate registries for development, testing, and production.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
Registry description.
-
#display_name ⇒ String
**[Required]** Data Connectivity Management Registry display name, registries can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#lifecycle_state ⇒ String
Lifecycle states for registries in Data Connectivity Management Service CREATING - The resource is being created and may not be usable until the entire metadata is defined UPDATING - The resource is being updated and may not be usable until all changes are commited DELETING - The resource is being deleted and might require deep cleanup of children.
-
#state_message ⇒ String
A message describing the current state in more detail.
-
#time_created ⇒ DateTime
The time the Data Connectivity Management Registry was created.
-
#time_updated ⇒ DateTime
The time the Data Connectivity Management Registry was updated.
-
#updated_by ⇒ String
Name of the user who updated the DCMS Registry.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Registry
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Registry
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 134 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.updated_by = attributes[:'updatedBy'] if attributes[:'updatedBy'] raise 'You cannot provide both :updatedBy and :updated_by' if attributes.key?(:'updatedBy') && attributes.key?(:'updated_by') self.updated_by = attributes[:'updated_by'] if attributes[:'updated_by'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'stateMessage'] if attributes[:'stateMessage'] raise 'You cannot provide both :stateMessage and :state_message' if attributes.key?(:'stateMessage') && attributes.key?(:'state_message') self. = attributes[:'state_message'] if attributes[:'state_message'] self.id = attributes[:'id'] if attributes[:'id'] end |
Instance Attribute Details
#compartment_id ⇒ String
Compartment Identifier
48 49 50 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 48 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
32 33 34 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 32 def @defined_tags end |
#description ⇒ String
Registry description
36 37 38 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 36 def description @description end |
#display_name ⇒ String
**[Required]** Data Connectivity Management Registry display name, registries can be renamed
40 41 42 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 40 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
26 27 28 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 26 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
77 78 79 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 77 def id @id end |
#lifecycle_state ⇒ String
Lifecycle states for registries in Data Connectivity Management Service CREATING - The resource is being created and may not be usable until the entire metadata is defined UPDATING - The resource is being updated and may not be usable until all changes are commited DELETING - The resource is being deleted and might require deep cleanup of children. ACTIVE - The resource is valid and available for access INACTIVE - The resource might be incomplete in its definition or might have been made unavailable for
administrative reasons
DELETED - The resource has been deleted and isn't available FAILED - The resource is in a failed state due to validation or other errors
69 70 71 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 69 def lifecycle_state @lifecycle_state end |
#state_message ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
73 74 75 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 73 def @state_message end |
#time_created ⇒ DateTime
The time the Data Connectivity Management Registry was created. An RFC3339 formatted datetime string
52 53 54 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 52 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the Data Connectivity Management Registry was updated. An RFC3339 formatted datetime string
56 57 58 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 56 def time_updated @time_updated end |
#updated_by ⇒ String
Name of the user who updated the DCMS Registry.
44 45 46 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 44 def updated_by @updated_by end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 80 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'description': :'description', 'display_name': :'displayName', 'updated_by': :'updatedBy', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'state_message': :'stateMessage', 'id': :'id' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 99 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'description': :'String', 'display_name': :'String', 'updated_by': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'state_message': :'String', 'id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 219 def ==(other) return true if equal?(other) self.class == other.class && == other. && == other. && description == other.description && display_name == other.display_name && updated_by == other.updated_by && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && == other. && id == other.id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 259 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
239 240 241 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 239 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 248 def hash [, , description, display_name, updated_by, compartment_id, time_created, time_updated, lifecycle_state, , id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
286 287 288 |
# File 'lib/oci/data_connectivity/models/registry.rb', line 286 def to_s to_hash.to_s end |