Class: OCI::DataConnectivity::Models::RegistrySummary
- Inherits:
-
Object
- Object
- OCI::DataConnectivity::Models::RegistrySummary
- Defined in:
- lib/oci/data_connectivity/models/registry_summary.rb
Overview
Summary of a Registry.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
Registry description.
-
#display_name ⇒ String
**[Required]** Data Connectivity Management Registry display name, registries can be renamed.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#lifecycle_state ⇒ String
The current state of the registry.
-
#state_message ⇒ String
A message describing the current state in more detail.
-
#time_created ⇒ DateTime
The time the Data Connectivity Management Registry was created.
-
#time_updated ⇒ DateTime
The time the Data Connectivity Management Registry was updated.
-
#updated_by ⇒ String
Name of the user who updated the DCMS Registry.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RegistrySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RegistrySummary
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 113 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.updated_by = attributes[:'updatedBy'] if attributes[:'updatedBy'] raise 'You cannot provide both :updatedBy and :updated_by' if attributes.key?(:'updatedBy') && attributes.key?(:'updated_by') self.updated_by = attributes[:'updated_by'] if attributes[:'updated_by'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'stateMessage'] if attributes[:'stateMessage'] raise 'You cannot provide both :stateMessage and :state_message' if attributes.key?(:'stateMessage') && attributes.key?(:'state_message') self. = attributes[:'state_message'] if attributes[:'state_message'] end |
Instance Attribute Details
#compartment_id ⇒ String
Compartment Identifier
24 25 26 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 24 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
48 49 50 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 48 def @defined_tags end |
#description ⇒ String
Registry description
16 17 18 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 16 def description @description end |
#display_name ⇒ String
**[Required]** Data Connectivity Management Registry display name, registries can be renamed
20 21 22 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 20 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
38 39 40 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 38 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
12 13 14 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 12 def id @id end |
#lifecycle_state ⇒ String
The current state of the registry.
52 53 54 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 52 def lifecycle_state @lifecycle_state end |
#state_message ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
56 57 58 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 56 def @state_message end |
#time_created ⇒ DateTime
The time the Data Connectivity Management Registry was created. An RFC3339 formatted datetime string
28 29 30 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 28 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the Data Connectivity Management Registry was updated. An RFC3339 formatted datetime string
32 33 34 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 32 def time_updated @time_updated end |
#updated_by ⇒ String
Name of the user who updated the DCMS Registry.
42 43 44 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 42 def updated_by @updated_by end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 59 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'updated_by': :'updatedBy', 'defined_tags': :'definedTags', 'lifecycle_state': :'lifecycleState', 'state_message': :'stateMessage' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 78 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'display_name': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'updated_by': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'lifecycle_state': :'String', 'state_message': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 185 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && display_name == other.display_name && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && == other. && updated_by == other.updated_by && == other. && lifecycle_state == other.lifecycle_state && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 225 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
205 206 207 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 205 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 214 def hash [id, description, display_name, compartment_id, time_created, time_updated, , updated_by, , lifecycle_state, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
252 253 254 |
# File 'lib/oci/data_connectivity/models/registry_summary.rb', line 252 def to_s to_hash.to_s end |