Class: DataConnectivity::Models::Target
- Inherits:
-
OCI::DataConnectivity::Models::CreateConnectivityValidationDetails
- Object
- OCI::DataConnectivity::Models::CreateConnectivityValidationDetails
- DataConnectivity::Models::Target
- Defined in:
- lib/oci/data_connectivity/models/target.rb
Overview
The information about the target operator. The target operator lets you specify the data entity to store the transformed data.
Constant Summary collapse
- DATA_PROPERTY_ENUM =
[ DATA_PROPERTY_TRUNCATE = 'TRUNCATE'.freeze, DATA_PROPERTY_MERGE = 'MERGE'.freeze, DATA_PROPERTY_BACKUP = 'BACKUP'.freeze, DATA_PROPERTY_OVERWRITE = 'OVERWRITE'.freeze, DATA_PROPERTY_APPEND = 'APPEND'.freeze, DATA_PROPERTY_IGNORE = 'IGNORE'.freeze, DATA_PROPERTY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from OCI::DataConnectivity::Models::CreateConnectivityValidationDetails
OCI::DataConnectivity::Models::CreateConnectivityValidationDetails::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#data_property ⇒ String
Specifies the data property.
-
#entity ⇒ OCI::DataConnectivity::Models::DataEntity
This attribute is required.
- #fixed_data_shape ⇒ OCI::DataConnectivity::Models::Shape
-
#is_copy_fields ⇒ BOOLEAN
Specifies the copy fields.
-
#is_predefined_shape ⇒ BOOLEAN
Specifies if this uses a predefined shape.
-
#is_read_access ⇒ BOOLEAN
Specifies the read access.
- #schema_drift_config ⇒ OCI::DataConnectivity::Models::SchemaDriftConfig
- #write_operation_config ⇒ OCI::DataConnectivity::Models::WriteOperationConfig
Attributes inherited from OCI::DataConnectivity::Models::CreateConnectivityValidationDetails
#description, #identifier, #input_ports, #key, #model_type, #model_version, #name, #object_status, #object_version, #op_config_values, #output_ports, #parameters, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Target
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from OCI::DataConnectivity::Models::CreateConnectivityValidationDetails
Constructor Details
#initialize(attributes = {}) ⇒ Target
Initializes the object
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/data_connectivity/models/target.rb', line 135 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'TARGET_OPERATOR' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.entity = attributes[:'entity'] if attributes[:'entity'] self.is_read_access = attributes[:'isReadAccess'] unless attributes[:'isReadAccess'].nil? raise 'You cannot provide both :isReadAccess and :is_read_access' if attributes.key?(:'isReadAccess') && attributes.key?(:'is_read_access') self.is_read_access = attributes[:'is_read_access'] unless attributes[:'is_read_access'].nil? self.is_copy_fields = attributes[:'isCopyFields'] unless attributes[:'isCopyFields'].nil? raise 'You cannot provide both :isCopyFields and :is_copy_fields' if attributes.key?(:'isCopyFields') && attributes.key?(:'is_copy_fields') self.is_copy_fields = attributes[:'is_copy_fields'] unless attributes[:'is_copy_fields'].nil? self.is_predefined_shape = attributes[:'isPredefinedShape'] unless attributes[:'isPredefinedShape'].nil? raise 'You cannot provide both :isPredefinedShape and :is_predefined_shape' if attributes.key?(:'isPredefinedShape') && attributes.key?(:'is_predefined_shape') self.is_predefined_shape = attributes[:'is_predefined_shape'] unless attributes[:'is_predefined_shape'].nil? self.data_property = attributes[:'dataProperty'] if attributes[:'dataProperty'] raise 'You cannot provide both :dataProperty and :data_property' if attributes.key?(:'dataProperty') && attributes.key?(:'data_property') self.data_property = attributes[:'data_property'] if attributes[:'data_property'] self.schema_drift_config = attributes[:'schemaDriftConfig'] if attributes[:'schemaDriftConfig'] raise 'You cannot provide both :schemaDriftConfig and :schema_drift_config' if attributes.key?(:'schemaDriftConfig') && attributes.key?(:'schema_drift_config') self.schema_drift_config = attributes[:'schema_drift_config'] if attributes[:'schema_drift_config'] self.fixed_data_shape = attributes[:'fixedDataShape'] if attributes[:'fixedDataShape'] raise 'You cannot provide both :fixedDataShape and :fixed_data_shape' if attributes.key?(:'fixedDataShape') && attributes.key?(:'fixed_data_shape') self.fixed_data_shape = attributes[:'fixed_data_shape'] if attributes[:'fixed_data_shape'] self.write_operation_config = attributes[:'writeOperationConfig'] if attributes[:'writeOperationConfig'] raise 'You cannot provide both :writeOperationConfig and :write_operation_config' if attributes.key?(:'writeOperationConfig') && attributes.key?(:'write_operation_config') self.write_operation_config = attributes[:'write_operation_config'] if attributes[:'write_operation_config'] end |
Instance Attribute Details
#data_property ⇒ String
Specifies the data property.
40 41 42 |
# File 'lib/oci/data_connectivity/models/target.rb', line 40 def data_property @data_property end |
#entity ⇒ OCI::DataConnectivity::Models::DataEntity
This attribute is required.
24 25 26 |
# File 'lib/oci/data_connectivity/models/target.rb', line 24 def entity @entity end |
#fixed_data_shape ⇒ OCI::DataConnectivity::Models::Shape
46 47 48 |
# File 'lib/oci/data_connectivity/models/target.rb', line 46 def fixed_data_shape @fixed_data_shape end |
#is_copy_fields ⇒ BOOLEAN
Specifies the copy fields.
32 33 34 |
# File 'lib/oci/data_connectivity/models/target.rb', line 32 def is_copy_fields @is_copy_fields end |
#is_predefined_shape ⇒ BOOLEAN
Specifies if this uses a predefined shape.
36 37 38 |
# File 'lib/oci/data_connectivity/models/target.rb', line 36 def is_predefined_shape @is_predefined_shape end |
#is_read_access ⇒ BOOLEAN
Specifies the read access.
28 29 30 |
# File 'lib/oci/data_connectivity/models/target.rb', line 28 def is_read_access @is_read_access end |
#schema_drift_config ⇒ OCI::DataConnectivity::Models::SchemaDriftConfig
43 44 45 |
# File 'lib/oci/data_connectivity/models/target.rb', line 43 def schema_drift_config @schema_drift_config end |
#write_operation_config ⇒ OCI::DataConnectivity::Models::WriteOperationConfig
49 50 51 |
# File 'lib/oci/data_connectivity/models/target.rb', line 49 def write_operation_config @write_operation_config end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/data_connectivity/models/target.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'input_ports': :'inputPorts', 'output_ports': :'outputPorts', 'object_status': :'objectStatus', 'identifier': :'identifier', 'parameters': :'parameters', 'op_config_values': :'opConfigValues', 'entity': :'entity', 'is_read_access': :'isReadAccess', 'is_copy_fields': :'isCopyFields', 'is_predefined_shape': :'isPredefinedShape', 'data_property': :'dataProperty', 'schema_drift_config': :'schemaDriftConfig', 'fixed_data_shape': :'fixedDataShape', 'write_operation_config': :'writeOperationConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/data_connectivity/models/target.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataConnectivity::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'input_ports': :'Array<OCI::DataConnectivity::Models::InputPort>', 'output_ports': :'Array<OCI::DataConnectivity::Models::OutputPort>', 'object_status': :'Integer', 'identifier': :'String', 'parameters': :'Array<OCI::DataConnectivity::Models::Parameter>', 'op_config_values': :'OCI::DataConnectivity::Models::ConfigValues', 'entity': :'OCI::DataConnectivity::Models::DataEntity', 'is_read_access': :'BOOLEAN', 'is_copy_fields': :'BOOLEAN', 'is_predefined_shape': :'BOOLEAN', 'data_property': :'String', 'schema_drift_config': :'OCI::DataConnectivity::Models::SchemaDriftConfig', 'fixed_data_shape': :'OCI::DataConnectivity::Models::Shape', 'write_operation_config': :'OCI::DataConnectivity::Models::WriteOperationConfig' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/oci/data_connectivity/models/target.rb', line 210 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && input_ports == other.input_ports && output_ports == other.output_ports && object_status == other.object_status && identifier == other.identifier && parameters == other.parameters && op_config_values == other.op_config_values && entity == other.entity && is_read_access == other.is_read_access && is_copy_fields == other.is_copy_fields && is_predefined_shape == other.is_predefined_shape && data_property == other.data_property && schema_drift_config == other.schema_drift_config && fixed_data_shape == other.fixed_data_shape && write_operation_config == other.write_operation_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/data_connectivity/models/target.rb', line 260 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
240 241 242 |
# File 'lib/oci/data_connectivity/models/target.rb', line 240 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
249 250 251 |
# File 'lib/oci/data_connectivity/models/target.rb', line 249 def hash [model_type, key, model_version, parent_ref, name, description, object_version, input_ports, output_ports, object_status, identifier, parameters, op_config_values, entity, is_read_access, is_copy_fields, is_predefined_shape, data_property, schema_drift_config, fixed_data_shape, write_operation_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
293 294 295 296 297 298 299 300 301 302 |
# File 'lib/oci/data_connectivity/models/target.rb', line 293 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
287 288 289 |
# File 'lib/oci/data_connectivity/models/target.rb', line 287 def to_s to_hash.to_s end |