Class: OCI::DataFlow::Models::Application

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_flow/models/application.rb

Overview

A Data Flow application object.

Constant Summary collapse

LANGUAGE_ENUM =
[
  LANGUAGE_SCALA = 'SCALA'.freeze,
  LANGUAGE_JAVA = 'JAVA'.freeze,
  LANGUAGE_PYTHON = 'PYTHON'.freeze,
  LANGUAGE_SQL = 'SQL'.freeze,
  LANGUAGE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Application

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :archive_uri (String)

    The value to assign to the #archive_uri property

  • :arguments (Array<String>)

    The value to assign to the #arguments property

  • :class_name (String)

    The value to assign to the #class_name property

  • :configuration (Hash<String, String>)

    The value to assign to the #configuration property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :description (String)

    The value to assign to the #description property

  • :display_name (String)

    The value to assign to the #display_name property

  • :driver_shape (String)

    The value to assign to the #driver_shape property

  • :execute (String)

    The value to assign to the #execute property

  • :executor_shape (String)

    The value to assign to the #executor_shape property

  • :file_uri (String)

    The value to assign to the #file_uri property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :id (String)

    The value to assign to the #id property

  • :language (String)

    The value to assign to the #language property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :logs_bucket_uri (String)

    The value to assign to the #logs_bucket_uri property

  • :metastore_id (String)

    The value to assign to the #metastore_id property

  • :num_executors (Integer)

    The value to assign to the #num_executors property

  • :owner_principal_id (String)

    The value to assign to the #owner_principal_id property

  • :owner_user_name (String)

    The value to assign to the #owner_user_name property

  • :parameters (Array<OCI::DataFlow::Models::ApplicationParameter>)

    The value to assign to the #parameters property

  • :private_endpoint_id (String)

    The value to assign to the #private_endpoint_id property

  • :spark_version (String)

    The value to assign to the #spark_version property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :warehouse_bucket_uri (String)

    The value to assign to the #warehouse_bucket_uri property



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/oci/data_flow/models/application.rb', line 294

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.archive_uri = attributes[:'archiveUri'] if attributes[:'archiveUri']

  raise 'You cannot provide both :archiveUri and :archive_uri' if attributes.key?(:'archiveUri') && attributes.key?(:'archive_uri')

  self.archive_uri = attributes[:'archive_uri'] if attributes[:'archive_uri']

  self.arguments = attributes[:'arguments'] if attributes[:'arguments']

  self.class_name = attributes[:'className'] if attributes[:'className']

  raise 'You cannot provide both :className and :class_name' if attributes.key?(:'className') && attributes.key?(:'class_name')

  self.class_name = attributes[:'class_name'] if attributes[:'class_name']

  self.configuration = attributes[:'configuration'] if attributes[:'configuration']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.driver_shape = attributes[:'driverShape'] if attributes[:'driverShape']

  raise 'You cannot provide both :driverShape and :driver_shape' if attributes.key?(:'driverShape') && attributes.key?(:'driver_shape')

  self.driver_shape = attributes[:'driver_shape'] if attributes[:'driver_shape']

  self.execute = attributes[:'execute'] if attributes[:'execute']

  self.executor_shape = attributes[:'executorShape'] if attributes[:'executorShape']

  raise 'You cannot provide both :executorShape and :executor_shape' if attributes.key?(:'executorShape') && attributes.key?(:'executor_shape')

  self.executor_shape = attributes[:'executor_shape'] if attributes[:'executor_shape']

  self.file_uri = attributes[:'fileUri'] if attributes[:'fileUri']

  raise 'You cannot provide both :fileUri and :file_uri' if attributes.key?(:'fileUri') && attributes.key?(:'file_uri')

  self.file_uri = attributes[:'file_uri'] if attributes[:'file_uri']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.id = attributes[:'id'] if attributes[:'id']

  self.language = attributes[:'language'] if attributes[:'language']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.logs_bucket_uri = attributes[:'logsBucketUri'] if attributes[:'logsBucketUri']

  raise 'You cannot provide both :logsBucketUri and :logs_bucket_uri' if attributes.key?(:'logsBucketUri') && attributes.key?(:'logs_bucket_uri')

  self.logs_bucket_uri = attributes[:'logs_bucket_uri'] if attributes[:'logs_bucket_uri']

  self.metastore_id = attributes[:'metastoreId'] if attributes[:'metastoreId']

  raise 'You cannot provide both :metastoreId and :metastore_id' if attributes.key?(:'metastoreId') && attributes.key?(:'metastore_id')

  self.metastore_id = attributes[:'metastore_id'] if attributes[:'metastore_id']

  self.num_executors = attributes[:'numExecutors'] if attributes[:'numExecutors']

  raise 'You cannot provide both :numExecutors and :num_executors' if attributes.key?(:'numExecutors') && attributes.key?(:'num_executors')

  self.num_executors = attributes[:'num_executors'] if attributes[:'num_executors']

  self.owner_principal_id = attributes[:'ownerPrincipalId'] if attributes[:'ownerPrincipalId']

  raise 'You cannot provide both :ownerPrincipalId and :owner_principal_id' if attributes.key?(:'ownerPrincipalId') && attributes.key?(:'owner_principal_id')

  self.owner_principal_id = attributes[:'owner_principal_id'] if attributes[:'owner_principal_id']

  self.owner_user_name = attributes[:'ownerUserName'] if attributes[:'ownerUserName']

  raise 'You cannot provide both :ownerUserName and :owner_user_name' if attributes.key?(:'ownerUserName') && attributes.key?(:'owner_user_name')

  self.owner_user_name = attributes[:'owner_user_name'] if attributes[:'owner_user_name']

  self.parameters = attributes[:'parameters'] if attributes[:'parameters']

  self.private_endpoint_id = attributes[:'privateEndpointId'] if attributes[:'privateEndpointId']

  raise 'You cannot provide both :privateEndpointId and :private_endpoint_id' if attributes.key?(:'privateEndpointId') && attributes.key?(:'private_endpoint_id')

  self.private_endpoint_id = attributes[:'private_endpoint_id'] if attributes[:'private_endpoint_id']

  self.spark_version = attributes[:'sparkVersion'] if attributes[:'sparkVersion']

  raise 'You cannot provide both :sparkVersion and :spark_version' if attributes.key?(:'sparkVersion') && attributes.key?(:'spark_version')

  self.spark_version = attributes[:'spark_version'] if attributes[:'spark_version']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.warehouse_bucket_uri = attributes[:'warehouseBucketUri'] if attributes[:'warehouseBucketUri']

  raise 'You cannot provide both :warehouseBucketUri and :warehouse_bucket_uri' if attributes.key?(:'warehouseBucketUri') && attributes.key?(:'warehouse_bucket_uri')

  self.warehouse_bucket_uri = attributes[:'warehouse_bucket_uri'] if attributes[:'warehouse_bucket_uri']
end

Instance Attribute Details

#archive_uriString

An Oracle Cloud Infrastructure URI of an archive.zip file containing custom dependencies that may be used to support the execution a Python, Java, or Scala application. See docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.

Returns:

  • (String)


31
32
33
# File 'lib/oci/data_flow/models/application.rb', line 31

def archive_uri
  @archive_uri
end

#argumentsArray<String>

The arguments passed to the running application as command line arguments. An argument is either a plain text or a placeholder. Placeholders are replaced using values from the parameters map. Each placeholder specified must be represented in the parameters map else the request (POST or PUT) will fail with a HTTP 400 status code. Placeholders are specified as ‘Service Api Spec`, where name is the name of the parameter. Example: `[ "–input", "$input_file", "–name", "John Doe" ]` If "input_file" has a value of "mydata.xml", then the value above will be translated to `–input mydata.xml –name "John Doe"`

Returns:

  • (Array<String>)


43
44
45
# File 'lib/oci/data_flow/models/application.rb', line 43

def arguments
  @arguments
end

#class_nameString

The class for the application.

Returns:

  • (String)


48
49
50
# File 'lib/oci/data_flow/models/application.rb', line 48

def class_name
  @class_name
end

#compartment_idString

[Required] The OCID of a compartment.

Returns:

  • (String)


62
63
64
# File 'lib/oci/data_flow/models/application.rb', line 62

def compartment_id
  @compartment_id
end

#configurationHash<String, String>

The Spark configuration passed to the running process. See spark.apache.org/docs/latest/configuration.html#available-properties. Example: { "spark.app.name" : "My App Name", "spark.shuffle.io.maxRetries" : "4" } Note: Not all Spark properties are permitted to be set. Attempting to set a property that is not allowed to be overwritten will cause a 400 status to be returned.

Returns:

  • (Hash<String, String>)


57
58
59
# File 'lib/oci/data_flow/models/application.rb', line 57

def configuration
  @configuration
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


68
69
70
# File 'lib/oci/data_flow/models/application.rb', line 68

def defined_tags
  @defined_tags
end

#descriptionString

A user-friendly description.

Returns:

  • (String)


73
74
75
# File 'lib/oci/data_flow/models/application.rb', line 73

def description
  @description
end

#display_nameString

[Required] A user-friendly name. This name is not necessarily unique.

Returns:

  • (String)


78
79
80
# File 'lib/oci/data_flow/models/application.rb', line 78

def display_name
  @display_name
end

#driver_shapeString

[Required] The VM shape for the driver. Sets the driver cores and memory.

Returns:

  • (String)


83
84
85
# File 'lib/oci/data_flow/models/application.rb', line 83

def driver_shape
  @driver_shape
end

#executeString

The input used for spark-submit command. For more details see spark.apache.org/docs/latest/submitting-applications.html#launching-applications-with-spark-submit. Supported options include --class, --file, --jars, --conf, --py-files, and main application file with arguments. Example: “–jars oci://path/to/a.jar,oci://path/to/b.jar –files oci://path/to/a.json,oci://path/to/b.csv –py-files oci://path/to/a.py,oci://path/to/b.py –conf spark.sql.crossJoin.enabled=true –class org.apache.spark.examples.SparkPi oci://path/to/main.jar 10“ Note: If execute is specified together with applicationId, className, configuration, fileUri, language, arguments, parameters during application create/update, or run create/submit, Data Flow service will use derived information from execute input only.

Returns:

  • (String)


92
93
94
# File 'lib/oci/data_flow/models/application.rb', line 92

def execute
  @execute
end

#executor_shapeString

[Required] The VM shape for the executors. Sets the executor cores and memory.

Returns:

  • (String)


97
98
99
# File 'lib/oci/data_flow/models/application.rb', line 97

def executor_shape
  @executor_shape
end

#file_uriString

[Required] An Oracle Cloud Infrastructure URI of the file containing the application to execute. See docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.

Returns:

  • (String)


103
104
105
# File 'lib/oci/data_flow/models/application.rb', line 103

def file_uri
  @file_uri
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


110
111
112
# File 'lib/oci/data_flow/models/application.rb', line 110

def freeform_tags
  @freeform_tags
end

#idString

[Required] The application ID.

Returns:

  • (String)


115
116
117
# File 'lib/oci/data_flow/models/application.rb', line 115

def id
  @id
end

#languageString

[Required] The Spark language.

Returns:

  • (String)


120
121
122
# File 'lib/oci/data_flow/models/application.rb', line 120

def language
  @language
end

#lifecycle_stateString

[Required] The current state of this application.

Returns:

  • (String)


125
126
127
# File 'lib/oci/data_flow/models/application.rb', line 125

def lifecycle_state
  @lifecycle_state
end

#logs_bucket_uriString

An Oracle Cloud Infrastructure URI of the bucket where the Spark job logs are to be uploaded. See docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.

Returns:

  • (String)


131
132
133
# File 'lib/oci/data_flow/models/application.rb', line 131

def logs_bucket_uri
  @logs_bucket_uri
end

#metastore_idString

The OCID of OCI Hive Metastore.

Returns:

  • (String)


136
137
138
# File 'lib/oci/data_flow/models/application.rb', line 136

def metastore_id
  @metastore_id
end

#num_executorsInteger

[Required] The number of executor VMs requested.

Returns:

  • (Integer)


141
142
143
# File 'lib/oci/data_flow/models/application.rb', line 141

def num_executors
  @num_executors
end

#owner_principal_idString

[Required] The OCID of the user who created the resource.

Returns:

  • (String)


146
147
148
# File 'lib/oci/data_flow/models/application.rb', line 146

def owner_principal_id
  @owner_principal_id
end

#owner_user_nameString

The username of the user who created the resource. If the username of the owner does not exist, null will be returned and the caller should refer to the ownerPrincipalId value instead.

Returns:

  • (String)


152
153
154
# File 'lib/oci/data_flow/models/application.rb', line 152

def owner_user_name
  @owner_user_name
end

#parametersArray<OCI::DataFlow::Models::ApplicationParameter>

An array of name/value pairs used to fill placeholders found in properties like Application.arguments. The name must be a string of one or more word characters (a-z, A-Z, 0-9, _). The value can be a string of 0 or more characters of any kind. Example: [ { name: "iterations", value: "10"}, { name: "input_file", value: "mydata.xml" }, { name: "variable_x", value: "$x"} ]



160
161
162
# File 'lib/oci/data_flow/models/application.rb', line 160

def parameters
  @parameters
end

#private_endpoint_idString

The OCID of a private endpoint.

Returns:

  • (String)


165
166
167
# File 'lib/oci/data_flow/models/application.rb', line 165

def private_endpoint_id
  @private_endpoint_id
end

#spark_versionString

[Required] The Spark version utilized to run the application.

Returns:

  • (String)


170
171
172
# File 'lib/oci/data_flow/models/application.rb', line 170

def spark_version
  @spark_version
end

#time_createdDateTime

[Required] The date and time a application was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: 2018-04-03T21:10:29.600Z

Returns:

  • (DateTime)


176
177
178
# File 'lib/oci/data_flow/models/application.rb', line 176

def time_created
  @time_created
end

#time_updatedDateTime

[Required] The date and time a application was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: 2018-04-03T21:10:29.600Z

Returns:

  • (DateTime)


182
183
184
# File 'lib/oci/data_flow/models/application.rb', line 182

def time_updated
  @time_updated
end

#warehouse_bucket_uriString

An Oracle Cloud Infrastructure URI of the bucket to be used as default warehouse directory for BATCH SQL runs. See docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.

Returns:

  • (String)


189
190
191
# File 'lib/oci/data_flow/models/application.rb', line 189

def warehouse_bucket_uri
  @warehouse_bucket_uri
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/oci/data_flow/models/application.rb', line 192

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'archive_uri': :'archiveUri',
    'arguments': :'arguments',
    'class_name': :'className',
    'configuration': :'configuration',
    'compartment_id': :'compartmentId',
    'defined_tags': :'definedTags',
    'description': :'description',
    'display_name': :'displayName',
    'driver_shape': :'driverShape',
    'execute': :'execute',
    'executor_shape': :'executorShape',
    'file_uri': :'fileUri',
    'freeform_tags': :'freeformTags',
    'id': :'id',
    'language': :'language',
    'lifecycle_state': :'lifecycleState',
    'logs_bucket_uri': :'logsBucketUri',
    'metastore_id': :'metastoreId',
    'num_executors': :'numExecutors',
    'owner_principal_id': :'ownerPrincipalId',
    'owner_user_name': :'ownerUserName',
    'parameters': :'parameters',
    'private_endpoint_id': :'privateEndpointId',
    'spark_version': :'sparkVersion',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'warehouse_bucket_uri': :'warehouseBucketUri'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/oci/data_flow/models/application.rb', line 227

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'archive_uri': :'String',
    'arguments': :'Array<String>',
    'class_name': :'String',
    'configuration': :'Hash<String, String>',
    'compartment_id': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'description': :'String',
    'display_name': :'String',
    'driver_shape': :'String',
    'execute': :'String',
    'executor_shape': :'String',
    'file_uri': :'String',
    'freeform_tags': :'Hash<String, String>',
    'id': :'String',
    'language': :'String',
    'lifecycle_state': :'String',
    'logs_bucket_uri': :'String',
    'metastore_id': :'String',
    'num_executors': :'Integer',
    'owner_principal_id': :'String',
    'owner_user_name': :'String',
    'parameters': :'Array<OCI::DataFlow::Models::ApplicationParameter>',
    'private_endpoint_id': :'String',
    'spark_version': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'warehouse_bucket_uri': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/oci/data_flow/models/application.rb', line 468

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    archive_uri == other.archive_uri &&
    arguments == other.arguments &&
    class_name == other.class_name &&
    configuration == other.configuration &&
    compartment_id == other.compartment_id &&
    defined_tags == other.defined_tags &&
    description == other.description &&
    display_name == other.display_name &&
    driver_shape == other.driver_shape &&
    execute == other.execute &&
    executor_shape == other.executor_shape &&
    file_uri == other.file_uri &&
    freeform_tags == other.freeform_tags &&
    id == other.id &&
    language == other.language &&
    lifecycle_state == other.lifecycle_state &&
    logs_bucket_uri == other.logs_bucket_uri &&
    metastore_id == other.metastore_id &&
    num_executors == other.num_executors &&
    owner_principal_id == other.owner_principal_id &&
    owner_user_name == other.owner_user_name &&
    parameters == other.parameters &&
    private_endpoint_id == other.private_endpoint_id &&
    spark_version == other.spark_version &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    warehouse_bucket_uri == other.warehouse_bucket_uri
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'lib/oci/data_flow/models/application.rb', line 524

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


504
505
506
# File 'lib/oci/data_flow/models/application.rb', line 504

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



513
514
515
# File 'lib/oci/data_flow/models/application.rb', line 513

def hash
  [archive_uri, arguments, class_name, configuration, compartment_id, defined_tags, description, display_name, driver_shape, execute, executor_shape, file_uri, freeform_tags, id, language, lifecycle_state, logs_bucket_uri, metastore_id, num_executors, owner_principal_id, owner_user_name, parameters, private_endpoint_id, spark_version, time_created, time_updated, warehouse_bucket_uri].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



557
558
559
560
561
562
563
564
565
566
# File 'lib/oci/data_flow/models/application.rb', line 557

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



551
552
553
# File 'lib/oci/data_flow/models/application.rb', line 551

def to_s
  to_hash.to_s
end