Class: OCI::DataFlow::Models::Run
- Inherits:
-
Object
- Object
- OCI::DataFlow::Models::Run
- Defined in:
- lib/oci/data_flow/models/run.rb
Overview
A run object.
Constant Summary collapse
- LANGUAGE_ENUM =
[ LANGUAGE_SCALA = 'SCALA'.freeze, LANGUAGE_JAVA = 'JAVA'.freeze, LANGUAGE_PYTHON = 'PYTHON'.freeze, LANGUAGE_SQL = 'SQL'.freeze, LANGUAGE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_STOPPING = 'STOPPING'.freeze, LIFECYCLE_STATE_STOPPED = 'STOPPED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TYPE_ENUM =
[ TYPE_BATCH = 'BATCH'.freeze, TYPE_STREAMING = 'STREAMING'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#application_id ⇒ String
[Required] The application ID.
-
#archive_uri ⇒ String
An Oracle Cloud Infrastructure URI of an archive.zip file containing custom dependencies that may be used to support the execution a Python, Java, or Scala application.
-
#arguments ⇒ Array<String>
The arguments passed to the running application as command line arguments.
-
#class_name ⇒ String
The class for the application.
-
#compartment_id ⇒ String
[Required] The OCID of a compartment.
-
#configuration ⇒ Hash<String, String>
The Spark configuration passed to the running process.
-
#data_read_in_bytes ⇒ Integer
The data read by the run in bytes.
-
#data_written_in_bytes ⇒ Integer
The data written by the run in bytes.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#driver_shape ⇒ String
[Required] The VM shape for the driver.
-
#execute ⇒ String
The input used for spark-submit command.
-
#executor_shape ⇒ String
[Required] The VM shape for the executors.
-
#file_uri ⇒ String
[Required] An Oracle Cloud Infrastructure URI of the file containing the application to execute.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The ID of a run.
-
#language ⇒ String
[Required] The Spark language.
-
#lifecycle_details ⇒ String
The detailed messages about the lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of this run.
-
#logs_bucket_uri ⇒ String
An Oracle Cloud Infrastructure URI of the bucket where the Spark job logs are to be uploaded.
-
#metastore_id ⇒ String
The OCID of OCI Hive Metastore.
-
#num_executors ⇒ Integer
[Required] The number of executor VMs requested.
-
#opc_request_id ⇒ String
Unique Oracle assigned identifier for the request.
-
#owner_principal_id ⇒ String
The OCID of the user who created the resource.
-
#owner_user_name ⇒ String
The username of the user who created the resource.
-
#parameters ⇒ Array<OCI::DataFlow::Models::ApplicationParameter>
An array of name/value pairs used to fill placeholders found in properties like
Application.arguments. -
#private_endpoint_dns_zones ⇒ Array<String>
An array of DNS zone names.
-
#private_endpoint_id ⇒ String
The OCID of a private endpoint.
-
#private_endpoint_max_host_count ⇒ Integer
The maximum number of hosts to be accessed through the private endpoint.
-
#private_endpoint_nsg_ids ⇒ Array<String>
An array of network security group OCIDs.
-
#private_endpoint_subnet_id ⇒ String
The OCID of a subnet.
-
#run_duration_in_milliseconds ⇒ Integer
The duration of the run in milliseconds.
-
#spark_version ⇒ String
[Required] The Spark version utilized to run the application.
-
#time_created ⇒ DateTime
[Required] The date and time a application was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_updated ⇒ DateTime
[Required] The date and time a application was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#total_o_cpu ⇒ Integer
The total number of oCPU requested by the run.
-
#type ⇒ String
The Spark application processing type.
-
#warehouse_bucket_uri ⇒ String
An Oracle Cloud Infrastructure URI of the bucket to be used as default warehouse directory for BATCH SQL runs.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Run
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Run
Initializes the object
398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 |
# File 'lib/oci/data_flow/models/run.rb', line 398 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.archive_uri = attributes[:'archiveUri'] if attributes[:'archiveUri'] raise 'You cannot provide both :archiveUri and :archive_uri' if attributes.key?(:'archiveUri') && attributes.key?(:'archive_uri') self.archive_uri = attributes[:'archive_uri'] if attributes[:'archive_uri'] self.arguments = attributes[:'arguments'] if attributes[:'arguments'] self.application_id = attributes[:'applicationId'] if attributes[:'applicationId'] raise 'You cannot provide both :applicationId and :application_id' if attributes.key?(:'applicationId') && attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] if attributes[:'application_id'] self.class_name = attributes[:'className'] if attributes[:'className'] raise 'You cannot provide both :className and :class_name' if attributes.key?(:'className') && attributes.key?(:'class_name') self.class_name = attributes[:'class_name'] if attributes[:'class_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.configuration = attributes[:'configuration'] if attributes[:'configuration'] self.data_read_in_bytes = attributes[:'dataReadInBytes'] if attributes[:'dataReadInBytes'] raise 'You cannot provide both :dataReadInBytes and :data_read_in_bytes' if attributes.key?(:'dataReadInBytes') && attributes.key?(:'data_read_in_bytes') self.data_read_in_bytes = attributes[:'data_read_in_bytes'] if attributes[:'data_read_in_bytes'] self.data_written_in_bytes = attributes[:'dataWrittenInBytes'] if attributes[:'dataWrittenInBytes'] raise 'You cannot provide both :dataWrittenInBytes and :data_written_in_bytes' if attributes.key?(:'dataWrittenInBytes') && attributes.key?(:'data_written_in_bytes') self.data_written_in_bytes = attributes[:'data_written_in_bytes'] if attributes[:'data_written_in_bytes'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.driver_shape = attributes[:'driverShape'] if attributes[:'driverShape'] raise 'You cannot provide both :driverShape and :driver_shape' if attributes.key?(:'driverShape') && attributes.key?(:'driver_shape') self.driver_shape = attributes[:'driver_shape'] if attributes[:'driver_shape'] self.execute = attributes[:'execute'] if attributes[:'execute'] self.executor_shape = attributes[:'executorShape'] if attributes[:'executorShape'] raise 'You cannot provide both :executorShape and :executor_shape' if attributes.key?(:'executorShape') && attributes.key?(:'executor_shape') self.executor_shape = attributes[:'executor_shape'] if attributes[:'executor_shape'] self.file_uri = attributes[:'fileUri'] if attributes[:'fileUri'] raise 'You cannot provide both :fileUri and :file_uri' if attributes.key?(:'fileUri') && attributes.key?(:'file_uri') self.file_uri = attributes[:'file_uri'] if attributes[:'file_uri'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.language = attributes[:'language'] if attributes[:'language'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.logs_bucket_uri = attributes[:'logsBucketUri'] if attributes[:'logsBucketUri'] raise 'You cannot provide both :logsBucketUri and :logs_bucket_uri' if attributes.key?(:'logsBucketUri') && attributes.key?(:'logs_bucket_uri') self.logs_bucket_uri = attributes[:'logs_bucket_uri'] if attributes[:'logs_bucket_uri'] self. = attributes[:'metastoreId'] if attributes[:'metastoreId'] raise 'You cannot provide both :metastoreId and :metastore_id' if attributes.key?(:'metastoreId') && attributes.key?(:'metastore_id') self. = attributes[:'metastore_id'] if attributes[:'metastore_id'] self.num_executors = attributes[:'numExecutors'] if attributes[:'numExecutors'] raise 'You cannot provide both :numExecutors and :num_executors' if attributes.key?(:'numExecutors') && attributes.key?(:'num_executors') self.num_executors = attributes[:'num_executors'] if attributes[:'num_executors'] self.opc_request_id = attributes[:'opcRequestId'] if attributes[:'opcRequestId'] raise 'You cannot provide both :opcRequestId and :opc_request_id' if attributes.key?(:'opcRequestId') && attributes.key?(:'opc_request_id') self.opc_request_id = attributes[:'opc_request_id'] if attributes[:'opc_request_id'] self.owner_principal_id = attributes[:'ownerPrincipalId'] if attributes[:'ownerPrincipalId'] raise 'You cannot provide both :ownerPrincipalId and :owner_principal_id' if attributes.key?(:'ownerPrincipalId') && attributes.key?(:'owner_principal_id') self.owner_principal_id = attributes[:'owner_principal_id'] if attributes[:'owner_principal_id'] self.owner_user_name = attributes[:'ownerUserName'] if attributes[:'ownerUserName'] raise 'You cannot provide both :ownerUserName and :owner_user_name' if attributes.key?(:'ownerUserName') && attributes.key?(:'owner_user_name') self.owner_user_name = attributes[:'owner_user_name'] if attributes[:'owner_user_name'] self.parameters = attributes[:'parameters'] if attributes[:'parameters'] self.private_endpoint_dns_zones = attributes[:'privateEndpointDnsZones'] if attributes[:'privateEndpointDnsZones'] raise 'You cannot provide both :privateEndpointDnsZones and :private_endpoint_dns_zones' if attributes.key?(:'privateEndpointDnsZones') && attributes.key?(:'private_endpoint_dns_zones') self.private_endpoint_dns_zones = attributes[:'private_endpoint_dns_zones'] if attributes[:'private_endpoint_dns_zones'] self.private_endpoint_max_host_count = attributes[:'privateEndpointMaxHostCount'] if attributes[:'privateEndpointMaxHostCount'] raise 'You cannot provide both :privateEndpointMaxHostCount and :private_endpoint_max_host_count' if attributes.key?(:'privateEndpointMaxHostCount') && attributes.key?(:'private_endpoint_max_host_count') self.private_endpoint_max_host_count = attributes[:'private_endpoint_max_host_count'] if attributes[:'private_endpoint_max_host_count'] self.private_endpoint_nsg_ids = attributes[:'privateEndpointNsgIds'] if attributes[:'privateEndpointNsgIds'] raise 'You cannot provide both :privateEndpointNsgIds and :private_endpoint_nsg_ids' if attributes.key?(:'privateEndpointNsgIds') && attributes.key?(:'private_endpoint_nsg_ids') self.private_endpoint_nsg_ids = attributes[:'private_endpoint_nsg_ids'] if attributes[:'private_endpoint_nsg_ids'] self.private_endpoint_id = attributes[:'privateEndpointId'] if attributes[:'privateEndpointId'] raise 'You cannot provide both :privateEndpointId and :private_endpoint_id' if attributes.key?(:'privateEndpointId') && attributes.key?(:'private_endpoint_id') self.private_endpoint_id = attributes[:'private_endpoint_id'] if attributes[:'private_endpoint_id'] self.private_endpoint_subnet_id = attributes[:'privateEndpointSubnetId'] if attributes[:'privateEndpointSubnetId'] raise 'You cannot provide both :privateEndpointSubnetId and :private_endpoint_subnet_id' if attributes.key?(:'privateEndpointSubnetId') && attributes.key?(:'private_endpoint_subnet_id') self.private_endpoint_subnet_id = attributes[:'private_endpoint_subnet_id'] if attributes[:'private_endpoint_subnet_id'] self.run_duration_in_milliseconds = attributes[:'runDurationInMilliseconds'] if attributes[:'runDurationInMilliseconds'] raise 'You cannot provide both :runDurationInMilliseconds and :run_duration_in_milliseconds' if attributes.key?(:'runDurationInMilliseconds') && attributes.key?(:'run_duration_in_milliseconds') self.run_duration_in_milliseconds = attributes[:'run_duration_in_milliseconds'] if attributes[:'run_duration_in_milliseconds'] self.spark_version = attributes[:'sparkVersion'] if attributes[:'sparkVersion'] raise 'You cannot provide both :sparkVersion and :spark_version' if attributes.key?(:'sparkVersion') && attributes.key?(:'spark_version') self.spark_version = attributes[:'spark_version'] if attributes[:'spark_version'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.total_o_cpu = attributes[:'totalOCpu'] if attributes[:'totalOCpu'] raise 'You cannot provide both :totalOCpu and :total_o_cpu' if attributes.key?(:'totalOCpu') && attributes.key?(:'total_o_cpu') self.total_o_cpu = attributes[:'total_o_cpu'] if attributes[:'total_o_cpu'] self.type = attributes[:'type'] if attributes[:'type'] self.type = "BATCH" if type.nil? && !attributes.key?(:'type') # rubocop:disable Style/StringLiterals self.warehouse_bucket_uri = attributes[:'warehouseBucketUri'] if attributes[:'warehouseBucketUri'] raise 'You cannot provide both :warehouseBucketUri and :warehouse_bucket_uri' if attributes.key?(:'warehouseBucketUri') && attributes.key?(:'warehouse_bucket_uri') self.warehouse_bucket_uri = attributes[:'warehouse_bucket_uri'] if attributes[:'warehouse_bucket_uri'] end |
Instance Attribute Details
#application_id ⇒ String
[Required] The application ID.
59 60 61 |
# File 'lib/oci/data_flow/models/run.rb', line 59 def application_id @application_id end |
#archive_uri ⇒ String
An Oracle Cloud Infrastructure URI of an archive.zip file containing custom dependencies that may be used to support the execution a Python, Java, or Scala application. See docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.
42 43 44 |
# File 'lib/oci/data_flow/models/run.rb', line 42 def archive_uri @archive_uri end |
#arguments ⇒ Array<String>
The arguments passed to the running application as command line arguments. An argument is either a plain text or a placeholder. Placeholders are replaced using values from the parameters map. Each placeholder specified must be represented in the parameters map else the request (POST or PUT) will fail with a HTTP 400 status code. Placeholders are specified as ‘Service Api Spec`, where name is the name of the parameter. Example: `[ "–input", "$input_file", "–name", "John Doe" ]` If "input_file" has a value of "mydata.xml", then the value above will be translated to `–input mydata.xml –name "John Doe"`
54 55 56 |
# File 'lib/oci/data_flow/models/run.rb', line 54 def arguments @arguments end |
#class_name ⇒ String
The class for the application.
64 65 66 |
# File 'lib/oci/data_flow/models/run.rb', line 64 def class_name @class_name end |
#compartment_id ⇒ String
[Required] The OCID of a compartment.
69 70 71 |
# File 'lib/oci/data_flow/models/run.rb', line 69 def compartment_id @compartment_id end |
#configuration ⇒ Hash<String, String>
The Spark configuration passed to the running process. See spark.apache.org/docs/latest/configuration.html#available-properties. Example: { "spark.app.name" : "My App Name", "spark.shuffle.io.maxRetries" : "4" } Note: Not all Spark properties are permitted to be set. Attempting to set a property that is not allowed to be overwritten will cause a 400 status to be returned.
78 79 80 |
# File 'lib/oci/data_flow/models/run.rb', line 78 def configuration @configuration end |
#data_read_in_bytes ⇒ Integer
The data read by the run in bytes.
83 84 85 |
# File 'lib/oci/data_flow/models/run.rb', line 83 def data_read_in_bytes @data_read_in_bytes end |
#data_written_in_bytes ⇒ Integer
The data written by the run in bytes.
88 89 90 |
# File 'lib/oci/data_flow/models/run.rb', line 88 def data_written_in_bytes @data_written_in_bytes end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
94 95 96 |
# File 'lib/oci/data_flow/models/run.rb', line 94 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. This name is not necessarily unique.
99 100 101 |
# File 'lib/oci/data_flow/models/run.rb', line 99 def display_name @display_name end |
#driver_shape ⇒ String
[Required] The VM shape for the driver. Sets the driver cores and memory.
104 105 106 |
# File 'lib/oci/data_flow/models/run.rb', line 104 def driver_shape @driver_shape end |
#execute ⇒ String
The input used for spark-submit command. For more details see spark.apache.org/docs/latest/submitting-applications.html#launching-applications-with-spark-submit. Supported options include --class, --file, --jars, --conf, --py-files, and main application file with arguments. Example: “–jars oci://path/to/a.jar,oci://path/to/b.jar –files oci://path/to/a.json,oci://path/to/b.csv –py-files oci://path/to/a.py,oci://path/to/b.py –conf spark.sql.crossJoin.enabled=true –class org.apache.spark.examples.SparkPi oci://path/to/main.jar 10“ Note: If execute is specified together with applicationId, className, configuration, fileUri, language, arguments, parameters during application create/update, or run create/submit, Data Flow service will use derived information from execute input only.
113 114 115 |
# File 'lib/oci/data_flow/models/run.rb', line 113 def execute @execute end |
#executor_shape ⇒ String
[Required] The VM shape for the executors. Sets the executor cores and memory.
118 119 120 |
# File 'lib/oci/data_flow/models/run.rb', line 118 def executor_shape @executor_shape end |
#file_uri ⇒ String
[Required] An Oracle Cloud Infrastructure URI of the file containing the application to execute. See docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.
124 125 126 |
# File 'lib/oci/data_flow/models/run.rb', line 124 def file_uri @file_uri end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
131 132 133 |
# File 'lib/oci/data_flow/models/run.rb', line 131 def @freeform_tags end |
#id ⇒ String
[Required] The ID of a run.
136 137 138 |
# File 'lib/oci/data_flow/models/run.rb', line 136 def id @id end |
#language ⇒ String
[Required] The Spark language.
141 142 143 |
# File 'lib/oci/data_flow/models/run.rb', line 141 def language @language end |
#lifecycle_details ⇒ String
The detailed messages about the lifecycle state.
146 147 148 |
# File 'lib/oci/data_flow/models/run.rb', line 146 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of this run.
151 152 153 |
# File 'lib/oci/data_flow/models/run.rb', line 151 def lifecycle_state @lifecycle_state end |
#logs_bucket_uri ⇒ String
An Oracle Cloud Infrastructure URI of the bucket where the Spark job logs are to be uploaded. See docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.
157 158 159 |
# File 'lib/oci/data_flow/models/run.rb', line 157 def logs_bucket_uri @logs_bucket_uri end |
#metastore_id ⇒ String
The OCID of OCI Hive Metastore.
162 163 164 |
# File 'lib/oci/data_flow/models/run.rb', line 162 def @metastore_id end |
#num_executors ⇒ Integer
[Required] The number of executor VMs requested.
167 168 169 |
# File 'lib/oci/data_flow/models/run.rb', line 167 def num_executors @num_executors end |
#opc_request_id ⇒ String
Unique Oracle assigned identifier for the request. If you need to contact Oracle about a particular request, please provide the request ID.
173 174 175 |
# File 'lib/oci/data_flow/models/run.rb', line 173 def opc_request_id @opc_request_id end |
#owner_principal_id ⇒ String
The OCID of the user who created the resource.
178 179 180 |
# File 'lib/oci/data_flow/models/run.rb', line 178 def owner_principal_id @owner_principal_id end |
#owner_user_name ⇒ String
The username of the user who created the resource. If the username of the owner does not exist, null will be returned and the caller should refer to the ownerPrincipalId value instead.
184 185 186 |
# File 'lib/oci/data_flow/models/run.rb', line 184 def owner_user_name @owner_user_name end |
#parameters ⇒ Array<OCI::DataFlow::Models::ApplicationParameter>
An array of name/value pairs used to fill placeholders found in properties like Application.arguments. The name must be a string of one or more word characters (a-z, A-Z, 0-9, _). The value can be a string of 0 or more characters of any kind. Example: [ { name: "iterations", value: "10"}, { name: "input_file", value: "mydata.xml" }, { name: "variable_x", value: "$x"} ]
192 193 194 |
# File 'lib/oci/data_flow/models/run.rb', line 192 def parameters @parameters end |
#private_endpoint_dns_zones ⇒ Array<String>
An array of DNS zone names. Example: ‘[ "app.examplecorp.com", "app.examplecorp2.com" ]`
198 199 200 |
# File 'lib/oci/data_flow/models/run.rb', line 198 def private_endpoint_dns_zones @private_endpoint_dns_zones end |
#private_endpoint_id ⇒ String
The OCID of a private endpoint.
216 217 218 |
# File 'lib/oci/data_flow/models/run.rb', line 216 def private_endpoint_id @private_endpoint_id end |
#private_endpoint_max_host_count ⇒ Integer
The maximum number of hosts to be accessed through the private endpoint. This value is used to calculate the relevant CIDR block and should be a multiple of 256. If the value is not a multiple of 256, it is rounded up to the next multiple of 256. For example, 300 is rounded up to 512.
206 207 208 |
# File 'lib/oci/data_flow/models/run.rb', line 206 def private_endpoint_max_host_count @private_endpoint_max_host_count end |
#private_endpoint_nsg_ids ⇒ Array<String>
An array of network security group OCIDs.
211 212 213 |
# File 'lib/oci/data_flow/models/run.rb', line 211 def private_endpoint_nsg_ids @private_endpoint_nsg_ids end |
#private_endpoint_subnet_id ⇒ String
The OCID of a subnet.
221 222 223 |
# File 'lib/oci/data_flow/models/run.rb', line 221 def private_endpoint_subnet_id @private_endpoint_subnet_id end |
#run_duration_in_milliseconds ⇒ Integer
The duration of the run in milliseconds.
226 227 228 |
# File 'lib/oci/data_flow/models/run.rb', line 226 def run_duration_in_milliseconds @run_duration_in_milliseconds end |
#spark_version ⇒ String
[Required] The Spark version utilized to run the application.
231 232 233 |
# File 'lib/oci/data_flow/models/run.rb', line 231 def spark_version @spark_version end |
#time_created ⇒ DateTime
[Required] The date and time a application was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: 2018-04-03T21:10:29.600Z
237 238 239 |
# File 'lib/oci/data_flow/models/run.rb', line 237 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time a application was updated, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: 2018-04-03T21:10:29.600Z
243 244 245 |
# File 'lib/oci/data_flow/models/run.rb', line 243 def time_updated @time_updated end |
#total_o_cpu ⇒ Integer
The total number of oCPU requested by the run.
248 249 250 |
# File 'lib/oci/data_flow/models/run.rb', line 248 def total_o_cpu @total_o_cpu end |
#type ⇒ String
The Spark application processing type.
253 254 255 |
# File 'lib/oci/data_flow/models/run.rb', line 253 def type @type end |
#warehouse_bucket_uri ⇒ String
An Oracle Cloud Infrastructure URI of the bucket to be used as default warehouse directory for BATCH SQL runs. See docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.
260 261 262 |
# File 'lib/oci/data_flow/models/run.rb', line 260 def warehouse_bucket_uri @warehouse_bucket_uri end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/oci/data_flow/models/run.rb', line 263 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'archive_uri': :'archiveUri', 'arguments': :'arguments', 'application_id': :'applicationId', 'class_name': :'className', 'compartment_id': :'compartmentId', 'configuration': :'configuration', 'data_read_in_bytes': :'dataReadInBytes', 'data_written_in_bytes': :'dataWrittenInBytes', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'driver_shape': :'driverShape', 'execute': :'execute', 'executor_shape': :'executorShape', 'file_uri': :'fileUri', 'freeform_tags': :'freeformTags', 'id': :'id', 'language': :'language', 'lifecycle_details': :'lifecycleDetails', 'lifecycle_state': :'lifecycleState', 'logs_bucket_uri': :'logsBucketUri', 'metastore_id': :'metastoreId', 'num_executors': :'numExecutors', 'opc_request_id': :'opcRequestId', 'owner_principal_id': :'ownerPrincipalId', 'owner_user_name': :'ownerUserName', 'parameters': :'parameters', 'private_endpoint_dns_zones': :'privateEndpointDnsZones', 'private_endpoint_max_host_count': :'privateEndpointMaxHostCount', 'private_endpoint_nsg_ids': :'privateEndpointNsgIds', 'private_endpoint_id': :'privateEndpointId', 'private_endpoint_subnet_id': :'privateEndpointSubnetId', 'run_duration_in_milliseconds': :'runDurationInMilliseconds', 'spark_version': :'sparkVersion', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'total_o_cpu': :'totalOCpu', 'type': :'type', 'warehouse_bucket_uri': :'warehouseBucketUri' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/oci/data_flow/models/run.rb', line 309 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'archive_uri': :'String', 'arguments': :'Array<String>', 'application_id': :'String', 'class_name': :'String', 'compartment_id': :'String', 'configuration': :'Hash<String, String>', 'data_read_in_bytes': :'Integer', 'data_written_in_bytes': :'Integer', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'driver_shape': :'String', 'execute': :'String', 'executor_shape': :'String', 'file_uri': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'language': :'String', 'lifecycle_details': :'String', 'lifecycle_state': :'String', 'logs_bucket_uri': :'String', 'metastore_id': :'String', 'num_executors': :'Integer', 'opc_request_id': :'String', 'owner_principal_id': :'String', 'owner_user_name': :'String', 'parameters': :'Array<OCI::DataFlow::Models::ApplicationParameter>', 'private_endpoint_dns_zones': :'Array<String>', 'private_endpoint_max_host_count': :'Integer', 'private_endpoint_nsg_ids': :'Array<String>', 'private_endpoint_id': :'String', 'private_endpoint_subnet_id': :'String', 'run_duration_in_milliseconds': :'Integer', 'spark_version': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'total_o_cpu': :'Integer', 'type': :'String', 'warehouse_bucket_uri': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 |
# File 'lib/oci/data_flow/models/run.rb', line 652 def ==(other) return true if equal?(other) self.class == other.class && archive_uri == other.archive_uri && arguments == other.arguments && application_id == other.application_id && class_name == other.class_name && compartment_id == other.compartment_id && configuration == other.configuration && data_read_in_bytes == other.data_read_in_bytes && data_written_in_bytes == other.data_written_in_bytes && == other. && display_name == other.display_name && driver_shape == other.driver_shape && execute == other.execute && executor_shape == other.executor_shape && file_uri == other.file_uri && == other. && id == other.id && language == other.language && lifecycle_details == other.lifecycle_details && lifecycle_state == other.lifecycle_state && logs_bucket_uri == other.logs_bucket_uri && == other. && num_executors == other.num_executors && opc_request_id == other.opc_request_id && owner_principal_id == other.owner_principal_id && owner_user_name == other.owner_user_name && parameters == other.parameters && private_endpoint_dns_zones == other.private_endpoint_dns_zones && private_endpoint_max_host_count == other.private_endpoint_max_host_count && private_endpoint_nsg_ids == other.private_endpoint_nsg_ids && private_endpoint_id == other.private_endpoint_id && private_endpoint_subnet_id == other.private_endpoint_subnet_id && run_duration_in_milliseconds == other.run_duration_in_milliseconds && spark_version == other.spark_version && time_created == other.time_created && time_updated == other.time_updated && total_o_cpu == other.total_o_cpu && type == other.type && warehouse_bucket_uri == other.warehouse_bucket_uri end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'lib/oci/data_flow/models/run.rb', line 719 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
699 700 701 |
# File 'lib/oci/data_flow/models/run.rb', line 699 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
708 709 710 |
# File 'lib/oci/data_flow/models/run.rb', line 708 def hash [archive_uri, arguments, application_id, class_name, compartment_id, configuration, data_read_in_bytes, data_written_in_bytes, , display_name, driver_shape, execute, executor_shape, file_uri, , id, language, lifecycle_details, lifecycle_state, logs_bucket_uri, , num_executors, opc_request_id, owner_principal_id, owner_user_name, parameters, private_endpoint_dns_zones, private_endpoint_max_host_count, private_endpoint_nsg_ids, private_endpoint_id, private_endpoint_subnet_id, run_duration_in_milliseconds, spark_version, time_created, time_updated, total_o_cpu, type, warehouse_bucket_uri].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
752 753 754 755 756 757 758 759 760 761 |
# File 'lib/oci/data_flow/models/run.rb', line 752 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
746 747 748 |
# File 'lib/oci/data_flow/models/run.rb', line 746 def to_s to_hash.to_s end |