Class: OCI::DataFlow::Models::UpdatePrivateEndpointDetails
- Inherits:
-
Object
- Object
- OCI::DataFlow::Models::UpdatePrivateEndpointDetails
- Defined in:
- lib/oci/data_flow/models/update_private_endpoint_details.rb
Overview
The details required to update a private endpoint.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A user-friendly description.
-
#display_name ⇒ String
A user-friendly name.
-
#dns_zones ⇒ Array<String>
An array of DNS zone names.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#max_host_count ⇒ Integer
The maximum number of hosts to be accessed through the private endpoint.
-
#nsg_ids ⇒ Array<String>
An array of network security group OCIDs.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdatePrivateEndpointDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdatePrivateEndpointDetails
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 96 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.dns_zones = attributes[:'dnsZones'] if attributes[:'dnsZones'] raise 'You cannot provide both :dnsZones and :dns_zones' if attributes.key?(:'dnsZones') && attributes.key?(:'dns_zones') self.dns_zones = attributes[:'dns_zones'] if attributes[:'dns_zones'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.max_host_count = attributes[:'maxHostCount'] if attributes[:'maxHostCount'] raise 'You cannot provide both :maxHostCount and :max_host_count' if attributes.key?(:'maxHostCount') && attributes.key?(:'max_host_count') self.max_host_count = attributes[:'max_host_count'] if attributes[:'max_host_count'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
15 16 17 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 15 def end |
#description ⇒ String
A user-friendly description. Avoid entering confidential information.
20 21 22 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 20 def description @description end |
#display_name ⇒ String
A user-friendly name. It does not have to be unique. Avoid entering confidential information.
25 26 27 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 25 def display_name @display_name end |
#dns_zones ⇒ Array<String>
An array of DNS zone names. Example: ‘[ "app.examplecorp.com", "app.examplecorp2.com" ]`
31 32 33 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 31 def dns_zones @dns_zones end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
38 39 40 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 38 def end |
#max_host_count ⇒ Integer
The maximum number of hosts to be accessed through the private endpoint. This value is used to calculate the relevant CIDR block and should be a multiple of 256. If the value is not a multiple of 256, it is rounded up to the next multiple of 256. For example, 300 is rounded up to 512.
46 47 48 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 46 def max_host_count @max_host_count end |
#nsg_ids ⇒ Array<String>
An array of network security group OCIDs.
51 52 53 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 51 def nsg_ids @nsg_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 54 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'definedTags', 'description': :'description', 'display_name': :'displayName', 'dns_zones': :'dnsZones', 'freeform_tags': :'freeformTags', 'max_host_count': :'maxHostCount', 'nsg_ids': :'nsgIds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'defined_tags': :'Hash<String, Hash<String, Object>>', 'description': :'String', 'display_name': :'String', 'dns_zones': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'max_host_count': :'Integer', 'nsg_ids': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 148 def ==(other) return true if equal?(other) self.class == other.class && == other. && description == other.description && display_name == other.display_name && dns_zones == other.dns_zones && == other. && max_host_count == other.max_host_count && nsg_ids == other.nsg_ids end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 184 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
164 165 166 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 164 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 173 def hash [, description, display_name, dns_zones, , max_host_count, nsg_ids].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
211 212 213 |
# File 'lib/oci/data_flow/models/update_private_endpoint_details.rb', line 211 def to_s to_hash.to_s end |