Class: OCI::DataIntegration::Models::ChildReference
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::ChildReference
- Defined in:
- lib/oci/data_integration/models/child_reference.rb
Overview
Child reference contains application configuration information.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_ORACLEDB_CONNECTION = 'ORACLEDB_CONNECTION'.freeze, TYPE_ORACLE_OBJECT_STORAGE_CONNECTION = 'ORACLE_OBJECT_STORAGE_CONNECTION'.freeze, TYPE_ORACLE_ATP_CONNECTION = 'ORACLE_ATP_CONNECTION'.freeze, TYPE_ORACLE_ADWC_CONNECTION = 'ORACLE_ADWC_CONNECTION'.freeze, TYPE_MYSQL_CONNECTION = 'MYSQL_CONNECTION'.freeze, TYPE_GENERIC_JDBC_CONNECTION = 'GENERIC_JDBC_CONNECTION'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#aggregator_key ⇒ String
The aggregator key of the child reference object.
-
#description ⇒ String
The description of reference object.
-
#identifier ⇒ String
The identifier of reference object.
-
#identifier_path ⇒ String
The identifier path of reference object.
-
#key ⇒ String
The reference’s key, key of the object that is being used by a published object or its dependents.
-
#name ⇒ String
The name of reference object.
-
#target_object ⇒ Object
The new reference object to use instead of the original reference.
-
#type ⇒ String
The type of the reference object.
-
#used_by ⇒ Array<OCI::DataIntegration::Models::ReferenceUsedBy>
List of published objects where this is used.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChildReference
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ChildReference
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 106 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.name = attributes[:'name'] if attributes[:'name'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.identifier_path = attributes[:'identifierPath'] if attributes[:'identifierPath'] raise 'You cannot provide both :identifierPath and :identifier_path' if attributes.key?(:'identifierPath') && attributes.key?(:'identifier_path') self.identifier_path = attributes[:'identifier_path'] if attributes[:'identifier_path'] self.description = attributes[:'description'] if attributes[:'description'] self.type = attributes[:'type'] if attributes[:'type'] self.target_object = attributes[:'targetObject'] if attributes[:'targetObject'] raise 'You cannot provide both :targetObject and :target_object' if attributes.key?(:'targetObject') && attributes.key?(:'target_object') self.target_object = attributes[:'target_object'] if attributes[:'target_object'] self.aggregator_key = attributes[:'aggregatorKey'] if attributes[:'aggregatorKey'] raise 'You cannot provide both :aggregatorKey and :aggregator_key' if attributes.key?(:'aggregatorKey') && attributes.key?(:'aggregator_key') self.aggregator_key = attributes[:'aggregator_key'] if attributes[:'aggregator_key'] self.used_by = attributes[:'usedBy'] if attributes[:'usedBy'] raise 'You cannot provide both :usedBy and :used_by' if attributes.key?(:'usedBy') && attributes.key?(:'used_by') self.used_by = attributes[:'used_by'] if attributes[:'used_by'] end |
Instance Attribute Details
#aggregator_key ⇒ String
The aggregator key of the child reference object. For example, this can be a data asset key.
51 52 53 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 51 def aggregator_key @aggregator_key end |
#description ⇒ String
The description of reference object.
39 40 41 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 39 def description @description end |
#identifier ⇒ String
The identifier of reference object.
31 32 33 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 31 def identifier @identifier end |
#identifier_path ⇒ String
The identifier path of reference object.
35 36 37 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 35 def identifier_path @identifier_path end |
#key ⇒ String
The reference’s key, key of the object that is being used by a published object or its dependents.
23 24 25 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 23 def key @key end |
#name ⇒ String
The name of reference object.
27 28 29 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 27 def name @name end |
#target_object ⇒ Object
The new reference object to use instead of the original reference. For example, this can be a data asset reference.
47 48 49 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 47 def target_object @target_object end |
#type ⇒ String
The type of the reference object.
43 44 45 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 43 def type @type end |
#used_by ⇒ Array<OCI::DataIntegration::Models::ReferenceUsedBy>
List of published objects where this is used.
55 56 57 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 55 def used_by @used_by end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'name': :'name', 'identifier': :'identifier', 'identifier_path': :'identifierPath', 'description': :'description', 'type': :'type', 'target_object': :'targetObject', 'aggregator_key': :'aggregatorKey', 'used_by': :'usedBy' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'name': :'String', 'identifier': :'String', 'identifier_path': :'String', 'description': :'String', 'type': :'String', 'target_object': :'Object', 'aggregator_key': :'String', 'used_by': :'Array<OCI::DataIntegration::Models::ReferenceUsedBy>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 167 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && name == other.name && identifier == other.identifier && identifier_path == other.identifier_path && description == other.description && type == other.type && target_object == other.target_object && aggregator_key == other.aggregator_key && used_by == other.used_by end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 205 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
185 186 187 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 185 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 194 def hash [key, name, identifier, identifier_path, description, type, target_object, aggregator_key, used_by].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 238 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
232 233 234 |
# File 'lib/oci/data_integration/models/child_reference.rb', line 232 def to_s to_hash.to_s end |