Class: OCI::DataIntegration::Models::CompositeFieldMap
- Defined in:
- lib/oci/data_integration/models/composite_field_map.rb
Overview
A composite field map.
Constant Summary
Constants inherited from FieldMap
Instance Attribute Summary collapse
- #config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#field_maps ⇒ Array<OCI::DataIntegration::Models::FieldMap>
An array of field maps.
-
#key ⇒ String
The object key.
-
#model_version ⇒ String
The object’s model version.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
Attributes inherited from FieldMap
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CompositeFieldMap
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from FieldMap
Constructor Details
#initialize(attributes = {}) ⇒ CompositeFieldMap
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'COMPOSITE_FIELD_MAP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.config_values = attributes[:'configValues'] if attributes[:'configValues'] raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values') self.config_values = attributes[:'config_values'] if attributes[:'config_values'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.field_maps = attributes[:'fieldMaps'] if attributes[:'fieldMaps'] raise 'You cannot provide both :fieldMaps and :field_maps' if attributes.key?(:'fieldMaps') && attributes.key?(:'field_maps') self.field_maps = attributes[:'field_maps'] if attributes[:'field_maps'] end |
Instance Attribute Details
#config_values ⇒ OCI::DataIntegration::Models::ConfigValues
23 24 25 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 23 def config_values @config_values end |
#field_maps ⇒ Array<OCI::DataIntegration::Models::FieldMap>
An array of field maps.
31 32 33 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 31 def field_maps @field_maps end |
#key ⇒ String
The object key.
13 14 15 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 13 def key @key end |
#model_version ⇒ String
The object’s model version.
17 18 19 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 17 def model_version @model_version end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
27 28 29 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 27 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
20 21 22 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 20 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'description': :'description', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'object_status': :'objectStatus', 'field_maps': :'fieldMaps' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'description': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'field_maps': :'Array<OCI::DataIntegration::Models::FieldMap>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 128 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && description == other.description && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && object_status == other.object_status && field_maps == other.field_maps end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 165 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
145 146 147 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 145 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
154 155 156 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 154 def hash [model_type, description, key, model_version, parent_ref, config_values, object_status, field_maps].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 198 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
192 193 194 |
# File 'lib/oci/data_integration/models/composite_field_map.rb', line 192 def to_s to_hash.to_s end |