Class: OCI::DataIntegration::Models::ConfigDefinition
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::ConfigDefinition
- Defined in:
- lib/oci/data_integration/models/config_definition.rb
Overview
The configuration details of a configurable object. This contains one or more config param definitions.
Instance Attribute Summary collapse
-
#config_parameter_definitions ⇒ Hash<String, OCI::DataIntegration::Models::ConfigParameterDefinition>
The parameter configuration details.
-
#is_contained ⇒ BOOLEAN
Specifies whether the configuration is contained or not.
-
#key ⇒ String
The key of the object.
-
#model_type ⇒ String
The type of the object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConfigDefinition
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConfigDefinition
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 87 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.is_contained = attributes[:'isContained'] unless attributes[:'isContained'].nil? raise 'You cannot provide both :isContained and :is_contained' if attributes.key?(:'isContained') && attributes.key?(:'is_contained') self.is_contained = attributes[:'is_contained'] unless attributes[:'is_contained'].nil? self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.config_parameter_definitions = attributes[:'configParameterDefinitions'] if attributes[:'configParameterDefinitions'] raise 'You cannot provide both :configParameterDefinitions and :config_parameter_definitions' if attributes.key?(:'configParameterDefinitions') && attributes.key?(:'config_parameter_definitions') self.config_parameter_definitions = attributes[:'config_parameter_definitions'] if attributes[:'config_parameter_definitions'] end |
Instance Attribute Details
#config_parameter_definitions ⇒ Hash<String, OCI::DataIntegration::Models::ConfigParameterDefinition>
The parameter configuration details.
39 40 41 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 39 def config_parameter_definitions @config_parameter_definitions end |
#is_contained ⇒ BOOLEAN
Specifies whether the configuration is contained or not.
31 32 33 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 31 def is_contained @is_contained end |
#key ⇒ String
The key of the object.
12 13 14 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 12 def key @key end |
#model_type ⇒ String
The type of the object.
16 17 18 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 16 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
20 21 22 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 20 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
27 28 29 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 27 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
35 36 37 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 35 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
23 24 25 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 23 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'is_contained': :'isContained', 'object_status': :'objectStatus', 'config_parameter_definitions': :'configParameterDefinitions' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'is_contained': :'BOOLEAN', 'object_status': :'Integer', 'config_parameter_definitions': :'Hash<String, OCI::DataIntegration::Models::ConfigParameterDefinition>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 141 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_type == other.model_type && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && is_contained == other.is_contained && object_status == other.object_status && config_parameter_definitions == other.config_parameter_definitions end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 178 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
158 159 160 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 158 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 167 def hash [key, model_type, model_version, parent_ref, name, is_contained, object_status, config_parameter_definitions].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 211 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
205 206 207 |
# File 'lib/oci/data_integration/models/config_definition.rb', line 205 def to_s to_hash.to_s end |