Class: OCI::DataIntegration::Models::CountStatisticSummary
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::CountStatisticSummary
- Defined in:
- lib/oci/data_integration/models/count_statistic_summary.rb
Overview
Details of the count statistic summary object.
Constant Summary collapse
- OBJECT_TYPE_ENUM =
[ OBJECT_TYPE_PROJECT = 'PROJECT'.freeze, OBJECT_TYPE_FOLDER = 'FOLDER'.freeze, OBJECT_TYPE_DATA_FLOW = 'DATA_FLOW'.freeze, OBJECT_TYPE_DATA_ASSET = 'DATA_ASSET'.freeze, OBJECT_TYPE_CONNECTION = 'CONNECTION'.freeze, OBJECT_TYPE_TASK = 'TASK'.freeze, OBJECT_TYPE_APPLICATION = 'APPLICATION'.freeze, OBJECT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#object_count ⇒ Integer
The value for the count statistic object.
-
#object_type ⇒ String
The type of object for the count statistic object.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CountStatisticSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CountStatisticSummary
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 58 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.object_type = attributes[:'objectType'] if attributes[:'objectType'] raise 'You cannot provide both :objectType and :object_type' if attributes.key?(:'objectType') && attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] if attributes[:'object_type'] self.object_count = attributes[:'objectCount'] if attributes[:'objectCount'] raise 'You cannot provide both :objectCount and :object_count' if attributes.key?(:'objectCount') && attributes.key?(:'object_count') self.object_count = attributes[:'object_count'] if attributes[:'object_count'] end |
Instance Attribute Details
#object_count ⇒ Integer
The value for the count statistic object.
28 29 30 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 28 def object_count @object_count end |
#object_type ⇒ String
The type of object for the count statistic object.
24 25 26 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 24 def object_type @object_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'object_type': :'objectType', 'object_count': :'objectCount' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'object_type': :'String', 'object_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
97 98 99 100 101 102 103 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 97 def ==(other) return true if equal?(other) self.class == other.class && object_type == other.object_type && object_count == other.object_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 128 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
108 109 110 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 108 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 117 def hash [object_type, object_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
155 156 157 |
# File 'lib/oci/data_integration/models/count_statistic_summary.rb', line 155 def to_s to_hash.to_s end |