Class: OCI::DataIntegration::Models::CreateDataAssetFromFusionApp
- Inherits:
-
CreateDataAssetDetails
- Object
- CreateDataAssetDetails
- OCI::DataIntegration::Models::CreateDataAssetFromFusionApp
- Defined in:
- lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb
Overview
Details for the FUSION_APP data asset type.
Constant Summary
Constants inherited from CreateDataAssetDetails
OCI::DataIntegration::Models::CreateDataAssetDetails::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
- #bucket_schema ⇒ OCI::DataIntegration::Models::Schema
- #default_connection ⇒ OCI::DataIntegration::Models::CreateConnectionDetails
-
#service_url ⇒ String
The generic JDBC host name.
- #staging_connection ⇒ OCI::DataIntegration::Models::ConnectionSummaryFromObjectStorage
- #staging_data_asset ⇒ OCI::DataIntegration::Models::DataAssetSummaryFromObjectStorage
Attributes inherited from CreateDataAssetDetails
#asset_properties, #description, #external_key, #identifier, #key, #model_type, #model_version, #name, #object_status, #registry_metadata
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDataAssetFromFusionApp
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateDataAssetDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateDataAssetFromFusionApp
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 93 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'FUSION_APP_DATA_ASSET' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.service_url = attributes[:'serviceUrl'] if attributes[:'serviceUrl'] raise 'You cannot provide both :serviceUrl and :service_url' if attributes.key?(:'serviceUrl') && attributes.key?(:'service_url') self.service_url = attributes[:'service_url'] if attributes[:'service_url'] self.default_connection = attributes[:'defaultConnection'] if attributes[:'defaultConnection'] raise 'You cannot provide both :defaultConnection and :default_connection' if attributes.key?(:'defaultConnection') && attributes.key?(:'default_connection') self.default_connection = attributes[:'default_connection'] if attributes[:'default_connection'] self.staging_data_asset = attributes[:'stagingDataAsset'] if attributes[:'stagingDataAsset'] raise 'You cannot provide both :stagingDataAsset and :staging_data_asset' if attributes.key?(:'stagingDataAsset') && attributes.key?(:'staging_data_asset') self.staging_data_asset = attributes[:'staging_data_asset'] if attributes[:'staging_data_asset'] self.staging_connection = attributes[:'stagingConnection'] if attributes[:'stagingConnection'] raise 'You cannot provide both :stagingConnection and :staging_connection' if attributes.key?(:'stagingConnection') && attributes.key?(:'staging_connection') self.staging_connection = attributes[:'staging_connection'] if attributes[:'staging_connection'] self.bucket_schema = attributes[:'bucketSchema'] if attributes[:'bucketSchema'] raise 'You cannot provide both :bucketSchema and :bucket_schema' if attributes.key?(:'bucketSchema') && attributes.key?(:'bucket_schema') self.bucket_schema = attributes[:'bucket_schema'] if attributes[:'bucket_schema'] end |
Instance Attribute Details
#bucket_schema ⇒ OCI::DataIntegration::Models::Schema
25 26 27 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 25 def bucket_schema @bucket_schema end |
#default_connection ⇒ OCI::DataIntegration::Models::CreateConnectionDetails
16 17 18 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 16 def default_connection @default_connection end |
#service_url ⇒ String
The generic JDBC host name.
13 14 15 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 13 def service_url @service_url end |
#staging_connection ⇒ OCI::DataIntegration::Models::ConnectionSummaryFromObjectStorage
22 23 24 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 22 def staging_connection @staging_connection end |
#staging_data_asset ⇒ OCI::DataIntegration::Models::DataAssetSummaryFromObjectStorage
19 20 21 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 19 def staging_data_asset @staging_data_asset end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 28 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'identifier': :'identifier', 'external_key': :'externalKey', 'asset_properties': :'assetProperties', 'registry_metadata': :'registryMetadata', 'service_url': :'serviceUrl', 'default_connection': :'defaultConnection', 'staging_data_asset': :'stagingDataAsset', 'staging_connection': :'stagingConnection', 'bucket_schema': :'bucketSchema' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'identifier': :'String', 'external_key': :'String', 'asset_properties': :'Hash<String, String>', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata', 'service_url': :'String', 'default_connection': :'OCI::DataIntegration::Models::CreateConnectionDetails', 'staging_data_asset': :'OCI::DataIntegration::Models::DataAssetSummaryFromObjectStorage', 'staging_connection': :'OCI::DataIntegration::Models::ConnectionSummaryFromObjectStorage', 'bucket_schema': :'OCI::DataIntegration::Models::Schema' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 141 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && name == other.name && description == other.description && object_status == other.object_status && identifier == other.identifier && external_key == other.external_key && asset_properties == other.asset_properties && == other. && service_url == other.service_url && default_connection == other.default_connection && staging_data_asset == other.staging_data_asset && staging_connection == other.staging_connection && bucket_schema == other.bucket_schema end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 185 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
165 166 167 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 165 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 174 def hash [model_type, key, model_version, name, description, object_status, identifier, external_key, asset_properties, , service_url, default_connection, staging_data_asset, staging_connection, bucket_schema].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
212 213 214 |
# File 'lib/oci/data_integration/models/create_data_asset_from_fusion_app.rb', line 212 def to_s to_hash.to_s end |