Class: OCI::DataIntegration::Models::CreateDataFlowDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::CreateDataFlowDetails
- Defined in:
- lib/oci/data_integration/models/create_data_flow_details.rb
Overview
Properties used in data flow create operations.
Instance Attribute Summary collapse
-
#description ⇒ String
Detailed description for the object.
- #flow_config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#identifier ⇒ String
[Required] Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
Generated key that can be used in API calls to identify data flow.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
[Required] Free form text without any restriction on permitted characters.
-
#nodes ⇒ Array<OCI::DataIntegration::Models::FlowNode>
An array of nodes.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#parameters ⇒ Array<OCI::DataIntegration::Models::Parameter>
An array of parameters.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
-
#registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDataFlowDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDataFlowDetails
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 107 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.nodes = attributes[:'nodes'] if attributes[:'nodes'] self.parameters = attributes[:'parameters'] if attributes[:'parameters'] self.description = attributes[:'description'] if attributes[:'description'] self.flow_config_values = attributes[:'flowConfigValues'] if attributes[:'flowConfigValues'] raise 'You cannot provide both :flowConfigValues and :flow_config_values' if attributes.key?(:'flowConfigValues') && attributes.key?(:'flow_config_values') self.flow_config_values = attributes[:'flow_config_values'] if attributes[:'flow_config_values'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] end |
Instance Attribute Details
#description ⇒ String
Detailed description for the object.
39 40 41 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 39 def description @description end |
#flow_config_values ⇒ OCI::DataIntegration::Models::ConfigValues
42 43 44 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 42 def flow_config_values @flow_config_values end |
#identifier ⇒ String
[Required] Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
27 28 29 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 27 def identifier @identifier end |
#key ⇒ String
Generated key that can be used in API calls to identify data flow. On scenarios where reference to the data flow is needed, a value can be passed in create.
12 13 14 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 12 def key @key end |
#model_version ⇒ String
The model version of an object.
16 17 18 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 16 def model_version @model_version end |
#name ⇒ String
[Required] Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
23 24 25 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 23 def name @name end |
#nodes ⇒ Array<OCI::DataIntegration::Models::FlowNode>
An array of nodes.
31 32 33 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 31 def nodes @nodes end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
46 47 48 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 46 def object_status @object_status end |
#parameters ⇒ Array<OCI::DataIntegration::Models::Parameter>
An array of parameters.
35 36 37 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 35 def parameters @parameters end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
19 20 21 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 19 def parent_ref @parent_ref end |
#registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
This attribute is required.
50 51 52 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 50 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 53 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'identifier': :'identifier', 'nodes': :'nodes', 'parameters': :'parameters', 'description': :'description', 'flow_config_values': :'flowConfigValues', 'object_status': :'objectStatus', 'registry_metadata': :'registryMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 72 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'identifier': :'String', 'nodes': :'Array<OCI::DataIntegration::Models::FlowNode>', 'parameters': :'Array<OCI::DataIntegration::Models::Parameter>', 'description': :'String', 'flow_config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 163 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && identifier == other.identifier && nodes == other.nodes && parameters == other.parameters && description == other.description && flow_config_values == other.flow_config_values && object_status == other.object_status && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 203 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
183 184 185 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 183 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 192 def hash [key, model_version, parent_ref, name, identifier, nodes, parameters, description, flow_config_values, object_status, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
230 231 232 |
# File 'lib/oci/data_integration/models/create_data_flow_details.rb', line 230 def to_s to_hash.to_s end |