Class: OCI::DataIntegration::Models::CreateTaskDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/create_task_details.rb

Overview

Properties used in task create operations. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Constant Summary collapse

MODEL_TYPE_ENUM =
[
  MODEL_TYPE_INTEGRATION_TASK = 'INTEGRATION_TASK'.freeze,
  MODEL_TYPE_DATA_LOADER_TASK = 'DATA_LOADER_TASK'.freeze,
  MODEL_TYPE_PIPELINE_TASK = 'PIPELINE_TASK'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateTaskDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/oci/data_integration/models/create_task_details.rb', line 151

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef']

  raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref')

  self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus']

  raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status')

  self.object_status = attributes[:'object_status'] if attributes[:'object_status']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.input_ports = attributes[:'inputPorts'] if attributes[:'inputPorts']

  raise 'You cannot provide both :inputPorts and :input_ports' if attributes.key?(:'inputPorts') && attributes.key?(:'input_ports')

  self.input_ports = attributes[:'input_ports'] if attributes[:'input_ports']

  self.output_ports = attributes[:'outputPorts'] if attributes[:'outputPorts']

  raise 'You cannot provide both :outputPorts and :output_ports' if attributes.key?(:'outputPorts') && attributes.key?(:'output_ports')

  self.output_ports = attributes[:'output_ports'] if attributes[:'output_ports']

  self.parameters = attributes[:'parameters'] if attributes[:'parameters']

  self.op_config_values = attributes[:'opConfigValues'] if attributes[:'opConfigValues']

  raise 'You cannot provide both :opConfigValues and :op_config_values' if attributes.key?(:'opConfigValues') && attributes.key?(:'op_config_values')

  self.op_config_values = attributes[:'op_config_values'] if attributes[:'op_config_values']

  self.config_provider_delegate = attributes[:'configProviderDelegate'] if attributes[:'configProviderDelegate']

  raise 'You cannot provide both :configProviderDelegate and :config_provider_delegate' if attributes.key?(:'configProviderDelegate') && attributes.key?(:'config_provider_delegate')

  self.config_provider_delegate = attributes[:'config_provider_delegate'] if attributes[:'config_provider_delegate']

  self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata']

  raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata')

  self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata']
end

Instance Attribute Details

#config_provider_delegateOCI::DataIntegration::Models::CreateConfigProvider



64
65
66
# File 'lib/oci/data_integration/models/create_task_details.rb', line 64

def config_provider_delegate
  @config_provider_delegate
end

#descriptionString

Detailed description for the object.

Returns:

  • (String)


38
39
40
# File 'lib/oci/data_integration/models/create_task_details.rb', line 38

def description
  @description
end

#identifierString

[Required] Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:

  • (String)


46
47
48
# File 'lib/oci/data_integration/models/create_task_details.rb', line 46

def identifier
  @identifier
end

#input_portsArray<OCI::DataIntegration::Models::InputPort>

An array of input ports.



50
51
52
# File 'lib/oci/data_integration/models/create_task_details.rb', line 50

def input_ports
  @input_ports
end

#keyString

Generated key that can be used in API calls to identify task. On scenarios where reference to the task is needed, a value can be passed in create.

Returns:

  • (String)


23
24
25
# File 'lib/oci/data_integration/models/create_task_details.rb', line 23

def key
  @key
end

#model_typeString

[Required] The type of the task.

Returns:

  • (String)


19
20
21
# File 'lib/oci/data_integration/models/create_task_details.rb', line 19

def model_type
  @model_type
end

#model_versionString

The object’s model version.

Returns:

  • (String)


27
28
29
# File 'lib/oci/data_integration/models/create_task_details.rb', line 27

def model_version
  @model_version
end

#nameString

[Required] Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:

  • (String)


34
35
36
# File 'lib/oci/data_integration/models/create_task_details.rb', line 34

def name
  @name
end

#object_statusInteger

The status of an object that can be set to value 1 for shallow references across objects, other values reserved.

Returns:

  • (Integer)


42
43
44
# File 'lib/oci/data_integration/models/create_task_details.rb', line 42

def object_status
  @object_status
end

#op_config_valuesOCI::DataIntegration::Models::ConfigValues



61
62
63
# File 'lib/oci/data_integration/models/create_task_details.rb', line 61

def op_config_values
  @op_config_values
end

#output_portsArray<OCI::DataIntegration::Models::OutputPort>

An array of output ports.



54
55
56
# File 'lib/oci/data_integration/models/create_task_details.rb', line 54

def output_ports
  @output_ports
end

#parametersArray<OCI::DataIntegration::Models::Parameter>

An array of parameters.



58
59
60
# File 'lib/oci/data_integration/models/create_task_details.rb', line 58

def parameters
  @parameters
end

#parent_refOCI::DataIntegration::Models::ParentReference



30
31
32
# File 'lib/oci/data_integration/models/create_task_details.rb', line 30

def parent_ref
  @parent_ref
end

#registry_metadataOCI::DataIntegration::Models::RegistryMetadata

This attribute is required.



68
69
70
# File 'lib/oci/data_integration/models/create_task_details.rb', line 68

def 
  
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/oci/data_integration/models/create_task_details.rb', line 71

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'input_ports': :'inputPorts',
    'output_ports': :'outputPorts',
    'parameters': :'parameters',
    'op_config_values': :'opConfigValues',
    'config_provider_delegate': :'configProviderDelegate',
    'registry_metadata': :'registryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



119
120
121
122
123
124
125
126
127
128
# File 'lib/oci/data_integration/models/create_task_details.rb', line 119

def self.get_subtype(object_hash)
  type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::DataIntegration::Models::CreateTaskFromIntegrationTask' if type == 'INTEGRATION_TASK'
  return 'OCI::DataIntegration::Models::CreateTaskFromDataLoaderTask' if type == 'DATA_LOADER_TASK'
  return 'OCI::DataIntegration::Models::CreateTaskFromPipelineTask' if type == 'PIPELINE_TASK'

  # TODO: Log a warning when the subtype is not found.
  'OCI::DataIntegration::Models::CreateTaskDetails'
end

.swagger_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/oci/data_integration/models/create_task_details.rb', line 93

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_status': :'Integer',
    'identifier': :'String',
    'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>',
    'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>',
    'parameters': :'Array<OCI::DataIntegration::Models::Parameter>',
    'op_config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'config_provider_delegate': :'OCI::DataIntegration::Models::CreateConfigProvider',
    'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/oci/data_integration/models/create_task_details.rb', line 237

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    input_ports == other.input_ports &&
    output_ports == other.output_ports &&
    parameters == other.parameters &&
    op_config_values == other.op_config_values &&
    config_provider_delegate == other.config_provider_delegate &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/oci/data_integration/models/create_task_details.rb', line 280

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/oci/data_integration/models/create_task_details.rb', line 260

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



269
270
271
# File 'lib/oci/data_integration/models/create_task_details.rb', line 269

def hash
  [model_type, key, model_version, parent_ref, name, description, object_status, identifier, input_ports, output_ports, parameters, op_config_values, config_provider_delegate, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



313
314
315
316
317
318
319
320
321
322
# File 'lib/oci/data_integration/models/create_task_details.rb', line 313

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



307
308
309
# File 'lib/oci/data_integration/models/create_task_details.rb', line 307

def to_s
  to_hash.to_s
end