Class: OCI::DataIntegration::Models::CreateTaskRunDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_integration/models/create_task_run_details.rb

Overview

The properties used in task run create operations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateTaskRunDetails

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 93

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.key = attributes[:'key'] if attributes[:'key']

  self.model_type = attributes[:'modelType'] if attributes[:'modelType']

  raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type')

  self.model_type = attributes[:'model_type'] if attributes[:'model_type']

  self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion']

  raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version')

  self.model_version = attributes[:'model_version'] if attributes[:'model_version']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.config_provider = attributes[:'configProvider'] if attributes[:'configProvider']

  raise 'You cannot provide both :configProvider and :config_provider' if attributes.key?(:'configProvider') && attributes.key?(:'config_provider')

  self.config_provider = attributes[:'config_provider'] if attributes[:'config_provider']

  self.identifier = attributes[:'identifier'] if attributes[:'identifier']

  self.task_schedule_key = attributes[:'taskScheduleKey'] if attributes[:'taskScheduleKey']

  raise 'You cannot provide both :taskScheduleKey and :task_schedule_key' if attributes.key?(:'taskScheduleKey') && attributes.key?(:'task_schedule_key')

  self.task_schedule_key = attributes[:'task_schedule_key'] if attributes[:'task_schedule_key']

  self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata']

  raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata')

  self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata']
end

Instance Attribute Details

#config_providerOCI::DataIntegration::Models::CreateConfigProvider

Returns:



31
32
33
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 31

def config_provider
  @config_provider
end

#descriptionString

Detailed description for the object.

Returns:



28
29
30
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 28

def description
  @description
end

#identifierString

Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.

Returns:



35
36
37
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 35

def identifier
  @identifier
end

#keyString

The key of the object.

Returns:



12
13
14
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 12

def key
  @key
end

#model_typeString

The type of the object.

Returns:



16
17
18
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 16

def model_type
  @model_type
end

#model_versionString

The model version of an object.

Returns:



20
21
22
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 20

def model_version
  @model_version
end

#nameString

Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.

Returns:



24
25
26
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 24

def name
  @name
end

#registry_metadataOCI::DataIntegration::Models::RegistryMetadata

Returns:



42
43
44
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 42

def 
  
end

#task_schedule_keyString

Optional task schedule key reference.

Returns:



39
40
41
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 39

def task_schedule_key
  @task_schedule_key
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 45

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'key',
    'model_type': :'modelType',
    'model_version': :'modelVersion',
    'name': :'name',
    'description': :'description',
    'config_provider': :'configProvider',
    'identifier': :'identifier',
    'task_schedule_key': :'taskScheduleKey',
    'registry_metadata': :'registryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 62

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'key': :'String',
    'model_type': :'String',
    'model_version': :'String',
    'name': :'String',
    'description': :'String',
    'config_provider': :'OCI::DataIntegration::Models::CreateConfigProvider',
    'identifier': :'String',
    'task_schedule_key': :'String',
    'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 145

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    key == other.key &&
    model_type == other.model_type &&
    model_version == other.model_version &&
    name == other.name &&
    description == other.description &&
    config_provider == other.config_provider &&
    identifier == other.identifier &&
    task_schedule_key == other.task_schedule_key &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 183

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


163
164
165
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 163

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



172
173
174
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 172

def hash
  [key, model_type, model_version, name, description, config_provider, identifier, task_schedule_key, ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



216
217
218
219
220
221
222
223
224
225
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 216

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



210
211
212
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 210

def to_s
  to_hash.to_s
end