Class: OCI::DataIntegration::Models::CreateTaskRunDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::CreateTaskRunDetails
- Defined in:
- lib/oci/data_integration/models/create_task_run_details.rb
Overview
The properties used in task run create operations.
Instance Attribute Summary collapse
- #config_provider ⇒ OCI::DataIntegration::Models::CreateConfigProvider
-
#description ⇒ String
Detailed description for the object.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
The key of the object.
-
#model_type ⇒ String
The type of the object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
- #registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateTaskRunDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateTaskRunDetails
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.config_provider = attributes[:'configProvider'] if attributes[:'configProvider'] raise 'You cannot provide both :configProvider and :config_provider' if attributes.key?(:'configProvider') && attributes.key?(:'config_provider') self.config_provider = attributes[:'config_provider'] if attributes[:'config_provider'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] end |
Instance Attribute Details
#config_provider ⇒ OCI::DataIntegration::Models::CreateConfigProvider
31 32 33 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 31 def config_provider @config_provider end |
#description ⇒ String
Detailed description for the object.
28 29 30 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 28 def description @description end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
35 36 37 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 35 def identifier @identifier end |
#key ⇒ String
The key of the object.
12 13 14 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 12 def key @key end |
#model_type ⇒ String
The type of the object.
16 17 18 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 16 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
20 21 22 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 20 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
24 25 26 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 24 def name @name end |
#registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
38 39 40 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 38 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'config_provider': :'configProvider', 'identifier': :'identifier', 'registry_metadata': :'registryMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'config_provider': :'OCI::DataIntegration::Models::CreateConfigProvider', 'identifier': :'String', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 132 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_type == other.model_type && model_version == other.model_version && name == other.name && description == other.description && config_provider == other.config_provider && identifier == other.identifier && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 169 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
149 150 151 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 149 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 158 def hash [key, model_type, model_version, name, description, config_provider, identifier, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
196 197 198 |
# File 'lib/oci/data_integration/models/create_task_run_details.rb', line 196 def to_s to_hash.to_s end |