Class: OCI::DataIntegration::Models::CsvFormatAttribute
- Inherits:
-
AbstractFormatAttribute
- Object
- AbstractFormatAttribute
- OCI::DataIntegration::Models::CsvFormatAttribute
- Defined in:
- lib/oci/data_integration/models/csv_format_attribute.rb
Overview
The CSV format attribute.
Constant Summary
Constants inherited from AbstractFormatAttribute
AbstractFormatAttribute::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#delimiter ⇒ String
The delimiter for the CSV format.
-
#encoding ⇒ String
The encoding for the file.
-
#escape_character ⇒ String
The escape character for the CSV format.
-
#has_header ⇒ BOOLEAN
Defines whether the file has a header row.
-
#is_file_pattern ⇒ BOOLEAN
Defines whether a file pattern is supported.
-
#quote_character ⇒ String
The quote character for the CSV format.
-
#timestamp_format ⇒ String
Format for timestamp information.
Attributes inherited from AbstractFormatAttribute
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CsvFormatAttribute
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractFormatAttribute
Constructor Details
#initialize(attributes = {}) ⇒ CsvFormatAttribute
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'CSV_FORMAT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.encoding = attributes[:'encoding'] if attributes[:'encoding'] self.escape_character = attributes[:'escapeCharacter'] if attributes[:'escapeCharacter'] raise 'You cannot provide both :escapeCharacter and :escape_character' if attributes.key?(:'escapeCharacter') && attributes.key?(:'escape_character') self.escape_character = attributes[:'escape_character'] if attributes[:'escape_character'] self.delimiter = attributes[:'delimiter'] if attributes[:'delimiter'] self.quote_character = attributes[:'quoteCharacter'] if attributes[:'quoteCharacter'] raise 'You cannot provide both :quoteCharacter and :quote_character' if attributes.key?(:'quoteCharacter') && attributes.key?(:'quote_character') self.quote_character = attributes[:'quote_character'] if attributes[:'quote_character'] self.has_header = attributes[:'hasHeader'] unless attributes[:'hasHeader'].nil? raise 'You cannot provide both :hasHeader and :has_header' if attributes.key?(:'hasHeader') && attributes.key?(:'has_header') self.has_header = attributes[:'has_header'] unless attributes[:'has_header'].nil? self.is_file_pattern = attributes[:'isFilePattern'] unless attributes[:'isFilePattern'].nil? raise 'You cannot provide both :isFilePattern and :is_file_pattern' if attributes.key?(:'isFilePattern') && attributes.key?(:'is_file_pattern') self.is_file_pattern = attributes[:'is_file_pattern'] unless attributes[:'is_file_pattern'].nil? self. = attributes[:'timestampFormat'] if attributes[:'timestampFormat'] raise 'You cannot provide both :timestampFormat and :timestamp_format' if attributes.key?(:'timestampFormat') && attributes.key?(:'timestamp_format') self. = attributes[:'timestamp_format'] if attributes[:'timestamp_format'] end |
Instance Attribute Details
#delimiter ⇒ String
The delimiter for the CSV format.
21 22 23 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 21 def delimiter @delimiter end |
#encoding ⇒ String
The encoding for the file.
13 14 15 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 13 def encoding @encoding end |
#escape_character ⇒ String
The escape character for the CSV format.
17 18 19 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 17 def escape_character @escape_character end |
#has_header ⇒ BOOLEAN
Defines whether the file has a header row.
29 30 31 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 29 def has_header @has_header end |
#is_file_pattern ⇒ BOOLEAN
Defines whether a file pattern is supported.
33 34 35 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 33 def is_file_pattern @is_file_pattern end |
#quote_character ⇒ String
The quote character for the CSV format.
25 26 27 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 25 def quote_character @quote_character end |
#timestamp_format ⇒ String
Format for timestamp information.
37 38 39 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 37 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'encoding': :'encoding', 'escape_character': :'escapeCharacter', 'delimiter': :'delimiter', 'quote_character': :'quoteCharacter', 'has_header': :'hasHeader', 'is_file_pattern': :'isFilePattern', 'timestamp_format': :'timestampFormat' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'encoding': :'String', 'escape_character': :'String', 'delimiter': :'String', 'quote_character': :'String', 'has_header': :'BOOLEAN', 'is_file_pattern': :'BOOLEAN', 'timestamp_format': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 136 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && encoding == other.encoding && escape_character == other.escape_character && delimiter == other.delimiter && quote_character == other.quote_character && has_header == other.has_header && is_file_pattern == other.is_file_pattern && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
153 154 155 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 153 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 162 def hash [model_type, encoding, escape_character, delimiter, quote_character, has_header, is_file_pattern, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
200 201 202 |
# File 'lib/oci/data_integration/models/csv_format_attribute.rb', line 200 def to_s to_hash.to_s end |