Class: OCI::DataIntegration::Models::DerivedField
- Inherits:
-
TypedObject
- Object
- TypedObject
- OCI::DataIntegration::Models::DerivedField
- Defined in:
- lib/oci/data_integration/models/derived_field.rb
Overview
The type representing the derived field concept. Derived fields have an expression to define how to derive the field.
Constant Summary
Constants inherited from TypedObject
Instance Attribute Summary collapse
- #expr ⇒ OCI::DataIntegration::Models::Expression
-
#labels ⇒ Array<String>
Labels are keywords or labels that you can add to data assets, dataflows and so on.
-
#type ⇒ String
The type of the field.
Attributes inherited from TypedObject
#config_values, #description, #key, #model_type, #model_version, #name, #object_status, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DerivedField
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from TypedObject
Constructor Details
#initialize(attributes = {}) ⇒ DerivedField
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'DERIVED_FIELD' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.expr = attributes[:'expr'] if attributes[:'expr'] self.type = attributes[:'type'] if attributes[:'type'] self.labels = attributes[:'labels'] if attributes[:'labels'] end |
Instance Attribute Details
#expr ⇒ OCI::DataIntegration::Models::Expression
12 13 14 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 12 def expr @expr end |
#labels ⇒ Array<String>
Labels are keywords or labels that you can add to data assets, dataflows and so on. You can define your own labels and use them to categorize content.
20 21 22 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 20 def labels @labels end |
#type ⇒ String
The type of the field.
16 17 18 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 16 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'object_status': :'objectStatus', 'name': :'name', 'description': :'description', 'expr': :'expr', 'type': :'type', 'labels': :'labels' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 42 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'name': :'String', 'description': :'String', 'expr': :'OCI::DataIntegration::Models::Expression', 'type': :'String', 'labels': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 100 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && object_status == other.object_status && name == other.name && description == other.description && expr == other.expr && type == other.type && labels == other.labels end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 140 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
120 121 122 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 120 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
129 130 131 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 129 def hash [model_type, key, model_version, parent_ref, config_values, object_status, name, description, expr, type, labels].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
167 168 169 |
# File 'lib/oci/data_integration/models/derived_field.rb', line 167 def to_s to_hash.to_s end |