Class: OCI::DataIntegration::Models::EnrichedEntity
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::EnrichedEntity
- Defined in:
- lib/oci/data_integration/models/enriched_entity.rb
Overview
This is used to specify runtime parameters for data entities such as files that need both the data entity and the format.
Instance Attribute Summary collapse
- #data_format ⇒ OCI::DataIntegration::Models::DataFormat
- #entity ⇒ OCI::DataIntegration::Models::DataEntity
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EnrichedEntity
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EnrichedEntity
Initializes the object
44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 44 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.entity = attributes[:'entity'] if attributes[:'entity'] self.data_format = attributes[:'dataFormat'] if attributes[:'dataFormat'] raise 'You cannot provide both :dataFormat and :data_format' if attributes.key?(:'dataFormat') && attributes.key?(:'data_format') self.data_format = attributes[:'data_format'] if attributes[:'data_format'] end |
Instance Attribute Details
#data_format ⇒ OCI::DataIntegration::Models::DataFormat
14 15 16 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 14 def data_format @data_format end |
#entity ⇒ OCI::DataIntegration::Models::DataEntity
11 12 13 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 11 def entity @entity end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
17 18 19 20 21 22 23 24 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 17 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity': :'entity', 'data_format': :'dataFormat' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
27 28 29 30 31 32 33 34 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 27 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity': :'OCI::DataIntegration::Models::DataEntity', 'data_format': :'OCI::DataIntegration::Models::DataFormat' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
66 67 68 69 70 71 72 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 66 def ==(other) return true if equal?(other) self.class == other.class && entity == other.entity && data_format == other.data_format end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 97 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
77 78 79 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 77 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
86 87 88 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 86 def hash [entity, data_format].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 130 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
124 125 126 |
# File 'lib/oci/data_integration/models/enriched_entity.rb', line 124 def to_s to_hash.to_s end |