Class: OCI::DataIntegration::Models::Parameter
- Inherits:
-
TypedObject
- Object
- TypedObject
- OCI::DataIntegration::Models::Parameter
- Defined in:
- lib/oci/data_integration/models/parameter.rb
Overview
Parameters are created and assigned values that can be configured for each integration task.
Constant Summary collapse
- OUTPUT_AGGREGATION_TYPE_ENUM =
[ OUTPUT_AGGREGATION_TYPE_MIN = 'MIN'.freeze, OUTPUT_AGGREGATION_TYPE_MAX = 'MAX'.freeze, OUTPUT_AGGREGATION_TYPE_COUNT = 'COUNT'.freeze, OUTPUT_AGGREGATION_TYPE_SUM = 'SUM'.freeze, OUTPUT_AGGREGATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from TypedObject
Instance Attribute Summary collapse
-
#default_value ⇒ Object
The default value of the parameter.
-
#is_input ⇒ BOOLEAN
Specifies whether the parameter is input value.
-
#is_output ⇒ BOOLEAN
Specifies whether the parameter is output value.
-
#output_aggregation_type ⇒ String
The output aggregation type.
-
#root_object_default_value ⇒ Object
The default value of the parameter which can be an object in DIS, such as a data entity.
-
#type ⇒ Object
This can either be a string value referencing the type or a BaseType object.
-
#type_name ⇒ String
The type of value the parameter was created for.
Attributes inherited from TypedObject
#config_values, #description, #key, #model_type, #model_version, #name, #object_status, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Parameter
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from TypedObject
Constructor Details
#initialize(attributes = {}) ⇒ Parameter
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/data_integration/models/parameter.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'PARAMETER' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.default_value = attributes[:'defaultValue'] if attributes[:'defaultValue'] raise 'You cannot provide both :defaultValue and :default_value' if attributes.key?(:'defaultValue') && attributes.key?(:'default_value') self.default_value = attributes[:'default_value'] if attributes[:'default_value'] self.root_object_default_value = attributes[:'rootObjectDefaultValue'] if attributes[:'rootObjectDefaultValue'] raise 'You cannot provide both :rootObjectDefaultValue and :root_object_default_value' if attributes.key?(:'rootObjectDefaultValue') && attributes.key?(:'root_object_default_value') self.root_object_default_value = attributes[:'root_object_default_value'] if attributes[:'root_object_default_value'] self.is_input = attributes[:'isInput'] unless attributes[:'isInput'].nil? raise 'You cannot provide both :isInput and :is_input' if attributes.key?(:'isInput') && attributes.key?(:'is_input') self.is_input = attributes[:'is_input'] unless attributes[:'is_input'].nil? self.is_output = attributes[:'isOutput'] unless attributes[:'isOutput'].nil? raise 'You cannot provide both :isOutput and :is_output' if attributes.key?(:'isOutput') && attributes.key?(:'is_output') self.is_output = attributes[:'is_output'] unless attributes[:'is_output'].nil? self.output_aggregation_type = attributes[:'outputAggregationType'] if attributes[:'outputAggregationType'] raise 'You cannot provide both :outputAggregationType and :output_aggregation_type' if attributes.key?(:'outputAggregationType') && attributes.key?(:'output_aggregation_type') self.output_aggregation_type = attributes[:'output_aggregation_type'] if attributes[:'output_aggregation_type'] self.type_name = attributes[:'typeName'] if attributes[:'typeName'] raise 'You cannot provide both :typeName and :type_name' if attributes.key?(:'typeName') && attributes.key?(:'type_name') self.type_name = attributes[:'type_name'] if attributes[:'type_name'] end |
Instance Attribute Details
#default_value ⇒ Object
The default value of the parameter.
26 27 28 |
# File 'lib/oci/data_integration/models/parameter.rb', line 26 def default_value @default_value end |
#is_input ⇒ BOOLEAN
Specifies whether the parameter is input value.
34 35 36 |
# File 'lib/oci/data_integration/models/parameter.rb', line 34 def is_input @is_input end |
#is_output ⇒ BOOLEAN
Specifies whether the parameter is output value.
38 39 40 |
# File 'lib/oci/data_integration/models/parameter.rb', line 38 def is_output @is_output end |
#output_aggregation_type ⇒ String
The output aggregation type.
42 43 44 |
# File 'lib/oci/data_integration/models/parameter.rb', line 42 def output_aggregation_type @output_aggregation_type end |
#root_object_default_value ⇒ Object
The default value of the parameter which can be an object in DIS, such as a data entity.
30 31 32 |
# File 'lib/oci/data_integration/models/parameter.rb', line 30 def root_object_default_value @root_object_default_value end |
#type ⇒ Object
This can either be a string value referencing the type or a BaseType object.
22 23 24 |
# File 'lib/oci/data_integration/models/parameter.rb', line 22 def type @type end |
#type_name ⇒ String
The type of value the parameter was created for.
46 47 48 |
# File 'lib/oci/data_integration/models/parameter.rb', line 46 def type_name @type_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/data_integration/models/parameter.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'object_status': :'objectStatus', 'name': :'name', 'description': :'description', 'type': :'type', 'default_value': :'defaultValue', 'root_object_default_value': :'rootObjectDefaultValue', 'is_input': :'isInput', 'is_output': :'isOutput', 'output_aggregation_type': :'outputAggregationType', 'type_name': :'typeName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/data_integration/models/parameter.rb', line 72 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'name': :'String', 'description': :'String', 'type': :'Object', 'default_value': :'Object', 'root_object_default_value': :'Object', 'is_input': :'BOOLEAN', 'is_output': :'BOOLEAN', 'output_aggregation_type': :'String', 'type_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/data_integration/models/parameter.rb', line 183 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && object_status == other.object_status && name == other.name && description == other.description && type == other.type && default_value == other.default_value && root_object_default_value == other.root_object_default_value && is_input == other.is_input && is_output == other.is_output && output_aggregation_type == other.output_aggregation_type && type_name == other.type_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/data_integration/models/parameter.rb', line 227 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
207 208 209 |
# File 'lib/oci/data_integration/models/parameter.rb', line 207 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/oci/data_integration/models/parameter.rb', line 216 def hash [model_type, key, model_version, parent_ref, config_values, object_status, name, description, type, default_value, root_object_default_value, is_input, is_output, output_aggregation_type, type_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/data_integration/models/parameter.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
254 255 256 |
# File 'lib/oci/data_integration/models/parameter.rb', line 254 def to_s to_hash.to_s end |