Class: OCI::DataIntegration::Models::Parameter

Inherits:
TypedObject
  • Object
show all
Defined in:
lib/oci/data_integration/models/parameter.rb

Overview

Parameters are created and assigned values that can be configured for each integration task.

Constant Summary collapse

OUTPUT_AGGREGATION_TYPE_ENUM =
[
  OUTPUT_AGGREGATION_TYPE_MIN = 'MIN'.freeze,
  OUTPUT_AGGREGATION_TYPE_MAX = 'MAX'.freeze,
  OUTPUT_AGGREGATION_TYPE_COUNT = 'COUNT'.freeze,
  OUTPUT_AGGREGATION_TYPE_SUM = 'SUM'.freeze,
  OUTPUT_AGGREGATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Constants inherited from TypedObject

TypedObject::MODEL_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from TypedObject

#config_values, #description, #key, #model_type, #model_version, #name, #object_status, #parent_ref

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from TypedObject

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ Parameter

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/data_integration/models/parameter.rb', line 113

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'PARAMETER'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.type = attributes[:'type'] if attributes[:'type']

  self.default_value = attributes[:'defaultValue'] if attributes[:'defaultValue']

  raise 'You cannot provide both :defaultValue and :default_value' if attributes.key?(:'defaultValue') && attributes.key?(:'default_value')

  self.default_value = attributes[:'default_value'] if attributes[:'default_value']

  self.root_object_default_value = attributes[:'rootObjectDefaultValue'] if attributes[:'rootObjectDefaultValue']

  raise 'You cannot provide both :rootObjectDefaultValue and :root_object_default_value' if attributes.key?(:'rootObjectDefaultValue') && attributes.key?(:'root_object_default_value')

  self.root_object_default_value = attributes[:'root_object_default_value'] if attributes[:'root_object_default_value']

  self.is_input = attributes[:'isInput'] unless attributes[:'isInput'].nil?

  raise 'You cannot provide both :isInput and :is_input' if attributes.key?(:'isInput') && attributes.key?(:'is_input')

  self.is_input = attributes[:'is_input'] unless attributes[:'is_input'].nil?

  self.is_output = attributes[:'isOutput'] unless attributes[:'isOutput'].nil?

  raise 'You cannot provide both :isOutput and :is_output' if attributes.key?(:'isOutput') && attributes.key?(:'is_output')

  self.is_output = attributes[:'is_output'] unless attributes[:'is_output'].nil?

  self.output_aggregation_type = attributes[:'outputAggregationType'] if attributes[:'outputAggregationType']

  raise 'You cannot provide both :outputAggregationType and :output_aggregation_type' if attributes.key?(:'outputAggregationType') && attributes.key?(:'output_aggregation_type')

  self.output_aggregation_type = attributes[:'output_aggregation_type'] if attributes[:'output_aggregation_type']

  self.type_name = attributes[:'typeName'] if attributes[:'typeName']

  raise 'You cannot provide both :typeName and :type_name' if attributes.key?(:'typeName') && attributes.key?(:'type_name')

  self.type_name = attributes[:'type_name'] if attributes[:'type_name']
end

Instance Attribute Details

#default_valueObject

The default value of the parameter.

Returns:

  • (Object)


25
26
27
# File 'lib/oci/data_integration/models/parameter.rb', line 25

def default_value
  @default_value
end

#is_inputBOOLEAN

Specifies whether the parameter is input value.

Returns:

  • (BOOLEAN)


33
34
35
# File 'lib/oci/data_integration/models/parameter.rb', line 33

def is_input
  @is_input
end

#is_outputBOOLEAN

Specifies whether the parameter is output value.

Returns:

  • (BOOLEAN)


37
38
39
# File 'lib/oci/data_integration/models/parameter.rb', line 37

def is_output
  @is_output
end

#output_aggregation_typeString

The output aggregation type.

Returns:

  • (String)


41
42
43
# File 'lib/oci/data_integration/models/parameter.rb', line 41

def output_aggregation_type
  @output_aggregation_type
end

#root_object_default_valueObject

The default value of the parameter which can be an object in DIS, such as a data entity.

Returns:

  • (Object)


29
30
31
# File 'lib/oci/data_integration/models/parameter.rb', line 29

def root_object_default_value
  @root_object_default_value
end

#typeOCI::DataIntegration::Models::BaseType



21
22
23
# File 'lib/oci/data_integration/models/parameter.rb', line 21

def type
  @type
end

#type_nameString

The type of value the parameter was created for.

Returns:

  • (String)


45
46
47
# File 'lib/oci/data_integration/models/parameter.rb', line 45

def type_name
  @type_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/oci/data_integration/models/parameter.rb', line 48

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'config_values': :'configValues',
    'object_status': :'objectStatus',
    'name': :'name',
    'description': :'description',
    'type': :'type',
    'default_value': :'defaultValue',
    'root_object_default_value': :'rootObjectDefaultValue',
    'is_input': :'isInput',
    'is_output': :'isOutput',
    'output_aggregation_type': :'outputAggregationType',
    'type_name': :'typeName'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/oci/data_integration/models/parameter.rb', line 71

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'object_status': :'Integer',
    'name': :'String',
    'description': :'String',
    'type': :'OCI::DataIntegration::Models::BaseType',
    'default_value': :'Object',
    'root_object_default_value': :'Object',
    'is_input': :'BOOLEAN',
    'is_output': :'BOOLEAN',
    'output_aggregation_type': :'String',
    'type_name': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/data_integration/models/parameter.rb', line 182

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    config_values == other.config_values &&
    object_status == other.object_status &&
    name == other.name &&
    description == other.description &&
    type == other.type &&
    default_value == other.default_value &&
    root_object_default_value == other.root_object_default_value &&
    is_input == other.is_input &&
    is_output == other.is_output &&
    output_aggregation_type == other.output_aggregation_type &&
    type_name == other.type_name
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/oci/data_integration/models/parameter.rb', line 226

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/oci/data_integration/models/parameter.rb', line 206

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



215
216
217
# File 'lib/oci/data_integration/models/parameter.rb', line 215

def hash
  [model_type, key, model_version, parent_ref, config_values, object_status, name, description, type, default_value, root_object_default_value, is_input, is_output, output_aggregation_type, type_name].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
# File 'lib/oci/data_integration/models/parameter.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



253
254
255
# File 'lib/oci/data_integration/models/parameter.rb', line 253

def to_s
  to_hash.to_s
end