Class: OCI::DataIntegration::Models::PatchChangeSummary
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::PatchChangeSummary
- Defined in:
- lib/oci/data_integration/models/patch_change_summary.rb
Overview
This is the patch report summary information.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_INTEGRATION_TASK = 'INTEGRATION_TASK'.freeze, TYPE_DATA_LOADER_TASK = 'DATA_LOADER_TASK'.freeze, TYPE_PIPELINE_TASK = 'PIPELINE_TASK'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ACTION_ENUM =
[ ACTION_CREATED = 'CREATED'.freeze, ACTION_DELETED = 'DELETED'.freeze, ACTION_UPDATED = 'UPDATED'.freeze, ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action ⇒ String
The patch action indicating if object was created, updated, or deleted.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers.
-
#key ⇒ String
The key of the object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#name_path ⇒ String
The fully qualified path of the published object, which would include its project and folder.
-
#object_version ⇒ Integer
The object version.
-
#type ⇒ String
The type of the object in patch.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchChangeSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PatchChangeSummary
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 96 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.key = attributes[:'key'] if attributes[:'key'] self.name = attributes[:'name'] if attributes[:'name'] self.name_path = attributes[:'namePath'] if attributes[:'namePath'] raise 'You cannot provide both :namePath and :name_path' if attributes.key?(:'namePath') && attributes.key?(:'name_path') self.name_path = attributes[:'name_path'] if attributes[:'name_path'] self.type = attributes[:'type'] if attributes[:'type'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.action = attributes[:'action'] if attributes[:'action'] end |
Instance Attribute Details
#action ⇒ String
The patch action indicating if object was created, updated, or deleted.
51 52 53 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 51 def action @action end |
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.
47 48 49 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 47 def identifier @identifier end |
#key ⇒ String
The key of the object.
27 28 29 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 27 def key @key end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
31 32 33 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 31 def name @name end |
#name_path ⇒ String
The fully qualified path of the published object, which would include its project and folder.
35 36 37 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 35 def name_path @name_path end |
#object_version ⇒ Integer
The object version.
43 44 45 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 43 def object_version @object_version end |
#type ⇒ String
The type of the object in patch.
39 40 41 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 39 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 54 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'name': :'name', 'name_path': :'namePath', 'type': :'type', 'object_version': :'objectVersion', 'identifier': :'identifier', 'action': :'action' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'name': :'String', 'name_path': :'String', 'type': :'String', 'object_version': :'Integer', 'identifier': :'String', 'action': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 155 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && name == other.name && name_path == other.name_path && type == other.type && object_version == other.object_version && identifier == other.identifier && action == other.action end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 191 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
171 172 173 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 171 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 180 def hash [key, name, name_path, type, object_version, identifier, action].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/oci/data_integration/models/patch_change_summary.rb', line 218 def to_s to_hash.to_s end |