Class: OCI::DataIntegration::Models::PublishedObjectFromDataLoaderTask
- Inherits:
-
PublishedObject
- Object
- PublishedObject
- OCI::DataIntegration::Models::PublishedObjectFromDataLoaderTask
- Defined in:
- lib/oci/data_integration/models/published_object_from_data_loader_task.rb
Overview
The data loader task published object.
Constant Summary
Constants inherited from PublishedObject
OCI::DataIntegration::Models::PublishedObject::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
- #conditional_composite_field_map ⇒ OCI::DataIntegration::Models::ConditionalCompositeFieldMap
- #config_provider_delegate ⇒ OCI::DataIntegration::Models::ConfigProvider
- #data_flow ⇒ OCI::DataIntegration::Models::DataFlow
-
#input_ports ⇒ Array<OCI::DataIntegration::Models::InputPort>
An array of input ports.
-
#is_single_load ⇒ BOOLEAN
If true, defines a singular load.
- #op_config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#output_ports ⇒ Array<OCI::DataIntegration::Models::OutputPort>
An array of output ports.
-
#parallel_load_limit ⇒ Integer
If not a singular load, this defines the number of entities being loaded in parallel at a time for a Data Loader task.
-
#parameters ⇒ Array<OCI::DataIntegration::Models::Parameter>
An array of parameters.
Attributes inherited from PublishedObject
#description, #identifier, #key, #model_type, #model_version, #name, #object_status, #object_version, #parent_ref
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PublishedObjectFromDataLoaderTask
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from PublishedObject
Constructor Details
#initialize(attributes = {}) ⇒ PublishedObjectFromDataLoaderTask
Initializes the object
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 118 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'DATA_LOADER_TASK' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.input_ports = attributes[:'inputPorts'] if attributes[:'inputPorts'] raise 'You cannot provide both :inputPorts and :input_ports' if attributes.key?(:'inputPorts') && attributes.key?(:'input_ports') self.input_ports = attributes[:'input_ports'] if attributes[:'input_ports'] self.output_ports = attributes[:'outputPorts'] if attributes[:'outputPorts'] raise 'You cannot provide both :outputPorts and :output_ports' if attributes.key?(:'outputPorts') && attributes.key?(:'output_ports') self.output_ports = attributes[:'output_ports'] if attributes[:'output_ports'] self.parameters = attributes[:'parameters'] if attributes[:'parameters'] self.op_config_values = attributes[:'opConfigValues'] if attributes[:'opConfigValues'] raise 'You cannot provide both :opConfigValues and :op_config_values' if attributes.key?(:'opConfigValues') && attributes.key?(:'op_config_values') self.op_config_values = attributes[:'op_config_values'] if attributes[:'op_config_values'] self.config_provider_delegate = attributes[:'configProviderDelegate'] if attributes[:'configProviderDelegate'] raise 'You cannot provide both :configProviderDelegate and :config_provider_delegate' if attributes.key?(:'configProviderDelegate') && attributes.key?(:'config_provider_delegate') self.config_provider_delegate = attributes[:'config_provider_delegate'] if attributes[:'config_provider_delegate'] self.data_flow = attributes[:'dataFlow'] if attributes[:'dataFlow'] raise 'You cannot provide both :dataFlow and :data_flow' if attributes.key?(:'dataFlow') && attributes.key?(:'data_flow') self.data_flow = attributes[:'data_flow'] if attributes[:'data_flow'] self.conditional_composite_field_map = attributes[:'conditionalCompositeFieldMap'] if attributes[:'conditionalCompositeFieldMap'] raise 'You cannot provide both :conditionalCompositeFieldMap and :conditional_composite_field_map' if attributes.key?(:'conditionalCompositeFieldMap') && attributes.key?(:'conditional_composite_field_map') self.conditional_composite_field_map = attributes[:'conditional_composite_field_map'] if attributes[:'conditional_composite_field_map'] self.is_single_load = attributes[:'isSingleLoad'] unless attributes[:'isSingleLoad'].nil? self.is_single_load = true if is_single_load.nil? && !attributes.key?(:'isSingleLoad') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isSingleLoad and :is_single_load' if attributes.key?(:'isSingleLoad') && attributes.key?(:'is_single_load') self.is_single_load = attributes[:'is_single_load'] unless attributes[:'is_single_load'].nil? self.is_single_load = true if is_single_load.nil? && !attributes.key?(:'isSingleLoad') && !attributes.key?(:'is_single_load') # rubocop:disable Style/StringLiterals self.parallel_load_limit = attributes[:'parallelLoadLimit'] if attributes[:'parallelLoadLimit'] raise 'You cannot provide both :parallelLoadLimit and :parallel_load_limit' if attributes.key?(:'parallelLoadLimit') && attributes.key?(:'parallel_load_limit') self.parallel_load_limit = attributes[:'parallel_load_limit'] if attributes[:'parallel_load_limit'] end |
Instance Attribute Details
#conditional_composite_field_map ⇒ OCI::DataIntegration::Models::ConditionalCompositeFieldMap
33 34 35 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 33 def conditional_composite_field_map @conditional_composite_field_map end |
#config_provider_delegate ⇒ OCI::DataIntegration::Models::ConfigProvider
27 28 29 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 27 def config_provider_delegate @config_provider_delegate end |
#data_flow ⇒ OCI::DataIntegration::Models::DataFlow
30 31 32 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 30 def data_flow @data_flow end |
#input_ports ⇒ Array<OCI::DataIntegration::Models::InputPort>
An array of input ports.
13 14 15 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 13 def input_ports @input_ports end |
#is_single_load ⇒ BOOLEAN
If true, defines a singular load.
37 38 39 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 37 def is_single_load @is_single_load end |
#op_config_values ⇒ OCI::DataIntegration::Models::ConfigValues
24 25 26 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 24 def op_config_values @op_config_values end |
#output_ports ⇒ Array<OCI::DataIntegration::Models::OutputPort>
An array of output ports.
17 18 19 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 17 def output_ports @output_ports end |
#parallel_load_limit ⇒ Integer
If not a singular load, this defines the number of entities being loaded in parallel at a time for a Data Loader task.
41 42 43 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 41 def parallel_load_limit @parallel_load_limit end |
#parameters ⇒ Array<OCI::DataIntegration::Models::Parameter>
An array of parameters.
21 22 23 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 21 def parameters @parameters end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'input_ports': :'inputPorts', 'output_ports': :'outputPorts', 'parameters': :'parameters', 'op_config_values': :'opConfigValues', 'config_provider_delegate': :'configProviderDelegate', 'data_flow': :'dataFlow', 'conditional_composite_field_map': :'conditionalCompositeFieldMap', 'is_single_load': :'isSingleLoad', 'parallel_load_limit': :'parallelLoadLimit' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 70 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>', 'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>', 'parameters': :'Array<OCI::DataIntegration::Models::Parameter>', 'op_config_values': :'OCI::DataIntegration::Models::ConfigValues', 'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider', 'data_flow': :'OCI::DataIntegration::Models::DataFlow', 'conditional_composite_field_map': :'OCI::DataIntegration::Models::ConditionalCompositeFieldMap', 'is_single_load': :'BOOLEAN', 'parallel_load_limit': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 188 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && input_ports == other.input_ports && output_ports == other.output_ports && parameters == other.parameters && op_config_values == other.op_config_values && config_provider_delegate == other.config_provider_delegate && data_flow == other.data_flow && conditional_composite_field_map == other.conditional_composite_field_map && is_single_load == other.is_single_load && parallel_load_limit == other.parallel_load_limit end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 235 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
215 216 217 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 215 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 224 def hash [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, input_ports, output_ports, parameters, op_config_values, config_provider_delegate, data_flow, conditional_composite_field_map, is_single_load, parallel_load_limit].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
262 263 264 |
# File 'lib/oci/data_integration/models/published_object_from_data_loader_task.rb', line 262 def to_s to_hash.to_s end |