Class: OCI::DataIntegration::Models::TaskFromRestTaskDetails

Inherits:
DataIntegration::Models::Task
  • Object
show all
Defined in:
lib/oci/data_integration/models/task_from_rest_task_details.rb

Overview

The information about the Generic REST task.

Constant Summary collapse

METHOD_TYPE_ENUM =
[
  METHOD_TYPE_GET = 'GET'.freeze,
  METHOD_TYPE_POST = 'POST'.freeze,
  METHOD_TYPE_PATCH = 'PATCH'.freeze,
  METHOD_TYPE_DELETE = 'DELETE'.freeze,
  METHOD_TYPE_PUT = 'PUT'.freeze,
  METHOD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
API_CALL_MODE_ENUM =
[
  API_CALL_MODE_SYNCHRONOUS = 'SYNCHRONOUS'.freeze,
  API_CALL_MODE_ASYNC_OCI_WORKREQUEST = 'ASYNC_OCI_WORKREQUEST'.freeze,
  API_CALL_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
CANCEL_METHOD_TYPE_ENUM =
[
  CANCEL_METHOD_TYPE_GET = 'GET'.freeze,
  CANCEL_METHOD_TYPE_POST = 'POST'.freeze,
  CANCEL_METHOD_TYPE_PATCH = 'PATCH'.freeze,
  CANCEL_METHOD_TYPE_DELETE = 'DELETE'.freeze,
  CANCEL_METHOD_TYPE_PUT = 'PUT'.freeze,
  CANCEL_METHOD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TaskFromRestTaskDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 161

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['modelType'] = 'REST_TASK'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.auth_details = attributes[:'authDetails'] if attributes[:'authDetails']

  raise 'You cannot provide both :authDetails and :auth_details' if attributes.key?(:'authDetails') && attributes.key?(:'auth_details')

  self.auth_details = attributes[:'auth_details'] if attributes[:'auth_details']

  self.endpoint = attributes[:'endpoint'] if attributes[:'endpoint']

  self.method_type = attributes[:'methodType'] if attributes[:'methodType']

  raise 'You cannot provide both :methodType and :method_type' if attributes.key?(:'methodType') && attributes.key?(:'method_type')

  self.method_type = attributes[:'method_type'] if attributes[:'method_type']

  self.headers = attributes[:'headers'] if attributes[:'headers']

  self.json_data = attributes[:'jsonData'] if attributes[:'jsonData']

  raise 'You cannot provide both :jsonData and :json_data' if attributes.key?(:'jsonData') && attributes.key?(:'json_data')

  self.json_data = attributes[:'json_data'] if attributes[:'json_data']

  self.api_call_mode = attributes[:'apiCallMode'] if attributes[:'apiCallMode']
  self.api_call_mode = "SYNCHRONOUS" if api_call_mode.nil? && !attributes.key?(:'apiCallMode') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :apiCallMode and :api_call_mode' if attributes.key?(:'apiCallMode') && attributes.key?(:'api_call_mode')

  self.api_call_mode = attributes[:'api_call_mode'] if attributes[:'api_call_mode']
  self.api_call_mode = "SYNCHRONOUS" if api_call_mode.nil? && !attributes.key?(:'apiCallMode') && !attributes.key?(:'api_call_mode') # rubocop:disable Style/StringLiterals

  self.cancel_endpoint = attributes[:'cancelEndpoint'] if attributes[:'cancelEndpoint']

  raise 'You cannot provide both :cancelEndpoint and :cancel_endpoint' if attributes.key?(:'cancelEndpoint') && attributes.key?(:'cancel_endpoint')

  self.cancel_endpoint = attributes[:'cancel_endpoint'] if attributes[:'cancel_endpoint']

  self.cancel_method_type = attributes[:'cancelMethodType'] if attributes[:'cancelMethodType']

  raise 'You cannot provide both :cancelMethodType and :cancel_method_type' if attributes.key?(:'cancelMethodType') && attributes.key?(:'cancel_method_type')

  self.cancel_method_type = attributes[:'cancel_method_type'] if attributes[:'cancel_method_type']
end

Instance Attribute Details

#api_call_modeString

The invocation type to be used for Generic REST invocation.

Returns:

  • (String)


56
57
58
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 56

def api_call_mode
  @api_call_mode
end

#auth_detailsOCI::DataIntegration::Models::AuthDetails



37
38
39
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 37

def auth_details
  @auth_details
end

#cancel_endpointOCI::DataIntegration::Models::Expression



59
60
61
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 59

def cancel_endpoint
  @cancel_endpoint
end

#cancel_method_typeString

The REST method to use for canceling the original request.

Returns:

  • (String)


63
64
65
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 63

def cancel_method_type
  @cancel_method_type
end

#endpointOCI::DataIntegration::Models::Expression



40
41
42
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 40

def endpoint
  @endpoint
end

#headersObject

The headers for the REST call.

Returns:

  • (Object)


48
49
50
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 48

def headers
  @headers
end

#json_dataString

JSON data for payload body.

Returns:

  • (String)


52
53
54
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 52

def json_data
  @json_data
end

#method_typeString

The REST method to use.

Returns:

  • (String)


44
45
46
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 44

def method_type
  @method_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 66

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'modelType',
    'key': :'key',
    'model_version': :'modelVersion',
    'parent_ref': :'parentRef',
    'name': :'name',
    'description': :'description',
    'object_version': :'objectVersion',
    'object_status': :'objectStatus',
    'identifier': :'identifier',
    'input_ports': :'inputPorts',
    'output_ports': :'outputPorts',
    'parameters': :'parameters',
    'op_config_values': :'opConfigValues',
    'config_provider_delegate': :'configProviderDelegate',
    'metadata': :'metadata',
    'key_map': :'keyMap',
    'registry_metadata': :'registryMetadata',
    'auth_details': :'authDetails',
    'endpoint': :'endpoint',
    'method_type': :'methodType',
    'headers': :'headers',
    'json_data': :'jsonData',
    'api_call_mode': :'apiCallMode',
    'cancel_endpoint': :'cancelEndpoint',
    'cancel_method_type': :'cancelMethodType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 99

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'model_type': :'String',
    'key': :'String',
    'model_version': :'String',
    'parent_ref': :'OCI::DataIntegration::Models::ParentReference',
    'name': :'String',
    'description': :'String',
    'object_version': :'Integer',
    'object_status': :'Integer',
    'identifier': :'String',
    'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>',
    'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>',
    'parameters': :'Array<OCI::DataIntegration::Models::Parameter>',
    'op_config_values': :'OCI::DataIntegration::Models::ConfigValues',
    'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider',
    'metadata': :'OCI::DataIntegration::Models::ObjectMetadata',
    'key_map': :'Hash<String, String>',
    'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata',
    'auth_details': :'OCI::DataIntegration::Models::AuthDetails',
    'endpoint': :'OCI::DataIntegration::Models::Expression',
    'method_type': :'String',
    'headers': :'Object',
    'json_data': :'String',
    'api_call_mode': :'String',
    'cancel_endpoint': :'OCI::DataIntegration::Models::Expression',
    'cancel_method_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 260

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    model_type == other.model_type &&
    key == other.key &&
    model_version == other.model_version &&
    parent_ref == other.parent_ref &&
    name == other.name &&
    description == other.description &&
    object_version == other.object_version &&
    object_status == other.object_status &&
    identifier == other.identifier &&
    input_ports == other.input_ports &&
    output_ports == other.output_ports &&
    parameters == other.parameters &&
    op_config_values == other.op_config_values &&
    config_provider_delegate == other.config_provider_delegate &&
     == other. &&
    key_map == other.key_map &&
     == other. &&
    auth_details == other.auth_details &&
    endpoint == other.endpoint &&
    method_type == other.method_type &&
    headers == other.headers &&
    json_data == other.json_data &&
    api_call_mode == other.api_call_mode &&
    cancel_endpoint == other.cancel_endpoint &&
    cancel_method_type == other.cancel_method_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 314

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


294
295
296
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 294

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



303
304
305
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 303

def hash
  [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, input_ports, output_ports, parameters, op_config_values, config_provider_delegate, , key_map, , auth_details, endpoint, method_type, headers, json_data, api_call_mode, cancel_endpoint, cancel_method_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



347
348
349
350
351
352
353
354
355
356
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 347

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



341
342
343
# File 'lib/oci/data_integration/models/task_from_rest_task_details.rb', line 341

def to_s
  to_hash.to_s
end