Class: DataIntegration::Models::TaskRun
- Inherits:
-
Object
- Object
- DataIntegration::Models::TaskRun
- Defined in:
- lib/oci/data_integration/models/task_run.rb
Overview
The information about a task run.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_NOT_STARTED = 'NOT_STARTED'.freeze, STATUS_QUEUED = 'QUEUED'.freeze, STATUS_RUNNING = 'RUNNING'.freeze, STATUS_TERMINATING = 'TERMINATING'.freeze, STATUS_TERMINATED = 'TERMINATED'.freeze, STATUS_SUCCESS = 'SUCCESS'.freeze, STATUS_ERROR = 'ERROR'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- EXPECTED_DURATION_UNIT_ENUM =
[ EXPECTED_DURATION_UNIT_SECONDS = 'SECONDS'.freeze, EXPECTED_DURATION_UNIT_MINUTES = 'MINUTES'.freeze, EXPECTED_DURATION_UNIT_HOURS = 'HOURS'.freeze, EXPECTED_DURATION_UNIT_DAYS = 'DAYS'.freeze, EXPECTED_DURATION_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- AUTH_MODE_ENUM =
[ AUTH_MODE_OBO = 'OBO'.freeze, AUTH_MODE_RESOURCE_PRINCIPAL = 'RESOURCE_PRINCIPAL'.freeze, AUTH_MODE_USER_CERTIFICATE = 'USER_CERTIFICATE'.freeze, AUTH_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TASK_TYPE_ENUM =
[ TASK_TYPE_INTEGRATION_TASK = 'INTEGRATION_TASK'.freeze, TASK_TYPE_DATA_LOADER_TASK = 'DATA_LOADER_TASK'.freeze, TASK_TYPE_PIPELINE_TASK = 'PIPELINE_TASK'.freeze, TASK_TYPE_SQL_TASK = 'SQL_TASK'.freeze, TASK_TYPE_OCI_DATAFLOW_TASK = 'OCI_DATAFLOW_TASK'.freeze, TASK_TYPE_REST_TASK = 'REST_TASK'.freeze, TASK_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#auth_mode ⇒ String
The autorization mode for when the task was executed.
-
#bytes_processed ⇒ Integer
The number of bytes processed in the task run.
- #config_provider ⇒ OCI::DataIntegration::Models::ConfigProvider
-
#description ⇒ String
Detailed description for the object.
-
#end_time_millis ⇒ Integer
The end time.
-
#error_message ⇒ String
Contains an error message if status is `ERROR`.
-
#execution_errors ⇒ Array<String>
An array of execution errors from the run.
-
#expected_duration ⇒ Float
The expected duration for the task run.
-
#expected_duration_unit ⇒ String
The expected duration unit of measure.
-
#external_id ⇒ String
The external identifier for the task run.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers.
-
#key ⇒ String
The key of the object.
-
#key_map ⇒ Hash<String, String>
A key map.
-
#last_updated ⇒ Integer
The date and time the object was last updated.
- #metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
-
#metrics ⇒ Hash<String, Float>
A map of metrics for the run.
-
#model_type ⇒ String
The type of the object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
-
#opc_request_id ⇒ String
The OPC request ID of execution of the task run.
-
#outputs ⇒ Hash<String, OCI::DataIntegration::Models::ParameterValue>
A map of the outputs of the run.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
-
#records_written ⇒ Integer
The number of records processed in the task run.
-
#retry_attempt ⇒ Integer
Holds the particular attempt number.
-
#start_time_millis ⇒ Integer
The start time.
-
#status ⇒ String
The status of the task run.
-
#task_key ⇒ String
Task Key of the task for which TaskRun is being created.
- #task_schedule ⇒ OCI::DataIntegration::Models::TaskSchedule
-
#task_type ⇒ String
The type of task run.
-
#termination_errors ⇒ Array<String>
An array of termination errors from the run.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TaskRun
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TaskRun
Initializes the object
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/oci/data_integration/models/task_run.rb', line 289 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.config_provider = attributes[:'configProvider'] if attributes[:'configProvider'] raise 'You cannot provide both :configProvider and :config_provider' if attributes.key?(:'configProvider') && attributes.key?(:'config_provider') self.config_provider = attributes[:'config_provider'] if attributes[:'config_provider'] self.status = attributes[:'status'] if attributes[:'status'] self.start_time_millis = attributes[:'startTimeMillis'] if attributes[:'startTimeMillis'] raise 'You cannot provide both :startTimeMillis and :start_time_millis' if attributes.key?(:'startTimeMillis') && attributes.key?(:'start_time_millis') self.start_time_millis = attributes[:'start_time_millis'] if attributes[:'start_time_millis'] self.end_time_millis = attributes[:'endTimeMillis'] if attributes[:'endTimeMillis'] raise 'You cannot provide both :endTimeMillis and :end_time_millis' if attributes.key?(:'endTimeMillis') && attributes.key?(:'end_time_millis') self.end_time_millis = attributes[:'end_time_millis'] if attributes[:'end_time_millis'] self.last_updated = attributes[:'lastUpdated'] if attributes[:'lastUpdated'] raise 'You cannot provide both :lastUpdated and :last_updated' if attributes.key?(:'lastUpdated') && attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] if attributes[:'last_updated'] self.records_written = attributes[:'recordsWritten'] if attributes[:'recordsWritten'] raise 'You cannot provide both :recordsWritten and :records_written' if attributes.key?(:'recordsWritten') && attributes.key?(:'records_written') self.records_written = attributes[:'records_written'] if attributes[:'records_written'] self.bytes_processed = attributes[:'bytesProcessed'] if attributes[:'bytesProcessed'] raise 'You cannot provide both :bytesProcessed and :bytes_processed' if attributes.key?(:'bytesProcessed') && attributes.key?(:'bytes_processed') self.bytes_processed = attributes[:'bytes_processed'] if attributes[:'bytes_processed'] self. = attributes[:'errorMessage'] if attributes[:'errorMessage'] raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message') self. = attributes[:'error_message'] if attributes[:'error_message'] self.expected_duration = attributes[:'expectedDuration'] if attributes[:'expectedDuration'] raise 'You cannot provide both :expectedDuration and :expected_duration' if attributes.key?(:'expectedDuration') && attributes.key?(:'expected_duration') self.expected_duration = attributes[:'expected_duration'] if attributes[:'expected_duration'] self.expected_duration_unit = attributes[:'expectedDurationUnit'] if attributes[:'expectedDurationUnit'] raise 'You cannot provide both :expectedDurationUnit and :expected_duration_unit' if attributes.key?(:'expectedDurationUnit') && attributes.key?(:'expected_duration_unit') self.expected_duration_unit = attributes[:'expected_duration_unit'] if attributes[:'expected_duration_unit'] self.task_key = attributes[:'taskKey'] if attributes[:'taskKey'] raise 'You cannot provide both :taskKey and :task_key' if attributes.key?(:'taskKey') && attributes.key?(:'task_key') self.task_key = attributes[:'task_key'] if attributes[:'task_key'] self.external_id = attributes[:'externalId'] if attributes[:'externalId'] raise 'You cannot provide both :externalId and :external_id' if attributes.key?(:'externalId') && attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] if attributes[:'external_id'] self.retry_attempt = attributes[:'retryAttempt'] if attributes[:'retryAttempt'] raise 'You cannot provide both :retryAttempt and :retry_attempt' if attributes.key?(:'retryAttempt') && attributes.key?(:'retry_attempt') self.retry_attempt = attributes[:'retry_attempt'] if attributes[:'retry_attempt'] self.task_schedule = attributes[:'taskSchedule'] if attributes[:'taskSchedule'] raise 'You cannot provide both :taskSchedule and :task_schedule' if attributes.key?(:'taskSchedule') && attributes.key?(:'task_schedule') self.task_schedule = attributes[:'task_schedule'] if attributes[:'task_schedule'] self.metrics = attributes[:'metrics'] if attributes[:'metrics'] self.outputs = attributes[:'outputs'] if attributes[:'outputs'] self.execution_errors = attributes[:'executionErrors'] if attributes[:'executionErrors'] raise 'You cannot provide both :executionErrors and :execution_errors' if attributes.key?(:'executionErrors') && attributes.key?(:'execution_errors') self.execution_errors = attributes[:'execution_errors'] if attributes[:'execution_errors'] self.termination_errors = attributes[:'terminationErrors'] if attributes[:'terminationErrors'] raise 'You cannot provide both :terminationErrors and :termination_errors' if attributes.key?(:'terminationErrors') && attributes.key?(:'termination_errors') self.termination_errors = attributes[:'termination_errors'] if attributes[:'termination_errors'] self.auth_mode = attributes[:'authMode'] if attributes[:'authMode'] raise 'You cannot provide both :authMode and :auth_mode' if attributes.key?(:'authMode') && attributes.key?(:'auth_mode') self.auth_mode = attributes[:'auth_mode'] if attributes[:'auth_mode'] self.opc_request_id = attributes[:'opcRequestId'] if attributes[:'opcRequestId'] raise 'You cannot provide both :opcRequestId and :opc_request_id' if attributes.key?(:'opcRequestId') && attributes.key?(:'opc_request_id') self.opc_request_id = attributes[:'opc_request_id'] if attributes[:'opc_request_id'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.task_type = attributes[:'taskType'] if attributes[:'taskType'] raise 'You cannot provide both :taskType and :task_type' if attributes.key?(:'taskType') && attributes.key?(:'task_type') self.task_type = attributes[:'task_type'] if attributes[:'task_type'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self. = attributes[:'metadata'] if attributes[:'metadata'] self.key_map = attributes[:'keyMap'] if attributes[:'keyMap'] raise 'You cannot provide both :keyMap and :key_map' if attributes.key?(:'keyMap') && attributes.key?(:'key_map') self.key_map = attributes[:'key_map'] if attributes[:'key_map'] end |
Instance Attribute Details
#auth_mode ⇒ String
The autorization mode for when the task was executed.
146 147 148 |
# File 'lib/oci/data_integration/models/task_run.rb', line 146 def auth_mode @auth_mode end |
#bytes_processed ⇒ Integer
The number of bytes processed in the task run.
99 100 101 |
# File 'lib/oci/data_integration/models/task_run.rb', line 99 def bytes_processed @bytes_processed end |
#config_provider ⇒ OCI::DataIntegration::Models::ConfigProvider
75 76 77 |
# File 'lib/oci/data_integration/models/task_run.rb', line 75 def config_provider @config_provider end |
#description ⇒ String
Detailed description for the object.
68 69 70 |
# File 'lib/oci/data_integration/models/task_run.rb', line 68 def description @description end |
#end_time_millis ⇒ Integer
The end time.
87 88 89 |
# File 'lib/oci/data_integration/models/task_run.rb', line 87 def end_time_millis @end_time_millis end |
#error_message ⇒ String
Contains an error message if status is `ERROR`.
103 104 105 |
# File 'lib/oci/data_integration/models/task_run.rb', line 103 def @error_message end |
#execution_errors ⇒ Array<String>
An array of execution errors from the run.
138 139 140 |
# File 'lib/oci/data_integration/models/task_run.rb', line 138 def execution_errors @execution_errors end |
#expected_duration ⇒ Float
The expected duration for the task run.
107 108 109 |
# File 'lib/oci/data_integration/models/task_run.rb', line 107 def expected_duration @expected_duration end |
#expected_duration_unit ⇒ String
The expected duration unit of measure.
111 112 113 |
# File 'lib/oci/data_integration/models/task_run.rb', line 111 def expected_duration_unit @expected_duration_unit end |
#external_id ⇒ String
The external identifier for the task run.
119 120 121 |
# File 'lib/oci/data_integration/models/task_run.rb', line 119 def external_id @external_id end |
#identifier ⇒ String
Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be modified.
162 163 164 |
# File 'lib/oci/data_integration/models/task_run.rb', line 162 def identifier @identifier end |
#key ⇒ String
The key of the object.
49 50 51 |
# File 'lib/oci/data_integration/models/task_run.rb', line 49 def key @key end |
#key_map ⇒ Hash<String, String>
A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.
169 170 171 |
# File 'lib/oci/data_integration/models/task_run.rb', line 169 def key_map @key_map end |
#last_updated ⇒ Integer
The date and time the object was last updated.
91 92 93 |
# File 'lib/oci/data_integration/models/task_run.rb', line 91 def last_updated @last_updated end |
#metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
165 166 167 |
# File 'lib/oci/data_integration/models/task_run.rb', line 165 def @metadata end |
#metrics ⇒ Hash<String, Float>
A map of metrics for the run.
130 131 132 |
# File 'lib/oci/data_integration/models/task_run.rb', line 130 def metrics @metrics end |
#model_type ⇒ String
The type of the object.
53 54 55 |
# File 'lib/oci/data_integration/models/task_run.rb', line 53 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
57 58 59 |
# File 'lib/oci/data_integration/models/task_run.rb', line 57 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
64 65 66 |
# File 'lib/oci/data_integration/models/task_run.rb', line 64 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
154 155 156 |
# File 'lib/oci/data_integration/models/task_run.rb', line 154 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
72 73 74 |
# File 'lib/oci/data_integration/models/task_run.rb', line 72 def object_version @object_version end |
#opc_request_id ⇒ String
The OPC request ID of execution of the task run.
150 151 152 |
# File 'lib/oci/data_integration/models/task_run.rb', line 150 def opc_request_id @opc_request_id end |
#outputs ⇒ Hash<String, OCI::DataIntegration::Models::ParameterValue>
A map of the outputs of the run.
134 135 136 |
# File 'lib/oci/data_integration/models/task_run.rb', line 134 def outputs @outputs end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
60 61 62 |
# File 'lib/oci/data_integration/models/task_run.rb', line 60 def parent_ref @parent_ref end |
#records_written ⇒ Integer
The number of records processed in the task run.
95 96 97 |
# File 'lib/oci/data_integration/models/task_run.rb', line 95 def records_written @records_written end |
#retry_attempt ⇒ Integer
Holds the particular attempt number.
123 124 125 |
# File 'lib/oci/data_integration/models/task_run.rb', line 123 def retry_attempt @retry_attempt end |
#start_time_millis ⇒ Integer
The start time.
83 84 85 |
# File 'lib/oci/data_integration/models/task_run.rb', line 83 def start_time_millis @start_time_millis end |
#status ⇒ String
The status of the task run.
79 80 81 |
# File 'lib/oci/data_integration/models/task_run.rb', line 79 def status @status end |
#task_key ⇒ String
Task Key of the task for which TaskRun is being created. If not specified, the AggregatorKey in RegistryMetadata will be assumed to be the TaskKey
115 116 117 |
# File 'lib/oci/data_integration/models/task_run.rb', line 115 def task_key @task_key end |
#task_schedule ⇒ OCI::DataIntegration::Models::TaskSchedule
126 127 128 |
# File 'lib/oci/data_integration/models/task_run.rb', line 126 def task_schedule @task_schedule end |
#task_type ⇒ String
The type of task run.
158 159 160 |
# File 'lib/oci/data_integration/models/task_run.rb', line 158 def task_type @task_type end |
#termination_errors ⇒ Array<String>
An array of termination errors from the run.
142 143 144 |
# File 'lib/oci/data_integration/models/task_run.rb', line 142 def termination_errors @termination_errors end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/data_integration/models/task_run.rb', line 172 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'config_provider': :'configProvider', 'status': :'status', 'start_time_millis': :'startTimeMillis', 'end_time_millis': :'endTimeMillis', 'last_updated': :'lastUpdated', 'records_written': :'recordsWritten', 'bytes_processed': :'bytesProcessed', 'error_message': :'errorMessage', 'expected_duration': :'expectedDuration', 'expected_duration_unit': :'expectedDurationUnit', 'task_key': :'taskKey', 'external_id': :'externalId', 'retry_attempt': :'retryAttempt', 'task_schedule': :'taskSchedule', 'metrics': :'metrics', 'outputs': :'outputs', 'execution_errors': :'executionErrors', 'termination_errors': :'terminationErrors', 'auth_mode': :'authMode', 'opc_request_id': :'opcRequestId', 'object_status': :'objectStatus', 'task_type': :'taskType', 'identifier': :'identifier', 'metadata': :'metadata', 'key_map': :'keyMap' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/data_integration/models/task_run.rb', line 212 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'config_provider': :'OCI::DataIntegration::Models::ConfigProvider', 'status': :'String', 'start_time_millis': :'Integer', 'end_time_millis': :'Integer', 'last_updated': :'Integer', 'records_written': :'Integer', 'bytes_processed': :'Integer', 'error_message': :'String', 'expected_duration': :'Float', 'expected_duration_unit': :'String', 'task_key': :'String', 'external_id': :'String', 'retry_attempt': :'Integer', 'task_schedule': :'OCI::DataIntegration::Models::TaskSchedule', 'metrics': :'Hash<String, Float>', 'outputs': :'Hash<String, OCI::DataIntegration::Models::ParameterValue>', 'execution_errors': :'Array<String>', 'termination_errors': :'Array<String>', 'auth_mode': :'String', 'opc_request_id': :'String', 'object_status': :'Integer', 'task_type': :'String', 'identifier': :'String', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata', 'key_map': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/oci/data_integration/models/task_run.rb', line 515 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_type == other.model_type && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && config_provider == other.config_provider && status == other.status && start_time_millis == other.start_time_millis && end_time_millis == other.end_time_millis && last_updated == other.last_updated && records_written == other.records_written && bytes_processed == other.bytes_processed && == other. && expected_duration == other.expected_duration && expected_duration_unit == other.expected_duration_unit && task_key == other.task_key && external_id == other.external_id && retry_attempt == other.retry_attempt && task_schedule == other.task_schedule && metrics == other.metrics && outputs == other.outputs && execution_errors == other.execution_errors && termination_errors == other.termination_errors && auth_mode == other.auth_mode && opc_request_id == other.opc_request_id && object_status == other.object_status && task_type == other.task_type && identifier == other.identifier && == other. && key_map == other.key_map end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/oci/data_integration/models/task_run.rb', line 576 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
556 557 558 |
# File 'lib/oci/data_integration/models/task_run.rb', line 556 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
565 566 567 |
# File 'lib/oci/data_integration/models/task_run.rb', line 565 def hash [key, model_type, model_version, parent_ref, name, description, object_version, config_provider, status, start_time_millis, end_time_millis, last_updated, records_written, bytes_processed, , expected_duration, expected_duration_unit, task_key, external_id, retry_attempt, task_schedule, metrics, outputs, execution_errors, termination_errors, auth_mode, opc_request_id, object_status, task_type, identifier, , key_map].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
609 610 611 612 613 614 615 616 617 618 |
# File 'lib/oci/data_integration/models/task_run.rb', line 609 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
603 604 605 |
# File 'lib/oci/data_integration/models/task_run.rb', line 603 def to_s to_hash.to_s end |