Class: OCI::DataIntegration::Models::TaskRunDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::TaskRunDetails
- Defined in:
- lib/oci/data_integration/models/task_run_details.rb
Overview
The task run object provides information on the execution of a task.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_NOT_STARTED = 'NOT_STARTED'.freeze, STATUS_QUEUED = 'QUEUED'.freeze, STATUS_RUNNING = 'RUNNING'.freeze, STATUS_TERMINATING = 'TERMINATING'.freeze, STATUS_TERMINATED = 'TERMINATED'.freeze, STATUS_SUCCESS = 'SUCCESS'.freeze, STATUS_ERROR = 'ERROR'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TASK_TYPE_ENUM =
[ TASK_TYPE_INTEGRATION_TASK = 'INTEGRATION_TASK'.freeze, TASK_TYPE_DATA_LOADER_TASK = 'DATA_LOADER_TASK'.freeze, TASK_TYPE_PIPELINE_TASK = 'PIPELINE_TASK'.freeze, TASK_TYPE_SQL_TASK = 'SQL_TASK'.freeze, TASK_TYPE_OCI_DATAFLOW_TASK = 'OCI_DATAFLOW_TASK'.freeze, TASK_TYPE_REST_TASK = 'REST_TASK'.freeze, TASK_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- RE_RUN_TYPE_ENUM =
[ RE_RUN_TYPE_BEGINNING = 'BEGINNING'.freeze, RE_RUN_TYPE_FAILED = 'FAILED'.freeze, RE_RUN_TYPE_STEP = 'STEP'.freeze, RE_RUN_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#bytes_processed ⇒ Integer
Number of bytes processed in task run.
-
#description ⇒ String
Detailed description for the object.
-
#end_time_millis ⇒ Integer
The task run end time.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
The object key.
-
#last_updated ⇒ Integer
The date and time the task run was last updated.
- #metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
-
#model_type ⇒ String
The object type.
-
#model_version ⇒ String
The object’s model version.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
-
#re_run_type ⇒ String
Supported re-run types.
-
#records_written ⇒ Integer
Number of records processed in task run.
-
#ref_task_run_id ⇒ String
Reference Task Run Id to be used for re-run.
-
#start_time_millis ⇒ Integer
The task run start time.
-
#status ⇒ String
status.
-
#step_id ⇒ String
Step Id for running from a certain step.
-
#task_type ⇒ String
The type of the task for the run.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TaskRunDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TaskRunDetails
Initializes the object
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 199 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.status = attributes[:'status'] if attributes[:'status'] self.start_time_millis = attributes[:'startTimeMillis'] if attributes[:'startTimeMillis'] raise 'You cannot provide both :startTimeMillis and :start_time_millis' if attributes.key?(:'startTimeMillis') && attributes.key?(:'start_time_millis') self.start_time_millis = attributes[:'start_time_millis'] if attributes[:'start_time_millis'] self.end_time_millis = attributes[:'endTimeMillis'] if attributes[:'endTimeMillis'] raise 'You cannot provide both :endTimeMillis and :end_time_millis' if attributes.key?(:'endTimeMillis') && attributes.key?(:'end_time_millis') self.end_time_millis = attributes[:'end_time_millis'] if attributes[:'end_time_millis'] self.last_updated = attributes[:'lastUpdated'] if attributes[:'lastUpdated'] raise 'You cannot provide both :lastUpdated and :last_updated' if attributes.key?(:'lastUpdated') && attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] if attributes[:'last_updated'] self.records_written = attributes[:'recordsWritten'] if attributes[:'recordsWritten'] raise 'You cannot provide both :recordsWritten and :records_written' if attributes.key?(:'recordsWritten') && attributes.key?(:'records_written') self.records_written = attributes[:'records_written'] if attributes[:'records_written'] self.bytes_processed = attributes[:'bytesProcessed'] if attributes[:'bytesProcessed'] raise 'You cannot provide both :bytesProcessed and :bytes_processed' if attributes.key?(:'bytesProcessed') && attributes.key?(:'bytes_processed') self.bytes_processed = attributes[:'bytes_processed'] if attributes[:'bytes_processed'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.task_type = attributes[:'taskType'] if attributes[:'taskType'] raise 'You cannot provide both :taskType and :task_type' if attributes.key?(:'taskType') && attributes.key?(:'task_type') self.task_type = attributes[:'task_type'] if attributes[:'task_type'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.ref_task_run_id = attributes[:'refTaskRunId'] if attributes[:'refTaskRunId'] raise 'You cannot provide both :refTaskRunId and :ref_task_run_id' if attributes.key?(:'refTaskRunId') && attributes.key?(:'ref_task_run_id') self.ref_task_run_id = attributes[:'ref_task_run_id'] if attributes[:'ref_task_run_id'] self.re_run_type = attributes[:'reRunType'] if attributes[:'reRunType'] raise 'You cannot provide both :reRunType and :re_run_type' if attributes.key?(:'reRunType') && attributes.key?(:'re_run_type') self.re_run_type = attributes[:'re_run_type'] if attributes[:'re_run_type'] self.step_id = attributes[:'stepId'] if attributes[:'stepId'] raise 'You cannot provide both :stepId and :step_id' if attributes.key?(:'stepId') && attributes.key?(:'step_id') self.step_id = attributes[:'step_id'] if attributes[:'step_id'] self. = attributes[:'metadata'] if attributes[:'metadata'] end |
Instance Attribute Details
#bytes_processed ⇒ Integer
Number of bytes processed in task run.
88 89 90 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 88 def bytes_processed @bytes_processed end |
#description ⇒ String
Detailed description for the object.
60 61 62 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 60 def description @description end |
#end_time_millis ⇒ Integer
The task run end time.
76 77 78 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 76 def end_time_millis @end_time_millis end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
100 101 102 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 100 def identifier @identifier end |
#key ⇒ String
The object key.
41 42 43 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 41 def key @key end |
#last_updated ⇒ Integer
The date and time the task run was last updated.
80 81 82 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 80 def last_updated @last_updated end |
#metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
115 116 117 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 115 def @metadata end |
#model_type ⇒ String
The object type.
45 46 47 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 45 def model_type @model_type end |
#model_version ⇒ String
The object’s model version.
49 50 51 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 49 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
56 57 58 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 56 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
92 93 94 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 92 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
64 65 66 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 64 def object_version @object_version end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
52 53 54 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 52 def parent_ref @parent_ref end |
#re_run_type ⇒ String
Supported re-run types
108 109 110 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 108 def re_run_type @re_run_type end |
#records_written ⇒ Integer
Number of records processed in task run.
84 85 86 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 84 def records_written @records_written end |
#ref_task_run_id ⇒ String
Reference Task Run Id to be used for re-run
104 105 106 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 104 def ref_task_run_id @ref_task_run_id end |
#start_time_millis ⇒ Integer
The task run start time.
72 73 74 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 72 def start_time_millis @start_time_millis end |
#status ⇒ String
status
68 69 70 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 68 def status @status end |
#step_id ⇒ String
Step Id for running from a certain step.
112 113 114 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 112 def step_id @step_id end |
#task_type ⇒ String
The type of the task for the run.
96 97 98 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 96 def task_type @task_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 118 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'model_type': :'modelType', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'status': :'status', 'start_time_millis': :'startTimeMillis', 'end_time_millis': :'endTimeMillis', 'last_updated': :'lastUpdated', 'records_written': :'recordsWritten', 'bytes_processed': :'bytesProcessed', 'object_status': :'objectStatus', 'task_type': :'taskType', 'identifier': :'identifier', 'ref_task_run_id': :'refTaskRunId', 're_run_type': :'reRunType', 'step_id': :'stepId', 'metadata': :'metadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 146 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'model_type': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'status': :'String', 'start_time_millis': :'Integer', 'end_time_millis': :'Integer', 'last_updated': :'Integer', 'records_written': :'Integer', 'bytes_processed': :'Integer', 'object_status': :'Integer', 'task_type': :'String', 'identifier': :'String', 'ref_task_run_id': :'String', 're_run_type': :'String', 'step_id': :'String', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 348 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && model_type == other.model_type && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && status == other.status && start_time_millis == other.start_time_millis && end_time_millis == other.end_time_millis && last_updated == other.last_updated && records_written == other.records_written && bytes_processed == other.bytes_processed && object_status == other.object_status && task_type == other.task_type && identifier == other.identifier && ref_task_run_id == other.ref_task_run_id && re_run_type == other.re_run_type && step_id == other.step_id && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 397 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
377 378 379 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 377 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
386 387 388 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 386 def hash [key, model_type, model_version, parent_ref, name, description, object_version, status, start_time_millis, end_time_millis, last_updated, records_written, bytes_processed, object_status, task_type, identifier, ref_task_run_id, re_run_type, step_id, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
430 431 432 433 434 435 436 437 438 439 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 430 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
424 425 426 |
# File 'lib/oci/data_integration/models/task_run_details.rb', line 424 def to_s to_hash.to_s end |