Class: OCI::DataIntegration::Models::TaskSummary
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::TaskSummary
- Defined in:
- lib/oci/data_integration/models/task_summary.rb
Overview
The task summary object type contains the audit summary information and the definition of the task summary object. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
TaskSummaryFromDataLoaderTask, TaskSummaryFromIntegrationTask, TaskSummaryFromPipelineTask
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_INTEGRATION_TASK = 'INTEGRATION_TASK'.freeze, MODEL_TYPE_DATA_LOADER_TASK = 'DATA_LOADER_TASK'.freeze, MODEL_TYPE_PIPELINE_TASK = 'PIPELINE_TASK'.freeze, MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #config_provider_delegate ⇒ OCI::DataIntegration::Models::ConfigProvider
-
#description ⇒ String
Detailed description for the object.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#input_ports ⇒ Array<OCI::DataIntegration::Models::InputPort>
An array of input ports.
-
#key ⇒ String
Generated key that can be used in API calls to identify task.
-
#key_map ⇒ Hash<String, String>
A key map.
- #metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
-
#model_type ⇒ String
The type of task.
-
#model_version ⇒ String
The object’s model version.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #op_config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#output_ports ⇒ Array<OCI::DataIntegration::Models::OutputPort>
An array of output ports.
-
#parameters ⇒ Array<OCI::DataIntegration::Models::Parameter>
An array of parameters.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TaskSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TaskSummary
Initializes the object
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 166 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.input_ports = attributes[:'inputPorts'] if attributes[:'inputPorts'] raise 'You cannot provide both :inputPorts and :input_ports' if attributes.key?(:'inputPorts') && attributes.key?(:'input_ports') self.input_ports = attributes[:'input_ports'] if attributes[:'input_ports'] self.output_ports = attributes[:'outputPorts'] if attributes[:'outputPorts'] raise 'You cannot provide both :outputPorts and :output_ports' if attributes.key?(:'outputPorts') && attributes.key?(:'output_ports') self.output_ports = attributes[:'output_ports'] if attributes[:'output_ports'] self.parameters = attributes[:'parameters'] if attributes[:'parameters'] self.op_config_values = attributes[:'opConfigValues'] if attributes[:'opConfigValues'] raise 'You cannot provide both :opConfigValues and :op_config_values' if attributes.key?(:'opConfigValues') && attributes.key?(:'op_config_values') self.op_config_values = attributes[:'op_config_values'] if attributes[:'op_config_values'] self.config_provider_delegate = attributes[:'configProviderDelegate'] if attributes[:'configProviderDelegate'] raise 'You cannot provide both :configProviderDelegate and :config_provider_delegate' if attributes.key?(:'configProviderDelegate') && attributes.key?(:'config_provider_delegate') self.config_provider_delegate = attributes[:'config_provider_delegate'] if attributes[:'config_provider_delegate'] self. = attributes[:'metadata'] if attributes[:'metadata'] self.key_map = attributes[:'keyMap'] if attributes[:'keyMap'] raise 'You cannot provide both :keyMap and :key_map' if attributes.key?(:'keyMap') && attributes.key?(:'key_map') self.key_map = attributes[:'key_map'] if attributes[:'key_map'] end |
Instance Attribute Details
#config_provider_delegate ⇒ OCI::DataIntegration::Models::ConfigProvider
70 71 72 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 70 def config_provider_delegate @config_provider_delegate end |
#description ⇒ String
Detailed description for the object.
40 41 42 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 40 def description @description end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
52 53 54 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 52 def identifier @identifier end |
#input_ports ⇒ Array<OCI::DataIntegration::Models::InputPort>
An array of input ports.
56 57 58 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 56 def input_ports @input_ports end |
#key ⇒ String
Generated key that can be used in API calls to identify task. On scenarios where reference to the task is needed, a value can be passed in create.
25 26 27 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 25 def key @key end |
#key_map ⇒ Hash<String, String>
A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.
77 78 79 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 77 def key_map @key_map end |
#metadata ⇒ OCI::DataIntegration::Models::ObjectMetadata
73 74 75 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 73 def end |
#model_type ⇒ String
The type of task.
21 22 23 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 21 def model_type @model_type end |
#model_version ⇒ String
The object’s model version.
29 30 31 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 29 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
36 37 38 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 36 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
48 49 50 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 48 def object_status @object_status end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
44 45 46 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 44 def object_version @object_version end |
#op_config_values ⇒ OCI::DataIntegration::Models::ConfigValues
67 68 69 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 67 def op_config_values @op_config_values end |
#output_ports ⇒ Array<OCI::DataIntegration::Models::OutputPort>
An array of output ports.
60 61 62 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 60 def output_ports @output_ports end |
#parameters ⇒ Array<OCI::DataIntegration::Models::Parameter>
An array of parameters.
64 65 66 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 64 def parameters @parameters end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
32 33 34 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 32 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 80 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'object_status': :'objectStatus', 'identifier': :'identifier', 'input_ports': :'inputPorts', 'output_ports': :'outputPorts', 'parameters': :'parameters', 'op_config_values': :'opConfigValues', 'config_provider_delegate': :'configProviderDelegate', 'metadata': :'metadata', 'key_map': :'keyMap' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 132 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataIntegration::Models::TaskSummaryFromIntegrationTask' if type == 'INTEGRATION_TASK' return 'OCI::DataIntegration::Models::TaskSummaryFromPipelineTask' if type == 'PIPELINE_TASK' return 'OCI::DataIntegration::Models::TaskSummaryFromDataLoaderTask' if type == 'DATA_LOADER_TASK' # TODO: Log a warning when the subtype is not found. 'OCI::DataIntegration::Models::TaskSummary' end |
.swagger_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 104 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'object_status': :'Integer', 'identifier': :'String', 'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>', 'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>', 'parameters': :'Array<OCI::DataIntegration::Models::Parameter>', 'op_config_values': :'OCI::DataIntegration::Models::ConfigValues', 'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider', 'metadata': :'OCI::DataIntegration::Models::ObjectMetadata', 'key_map': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 265 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_version == other.object_version && object_status == other.object_status && identifier == other.identifier && input_ports == other.input_ports && output_ports == other.output_ports && parameters == other.parameters && op_config_values == other.op_config_values && config_provider_delegate == other.config_provider_delegate && == other. && key_map == other.key_map end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 310 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
290 291 292 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 290 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
299 300 301 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 299 def hash [model_type, key, model_version, parent_ref, name, description, object_version, object_status, identifier, input_ports, output_ports, parameters, op_config_values, config_provider_delegate, , key_map].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
343 344 345 346 347 348 349 350 351 352 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 343 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
337 338 339 |
# File 'lib/oci/data_integration/models/task_summary.rb', line 337 def to_s to_hash.to_s end |