Class: OCI::DataIntegration::Models::TypedObject
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::TypedObject
- Defined in:
- lib/oci/data_integration/models/typed_object.rb
Overview
The TypedObject class is a base class for any model object that has a type. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
DataIntegration::Models::Shape, AbstractField, DerivedField, DynamicInputField, DynamicProxyField, FlowPort, InputField, InputPort, MacroField, OutputField, OutputPort, Parameter, ProxyField, ShapeField
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_SHAPE = 'SHAPE'.freeze, MODEL_TYPE_INPUT_PORT = 'INPUT_PORT'.freeze, MODEL_TYPE_SHAPE_FIELD = 'SHAPE_FIELD'.freeze, MODEL_TYPE_INPUT_FIELD = 'INPUT_FIELD'.freeze, MODEL_TYPE_DERIVED_FIELD = 'DERIVED_FIELD'.freeze, MODEL_TYPE_MACRO_FIELD = 'MACRO_FIELD'.freeze, MODEL_TYPE_OUTPUT_FIELD = 'OUTPUT_FIELD'.freeze, MODEL_TYPE_DYNAMIC_PROXY_FIELD = 'DYNAMIC_PROXY_FIELD'.freeze, MODEL_TYPE_OUTPUT_PORT = 'OUTPUT_PORT'.freeze, MODEL_TYPE_DYNAMIC_INPUT_FIELD = 'DYNAMIC_INPUT_FIELD'.freeze, MODEL_TYPE_PROXY_FIELD = 'PROXY_FIELD'.freeze, MODEL_TYPE_PARAMETER = 'PARAMETER'.freeze, MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #config_values ⇒ OCI::DataIntegration::Models::ConfigValues
-
#description ⇒ String
Detailed description for the object.
-
#key ⇒ String
The key of the object.
-
#model_type ⇒ String
[Required] The type of the types object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TypedObject
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TypedObject
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 132 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.config_values = attributes[:'configValues'] if attributes[:'configValues'] raise 'You cannot provide both :configValues and :config_values' if attributes.key?(:'configValues') && attributes.key?(:'config_values') self.config_values = attributes[:'config_values'] if attributes[:'config_values'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] end |
Instance Attribute Details
#config_values ⇒ OCI::DataIntegration::Models::ConfigValues
44 45 46 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 44 def config_values @config_values end |
#description ⇒ String
Detailed description for the object.
56 57 58 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 56 def description @description end |
#key ⇒ String
The key of the object.
34 35 36 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 34 def key @key end |
#model_type ⇒ String
[Required] The type of the types object.
30 31 32 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 30 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
38 39 40 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 38 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
52 53 54 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 52 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
48 49 50 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 48 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
41 42 43 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 41 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 59 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'config_values': :'configValues', 'object_status': :'objectStatus', 'name': :'name', 'description': :'description' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 95 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataIntegration::Models::OutputPort' if type == 'OUTPUT_PORT' return 'OCI::DataIntegration::Models::DynamicInputField' if type == 'DYNAMIC_INPUT_FIELD' return 'OCI::DataIntegration::Models::AbstractField' if type == 'FIELD' return 'OCI::DataIntegration::Models::InputField' if type == 'INPUT_FIELD' return 'OCI::DataIntegration::Models::Shape' if type == 'SHAPE' return 'OCI::DataIntegration::Models::InputPort' if type == 'INPUT_PORT' return 'OCI::DataIntegration::Models::ProxyField' if type == 'PROXY_FIELD' return 'OCI::DataIntegration::Models::DynamicProxyField' if type == 'DYNAMIC_PROXY_FIELD' return 'OCI::DataIntegration::Models::ShapeField' if type == 'SHAPE_FIELD' return 'OCI::DataIntegration::Models::Parameter' if type == 'PARAMETER' return 'OCI::DataIntegration::Models::OutputField' if type == 'OUTPUT_FIELD' return 'OCI::DataIntegration::Models::MacroField' if type == 'MACRO_FIELD' return 'OCI::DataIntegration::Models::DerivedField' if type == 'DERIVED_FIELD' return 'OCI::DataIntegration::Models::FlowPort' if type == 'FLOW_PORT' # TODO: Log a warning when the subtype is not found. 'OCI::DataIntegration::Models::TypedObject' end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'config_values': :'OCI::DataIntegration::Models::ConfigValues', 'object_status': :'Integer', 'name': :'String', 'description': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 195 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && config_values == other.config_values && object_status == other.object_status && name == other.name && description == other.description end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 232 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
212 213 214 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 212 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 221 def hash [model_type, key, model_version, parent_ref, config_values, object_status, name, description].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
265 266 267 268 269 270 271 272 273 274 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 265 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
259 260 261 |
# File 'lib/oci/data_integration/models/typed_object.rb', line 259 def to_s to_hash.to_s end |