Class: OCI::DataIntegration::Models::UniqueKey
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::UniqueKey
- Defined in:
- lib/oci/data_integration/models/unique_key.rb
Overview
The unqique key object. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_PRIMARY_KEY = 'PRIMARY_KEY'.freeze, MODEL_TYPE_UNIQUE_KEY = 'UNIQUE_KEY'.freeze, MODEL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#attribute_refs ⇒ Array<OCI::DataIntegration::Models::KeyAttribute>
An array of attribute references.
-
#key ⇒ String
The object key.
-
#model_type ⇒ String
[Required] The key type.
-
#model_version ⇒ String
The object’s model version.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
- #parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UniqueKey
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UniqueKey
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 103 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.parent_ref = attributes[:'parentRef'] if attributes[:'parentRef'] raise 'You cannot provide both :parentRef and :parent_ref' if attributes.key?(:'parentRef') && attributes.key?(:'parent_ref') self.parent_ref = attributes[:'parent_ref'] if attributes[:'parent_ref'] self.name = attributes[:'name'] if attributes[:'name'] self.attribute_refs = attributes[:'attributeRefs'] if attributes[:'attributeRefs'] raise 'You cannot provide both :attributeRefs and :attribute_refs' if attributes.key?(:'attributeRefs') && attributes.key?(:'attribute_refs') self.attribute_refs = attributes[:'attribute_refs'] if attributes[:'attribute_refs'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] end |
Instance Attribute Details
#attribute_refs ⇒ Array<OCI::DataIntegration::Models::KeyAttribute>
An array of attribute references.
39 40 41 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 39 def attribute_refs @attribute_refs end |
#key ⇒ String
The object key.
24 25 26 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 24 def key @key end |
#model_type ⇒ String
[Required] The key type.
20 21 22 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 20 def model_type @model_type end |
#model_version ⇒ String
The object’s model version.
28 29 30 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 28 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
35 36 37 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 35 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
43 44 45 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 43 def object_status @object_status end |
#parent_ref ⇒ OCI::DataIntegration::Models::ParentReference
31 32 33 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 31 def parent_ref @parent_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'attribute_refs': :'attributeRefs', 'object_status': :'objectStatus' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
80 81 82 83 84 85 86 87 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 80 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataIntegration::Models::PrimaryKey' if type == 'PRIMARY_KEY' # TODO: Log a warning when the subtype is not found. 'OCI::DataIntegration::Models::UniqueKey' end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'attribute_refs': :'Array<OCI::DataIntegration::Models::KeyAttribute>', 'object_status': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 164 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && attribute_refs == other.attribute_refs && object_status == other.object_status end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 200 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
180 181 182 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 180 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
189 190 191 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 189 def hash [model_type, key, model_version, parent_ref, name, attribute_refs, object_status].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
227 228 229 |
# File 'lib/oci/data_integration/models/unique_key.rb', line 227 def to_s to_hash.to_s end |