Class: OCI::DataIntegration::Models::UpdateDataAssetDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::UpdateDataAssetDetails
- Defined in:
- lib/oci/data_integration/models/update_data_asset_details.rb
Overview
Properties used in data asset update operations. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
UpdateDataAssetFromAdwc, UpdateDataAssetFromAmazonS3, UpdateDataAssetFromAtp, UpdateDataAssetFromFusionApp, UpdateDataAssetFromJdbc, UpdateDataAssetFromMySQL, UpdateDataAssetFromObjectStorage, UpdateDataAssetFromOracle
Constant Summary collapse
- MODEL_TYPE_ENUM =
[ MODEL_TYPE_ORACLE_DATA_ASSET = 'ORACLE_DATA_ASSET'.freeze, MODEL_TYPE_ORACLE_OBJECT_STORAGE_DATA_ASSET = 'ORACLE_OBJECT_STORAGE_DATA_ASSET'.freeze, MODEL_TYPE_ORACLE_ATP_DATA_ASSET = 'ORACLE_ATP_DATA_ASSET'.freeze, MODEL_TYPE_ORACLE_ADWC_DATA_ASSET = 'ORACLE_ADWC_DATA_ASSET'.freeze, MODEL_TYPE_MYSQL_DATA_ASSET = 'MYSQL_DATA_ASSET'.freeze, MODEL_TYPE_GENERIC_JDBC_DATA_ASSET = 'GENERIC_JDBC_DATA_ASSET'.freeze, MODEL_TYPE_FUSION_APP_DATA_ASSET = 'FUSION_APP_DATA_ASSET'.freeze, MODEL_TYPE_AMAZON_S3_DATA_ASSET = 'AMAZON_S3_DATA_ASSET'.freeze ].freeze
Instance Attribute Summary collapse
-
#asset_properties ⇒ Hash<String, String>
Additional properties for the data asset.
-
#description ⇒ String
The user-defined description of the data asset.
-
#external_key ⇒ String
The external key for the object.
-
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers.
-
#key ⇒ String
[Required] Generated key that can be used in API calls to identify data asset.
-
#model_type ⇒ String
[Required] The type of the data asset.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
-
#object_version ⇒ Integer
[Required] The version of the object that is used to track changes in the object instance.
- #registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDataAssetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDataAssetDetails
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 142 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.key = attributes[:'key'] if attributes[:'key'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_status = attributes[:'objectStatus'] if attributes[:'objectStatus'] raise 'You cannot provide both :objectStatus and :object_status' if attributes.key?(:'objectStatus') && attributes.key?(:'object_status') self.object_status = attributes[:'object_status'] if attributes[:'object_status'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self.identifier = attributes[:'identifier'] if attributes[:'identifier'] self.external_key = attributes[:'externalKey'] if attributes[:'externalKey'] raise 'You cannot provide both :externalKey and :external_key' if attributes.key?(:'externalKey') && attributes.key?(:'external_key') self.external_key = attributes[:'external_key'] if attributes[:'external_key'] self.asset_properties = attributes[:'assetProperties'] if attributes[:'assetProperties'] raise 'You cannot provide both :assetProperties and :asset_properties' if attributes.key?(:'assetProperties') && attributes.key?(:'asset_properties') self.asset_properties = attributes[:'asset_properties'] if attributes[:'asset_properties'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] end |
Instance Attribute Details
#asset_properties ⇒ Hash<String, String>
Additional properties for the data asset.
60 61 62 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 60 def asset_properties @asset_properties end |
#description ⇒ String
The user-defined description of the data asset.
40 41 42 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 40 def description @description end |
#external_key ⇒ String
The external key for the object.
56 57 58 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 56 def external_key @external_key end |
#identifier ⇒ String
Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
52 53 54 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 52 def identifier @identifier end |
#key ⇒ String
[Required] Generated key that can be used in API calls to identify data asset.
28 29 30 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 28 def key @key end |
#model_type ⇒ String
[Required] The type of the data asset.
24 25 26 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 24 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
32 33 34 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 32 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
36 37 38 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 36 def name @name end |
#object_status ⇒ Integer
The status of an object that can be set to value 1 for shallow references across objects, other values reserved.
44 45 46 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 44 def object_status @object_status end |
#object_version ⇒ Integer
[Required] The version of the object that is used to track changes in the object instance.
48 49 50 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 48 def object_version @object_version end |
#registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
63 64 65 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 63 def @registry_metadata end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 66 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'object_version': :'objectVersion', 'identifier': :'identifier', 'external_key': :'externalKey', 'asset_properties': :'assetProperties', 'registry_metadata': :'registryMetadata' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 108 def self.get_subtype(object_hash) type = object_hash[:'modelType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DataIntegration::Models::UpdateDataAssetFromAtp' if type == 'ORACLE_ATP_DATA_ASSET' return 'OCI::DataIntegration::Models::UpdateDataAssetFromAdwc' if type == 'ORACLE_ADWC_DATA_ASSET' return 'OCI::DataIntegration::Models::UpdateDataAssetFromJdbc' if type == 'GENERIC_JDBC_DATA_ASSET' return 'OCI::DataIntegration::Models::UpdateDataAssetFromObjectStorage' if type == 'ORACLE_OBJECT_STORAGE_DATA_ASSET' return 'OCI::DataIntegration::Models::UpdateDataAssetFromAmazonS3' if type == 'AMAZON_S3_DATA_ASSET' return 'OCI::DataIntegration::Models::UpdateDataAssetFromFusionApp' if type == 'FUSION_APP_DATA_ASSET' return 'OCI::DataIntegration::Models::UpdateDataAssetFromMySQL' if type == 'MYSQL_DATA_ASSET' return 'OCI::DataIntegration::Models::UpdateDataAssetFromOracle' if type == 'ORACLE_DATA_ASSET' # TODO: Log a warning when the subtype is not found. 'OCI::DataIntegration::Models::UpdateDataAssetDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 85 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'object_version': :'Integer', 'identifier': :'String', 'external_key': :'String', 'asset_properties': :'Hash<String, String>', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 214 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && name == other.name && description == other.description && object_status == other.object_status && object_version == other.object_version && identifier == other.identifier && external_key == other.external_key && asset_properties == other.asset_properties && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 254 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
234 235 236 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 234 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 243 def hash [model_type, key, model_version, name, description, object_status, object_version, identifier, external_key, asset_properties, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
281 282 283 |
# File 'lib/oci/data_integration/models/update_data_asset_details.rb', line 281 def to_s to_hash.to_s end |