Class: OCI::DataIntegration::Models::UpdateTaskFromRestTask
- Inherits:
-
UpdateTaskDetails
- Object
- UpdateTaskDetails
- OCI::DataIntegration::Models::UpdateTaskFromRestTask
- Defined in:
- lib/oci/data_integration/models/update_task_from_rest_task.rb
Overview
The information about the Generic REST task. The endpoint and cancelEndpoint properties are deprecated, use the properties executeRestCallConfig, cancelRestCallConfig and pollRestCallConfig for execute, cancel and polling of the calls.
Constant Summary collapse
- METHOD_TYPE_ENUM =
[ METHOD_TYPE_GET = 'GET'.freeze, METHOD_TYPE_POST = 'POST'.freeze, METHOD_TYPE_PATCH = 'PATCH'.freeze, METHOD_TYPE_DELETE = 'DELETE'.freeze, METHOD_TYPE_PUT = 'PUT'.freeze ].freeze
- API_CALL_MODE_ENUM =
[ API_CALL_MODE_SYNCHRONOUS = 'SYNCHRONOUS'.freeze, API_CALL_MODE_ASYNC_OCI_WORKREQUEST = 'ASYNC_OCI_WORKREQUEST'.freeze, API_CALL_MODE_ASYNC_GENERIC = 'ASYNC_GENERIC'.freeze ].freeze
- CANCEL_METHOD_TYPE_ENUM =
[ CANCEL_METHOD_TYPE_GET = 'GET'.freeze, CANCEL_METHOD_TYPE_POST = 'POST'.freeze, CANCEL_METHOD_TYPE_PATCH = 'PATCH'.freeze, CANCEL_METHOD_TYPE_DELETE = 'DELETE'.freeze, CANCEL_METHOD_TYPE_PUT = 'PUT'.freeze ].freeze
Constants inherited from UpdateTaskDetails
OCI::DataIntegration::Models::UpdateTaskDetails::MODEL_TYPE_ENUM
Instance Attribute Summary collapse
-
#additional_properties ⇒ String
Header value.
-
#api_call_mode ⇒ String
The REST invocation pattern to use.
- #auth_details ⇒ OCI::DataIntegration::Models::AuthDetails
- #cancel_endpoint ⇒ OCI::DataIntegration::Models::Expression
-
#cancel_method_type ⇒ String
The REST method to use for canceling the original request.
- #cancel_rest_call_config ⇒ OCI::DataIntegration::Models::CancelRestCallConfig
- #endpoint ⇒ OCI::DataIntegration::Models::Expression
- #execute_rest_call_config ⇒ OCI::DataIntegration::Models::ExecuteRestCallConfig
- #headers ⇒ Object
-
#json_data ⇒ String
JSON data for payload body.
-
#method_type ⇒ String
The REST method to use.
Attributes inherited from UpdateTaskDetails
#config_provider_delegate, #description, #identifier, #input_ports, #key, #model_type, #model_version, #name, #object_status, #object_version, #op_config_values, #output_ports, #parameters, #parent_ref, #registry_metadata
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateTaskFromRestTask
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateTaskDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateTaskFromRestTask
Initializes the object
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 170 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['modelType'] = 'REST_TASK' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.auth_details = attributes[:'authDetails'] if attributes[:'authDetails'] raise 'You cannot provide both :authDetails and :auth_details' if attributes.key?(:'authDetails') && attributes.key?(:'auth_details') self.auth_details = attributes[:'auth_details'] if attributes[:'auth_details'] self.endpoint = attributes[:'endpoint'] if attributes[:'endpoint'] self.method_type = attributes[:'methodType'] if attributes[:'methodType'] raise 'You cannot provide both :methodType and :method_type' if attributes.key?(:'methodType') && attributes.key?(:'method_type') self.method_type = attributes[:'method_type'] if attributes[:'method_type'] self.headers = attributes[:'headers'] if attributes[:'headers'] self.additional_properties = attributes[:'additionalProperties'] if attributes[:'additionalProperties'] raise 'You cannot provide both :additionalProperties and :additional_properties' if attributes.key?(:'additionalProperties') && attributes.key?(:'additional_properties') self.additional_properties = attributes[:'additional_properties'] if attributes[:'additional_properties'] self.json_data = attributes[:'jsonData'] if attributes[:'jsonData'] raise 'You cannot provide both :jsonData and :json_data' if attributes.key?(:'jsonData') && attributes.key?(:'json_data') self.json_data = attributes[:'json_data'] if attributes[:'json_data'] self.api_call_mode = attributes[:'apiCallMode'] if attributes[:'apiCallMode'] raise 'You cannot provide both :apiCallMode and :api_call_mode' if attributes.key?(:'apiCallMode') && attributes.key?(:'api_call_mode') self.api_call_mode = attributes[:'api_call_mode'] if attributes[:'api_call_mode'] self.cancel_endpoint = attributes[:'cancelEndpoint'] if attributes[:'cancelEndpoint'] raise 'You cannot provide both :cancelEndpoint and :cancel_endpoint' if attributes.key?(:'cancelEndpoint') && attributes.key?(:'cancel_endpoint') self.cancel_endpoint = attributes[:'cancel_endpoint'] if attributes[:'cancel_endpoint'] self.cancel_method_type = attributes[:'cancelMethodType'] if attributes[:'cancelMethodType'] raise 'You cannot provide both :cancelMethodType and :cancel_method_type' if attributes.key?(:'cancelMethodType') && attributes.key?(:'cancel_method_type') self.cancel_method_type = attributes[:'cancel_method_type'] if attributes[:'cancel_method_type'] self.execute_rest_call_config = attributes[:'executeRestCallConfig'] if attributes[:'executeRestCallConfig'] raise 'You cannot provide both :executeRestCallConfig and :execute_rest_call_config' if attributes.key?(:'executeRestCallConfig') && attributes.key?(:'execute_rest_call_config') self.execute_rest_call_config = attributes[:'execute_rest_call_config'] if attributes[:'execute_rest_call_config'] self.cancel_rest_call_config = attributes[:'cancelRestCallConfig'] if attributes[:'cancelRestCallConfig'] raise 'You cannot provide both :cancelRestCallConfig and :cancel_rest_call_config' if attributes.key?(:'cancelRestCallConfig') && attributes.key?(:'cancel_rest_call_config') self.cancel_rest_call_config = attributes[:'cancel_rest_call_config'] if attributes[:'cancel_rest_call_config'] end |
Instance Attribute Details
#additional_properties ⇒ String
Header value.
48 49 50 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 48 def additional_properties @additional_properties end |
#api_call_mode ⇒ String
The REST invocation pattern to use. ASYNC_OCI_WORKREQUEST is being deprecated as well as cancelEndpoint/MethodType.
56 57 58 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 56 def api_call_mode @api_call_mode end |
#auth_details ⇒ OCI::DataIntegration::Models::AuthDetails
34 35 36 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 34 def auth_details @auth_details end |
#cancel_endpoint ⇒ OCI::DataIntegration::Models::Expression
59 60 61 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 59 def cancel_endpoint @cancel_endpoint end |
#cancel_method_type ⇒ String
The REST method to use for canceling the original request.
63 64 65 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 63 def cancel_method_type @cancel_method_type end |
#cancel_rest_call_config ⇒ OCI::DataIntegration::Models::CancelRestCallConfig
69 70 71 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 69 def cancel_rest_call_config @cancel_rest_call_config end |
#endpoint ⇒ OCI::DataIntegration::Models::Expression
37 38 39 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 37 def endpoint @endpoint end |
#execute_rest_call_config ⇒ OCI::DataIntegration::Models::ExecuteRestCallConfig
66 67 68 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 66 def execute_rest_call_config @execute_rest_call_config end |
#headers ⇒ Object
44 45 46 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 44 def headers @headers end |
#json_data ⇒ String
JSON data for payload body. This property is deprecated, use ExecuteRestCallConfig’s payload config param instead.
52 53 54 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 52 def json_data @json_data end |
#method_type ⇒ String
The REST method to use. This property is deprecated, use ExecuteRestCallConfig’s methodType property instead.
41 42 43 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 41 def method_type @method_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 72 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'model_type': :'modelType', 'key': :'key', 'model_version': :'modelVersion', 'parent_ref': :'parentRef', 'name': :'name', 'description': :'description', 'object_status': :'objectStatus', 'object_version': :'objectVersion', 'identifier': :'identifier', 'input_ports': :'inputPorts', 'output_ports': :'outputPorts', 'parameters': :'parameters', 'op_config_values': :'opConfigValues', 'config_provider_delegate': :'configProviderDelegate', 'registry_metadata': :'registryMetadata', 'auth_details': :'authDetails', 'endpoint': :'endpoint', 'method_type': :'methodType', 'headers': :'headers', 'additional_properties': :'additionalProperties', 'json_data': :'jsonData', 'api_call_mode': :'apiCallMode', 'cancel_endpoint': :'cancelEndpoint', 'cancel_method_type': :'cancelMethodType', 'execute_rest_call_config': :'executeRestCallConfig', 'cancel_rest_call_config': :'cancelRestCallConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 106 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'model_type': :'String', 'key': :'String', 'model_version': :'String', 'parent_ref': :'OCI::DataIntegration::Models::ParentReference', 'name': :'String', 'description': :'String', 'object_status': :'Integer', 'object_version': :'Integer', 'identifier': :'String', 'input_ports': :'Array<OCI::DataIntegration::Models::InputPort>', 'output_ports': :'Array<OCI::DataIntegration::Models::OutputPort>', 'parameters': :'Array<OCI::DataIntegration::Models::Parameter>', 'op_config_values': :'OCI::DataIntegration::Models::ConfigValues', 'config_provider_delegate': :'OCI::DataIntegration::Models::ConfigProvider', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata', 'auth_details': :'OCI::DataIntegration::Models::AuthDetails', 'endpoint': :'OCI::DataIntegration::Models::Expression', 'method_type': :'String', 'headers': :'Object', 'additional_properties': :'String', 'json_data': :'String', 'api_call_mode': :'String', 'cancel_endpoint': :'OCI::DataIntegration::Models::Expression', 'cancel_method_type': :'String', 'execute_rest_call_config': :'OCI::DataIntegration::Models::ExecuteRestCallConfig', 'cancel_rest_call_config': :'OCI::DataIntegration::Models::CancelRestCallConfig' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 270 def ==(other) return true if equal?(other) self.class == other.class && model_type == other.model_type && key == other.key && model_version == other.model_version && parent_ref == other.parent_ref && name == other.name && description == other.description && object_status == other.object_status && object_version == other.object_version && identifier == other.identifier && input_ports == other.input_ports && output_ports == other.output_ports && parameters == other.parameters && op_config_values == other.op_config_values && config_provider_delegate == other.config_provider_delegate && == other. && auth_details == other.auth_details && endpoint == other.endpoint && method_type == other.method_type && headers == other.headers && additional_properties == other.additional_properties && json_data == other.json_data && api_call_mode == other.api_call_mode && cancel_endpoint == other.cancel_endpoint && cancel_method_type == other.cancel_method_type && execute_rest_call_config == other.execute_rest_call_config && cancel_rest_call_config == other.cancel_rest_call_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 325 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
305 306 307 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 305 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
314 315 316 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 314 def hash [model_type, key, model_version, parent_ref, name, description, object_status, object_version, identifier, input_ports, output_ports, parameters, op_config_values, config_provider_delegate, , auth_details, endpoint, method_type, headers, additional_properties, json_data, api_call_mode, cancel_endpoint, cancel_method_type, execute_rest_call_config, cancel_rest_call_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
358 359 360 361 362 363 364 365 366 367 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 358 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
352 353 354 |
# File 'lib/oci/data_integration/models/update_task_from_rest_task.rb', line 352 def to_s to_hash.to_s end |