Class: OCI::DataIntegration::Models::UpdateTaskRunDetails
- Inherits:
-
Object
- Object
- OCI::DataIntegration::Models::UpdateTaskRunDetails
- Defined in:
- lib/oci/data_integration/models/update_task_run_details.rb
Overview
Properties used in task run update operations.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_TERMINATING = 'TERMINATING'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
Detailed description for the object.
-
#key ⇒ String
The key of the object.
-
#model_type ⇒ String
The type of the object.
-
#model_version ⇒ String
The model version of an object.
-
#name ⇒ String
Free form text without any restriction on permitted characters.
-
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
- #registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
-
#status ⇒ String
The status of the object.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateTaskRunDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateTaskRunDetails
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key = attributes[:'key'] if attributes[:'key'] self.status = attributes[:'status'] if attributes[:'status'] self.model_type = attributes[:'modelType'] if attributes[:'modelType'] raise 'You cannot provide both :modelType and :model_type' if attributes.key?(:'modelType') && attributes.key?(:'model_type') self.model_type = attributes[:'model_type'] if attributes[:'model_type'] self.model_version = attributes[:'modelVersion'] if attributes[:'modelVersion'] raise 'You cannot provide both :modelVersion and :model_version' if attributes.key?(:'modelVersion') && attributes.key?(:'model_version') self.model_version = attributes[:'model_version'] if attributes[:'model_version'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.object_version = attributes[:'objectVersion'] if attributes[:'objectVersion'] raise 'You cannot provide both :objectVersion and :object_version' if attributes.key?(:'objectVersion') && attributes.key?(:'object_version') self.object_version = attributes[:'object_version'] if attributes[:'object_version'] self. = attributes[:'registryMetadata'] if attributes[:'registryMetadata'] raise 'You cannot provide both :registryMetadata and :registry_metadata' if attributes.key?(:'registryMetadata') && attributes.key?(:'registry_metadata') self. = attributes[:'registry_metadata'] if attributes[:'registry_metadata'] end |
Instance Attribute Details
#description ⇒ String
Detailed description for the object.
36 37 38 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 36 def description @description end |
#key ⇒ String
The key of the object.
16 17 18 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 16 def key @key end |
#model_type ⇒ String
The type of the object.
24 25 26 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 24 def model_type @model_type end |
#model_version ⇒ String
The model version of an object.
28 29 30 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 28 def model_version @model_version end |
#name ⇒ String
Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
32 33 34 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 32 def name @name end |
#object_version ⇒ Integer
The version of the object that is used to track changes in the object instance.
40 41 42 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 40 def object_version @object_version end |
#registry_metadata ⇒ OCI::DataIntegration::Models::RegistryMetadata
43 44 45 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 43 def end |
#status ⇒ String
The status of the object.
20 21 22 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 20 def status @status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key': :'key', 'status': :'status', 'model_type': :'modelType', 'model_version': :'modelVersion', 'name': :'name', 'description': :'description', 'object_version': :'objectVersion', 'registry_metadata': :'registryMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 62 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key': :'String', 'status': :'String', 'model_type': :'String', 'model_version': :'String', 'name': :'String', 'description': :'String', 'object_version': :'Integer', 'registry_metadata': :'OCI::DataIntegration::Models::RegistryMetadata' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 145 def ==(other) return true if equal?(other) self.class == other.class && key == other.key && status == other.status && model_type == other.model_type && model_version == other.model_version && name == other.name && description == other.description && object_version == other.object_version && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 182 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
162 163 164 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 162 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 171 def hash [key, status, model_type, model_version, name, description, object_version, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
209 210 211 |
# File 'lib/oci/data_integration/models/update_task_run_details.rb', line 209 def to_s to_hash.to_s end |