Class: OCI::DataLabelingService::DataLabelingManagementClient
- Inherits:
-
Object
- Object
- OCI::DataLabelingService::DataLabelingManagementClient
- Defined in:
- lib/oci/data_labeling_service/data_labeling_management_client.rb
Overview
Use Data Labeling Management API to create, list, edit & delete datasets.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#add_dataset_labels(dataset_id, add_dataset_labels_details, opts = {}) ⇒ Response
Add Labels to the Dataset LabelSet until the maximum number of Labels has been reached.
-
#change_dataset_compartment(dataset_id, change_dataset_compartment_details, opts = {}) ⇒ Response
Moves a Dataset resource from one compartment identifier to another.
-
#create_dataset(create_dataset_details, opts = {}) ⇒ Response
Creates a new Dataset.
-
#delete_dataset(dataset_id, opts = {}) ⇒ Response
Deletes a Dataset resource by identifier.
-
#generate_dataset_records(dataset_id, generate_dataset_records_details, opts = {}) ⇒ Response
Generates Record resources from the Dataset’s data source.
-
#get_dataset(dataset_id, opts = {}) ⇒ Response
Gets a Dataset by identifier.
-
#get_work_request(work_request_id, opts = {}) ⇒ Response
Gets the status of the work request with the given ID.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ DataLabelingManagementClient
constructor
Creates a new DataLabelingManagementClient.
-
#list_annotation_formats(compartment_id, opts = {}) ⇒ Response
These are a static list in a given region.
-
#list_datasets(compartment_id, opts = {}) ⇒ Response
Returns a list of Datasets.
-
#list_work_request_errors(work_request_id, opts = {}) ⇒ Response
Return a (paginated) list of errors for a given work request.
-
#list_work_request_logs(work_request_id, opts = {}) ⇒ Response
Return a (paginated) list of logs for a given work request.
-
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Lists the work requests in a compartment.
-
#logger ⇒ Logger
The logger for this client.
-
#remove_dataset_labels(dataset_id, remove_dataset_labels_details, opts = {}) ⇒ Response
Removes the labels from the Dataset Labelset.
-
#rename_dataset_labels(dataset_id, rename_dataset_labels_details, opts = {}) ⇒ Response
Renames the labels from the Dataset Labelset.
-
#snapshot_dataset(dataset_id, snapshot_dataset_details, opts = {}) ⇒ Response
Writes the dataset records and annotations in a consolidated format out to an object storage reference for consumption.
-
#update_dataset(dataset_id, update_dataset_details, opts = {}) ⇒ Response
Updates the Dataset.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ DataLabelingManagementClient
Creates a new DataLabelingManagementClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20211001' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "DataLabelingManagementClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#add_dataset_labels(dataset_id, add_dataset_labels_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/add_dataset_labels.rb.html) to see an example of how to use add_dataset_labels API.
Add Labels to the Dataset LabelSet until the maximum number of Labels has been reached.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 123 def add_dataset_labels(dataset_id, add_dataset_labels_details, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#add_dataset_labels.' if logger raise "Missing the required parameter 'dataset_id' when calling add_dataset_labels." if dataset_id.nil? raise "Missing the required parameter 'add_dataset_labels_details' when calling add_dataset_labels." if add_dataset_labels_details.nil? raise "Parameter value for 'dataset_id' must not be blank" if OCI::Internal::Util.blank_string?(dataset_id) path = '/datasets/{datasetId}/actions/addLabels'.sub('{datasetId}', dataset_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(add_dataset_labels_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#add_dataset_labels') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#change_dataset_compartment(dataset_id, change_dataset_compartment_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/change_dataset_compartment.rb.html) to see an example of how to use change_dataset_compartment API.
Moves a Dataset resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 187 def change_dataset_compartment(dataset_id, change_dataset_compartment_details, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#change_dataset_compartment.' if logger raise "Missing the required parameter 'dataset_id' when calling change_dataset_compartment." if dataset_id.nil? raise "Missing the required parameter 'change_dataset_compartment_details' when calling change_dataset_compartment." if change_dataset_compartment_details.nil? raise "Parameter value for 'dataset_id' must not be blank" if OCI::Internal::Util.blank_string?(dataset_id) path = '/datasets/{datasetId}/actions/changeCompartment'.sub('{datasetId}', dataset_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(change_dataset_compartment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#change_dataset_compartment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_dataset(create_dataset_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/create_dataset.rb.html) to see an example of how to use create_dataset API.
Creates a new Dataset.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 249 def create_dataset(create_dataset_details, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#create_dataset.' if logger raise "Missing the required parameter 'create_dataset_details' when calling create_dataset." if create_dataset_details.nil? path = '/datasets' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_dataset_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#create_dataset') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataLabelingService::Models::Dataset' ) end # rubocop:enable Metrics/BlockLength end |
#delete_dataset(dataset_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/delete_dataset.rb.html) to see an example of how to use delete_dataset API.
Deletes a Dataset resource by identifier
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 310 def delete_dataset(dataset_id, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#delete_dataset.' if logger raise "Missing the required parameter 'dataset_id' when calling delete_dataset." if dataset_id.nil? raise "Parameter value for 'dataset_id' must not be blank" if OCI::Internal::Util.blank_string?(dataset_id) path = '/datasets/{datasetId}'.sub('{datasetId}', dataset_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#delete_dataset') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#generate_dataset_records(dataset_id, generate_dataset_records_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/generate_dataset_records.rb.html) to see an example of how to use generate_dataset_records API.
Generates Record resources from the Dataset’s data source
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 377 def generate_dataset_records(dataset_id, generate_dataset_records_details, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#generate_dataset_records.' if logger raise "Missing the required parameter 'dataset_id' when calling generate_dataset_records." if dataset_id.nil? raise "Missing the required parameter 'generate_dataset_records_details' when calling generate_dataset_records." if generate_dataset_records_details.nil? raise "Parameter value for 'dataset_id' must not be blank" if OCI::Internal::Util.blank_string?(dataset_id) path = '/datasets/{datasetId}/actions/generateDatasetRecords'.sub('{datasetId}', dataset_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(generate_dataset_records_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#generate_dataset_records') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_dataset(dataset_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/get_dataset.rb.html) to see an example of how to use get_dataset API.
Gets a Dataset by identifier
434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 434 def get_dataset(dataset_id, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#get_dataset.' if logger raise "Missing the required parameter 'dataset_id' when calling get_dataset." if dataset_id.nil? raise "Parameter value for 'dataset_id' must not be blank" if OCI::Internal::Util.blank_string?(dataset_id) path = '/datasets/{datasetId}'.sub('{datasetId}', dataset_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#get_dataset') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataLabelingService::Models::Dataset' ) end # rubocop:enable Metrics/BlockLength end |
#get_work_request(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/get_work_request.rb.html) to see an example of how to use get_work_request API.
Gets the status of the work request with the given ID.
488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 488 def get_work_request(work_request_id, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#get_work_request.' if logger raise "Missing the required parameter 'work_request_id' when calling get_work_request." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#get_work_request') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataLabelingService::Models::WorkRequest' ) end # rubocop:enable Metrics/BlockLength end |
#list_annotation_formats(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/list_annotation_formats.rb.html) to see an example of how to use list_annotation_formats API.
These are a static list in a given region.
545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 545 def list_annotation_formats(compartment_id, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#list_annotation_formats.' if logger raise "Missing the required parameter 'compartment_id' when calling list_annotation_formats." if compartment_id.nil? if opts[:sort_order] && !OCI::DataLabelingService::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::DataLabelingService::Models::SORT_ORDER_ENUM.' end path = '/annotationFormats' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#list_annotation_formats') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataLabelingService::Models::AnnotationFormatCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_datasets(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/list_datasets.rb.html) to see an example of how to use list_datasets API.
Returns a list of Datasets.
Allowed values are: timeCreated, displayName
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 617 def list_datasets(compartment_id, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#list_datasets.' if logger raise "Missing the required parameter 'compartment_id' when calling list_datasets." if compartment_id.nil? if opts[:lifecycle_state] && !OCI::DataLabelingService::Models::Dataset::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::DataLabelingService::Models::Dataset::LIFECYCLE_STATE_ENUM.' end if opts[:sort_order] && !OCI::DataLabelingService::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::DataLabelingService::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end path = '/datasets' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:id] = opts[:id] if opts[:id] query_params[:annotationFormat] = opts[:annotation_format] if opts[:annotation_format] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#list_datasets') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataLabelingService::Models::DatasetCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_errors(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/list_work_request_errors.rb.html) to see an example of how to use list_work_request_errors API.
Return a (paginated) list of errors for a given work request.
694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 694 def list_work_request_errors(work_request_id, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#list_work_request_errors.' if logger raise "Missing the required parameter 'work_request_id' when calling list_work_request_errors." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/errors'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#list_work_request_errors') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataLabelingService::Models::WorkRequestErrorCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_logs(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/list_work_request_logs.rb.html) to see an example of how to use list_work_request_logs API.
Return a (paginated) list of logs for a given work request.
753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 753 def list_work_request_logs(work_request_id, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#list_work_request_logs.' if logger raise "Missing the required parameter 'work_request_id' when calling list_work_request_logs." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/logs'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#list_work_request_logs') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataLabelingService::Models::WorkRequestLogEntryCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_requests(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/list_work_requests.rb.html) to see an example of how to use list_work_requests API.
Lists the work requests in a compartment.
813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 813 def list_work_requests(compartment_id, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#list_work_requests.' if logger raise "Missing the required parameter 'compartment_id' when calling list_work_requests." if compartment_id.nil? path = '/workRequests' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:workRequestId] = opts[:work_request_id] if opts[:work_request_id] query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#list_work_requests') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataLabelingService::Models::WorkRequestSummaryCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 92 def logger @api_client.config.logger end |
#remove_dataset_labels(dataset_id, remove_dataset_labels_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/remove_dataset_labels.rb.html) to see an example of how to use remove_dataset_labels API.
Removes the labels from the Dataset Labelset. Labels can only be removed if there are no Annotations associated with the Dataset that reference the Label names.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 884 def remove_dataset_labels(dataset_id, remove_dataset_labels_details, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#remove_dataset_labels.' if logger raise "Missing the required parameter 'dataset_id' when calling remove_dataset_labels." if dataset_id.nil? raise "Missing the required parameter 'remove_dataset_labels_details' when calling remove_dataset_labels." if remove_dataset_labels_details.nil? raise "Parameter value for 'dataset_id' must not be blank" if OCI::Internal::Util.blank_string?(dataset_id) path = '/datasets/{datasetId}/actions/removeLabels'.sub('{datasetId}', dataset_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(remove_dataset_labels_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#remove_dataset_labels') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#rename_dataset_labels(dataset_id, rename_dataset_labels_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/rename_dataset_labels.rb.html) to see an example of how to use rename_dataset_labels API.
Renames the labels from the Dataset Labelset. Labels that are renamed will be reflected in Annotations associated with the Dataset that reference the Label names.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 955 def rename_dataset_labels(dataset_id, rename_dataset_labels_details, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#rename_dataset_labels.' if logger raise "Missing the required parameter 'dataset_id' when calling rename_dataset_labels." if dataset_id.nil? raise "Missing the required parameter 'rename_dataset_labels_details' when calling rename_dataset_labels." if rename_dataset_labels_details.nil? raise "Parameter value for 'dataset_id' must not be blank" if OCI::Internal::Util.blank_string?(dataset_id) path = '/datasets/{datasetId}/actions/renameLabels'.sub('{datasetId}', dataset_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(rename_dataset_labels_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#rename_dataset_labels') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#snapshot_dataset(dataset_id, snapshot_dataset_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/snapshot_dataset.rb.html) to see an example of how to use snapshot_dataset API.
Writes the dataset records and annotations in a consolidated format out to an object storage reference for consumption. While the snapshot takes place, there may be a time while records and annotations cannot be created to ensure the snapshot is a point in time.
1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 1027 def snapshot_dataset(dataset_id, snapshot_dataset_details, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#snapshot_dataset.' if logger raise "Missing the required parameter 'dataset_id' when calling snapshot_dataset." if dataset_id.nil? raise "Missing the required parameter 'snapshot_dataset_details' when calling snapshot_dataset." if snapshot_dataset_details.nil? raise "Parameter value for 'dataset_id' must not be blank" if OCI::Internal::Util.blank_string?(dataset_id) path = '/datasets/{datasetId}/actions/snapshot'.sub('{datasetId}', dataset_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(snapshot_dataset_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#snapshot_dataset') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#update_dataset(dataset_id, update_dataset_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/datalabelingservice/update_dataset.rb.html) to see an example of how to use update_dataset API.
Updates the Dataset
1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 |
# File 'lib/oci/data_labeling_service/data_labeling_management_client.rb', line 1091 def update_dataset(dataset_id, update_dataset_details, opts = {}) logger.debug 'Calling operation DataLabelingManagementClient#update_dataset.' if logger raise "Missing the required parameter 'dataset_id' when calling update_dataset." if dataset_id.nil? raise "Missing the required parameter 'update_dataset_details' when calling update_dataset." if update_dataset_details.nil? raise "Parameter value for 'dataset_id' must not be blank" if OCI::Internal::Util.blank_string?(dataset_id) path = '/datasets/{datasetId}'.sub('{datasetId}', dataset_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_dataset_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'DataLabelingManagementClient#update_dataset') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::DataLabelingService::Models::Dataset' ) end # rubocop:enable Metrics/BlockLength end |