Class: OCI::DataLabelingService::Models::DocumentDatasetFormatDetails
- Inherits:
-
DatasetFormatDetails
- Object
- DatasetFormatDetails
- OCI::DataLabelingService::Models::DocumentDatasetFormatDetails
- Defined in:
- lib/oci/data_labeling_service/models/document_dataset_format_details.rb
Overview
Allows the user to specify that the dataset is comprised of document files (e.g. PDFs, DOCs, etc.). It is open for further configurability.
Constant Summary
Constants inherited from DatasetFormatDetails
OCI::DataLabelingService::Models::DatasetFormatDetails::FORMAT_TYPE_ENUM
Instance Attribute Summary
Attributes inherited from DatasetFormatDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DocumentDatasetFormatDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DatasetFormatDetails
Constructor Details
#initialize(attributes = {}) ⇒ DocumentDatasetFormatDetails
Initializes the object
35 36 37 38 39 40 41 |
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 35 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['formatType'] = 'DOCUMENT' super(attributes) end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
12 13 14 15 16 17 18 |
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 12 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'format_type': :'formatType' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
21 22 23 24 25 26 27 |
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 21 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'format_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
50 51 52 53 54 55 |
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 50 def ==(other) return true if equal?(other) self.class == other.class && format_type == other.format_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 80 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
60 61 62 |
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 60 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
69 70 71 |
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 69 def hash [format_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 113 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
107 108 109 |
# File 'lib/oci/data_labeling_service/models/document_dataset_format_details.rb', line 107 def to_s to_hash.to_s end |