Class: OCI::DataLabelingServiceDataplane::Models::AnnotationAnalyticsAggregation

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb

Overview

Aggregation entities are required by the API consistency guidelines for API Consistency Guidelines#AnalyticsAPIs. These are used to summarize annotations for a given dataset and will be used to populate UI elements. Aggregations need to have the fields that identify the exact scope that they’re summarizing. Any filters applied to the list API, have to show up in the aggregation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AnnotationAnalyticsAggregation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 73

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.count = attributes[:'count'] if attributes[:'count']

  self.dataset_id = attributes[:'datasetId'] if attributes[:'datasetId']

  raise 'You cannot provide both :datasetId and :dataset_id' if attributes.key?(:'datasetId') && attributes.key?(:'dataset_id')

  self.dataset_id = attributes[:'dataset_id'] if attributes[:'dataset_id']

  self.dimensions = attributes[:'dimensions'] if attributes[:'dimensions']

  self.updated_by = attributes[:'updatedBy'] if attributes[:'updatedBy']

  raise 'You cannot provide both :updatedBy and :updated_by' if attributes.key?(:'updatedBy') && attributes.key?(:'updated_by')

  self.updated_by = attributes[:'updated_by'] if attributes[:'updated_by']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment containing the annotations.

Returns:

  • (String)


27
28
29
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 27

def compartment_id
  @compartment_id
end

#countFloat

[Required] The count of the matching results.

Returns:

  • (Float)


12
13
14
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 12

def count
  @count
end

#dataset_idString

[Required] The OCID of the dataset the annotations belong to.

Returns:

  • (String)


16
17
18
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 16

def dataset_id
  @dataset_id
end

#dimensionsOCI::DataLabelingServiceDataplane::Models::AnnotationAggregationDimensions



19
20
21
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 19

def dimensions
  @dimensions
end

#lifecycle_stateString

Describes the lifecycle state.

Returns:

  • (String)


31
32
33
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 31

def lifecycle_state
  @lifecycle_state
end

#updated_byString

The OCID of the principal which updated the annotation.

Returns:

  • (String)


23
24
25
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 23

def updated_by
  @updated_by
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 34

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'count': :'count',
    'dataset_id': :'datasetId',
    'dimensions': :'dimensions',
    'updated_by': :'updatedBy',
    'compartment_id': :'compartmentId',
    'lifecycle_state': :'lifecycleState'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 48

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'count': :'Float',
    'dataset_id': :'String',
    'dimensions': :'OCI::DataLabelingServiceDataplane::Models::AnnotationAggregationDimensions',
    'updated_by': :'String',
    'compartment_id': :'String',
    'lifecycle_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



115
116
117
118
119
120
121
122
123
124
125
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 115

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    count == other.count &&
    dataset_id == other.dataset_id &&
    dimensions == other.dimensions &&
    updated_by == other.updated_by &&
    compartment_id == other.compartment_id &&
    lifecycle_state == other.lifecycle_state
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 150

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


130
131
132
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 130

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



139
140
141
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 139

def hash
  [count, dataset_id, dimensions, updated_by, compartment_id, lifecycle_state].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



183
184
185
186
187
188
189
190
191
192
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 183

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



177
178
179
# File 'lib/oci/data_labeling_service_dataplane/models/annotation_analytics_aggregation.rb', line 177

def to_s
  to_hash.to_s
end