Class: OCI::DataLabelingServiceDataplane::Models::ImageObjectSelectionEntity
- Inherits:
-
DataLabelingServiceDataplane::Models::Entity
- Object
- DataLabelingServiceDataplane::Models::Entity
- OCI::DataLabelingServiceDataplane::Models::ImageObjectSelectionEntity
- Defined in:
- lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb
Overview
This lets the labeler specify a series of coordinates in the image to represent an object and apply labels to it. The coordinates are connected in the order that they are provided. The last coordinate in the array is connected to the first coordinate.
Instance Attribute Summary collapse
-
#bounding_polygon ⇒ OCI::DataLabelingServiceDataplane::Models::BoundingPolygon
This attribute is required.
-
#extended_metadata ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#labels ⇒ Array<OCI::DataLabelingServiceDataplane::Models::Label>
[Required] A collection of label entities.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImageObjectSelectionEntity
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ImageObjectSelectionEntity
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 58 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['entityType'] = 'IMAGEOBJECTSELECTION' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.labels = attributes[:'labels'] if attributes[:'labels'] self.bounding_polygon = attributes[:'boundingPolygon'] if attributes[:'boundingPolygon'] raise 'You cannot provide both :boundingPolygon and :bounding_polygon' if attributes.key?(:'boundingPolygon') && attributes.key?(:'bounding_polygon') self.bounding_polygon = attributes[:'bounding_polygon'] if attributes[:'bounding_polygon'] self. = attributes[:'extendedMetadata'] if attributes[:'extendedMetadata'] raise 'You cannot provide both :extendedMetadata and :extended_metadata' if attributes.key?(:'extendedMetadata') && attributes.key?(:'extended_metadata') self. = attributes[:'extended_metadata'] if attributes[:'extended_metadata'] end |
Instance Attribute Details
#bounding_polygon ⇒ OCI::DataLabelingServiceDataplane::Models::BoundingPolygon
This attribute is required.
17 18 19 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 17 def bounding_polygon @bounding_polygon end |
#extended_metadata ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only. For example: ‘"value"`
23 24 25 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 23 def @extended_metadata end |
#labels ⇒ Array<OCI::DataLabelingServiceDataplane::Models::Label>
[Required] A collection of label entities.
13 14 15 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 13 def labels @labels end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_type': :'entityType', 'labels': :'labels', 'bounding_polygon': :'boundingPolygon', 'extended_metadata': :'extendedMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 38 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_type': :'String', 'labels': :'Array<OCI::DataLabelingServiceDataplane::Models::Label>', 'bounding_polygon': :'OCI::DataLabelingServiceDataplane::Models::BoundingPolygon', 'extended_metadata': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && entity_type == other.entity_type && labels == other.labels && bounding_polygon == other.bounding_polygon && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 123 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
103 104 105 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 103 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
112 113 114 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 112 def hash [entity_type, labels, bounding_polygon, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 156 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
150 151 152 |
# File 'lib/oci/data_labeling_service_dataplane/models/image_object_selection_entity.rb', line 150 def to_s to_hash.to_s end |