Class: OCI::DataSafe::Models::AuditEventSummary
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::AuditEventSummary
- Defined in:
- lib/oci/data_safe/models/audit_event_summary.rb
Overview
The resource represents the audit events collected from the target database by Oracle Data Safe.
Constant Summary collapse
- DATABASE_TYPE_ENUM =
[ DATABASE_TYPE_DATABASE_CLOUD_SERVICE = 'DATABASE_CLOUD_SERVICE'.freeze, DATABASE_TYPE_AUTONOMOUS_DATABASE = 'AUTONOMOUS_DATABASE'.freeze, DATABASE_TYPE_INSTALLED_DATABASE = 'INSTALLED_DATABASE'.freeze, DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TARGET_CLASS_ENUM =
[ TARGET_CLASS_DATABASE = 'DATABASE'.freeze, TARGET_CLASS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- OPERATION_STATUS_ENUM =
[ OPERATION_STATUS_SUCCESS = 'SUCCESS'.freeze, OPERATION_STATUS_FAILURE = 'FAILURE'.freeze, OPERATION_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- AUDIT_LOCATION_ENUM =
[ AUDIT_LOCATION_AUDIT_TABLE = 'AUDIT_TABLE'.freeze, AUDIT_LOCATION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- AUDIT_TYPE_ENUM =
[ AUDIT_TYPE_STANDARD = 'STANDARD'.freeze, AUDIT_TYPE_FINE_GRAINED = 'FINE_GRAINED'.freeze, AUDIT_TYPE_XS = 'XS'.freeze, AUDIT_TYPE_DATABASE_VAULT = 'DATABASE_VAULT'.freeze, AUDIT_TYPE_LABEL_SECURITY = 'LABEL_SECURITY'.freeze, AUDIT_TYPE_RMAN = 'RMAN'.freeze, AUDIT_TYPE_DATAPUMP = 'DATAPUMP'.freeze, AUDIT_TYPE_DIRECT_PATH_API = 'DIRECT_PATH_API'.freeze, AUDIT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action_taken ⇒ String
The action taken for this audit event.
-
#audit_event_time ⇒ DateTime
[Required] Time of audit event occurrence in the target database.
-
#audit_location ⇒ String
The location of the audit.
-
#audit_policies ⇒ String
Comma-seperated list of audit policies that caused the current audit event.
-
#audit_trail_id ⇒ String
The OCID of the audit trail that generated this audit event.
-
#audit_type ⇒ String
Type of auditing.
-
#client_hostname ⇒ String
Name of the host machine from which the session was spawned.
-
#client_id ⇒ String
The client identifier in each Oracle session.
-
#client_ip ⇒ String
IP address of the host from which the session was spawned.
-
#client_program ⇒ String
The application from which the audit event was generated.
-
#command_param ⇒ String
List of bind variables associated with the command text.
-
#command_text ⇒ String
The SQL associated with the audit event.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the audit event.
-
#database_type ⇒ String
[Required] The type of the target database that was audited.
-
#db_user_name ⇒ String
Name of the database user whose actions were audited.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#error_code ⇒ String
Oracle Error code generated by the action.
-
#error_message ⇒ String
Detailed message on why the Error occurred.
-
#event_name ⇒ String
Name of the detail action executed by the user on the target database.
-
#extended_event_attributes ⇒ String
List of all other attributes of the audit event seperated by a colon other than the one returned in audit record.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the audit event.
-
#is_alerted ⇒ BOOLEAN
[Required] Indicates whether an alert was raised for this audit event.
-
#object_name ⇒ String
Name of the object affected by the action.
-
#object_owner ⇒ String
Schema name of object affected but the action.
-
#object_type ⇒ String
Type of object in the source database affected by the action.
-
#operation ⇒ String
Name of the action executed by the user on the target database.
-
#operation_status ⇒ String
Indicates whether the operation was a success or a failure.
-
#os_terminal ⇒ String
The operating system terminal of the user session.
-
#os_user_name ⇒ String
Name of the operating system user for the database session.
-
#target_class ⇒ String
Class of the target that was audited.
-
#target_id ⇒ String
[Required] The OCID of the target database that was audited.
-
#target_name ⇒ String
[Required] The name of the target database that was audited.
-
#time_collected ⇒ DateTime
[Required] Timestamp when this audit event was collected from the target database by Data Safe.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuditEventSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AuditEventSummary
Initializes the object
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 316 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.db_user_name = attributes[:'dbUserName'] if attributes[:'dbUserName'] raise 'You cannot provide both :dbUserName and :db_user_name' if attributes.key?(:'dbUserName') && attributes.key?(:'db_user_name') self.db_user_name = attributes[:'db_user_name'] if attributes[:'db_user_name'] self.target_id = attributes[:'targetId'] if attributes[:'targetId'] raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id') self.target_id = attributes[:'target_id'] if attributes[:'target_id'] self.target_name = attributes[:'targetName'] if attributes[:'targetName'] raise 'You cannot provide both :targetName and :target_name' if attributes.key?(:'targetName') && attributes.key?(:'target_name') self.target_name = attributes[:'target_name'] if attributes[:'target_name'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.target_class = attributes[:'targetClass'] if attributes[:'targetClass'] raise 'You cannot provide both :targetClass and :target_class' if attributes.key?(:'targetClass') && attributes.key?(:'target_class') self.target_class = attributes[:'target_class'] if attributes[:'target_class'] self.audit_event_time = attributes[:'auditEventTime'] if attributes[:'auditEventTime'] raise 'You cannot provide both :auditEventTime and :audit_event_time' if attributes.key?(:'auditEventTime') && attributes.key?(:'audit_event_time') self.audit_event_time = attributes[:'audit_event_time'] if attributes[:'audit_event_time'] self.time_collected = attributes[:'timeCollected'] if attributes[:'timeCollected'] raise 'You cannot provide both :timeCollected and :time_collected' if attributes.key?(:'timeCollected') && attributes.key?(:'time_collected') self.time_collected = attributes[:'time_collected'] if attributes[:'time_collected'] self.os_user_name = attributes[:'osUserName'] if attributes[:'osUserName'] raise 'You cannot provide both :osUserName and :os_user_name' if attributes.key?(:'osUserName') && attributes.key?(:'os_user_name') self.os_user_name = attributes[:'os_user_name'] if attributes[:'os_user_name'] self.operation = attributes[:'operation'] if attributes[:'operation'] self.operation_status = attributes[:'operationStatus'] if attributes[:'operationStatus'] raise 'You cannot provide both :operationStatus and :operation_status' if attributes.key?(:'operationStatus') && attributes.key?(:'operation_status') self.operation_status = attributes[:'operation_status'] if attributes[:'operation_status'] self.event_name = attributes[:'eventName'] if attributes[:'eventName'] raise 'You cannot provide both :eventName and :event_name' if attributes.key?(:'eventName') && attributes.key?(:'event_name') self.event_name = attributes[:'event_name'] if attributes[:'event_name'] self.error_code = attributes[:'errorCode'] if attributes[:'errorCode'] raise 'You cannot provide both :errorCode and :error_code' if attributes.key?(:'errorCode') && attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] if attributes[:'error_code'] self. = attributes[:'errorMessage'] if attributes[:'errorMessage'] raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message') self. = attributes[:'error_message'] if attributes[:'error_message'] self.object_type = attributes[:'objectType'] if attributes[:'objectType'] raise 'You cannot provide both :objectType and :object_type' if attributes.key?(:'objectType') && attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] if attributes[:'object_type'] self.object_name = attributes[:'objectName'] if attributes[:'objectName'] raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name') self.object_name = attributes[:'object_name'] if attributes[:'object_name'] self.object_owner = attributes[:'objectOwner'] if attributes[:'objectOwner'] raise 'You cannot provide both :objectOwner and :object_owner' if attributes.key?(:'objectOwner') && attributes.key?(:'object_owner') self.object_owner = attributes[:'object_owner'] if attributes[:'object_owner'] self.client_hostname = attributes[:'clientHostname'] if attributes[:'clientHostname'] raise 'You cannot provide both :clientHostname and :client_hostname' if attributes.key?(:'clientHostname') && attributes.key?(:'client_hostname') self.client_hostname = attributes[:'client_hostname'] if attributes[:'client_hostname'] self.client_ip = attributes[:'clientIp'] if attributes[:'clientIp'] raise 'You cannot provide both :clientIp and :client_ip' if attributes.key?(:'clientIp') && attributes.key?(:'client_ip') self.client_ip = attributes[:'client_ip'] if attributes[:'client_ip'] self.audit_trail_id = attributes[:'auditTrailId'] if attributes[:'auditTrailId'] raise 'You cannot provide both :auditTrailId and :audit_trail_id' if attributes.key?(:'auditTrailId') && attributes.key?(:'audit_trail_id') self.audit_trail_id = attributes[:'audit_trail_id'] if attributes[:'audit_trail_id'] self.is_alerted = attributes[:'isAlerted'] unless attributes[:'isAlerted'].nil? raise 'You cannot provide both :isAlerted and :is_alerted' if attributes.key?(:'isAlerted') && attributes.key?(:'is_alerted') self.is_alerted = attributes[:'is_alerted'] unless attributes[:'is_alerted'].nil? self.action_taken = attributes[:'actionTaken'] if attributes[:'actionTaken'] raise 'You cannot provide both :actionTaken and :action_taken' if attributes.key?(:'actionTaken') && attributes.key?(:'action_taken') self.action_taken = attributes[:'action_taken'] if attributes[:'action_taken'] self.client_program = attributes[:'clientProgram'] if attributes[:'clientProgram'] raise 'You cannot provide both :clientProgram and :client_program' if attributes.key?(:'clientProgram') && attributes.key?(:'client_program') self.client_program = attributes[:'client_program'] if attributes[:'client_program'] self.command_text = attributes[:'commandText'] if attributes[:'commandText'] raise 'You cannot provide both :commandText and :command_text' if attributes.key?(:'commandText') && attributes.key?(:'command_text') self.command_text = attributes[:'command_text'] if attributes[:'command_text'] self.command_param = attributes[:'commandParam'] if attributes[:'commandParam'] raise 'You cannot provide both :commandParam and :command_param' if attributes.key?(:'commandParam') && attributes.key?(:'command_param') self.command_param = attributes[:'command_param'] if attributes[:'command_param'] self.extended_event_attributes = attributes[:'extendedEventAttributes'] if attributes[:'extendedEventAttributes'] raise 'You cannot provide both :extendedEventAttributes and :extended_event_attributes' if attributes.key?(:'extendedEventAttributes') && attributes.key?(:'extended_event_attributes') self.extended_event_attributes = attributes[:'extended_event_attributes'] if attributes[:'extended_event_attributes'] self.audit_location = attributes[:'auditLocation'] if attributes[:'auditLocation'] raise 'You cannot provide both :auditLocation and :audit_location' if attributes.key?(:'auditLocation') && attributes.key?(:'audit_location') self.audit_location = attributes[:'audit_location'] if attributes[:'audit_location'] self.os_terminal = attributes[:'osTerminal'] if attributes[:'osTerminal'] raise 'You cannot provide both :osTerminal and :os_terminal' if attributes.key?(:'osTerminal') && attributes.key?(:'os_terminal') self.os_terminal = attributes[:'os_terminal'] if attributes[:'os_terminal'] self.client_id = attributes[:'clientId'] if attributes[:'clientId'] raise 'You cannot provide both :clientId and :client_id' if attributes.key?(:'clientId') && attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] if attributes[:'client_id'] self.audit_policies = attributes[:'auditPolicies'] if attributes[:'auditPolicies'] raise 'You cannot provide both :auditPolicies and :audit_policies' if attributes.key?(:'auditPolicies') && attributes.key?(:'audit_policies') self.audit_policies = attributes[:'audit_policies'] if attributes[:'audit_policies'] self.audit_type = attributes[:'auditType'] if attributes[:'auditType'] raise 'You cannot provide both :auditType and :audit_type' if attributes.key?(:'auditType') && attributes.key?(:'audit_type') self.audit_type = attributes[:'audit_type'] if attributes[:'audit_type'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#action_taken ⇒ String
The action taken for this audit event.
140 141 142 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 140 def action_taken @action_taken end |
#audit_event_time ⇒ DateTime
[Required] Time of audit event occurrence in the target database.
80 81 82 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 80 def audit_event_time @audit_event_time end |
#audit_location ⇒ String
The location of the audit. Currently the value is audit table.
160 161 162 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 160 def audit_location @audit_location end |
#audit_policies ⇒ String
Comma-seperated list of audit policies that caused the current audit event.
172 173 174 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 172 def audit_policies @audit_policies end |
#audit_trail_id ⇒ String
The OCID of the audit trail that generated this audit event.
132 133 134 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 132 def audit_trail_id @audit_trail_id end |
#audit_type ⇒ String
Type of auditing.
176 177 178 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 176 def audit_type @audit_type end |
#client_hostname ⇒ String
Name of the host machine from which the session was spawned.
124 125 126 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 124 def client_hostname @client_hostname end |
#client_id ⇒ String
The client identifier in each Oracle session.
168 169 170 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 168 def client_id @client_id end |
#client_ip ⇒ String
IP address of the host from which the session was spawned.
128 129 130 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 128 def client_ip @client_ip end |
#client_program ⇒ String
The application from which the audit event was generated. Examples SQL Plus or SQL Developer.
144 145 146 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 144 def client_program @client_program end |
#command_param ⇒ String
List of bind variables associated with the command text.
152 153 154 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 152 def command_param @command_param end |
#command_text ⇒ String
The SQL associated with the audit event.
148 149 150 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 148 def command_text @command_text end |
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the audit event. This is the same audited target database resource comparment.
52 53 54 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 52 def compartment_id @compartment_id end |
#database_type ⇒ String
[Required] The type of the target database that was audited. Allowed values are
- DATABASE_CLOUD_SERVICE - Represents Oracle Database Cloud Services.
- AUTONOMOUS_DATABASE - Represents Oracle Autonomous Databases.
- INSTALLED_DATABASE - Represents databases running on-premises or on compute instances.
72 73 74 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 72 def database_type @database_type end |
#db_user_name ⇒ String
Name of the database user whose actions were audited.
56 57 58 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 56 def db_user_name @db_user_name end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
190 191 192 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 190 def end |
#error_code ⇒ String
Oracle Error code generated by the action. Zero indicates the action was successful.
104 105 106 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 104 def error_code @error_code end |
#error_message ⇒ String
Detailed message on why the Error occurred.
108 109 110 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 108 def end |
#event_name ⇒ String
Name of the detail action executed by the user on the target database. i.e ALTER SEQUENCE, CREATE TRIGGER, CREATE INDEX.
100 101 102 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 100 def event_name @event_name end |
#extended_event_attributes ⇒ String
List of all other attributes of the audit event seperated by a colon other than the one returned in audit record.
156 157 158 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 156 def extended_event_attributes @extended_event_attributes end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
183 184 185 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 183 def end |
#id ⇒ String
[Required] The OCID of the audit event.
48 49 50 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 48 def id @id end |
#is_alerted ⇒ BOOLEAN
[Required] Indicates whether an alert was raised for this audit event.
136 137 138 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 136 def is_alerted @is_alerted end |
#object_name ⇒ String
Name of the object affected by the action.
116 117 118 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 116 def object_name @object_name end |
#object_owner ⇒ String
Schema name of object affected but the action.
120 121 122 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 120 def object_owner @object_owner end |
#object_type ⇒ String
Type of object in the source database affected by the action. i.e PL/SQL, SYNONYM, PACKAGE BODY.
112 113 114 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 112 def object_type @object_type end |
#operation ⇒ String
Name of the action executed by the user on the target database. i.e ALTER, CREATE, DROP.
92 93 94 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 92 def operation @operation end |
#operation_status ⇒ String
Indicates whether the operation was a success or a failure.
96 97 98 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 96 def operation_status @operation_status end |
#os_terminal ⇒ String
The operating system terminal of the user session.
164 165 166 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 164 def os_terminal @os_terminal end |
#os_user_name ⇒ String
Name of the operating system user for the database session.
88 89 90 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 88 def os_user_name @os_user_name end |
#target_class ⇒ String
Class of the target that was audited.
76 77 78 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 76 def target_class @target_class end |
#target_id ⇒ String
[Required] The OCID of the target database that was audited.
60 61 62 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 60 def target_id @target_id end |
#target_name ⇒ String
[Required] The name of the target database that was audited.
64 65 66 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 64 def target_name @target_name end |
#time_collected ⇒ DateTime
[Required] Timestamp when this audit event was collected from the target database by Data Safe.
84 85 86 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 84 def time_collected @time_collected end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 193 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'db_user_name': :'dbUserName', 'target_id': :'targetId', 'target_name': :'targetName', 'database_type': :'databaseType', 'target_class': :'targetClass', 'audit_event_time': :'auditEventTime', 'time_collected': :'timeCollected', 'os_user_name': :'osUserName', 'operation': :'operation', 'operation_status': :'operationStatus', 'event_name': :'eventName', 'error_code': :'errorCode', 'error_message': :'errorMessage', 'object_type': :'objectType', 'object_name': :'objectName', 'object_owner': :'objectOwner', 'client_hostname': :'clientHostname', 'client_ip': :'clientIp', 'audit_trail_id': :'auditTrailId', 'is_alerted': :'isAlerted', 'action_taken': :'actionTaken', 'client_program': :'clientProgram', 'command_text': :'commandText', 'command_param': :'commandParam', 'extended_event_attributes': :'extendedEventAttributes', 'audit_location': :'auditLocation', 'os_terminal': :'osTerminal', 'client_id': :'clientId', 'audit_policies': :'auditPolicies', 'audit_type': :'auditType', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 235 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'db_user_name': :'String', 'target_id': :'String', 'target_name': :'String', 'database_type': :'String', 'target_class': :'String', 'audit_event_time': :'DateTime', 'time_collected': :'DateTime', 'os_user_name': :'String', 'operation': :'String', 'operation_status': :'String', 'event_name': :'String', 'error_code': :'String', 'error_message': :'String', 'object_type': :'String', 'object_name': :'String', 'object_owner': :'String', 'client_hostname': :'String', 'client_ip': :'String', 'audit_trail_id': :'String', 'is_alerted': :'BOOLEAN', 'action_taken': :'String', 'client_program': :'String', 'command_text': :'String', 'command_param': :'String', 'extended_event_attributes': :'String', 'audit_location': :'String', 'os_terminal': :'String', 'client_id': :'String', 'audit_policies': :'String', 'audit_type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 591 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && db_user_name == other.db_user_name && target_id == other.target_id && target_name == other.target_name && database_type == other.database_type && target_class == other.target_class && audit_event_time == other.audit_event_time && time_collected == other.time_collected && os_user_name == other.os_user_name && operation == other.operation && operation_status == other.operation_status && event_name == other.event_name && error_code == other.error_code && == other. && object_type == other.object_type && object_name == other.object_name && object_owner == other.object_owner && client_hostname == other.client_hostname && client_ip == other.client_ip && audit_trail_id == other.audit_trail_id && is_alerted == other.is_alerted && action_taken == other.action_taken && client_program == other.client_program && command_text == other.command_text && command_param == other.command_param && extended_event_attributes == other.extended_event_attributes && audit_location == other.audit_location && os_terminal == other.os_terminal && client_id == other.client_id && audit_policies == other.audit_policies && audit_type == other.audit_type && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 654 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
634 635 636 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 634 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
643 644 645 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 643 def hash [id, compartment_id, db_user_name, target_id, target_name, database_type, target_class, audit_event_time, time_collected, os_user_name, operation, operation_status, event_name, error_code, , object_type, object_name, object_owner, client_hostname, client_ip, audit_trail_id, is_alerted, action_taken, client_program, command_text, command_param, extended_event_attributes, audit_location, os_terminal, client_id, audit_policies, audit_type, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
687 688 689 690 691 692 693 694 695 696 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 687 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
681 682 683 |
# File 'lib/oci/data_safe/models/audit_event_summary.rb', line 681 def to_s to_hash.to_s end |