Class: OCI::DataSafe::Models::AuditTrail
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::AuditTrail
- Defined in:
- lib/oci/data_safe/models/audit_trail.rb
Overview
An audit trail represents the source of audit records that provides documentary evidence of the sequence of activities in the target database. Configuring audit trails in Data Safe, and enabling audit data collection on the audit trails copies the audit records from the target database’s audit trail into the Data Safe repository.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_STARTING = 'STARTING'.freeze, STATUS_COLLECTING = 'COLLECTING'.freeze, STATUS_RECOVERING = 'RECOVERING'.freeze, STATUS_IDLE = 'IDLE'.freeze, STATUS_STOPPING = 'STOPPING'.freeze, STATUS_STOPPED = 'STOPPED'.freeze, STATUS_RESUMING = 'RESUMING'.freeze, STATUS_RETRYING = 'RETRYING'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#audit_collection_start_time ⇒ DateTime
The date from which the audit trail must start collecting data, in the format defined by RFC3339.
-
#audit_profile_id ⇒ String
[Required] The OCID of the parent audit.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the audit trail and its same as the compartment of audit profile resource.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the audit trail.
-
#display_name ⇒ String
[Required] The display name of the audit trail.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the audit trail.
-
#is_auto_purge_enabled ⇒ BOOLEAN
Indicates if auto purge is enabled on the target database, which helps delete audit data in the target database every seven days so that the database’s audit trail does not become too large.
-
#lifecycle_details ⇒ String
Details about the current state of the audit trail in Data Safe.
-
#lifecycle_state ⇒ String
[Required] The current state of the audit trail.
-
#status ⇒ String
[Required] The current sub-state of the audit trail.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#target_id ⇒ String
[Required] The OCID of the Data Safe target for which the audit trail is created.
-
#time_created ⇒ DateTime
[Required] The date and time the audit trail was created, in the format defined by RFC3339.
-
#time_updated ⇒ DateTime
[Required] The date and time the audit trail was updated, in the format defined by RFC3339.
-
#trail_location ⇒ String
An audit trail location represents the source of audit records that provides documentary evidence of the sequence of activities in the target database.
-
#work_request_id ⇒ String
The OCID of the workrequest for audit trail which collects audit records.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuditTrail
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AuditTrail
Initializes the object
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 199 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.audit_profile_id = attributes[:'auditProfileId'] if attributes[:'auditProfileId'] raise 'You cannot provide both :auditProfileId and :audit_profile_id' if attributes.key?(:'auditProfileId') && attributes.key?(:'audit_profile_id') self.audit_profile_id = attributes[:'audit_profile_id'] if attributes[:'audit_profile_id'] self.target_id = attributes[:'targetId'] if attributes[:'targetId'] raise 'You cannot provide both :targetId and :target_id' if attributes.key?(:'targetId') && attributes.key?(:'target_id') self.target_id = attributes[:'target_id'] if attributes[:'target_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.status = attributes[:'status'] if attributes[:'status'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.trail_location = attributes[:'trailLocation'] if attributes[:'trailLocation'] raise 'You cannot provide both :trailLocation and :trail_location' if attributes.key?(:'trailLocation') && attributes.key?(:'trail_location') self.trail_location = attributes[:'trail_location'] if attributes[:'trail_location'] self.description = attributes[:'description'] if attributes[:'description'] self.is_auto_purge_enabled = attributes[:'isAutoPurgeEnabled'] unless attributes[:'isAutoPurgeEnabled'].nil? raise 'You cannot provide both :isAutoPurgeEnabled and :is_auto_purge_enabled' if attributes.key?(:'isAutoPurgeEnabled') && attributes.key?(:'is_auto_purge_enabled') self.is_auto_purge_enabled = attributes[:'is_auto_purge_enabled'] unless attributes[:'is_auto_purge_enabled'].nil? self.audit_collection_start_time = attributes[:'auditCollectionStartTime'] if attributes[:'auditCollectionStartTime'] raise 'You cannot provide both :auditCollectionStartTime and :audit_collection_start_time' if attributes.key?(:'auditCollectionStartTime') && attributes.key?(:'audit_collection_start_time') self.audit_collection_start_time = attributes[:'audit_collection_start_time'] if attributes[:'audit_collection_start_time'] self.work_request_id = attributes[:'workRequestId'] if attributes[:'workRequestId'] raise 'You cannot provide both :workRequestId and :work_request_id' if attributes.key?(:'workRequestId') && attributes.key?(:'work_request_id') self.work_request_id = attributes[:'work_request_id'] if attributes[:'work_request_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#audit_collection_start_time ⇒ DateTime
The date from which the audit trail must start collecting data, in the format defined by RFC3339.
91 92 93 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 91 def audit_collection_start_time @audit_collection_start_time end |
#audit_profile_id ⇒ String
[Required] The OCID of the parent audit.
43 44 45 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 43 def audit_profile_id @audit_profile_id end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the audit trail and its same as the compartment of audit profile resource.
101 102 103 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 101 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
115 116 117 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 115 def @defined_tags end |
#description ⇒ String
The description of the audit trail.
81 82 83 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 81 def description @description end |
#display_name ⇒ String
[Required] The display name of the audit trail.
51 52 53 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 51 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
108 109 110 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 108 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the audit trail.
39 40 41 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 39 def id @id end |
#is_auto_purge_enabled ⇒ BOOLEAN
Indicates if auto purge is enabled on the target database, which helps delete audit data in the target database every seven days so that the database’s audit trail does not become too large.
87 88 89 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 87 def is_auto_purge_enabled @is_auto_purge_enabled end |
#lifecycle_details ⇒ String
Details about the current state of the audit trail in Data Safe.
71 72 73 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 71 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the audit trail.
63 64 65 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 63 def lifecycle_state @lifecycle_state end |
#status ⇒ String
[Required] The current sub-state of the audit trail.
67 68 69 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 67 def status @status end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: ‘{"free-tier-retained": "true"}`
121 122 123 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 121 def @system_tags end |
#target_id ⇒ String
[Required] The OCID of the Data Safe target for which the audit trail is created.
47 48 49 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 47 def target_id @target_id end |
#time_created ⇒ DateTime
[Required] The date and time the audit trail was created, in the format defined by RFC3339.
55 56 57 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 55 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time the audit trail was updated, in the format defined by RFC3339.
59 60 61 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 59 def time_updated @time_updated end |
#trail_location ⇒ String
An audit trail location represents the source of audit records that provides documentary evidence of the sequence of activities in the target database.
77 78 79 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 77 def trail_location @trail_location end |
#work_request_id ⇒ String
The OCID of the workrequest for audit trail which collects audit records.
95 96 97 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 95 def work_request_id @work_request_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 124 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'audit_profile_id': :'auditProfileId', 'target_id': :'targetId', 'display_name': :'displayName', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'status': :'status', 'lifecycle_details': :'lifecycleDetails', 'trail_location': :'trailLocation', 'description': :'description', 'is_auto_purge_enabled': :'isAutoPurgeEnabled', 'audit_collection_start_time': :'auditCollectionStartTime', 'work_request_id': :'workRequestId', 'compartment_id': :'compartmentId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 150 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'audit_profile_id': :'String', 'target_id': :'String', 'display_name': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'status': :'String', 'lifecycle_details': :'String', 'trail_location': :'String', 'description': :'String', 'is_auto_purge_enabled': :'BOOLEAN', 'audit_collection_start_time': :'DateTime', 'work_request_id': :'String', 'compartment_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 335 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && audit_profile_id == other.audit_profile_id && target_id == other.target_id && display_name == other.display_name && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && status == other.status && lifecycle_details == other.lifecycle_details && trail_location == other.trail_location && description == other.description && is_auto_purge_enabled == other.is_auto_purge_enabled && audit_collection_start_time == other.audit_collection_start_time && work_request_id == other.work_request_id && compartment_id == other.compartment_id && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 382 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
362 363 364 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 362 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
371 372 373 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 371 def hash [id, audit_profile_id, target_id, display_name, time_created, time_updated, lifecycle_state, status, lifecycle_details, trail_location, description, is_auto_purge_enabled, audit_collection_start_time, work_request_id, compartment_id, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
415 416 417 418 419 420 421 422 423 424 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 415 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
409 410 411 |
# File 'lib/oci/data_safe/models/audit_trail.rb', line 409 def to_s to_hash.to_s end |