Class: OCI::DataSafe::Models::GenerateReportDetails
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::GenerateReportDetails
- Defined in:
- lib/oci/data_safe/models/generate_report_details.rb
Overview
Details for the report generation.
Constant Summary collapse
- MIME_TYPE_ENUM =
[ MIME_TYPE_PDF = 'PDF'.freeze, MIME_TYPE_XLS = 'XLS'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment into which the resource should be moved.
-
#description ⇒ String
The description of the report to be generated.
-
#display_name ⇒ String
[Required] The name of the report to be generated.
-
#mime_type ⇒ String
[Required] Specifies the format of report to be excel or pdf.
-
#row_limit ⇒ Integer
Specifies the limit on number of rows in report.
-
#target_ids ⇒ Array<String>
Array of database target OCIDs.
-
#time_greater_than ⇒ DateTime
Specifies the time after which the data needs to be reported.
-
#time_less_than ⇒ DateTime
Specifies the time before which the data needs to be reported.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GenerateReportDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ GenerateReportDetails
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.target_ids = attributes[:'targetIds'] if attributes[:'targetIds'] raise 'You cannot provide both :targetIds and :target_ids' if attributes.key?(:'targetIds') && attributes.key?(:'target_ids') self.target_ids = attributes[:'target_ids'] if attributes[:'target_ids'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.mime_type = attributes[:'mimeType'] if attributes[:'mimeType'] raise 'You cannot provide both :mimeType and :mime_type' if attributes.key?(:'mimeType') && attributes.key?(:'mime_type') self.mime_type = attributes[:'mime_type'] if attributes[:'mime_type'] self.time_less_than = attributes[:'timeLessThan'] if attributes[:'timeLessThan'] raise 'You cannot provide both :timeLessThan and :time_less_than' if attributes.key?(:'timeLessThan') && attributes.key?(:'time_less_than') self.time_less_than = attributes[:'time_less_than'] if attributes[:'time_less_than'] self.time_greater_than = attributes[:'timeGreaterThan'] if attributes[:'timeGreaterThan'] raise 'You cannot provide both :timeGreaterThan and :time_greater_than' if attributes.key?(:'timeGreaterThan') && attributes.key?(:'time_greater_than') self.time_greater_than = attributes[:'time_greater_than'] if attributes[:'time_greater_than'] self.row_limit = attributes[:'rowLimit'] if attributes[:'rowLimit'] raise 'You cannot provide both :rowLimit and :row_limit' if attributes.key?(:'rowLimit') && attributes.key?(:'row_limit') self.row_limit = attributes[:'row_limit'] if attributes[:'row_limit'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment into which the resource should be moved.
31 32 33 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 31 def compartment_id @compartment_id end |
#description ⇒ String
The description of the report to be generated
25 26 27 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 25 def description @description end |
#display_name ⇒ String
[Required] The name of the report to be generated
17 18 19 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 17 def display_name @display_name end |
#mime_type ⇒ String
[Required] Specifies the format of report to be excel or pdf
35 36 37 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 35 def mime_type @mime_type end |
#row_limit ⇒ Integer
Specifies the limit on number of rows in report.
47 48 49 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 47 def row_limit @row_limit end |
#target_ids ⇒ Array<String>
Array of database target OCIDs.
21 22 23 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 21 def target_ids @target_ids end |
#time_greater_than ⇒ DateTime
Specifies the time after which the data needs to be reported.
43 44 45 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 43 def time_greater_than @time_greater_than end |
#time_less_than ⇒ DateTime
Specifies the time before which the data needs to be reported.
39 40 41 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 39 def time_less_than @time_less_than end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'target_ids': :'targetIds', 'description': :'description', 'compartment_id': :'compartmentId', 'mime_type': :'mimeType', 'time_less_than': :'timeLessThan', 'time_greater_than': :'timeGreaterThan', 'row_limit': :'rowLimit' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'target_ids': :'Array<String>', 'description': :'String', 'compartment_id': :'String', 'mime_type': :'String', 'time_less_than': :'DateTime', 'time_greater_than': :'DateTime', 'row_limit': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 161 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && target_ids == other.target_ids && description == other.description && compartment_id == other.compartment_id && mime_type == other.mime_type && time_less_than == other.time_less_than && time_greater_than == other.time_greater_than && row_limit == other.row_limit end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 198 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
178 179 180 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 178 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 187 def hash [display_name, target_ids, description, compartment_id, mime_type, time_less_than, time_greater_than, row_limit].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
231 232 233 234 235 236 237 238 239 240 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 231 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
225 226 227 |
# File 'lib/oci/data_safe/models/generate_report_details.rb', line 225 def to_s to_hash.to_s end |