Class: OCI::DataSafe::Models::SecurityAssessment
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::SecurityAssessment
- Defined in:
- lib/oci/data_safe/models/security_assessment.rb
Overview
A security assessment that provides an overall insight into your database security posture. The security assessment results are based on the analysis of your database configurations, user accounts, and security controls. For more information, see [Security Assessment Overview](docs.oracle.com/en/cloud/paas/data-safe/udscs/security-assessment-overview.html).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TRIGGERED_BY_ENUM =
[ TRIGGERED_BY_USER = 'USER'.freeze, TRIGGERED_BY_SYSTEM = 'SYSTEM'.freeze, TRIGGERED_BY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TYPE_ENUM =
[ TYPE_LATEST = 'LATEST'.freeze, TYPE_SAVED = 'SAVED'.freeze, TYPE_SAVE_SCHEDULE = 'SAVE_SCHEDULE'.freeze, TYPE_COMPARTMENT = 'COMPARTMENT'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the security assessment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the security assessment.
-
#display_name ⇒ String
[Required] The display name of the security assessment.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the security assessment.
-
#ignored_assessment_ids ⇒ Array<Object>
List containing maps as values.
-
#ignored_targets ⇒ Array<Object>
List containing maps as values.
-
#is_baseline ⇒ BOOLEAN
Indicates whether or not the security assessment is set as a baseline.
-
#is_deviated_from_baseline ⇒ BOOLEAN
Indicates if the assessment has deviated from the baseline.
-
#last_compared_baseline_id ⇒ String
The OCID of the baseline against which the latest security assessment was compared.
-
#lifecycle_details ⇒ String
Details about the current state of the security assessment.
-
#lifecycle_state ⇒ String
[Required] The current state of the security assessment.
-
#link ⇒ String
The summary of findings for the security assessment.
-
#schedule ⇒ String
Schedule to save the assessment periodically in the specified format: <version-string>;<version-specific-schedule>.
-
#schedule_security_assessment_id ⇒ String
The OCID of the security assessment that is responsible for creating this scheduled save assessment.
- #statistics ⇒ OCI::DataSafe::Models::SecurityAssessmentStatistics
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#target_ids ⇒ Array<String>
[Required] Array of database target OCIDs.
-
#target_version ⇒ String
The version of the target database.
-
#time_created ⇒ DateTime
[Required] The date and time when the security assessment was created.
-
#time_updated ⇒ DateTime
[Required] The date and time when the security assessment was last updated.
-
#triggered_by ⇒ String
Indicates whether the security assessment was created by system or by a user.
-
#type ⇒ String
[Required] The type of this security assessment.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SecurityAssessment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SecurityAssessment
Initializes the object
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 261 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.target_ids = attributes[:'targetIds'] if attributes[:'targetIds'] raise 'You cannot provide both :targetIds and :target_ids' if attributes.key?(:'targetIds') && attributes.key?(:'target_ids') self.target_ids = attributes[:'target_ids'] if attributes[:'target_ids'] self.ignored_targets = attributes[:'ignoredTargets'] if attributes[:'ignoredTargets'] raise 'You cannot provide both :ignoredTargets and :ignored_targets' if attributes.key?(:'ignoredTargets') && attributes.key?(:'ignored_targets') self.ignored_targets = attributes[:'ignored_targets'] if attributes[:'ignored_targets'] self.ignored_assessment_ids = attributes[:'ignoredAssessmentIds'] if attributes[:'ignoredAssessmentIds'] raise 'You cannot provide both :ignoredAssessmentIds and :ignored_assessment_ids' if attributes.key?(:'ignoredAssessmentIds') && attributes.key?(:'ignored_assessment_ids') self.ignored_assessment_ids = attributes[:'ignored_assessment_ids'] if attributes[:'ignored_assessment_ids'] self.target_version = attributes[:'targetVersion'] if attributes[:'targetVersion'] raise 'You cannot provide both :targetVersion and :target_version' if attributes.key?(:'targetVersion') && attributes.key?(:'target_version') self.target_version = attributes[:'target_version'] if attributes[:'target_version'] self.is_baseline = attributes[:'isBaseline'] unless attributes[:'isBaseline'].nil? raise 'You cannot provide both :isBaseline and :is_baseline' if attributes.key?(:'isBaseline') && attributes.key?(:'is_baseline') self.is_baseline = attributes[:'is_baseline'] unless attributes[:'is_baseline'].nil? self.is_deviated_from_baseline = attributes[:'isDeviatedFromBaseline'] unless attributes[:'isDeviatedFromBaseline'].nil? raise 'You cannot provide both :isDeviatedFromBaseline and :is_deviated_from_baseline' if attributes.key?(:'isDeviatedFromBaseline') && attributes.key?(:'is_deviated_from_baseline') self.is_deviated_from_baseline = attributes[:'is_deviated_from_baseline'] unless attributes[:'is_deviated_from_baseline'].nil? self.last_compared_baseline_id = attributes[:'lastComparedBaselineId'] if attributes[:'lastComparedBaselineId'] raise 'You cannot provide both :lastComparedBaselineId and :last_compared_baseline_id' if attributes.key?(:'lastComparedBaselineId') && attributes.key?(:'last_compared_baseline_id') self.last_compared_baseline_id = attributes[:'last_compared_baseline_id'] if attributes[:'last_compared_baseline_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.schedule_security_assessment_id = attributes[:'scheduleSecurityAssessmentId'] if attributes[:'scheduleSecurityAssessmentId'] raise 'You cannot provide both :scheduleSecurityAssessmentId and :schedule_security_assessment_id' if attributes.key?(:'scheduleSecurityAssessmentId') && attributes.key?(:'schedule_security_assessment_id') self.schedule_security_assessment_id = attributes[:'schedule_security_assessment_id'] if attributes[:'schedule_security_assessment_id'] self.triggered_by = attributes[:'triggeredBy'] if attributes[:'triggeredBy'] raise 'You cannot provide both :triggeredBy and :triggered_by' if attributes.key?(:'triggeredBy') && attributes.key?(:'triggered_by') self.triggered_by = attributes[:'triggered_by'] if attributes[:'triggered_by'] self.description = attributes[:'description'] if attributes[:'description'] self.schedule = attributes[:'schedule'] if attributes[:'schedule'] self.link = attributes[:'link'] if attributes[:'link'] self.type = attributes[:'type'] if attributes[:'type'] self.statistics = attributes[:'statistics'] if attributes[:'statistics'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the security assessment.
51 52 53 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 51 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
159 160 161 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 159 def @defined_tags end |
#description ⇒ String
The description of the security assessment.
107 108 109 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 107 def description @description end |
#display_name ⇒ String
[Required] The display name of the security assessment.
55 56 57 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 55 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
152 153 154 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 152 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the security assessment.
39 40 41 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 39 def id @id end |
#ignored_assessment_ids ⇒ Array<Object>
List containing maps as values. Example: ‘[ {"CostCenter": "42" ] }`
71 72 73 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 71 def ignored_assessment_ids @ignored_assessment_ids end |
#ignored_targets ⇒ Array<Object>
List containing maps as values. Example: ‘[ {"CostCenter": "42" ] }`
65 66 67 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 65 def ignored_targets @ignored_targets end |
#is_baseline ⇒ BOOLEAN
Indicates whether or not the security assessment is set as a baseline. This is applicable only for saved security assessments.
79 80 81 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 79 def is_baseline @is_baseline end |
#is_deviated_from_baseline ⇒ BOOLEAN
Indicates if the assessment has deviated from the baseline.
83 84 85 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 83 def is_deviated_from_baseline @is_deviated_from_baseline end |
#last_compared_baseline_id ⇒ String
The OCID of the baseline against which the latest security assessment was compared.
87 88 89 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 87 def last_compared_baseline_id @last_compared_baseline_id end |
#lifecycle_details ⇒ String
Details about the current state of the security assessment.
95 96 97 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 95 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the security assessment.
91 92 93 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 91 def lifecycle_state @lifecycle_state end |
#link ⇒ String
The summary of findings for the security assessment
130 131 132 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 130 def link @link end |
#schedule ⇒ String
Schedule to save the assessment periodically in the specified format: <version-string>;<version-specific-schedule>
Allowed version strings - "v1" v1’s version specific schedule -<ss> <mm> <hh> <day-of-week> <day-of-month> Each of the above fields potentially introduce constraints. A workrequest is created only when clock time satisfies all the constraints. Constraints introduced:
-
seconds = <ss> (So, the allowed range for <ss> is [0, 59])
-
minutes = <mm> (So, the allowed range for <mm> is [0, 59])
-
hours = <hh> (So, the allowed range for <hh> is [0, 23])
<day-of-week> can be either ‘*’ (without quotes or a number between 1(Monday) and 7(Sunday))
-
No constraint introduced when it is ‘*’. When not, day of week must equal the given value
<day-of-month> can be either ‘*’ (without quotes or a number between 1 and 28)
-
No constraint introduced when it is ‘*’. When not, day of month must equal the given value
125 126 127 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 125 def schedule @schedule end |
#schedule_security_assessment_id ⇒ String
The OCID of the security assessment that is responsible for creating this scheduled save assessment.
99 100 101 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 99 def schedule_security_assessment_id @schedule_security_assessment_id end |
#statistics ⇒ OCI::DataSafe::Models::SecurityAssessmentStatistics
145 146 147 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 145 def statistics @statistics end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: ‘{"free-tier-retained": "true"}`
165 166 167 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 165 def @system_tags end |
#target_ids ⇒ Array<String>
[Required] Array of database target OCIDs.
59 60 61 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 59 def target_ids @target_ids end |
#target_version ⇒ String
The version of the target database.
75 76 77 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 75 def target_version @target_version end |
#time_created ⇒ DateTime
[Required] The date and time when the security assessment was created. Conforms to the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
43 44 45 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 43 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time when the security assessment was last updated. Conforms to the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
47 48 49 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 47 def time_updated @time_updated end |
#triggered_by ⇒ String
Indicates whether the security assessment was created by system or by a user.
103 104 105 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 103 def triggered_by @triggered_by end |
#type ⇒ String
[Required] The type of this security assessment. The possible types are:
LATEST: The most up-to-date assessment that is running automatically for a target. It is system generated. SAVED: A saved security assessment. LATEST assessments are always saved in order to maintain the history of runs. A SAVED assessment is also generated by a ‘refresh’ action (triggered by the user). SAVE_SCHEDULE: The schedule for periodic saves of LATEST assessments. COMPARTMENT: An automatically managed assessment type that stores all details of targets in one compartment.
This type keeps an up-to-date assessment of all database risks in one compartment. It is automatically updated when
the latest assessment or refresh action is executed. It is also automatically updated when a target is deleted or move to a different compartment.
142 143 144 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 142 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 168 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'target_ids': :'targetIds', 'ignored_targets': :'ignoredTargets', 'ignored_assessment_ids': :'ignoredAssessmentIds', 'target_version': :'targetVersion', 'is_baseline': :'isBaseline', 'is_deviated_from_baseline': :'isDeviatedFromBaseline', 'last_compared_baseline_id': :'lastComparedBaselineId', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'schedule_security_assessment_id': :'scheduleSecurityAssessmentId', 'triggered_by': :'triggeredBy', 'description': :'description', 'schedule': :'schedule', 'link': :'link', 'type': :'type', 'statistics': :'statistics', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 200 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'compartment_id': :'String', 'display_name': :'String', 'target_ids': :'Array<String>', 'ignored_targets': :'Array<Object>', 'ignored_assessment_ids': :'Array<Object>', 'target_version': :'String', 'is_baseline': :'BOOLEAN', 'is_deviated_from_baseline': :'BOOLEAN', 'last_compared_baseline_id': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'schedule_security_assessment_id': :'String', 'triggered_by': :'String', 'description': :'String', 'schedule': :'String', 'link': :'String', 'type': :'String', 'statistics': :'OCI::DataSafe::Models::SecurityAssessmentStatistics', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 434 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && time_created == other.time_created && time_updated == other.time_updated && compartment_id == other.compartment_id && display_name == other.display_name && target_ids == other.target_ids && ignored_targets == other.ignored_targets && ignored_assessment_ids == other.ignored_assessment_ids && target_version == other.target_version && is_baseline == other.is_baseline && is_deviated_from_baseline == other.is_deviated_from_baseline && last_compared_baseline_id == other.last_compared_baseline_id && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && schedule_security_assessment_id == other.schedule_security_assessment_id && triggered_by == other.triggered_by && description == other.description && schedule == other.schedule && link == other.link && type == other.type && statistics == other.statistics && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 487 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
467 468 469 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 467 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
476 477 478 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 476 def hash [id, time_created, time_updated, compartment_id, display_name, target_ids, ignored_targets, ignored_assessment_ids, target_version, is_baseline, is_deviated_from_baseline, last_compared_baseline_id, lifecycle_state, lifecycle_details, schedule_security_assessment_id, triggered_by, description, schedule, link, type, statistics, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
520 521 522 523 524 525 526 527 528 529 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 520 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
514 515 516 |
# File 'lib/oci/data_safe/models/security_assessment.rb', line 514 def to_s to_hash.to_s end |