Class: OCI::DataSafe::Models::SecurityAssessmentSummary
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::SecurityAssessmentSummary
- Defined in:
- lib/oci/data_safe/models/security_assessment_summary.rb
Overview
The summary of a security assessment.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TRIGGERED_BY_ENUM =
[ TRIGGERED_BY_USER = 'USER'.freeze, TRIGGERED_BY_SYSTEM = 'SYSTEM'.freeze, TRIGGERED_BY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TYPE_ENUM =
[ TYPE_LATEST = 'LATEST'.freeze, TYPE_SAVED = 'SAVED'.freeze, TYPE_SAVE_SCHEDULE = 'SAVE_SCHEDULE'.freeze, TYPE_COMPARTMENT = 'COMPARTMENT'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the security assessment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the security assessment.
-
#display_name ⇒ String
**[Required]** The display name of the security assessment.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the security assessment.
-
#ignored_assessment_ids ⇒ Array<Object>
List containing maps as values.
-
#ignored_target_ids ⇒ Array<Object>
List containing maps as values.
-
#is_baseline ⇒ BOOLEAN
Indicates whether or not the assessment is a baseline assessment.
-
#is_deviated_from_baseline ⇒ BOOLEAN
Indicates whether or not the security assessment deviates from the baseline.
-
#last_compared_baseline_id ⇒ String
The OCID of the baseline against which the latest assessment was compared.
-
#lifecycle_details ⇒ String
Details about the current state of the security assessment.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the security assessment.
-
#link ⇒ String
The summary of findings for the security assessment.
-
#schedule ⇒ String
Schedule of the assessment that runs periodically in the specified format: - <version-string>;<version-specific-schedule>.
-
#schedule_security_assessment_id ⇒ String
The OCID of the security assessment that created this scheduled save assessment.
- #statistics ⇒ OCI::DataSafe::Models::SecurityAssessmentStatistics
-
#target_ids ⇒ Array<String>
**[Required]** Array of database target OCIDs.
-
#time_created ⇒ DateTime
**[Required]** The date and time when the security assessment was created.
-
#time_updated ⇒ DateTime
**[Required]** The date and time when the security assessment was last updated.
-
#triggered_by ⇒ String
Indicates whether the security assessment was created by system or by a user.
-
#type ⇒ String
**[Required]** The type of the security assessment.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SecurityAssessmentSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SecurityAssessmentSummary
Initializes the object
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 242 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.description = attributes[:'description'] if attributes[:'description'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.target_ids = attributes[:'targetIds'] if attributes[:'targetIds'] raise 'You cannot provide both :targetIds and :target_ids' if attributes.key?(:'targetIds') && attributes.key?(:'target_ids') self.target_ids = attributes[:'target_ids'] if attributes[:'target_ids'] self.ignored_target_ids = attributes[:'ignoredTargetIds'] if attributes[:'ignoredTargetIds'] raise 'You cannot provide both :ignoredTargetIds and :ignored_target_ids' if attributes.key?(:'ignoredTargetIds') && attributes.key?(:'ignored_target_ids') self.ignored_target_ids = attributes[:'ignored_target_ids'] if attributes[:'ignored_target_ids'] self.ignored_assessment_ids = attributes[:'ignoredAssessmentIds'] if attributes[:'ignoredAssessmentIds'] raise 'You cannot provide both :ignoredAssessmentIds and :ignored_assessment_ids' if attributes.key?(:'ignoredAssessmentIds') && attributes.key?(:'ignored_assessment_ids') self.ignored_assessment_ids = attributes[:'ignored_assessment_ids'] if attributes[:'ignored_assessment_ids'] self.is_baseline = attributes[:'isBaseline'] unless attributes[:'isBaseline'].nil? raise 'You cannot provide both :isBaseline and :is_baseline' if attributes.key?(:'isBaseline') && attributes.key?(:'is_baseline') self.is_baseline = attributes[:'is_baseline'] unless attributes[:'is_baseline'].nil? self.is_deviated_from_baseline = attributes[:'isDeviatedFromBaseline'] unless attributes[:'isDeviatedFromBaseline'].nil? raise 'You cannot provide both :isDeviatedFromBaseline and :is_deviated_from_baseline' if attributes.key?(:'isDeviatedFromBaseline') && attributes.key?(:'is_deviated_from_baseline') self.is_deviated_from_baseline = attributes[:'is_deviated_from_baseline'] unless attributes[:'is_deviated_from_baseline'].nil? self.last_compared_baseline_id = attributes[:'lastComparedBaselineId'] if attributes[:'lastComparedBaselineId'] raise 'You cannot provide both :lastComparedBaselineId and :last_compared_baseline_id' if attributes.key?(:'lastComparedBaselineId') && attributes.key?(:'last_compared_baseline_id') self.last_compared_baseline_id = attributes[:'last_compared_baseline_id'] if attributes[:'last_compared_baseline_id'] self.schedule_security_assessment_id = attributes[:'scheduleSecurityAssessmentId'] if attributes[:'scheduleSecurityAssessmentId'] raise 'You cannot provide both :scheduleSecurityAssessmentId and :schedule_security_assessment_id' if attributes.key?(:'scheduleSecurityAssessmentId') && attributes.key?(:'schedule_security_assessment_id') self.schedule_security_assessment_id = attributes[:'schedule_security_assessment_id'] if attributes[:'schedule_security_assessment_id'] self.schedule = attributes[:'schedule'] if attributes[:'schedule'] self.triggered_by = attributes[:'triggeredBy'] if attributes[:'triggeredBy'] raise 'You cannot provide both :triggeredBy and :triggered_by' if attributes.key?(:'triggeredBy') && attributes.key?(:'triggered_by') self.triggered_by = attributes[:'triggered_by'] if attributes[:'triggered_by'] self.link = attributes[:'link'] if attributes[:'link'] self.type = attributes[:'type'] if attributes[:'type'] self.statistics = attributes[:'statistics'] if attributes[:'statistics'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the security assessment.
61 62 63 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 61 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: `{"CostCenter": "42"}`
152 153 154 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 152 def @defined_tags end |
#description ⇒ String
The description of the security assessment.
41 42 43 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 41 def description @description end |
#display_name ⇒ String
**[Required]** The display name of the security assessment.
65 66 67 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 65 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: `"Finance"`
145 146 147 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 145 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the security assessment.
37 38 39 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 37 def id @id end |
#ignored_assessment_ids ⇒ Array<Object>
List containing maps as values. Example: `[ {"CostCenter": "42" ] }`
81 82 83 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 81 def ignored_assessment_ids @ignored_assessment_ids end |
#ignored_target_ids ⇒ Array<Object>
List containing maps as values. Example: `[ {"CostCenter": "42" ] }`
75 76 77 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 75 def ignored_target_ids @ignored_target_ids end |
#is_baseline ⇒ BOOLEAN
Indicates whether or not the assessment is a baseline assessment. This applied to saved security assessments only.
85 86 87 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 85 def is_baseline @is_baseline end |
#is_deviated_from_baseline ⇒ BOOLEAN
Indicates whether or not the security assessment deviates from the baseline.
89 90 91 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 89 def is_deviated_from_baseline @is_deviated_from_baseline end |
#last_compared_baseline_id ⇒ String
The OCID of the baseline against which the latest assessment was compared.
93 94 95 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 93 def last_compared_baseline_id @last_compared_baseline_id end |
#lifecycle_details ⇒ String
Details about the current state of the security assessment.
49 50 51 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 49 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the security assessment.
45 46 47 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 45 def lifecycle_state @lifecycle_state end |
#link ⇒ String
The summary of findings for the security assessment.
124 125 126 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 124 def link @link end |
#schedule ⇒ String
Schedule of the assessment that runs periodically in the specified format: - <version-string>;<version-specific-schedule>
Allowed version strings - "v1" v1's version specific schedule -<ss> <mm> <hh> <day-of-week> <day-of-month> Each of the above fields potentially introduce constraints. A workrequest is created only when clock time satisfies all the constraints. Constraints introduced:
-
seconds = <ss> (So, the allowed range for <ss> is [0, 59])
-
minutes = <mm> (So, the allowed range for <mm> is [0, 59])
-
hours = <hh> (So, the allowed range for <hh> is [0, 23])
<day-of-week> can be either '*' (without quotes or a number between 1(Monday) and 7(Sunday))
-
No constraint introduced when it is '*'. When not, day of week must equal the given value
<day-of-month> can be either '*' (without quotes or a number between 1 and 28)
-
No constraint introduced when it is '*'. When not, day of month must equal the given value
115 116 117 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 115 def schedule @schedule end |
#schedule_security_assessment_id ⇒ String
The OCID of the security assessment that created this scheduled save assessment.
97 98 99 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 97 def schedule_security_assessment_id @schedule_security_assessment_id end |
#statistics ⇒ OCI::DataSafe::Models::SecurityAssessmentStatistics
138 139 140 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 138 def statistics @statistics end |
#target_ids ⇒ Array<String>
**[Required]** Array of database target OCIDs.
69 70 71 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 69 def target_ids @target_ids end |
#time_created ⇒ DateTime
**[Required]** The date and time when the security assessment was created. Conforms to the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
53 54 55 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 53 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The date and time when the security assessment was last updated. Conforms to the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
57 58 59 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 57 def time_updated @time_updated end |
#triggered_by ⇒ String
Indicates whether the security assessment was created by system or by a user.
119 120 121 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 119 def triggered_by @triggered_by end |
#type ⇒ String
**[Required]** The type of the security assessment. Possible values are:
LATEST: The most up-to-date assessment that is running automatically for a target. It is system generated. SAVED: A saved security assessment. LATEST assessments are always saved in order to maintain the history of runs. A SAVED assessment is also generated by a 'refresh' action (triggered by the user). SAVE_SCHEDULE: The schedule for periodic saves of LATEST assessments. COMPARTMENT: An automatically managed assessment type that stores all details of targets in one compartment. This type keeps an up-to-date assessment of all database risks in one compartment. It is automatically updated when the latest assessment or refresh action is executed. It is also automatically updated when a target is deleted or move to a different compartment.
135 136 137 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 135 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 155 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'target_ids': :'targetIds', 'ignored_target_ids': :'ignoredTargetIds', 'ignored_assessment_ids': :'ignoredAssessmentIds', 'is_baseline': :'isBaseline', 'is_deviated_from_baseline': :'isDeviatedFromBaseline', 'last_compared_baseline_id': :'lastComparedBaselineId', 'schedule_security_assessment_id': :'scheduleSecurityAssessmentId', 'schedule': :'schedule', 'triggered_by': :'triggeredBy', 'link': :'link', 'type': :'type', 'statistics': :'statistics', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 185 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'compartment_id': :'String', 'display_name': :'String', 'target_ids': :'Array<String>', 'ignored_target_ids': :'Array<Object>', 'ignored_assessment_ids': :'Array<Object>', 'is_baseline': :'BOOLEAN', 'is_deviated_from_baseline': :'BOOLEAN', 'last_compared_baseline_id': :'String', 'schedule_security_assessment_id': :'String', 'schedule': :'String', 'triggered_by': :'String', 'link': :'String', 'type': :'String', 'statistics': :'OCI::DataSafe::Models::SecurityAssessmentStatistics', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 403 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created && time_updated == other.time_updated && compartment_id == other.compartment_id && display_name == other.display_name && target_ids == other.target_ids && ignored_target_ids == other.ignored_target_ids && ignored_assessment_ids == other.ignored_assessment_ids && is_baseline == other.is_baseline && is_deviated_from_baseline == other.is_deviated_from_baseline && last_compared_baseline_id == other.last_compared_baseline_id && schedule_security_assessment_id == other.schedule_security_assessment_id && schedule == other.schedule && triggered_by == other.triggered_by && link == other.link && type == other.type && statistics == other.statistics && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 454 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
434 435 436 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 434 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
443 444 445 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 443 def hash [id, description, lifecycle_state, lifecycle_details, time_created, time_updated, compartment_id, display_name, target_ids, ignored_target_ids, ignored_assessment_ids, is_baseline, is_deviated_from_baseline, last_compared_baseline_id, schedule_security_assessment_id, schedule, triggered_by, link, type, statistics, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
487 488 489 490 491 492 493 494 495 496 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 487 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
481 482 483 |
# File 'lib/oci/data_safe/models/security_assessment_summary.rb', line 481 def to_s to_hash.to_s end |