Class: OCI::DataSafe::Models::TargetDatabase
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::TargetDatabase
- Defined in:
- lib/oci/data_safe/models/target_database.rb
Overview
The details of the Data Safe target database.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment which contains the Data Safe target database.
- #connection_option ⇒ OCI::DataSafe::Models::ConnectionOption
- #credentials ⇒ OCI::DataSafe::Models::Credentials
-
#database_details ⇒ OCI::DataSafe::Models::DatabaseDetails
This attribute is required.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the target database in Data Safe.
-
#display_name ⇒ String
[Required] The display name of the target database in Data Safe.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the Data Safe target database.
-
#lifecycle_details ⇒ String
Details about the current state of the target database in Data Safe.
-
#lifecycle_state ⇒ String
[Required] The current state of the target database in Data Safe.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
[Required] The date and time of target database registration and creation in Data Safe.
-
#time_updated ⇒ DateTime
The date and time of the target database update in Data Safe.
- #tls_config ⇒ OCI::DataSafe::Models::TlsConfig
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TargetDatabase
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TargetDatabase
Initializes the object
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/data_safe/models/target_database.rb', line 155 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.database_details = attributes[:'databaseDetails'] if attributes[:'databaseDetails'] raise 'You cannot provide both :databaseDetails and :database_details' if attributes.key?(:'databaseDetails') && attributes.key?(:'database_details') self.database_details = attributes[:'database_details'] if attributes[:'database_details'] self.credentials = attributes[:'credentials'] if attributes[:'credentials'] self.tls_config = attributes[:'tlsConfig'] if attributes[:'tlsConfig'] raise 'You cannot provide both :tlsConfig and :tls_config' if attributes.key?(:'tlsConfig') && attributes.key?(:'tls_config') self.tls_config = attributes[:'tls_config'] if attributes[:'tls_config'] self.connection_option = attributes[:'connectionOption'] if attributes[:'connectionOption'] raise 'You cannot provide both :connectionOption and :connection_option' if attributes.key?(:'connectionOption') && attributes.key?(:'connection_option') self.connection_option = attributes[:'connection_option'] if attributes[:'connection_option'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment which contains the Data Safe target database.
25 26 27 |
# File 'lib/oci/data_safe/models/target_database.rb', line 25 def compartment_id @compartment_id end |
#connection_option ⇒ OCI::DataSafe::Models::ConnectionOption
50 51 52 |
# File 'lib/oci/data_safe/models/target_database.rb', line 50 def connection_option @connection_option end |
#credentials ⇒ OCI::DataSafe::Models::Credentials
44 45 46 |
# File 'lib/oci/data_safe/models/target_database.rb', line 44 def credentials @credentials end |
#database_details ⇒ OCI::DataSafe::Models::DatabaseDetails
This attribute is required.
41 42 43 |
# File 'lib/oci/data_safe/models/target_database.rb', line 41 def database_details @database_details end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘{"CostCenter": "42"}`
80 81 82 |
# File 'lib/oci/data_safe/models/target_database.rb', line 80 def end |
#description ⇒ String
The description of the target database in Data Safe.
37 38 39 |
# File 'lib/oci/data_safe/models/target_database.rb', line 37 def description @description end |
#display_name ⇒ String
[Required] The display name of the target database in Data Safe.
33 34 35 |
# File 'lib/oci/data_safe/models/target_database.rb', line 33 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: ‘"Finance"`
73 74 75 |
# File 'lib/oci/data_safe/models/target_database.rb', line 73 def end |
#id ⇒ String
[Required] The OCID of the Data Safe target database.
29 30 31 |
# File 'lib/oci/data_safe/models/target_database.rb', line 29 def id @id end |
#lifecycle_details ⇒ String
Details about the current state of the target database in Data Safe.
58 59 60 |
# File 'lib/oci/data_safe/models/target_database.rb', line 58 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the target database in Data Safe.
54 55 56 |
# File 'lib/oci/data_safe/models/target_database.rb', line 54 def lifecycle_state @lifecycle_state end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: ‘{"free-tier-retained": "true"}`
86 87 88 |
# File 'lib/oci/data_safe/models/target_database.rb', line 86 def end |
#time_created ⇒ DateTime
[Required] The date and time of target database registration and creation in Data Safe.
62 63 64 |
# File 'lib/oci/data_safe/models/target_database.rb', line 62 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time of the target database update in Data Safe.
66 67 68 |
# File 'lib/oci/data_safe/models/target_database.rb', line 66 def time_updated @time_updated end |
#tls_config ⇒ OCI::DataSafe::Models::TlsConfig
47 48 49 |
# File 'lib/oci/data_safe/models/target_database.rb', line 47 def tls_config @tls_config end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/data_safe/models/target_database.rb', line 89 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'database_details': :'databaseDetails', 'credentials': :'credentials', 'tls_config': :'tlsConfig', 'connection_option': :'connectionOption', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/data_safe/models/target_database.rb', line 112 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'id': :'String', 'display_name': :'String', 'description': :'String', 'database_details': :'OCI::DataSafe::Models::DatabaseDetails', 'credentials': :'OCI::DataSafe::Models::Credentials', 'tls_config': :'OCI::DataSafe::Models::TlsConfig', 'connection_option': :'OCI::DataSafe::Models::ConnectionOption', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/oci/data_safe/models/target_database.rb', line 260 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && id == other.id && display_name == other.display_name && description == other.description && database_details == other.database_details && credentials == other.credentials && tls_config == other.tls_config && connection_option == other.connection_option && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/oci/data_safe/models/target_database.rb', line 304 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
284 285 286 |
# File 'lib/oci/data_safe/models/target_database.rb', line 284 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
293 294 295 |
# File 'lib/oci/data_safe/models/target_database.rb', line 293 def hash [compartment_id, id, display_name, description, database_details, credentials, tls_config, connection_option, lifecycle_state, lifecycle_details, time_created, time_updated, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 346 |
# File 'lib/oci/data_safe/models/target_database.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
331 332 333 |
# File 'lib/oci/data_safe/models/target_database.rb', line 331 def to_s to_hash.to_s end |