Class: OCI::DataSafe::Models::UserAssessment

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/data_safe/models/user_assessment.rb

Overview

The details of the user assessment, which includes statistics related to target database users.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TRIGGERED_BY_ENUM =
[
  TRIGGERED_BY_USER = 'USER'.freeze,
  TRIGGERED_BY_SYSTEM = 'SYSTEM'.freeze,
  TRIGGERED_BY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
TYPE_ENUM =
[
  TYPE_LATEST = 'LATEST'.freeze,
  TYPE_SAVED = 'SAVED'.freeze,
  TYPE_SAVE_SCHEDULE = 'SAVE_SCHEDULE'.freeze,
  TYPE_COMPARTMENT = 'COMPARTMENT'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UserAssessment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :description (String)

    The value to assign to the #description property

  • :display_name (String)

    The value to assign to the #display_name property

  • :id (String)

    The value to assign to the #id property

  • :ignored_targets (Array<Object>)

    The value to assign to the #ignored_targets property

  • :ignored_assessment_ids (Array<Object>)

    The value to assign to the #ignored_assessment_ids property

  • :is_baseline (BOOLEAN)

    The value to assign to the #is_baseline property

  • :is_deviated_from_baseline (BOOLEAN)

    The value to assign to the #is_deviated_from_baseline property

  • :last_compared_baseline_id (String)

    The value to assign to the #last_compared_baseline_id property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :schedule_assessment_id (String)

    The value to assign to the #schedule_assessment_id property

  • :schedule (String)

    The value to assign to the #schedule property

  • :statistics (Hash<String, Hash<String, Object>>)

    The value to assign to the #statistics property

  • :target_ids (Array<String>)

    The value to assign to the #target_ids property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :triggered_by (String)

    The value to assign to the #triggered_by property

  • :type (String)

    The value to assign to the #type property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/oci/data_safe/models/user_assessment.rb', line 245

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.description = attributes[:'description'] if attributes[:'description']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.id = attributes[:'id'] if attributes[:'id']

  self.ignored_targets = attributes[:'ignoredTargets'] if attributes[:'ignoredTargets']

  raise 'You cannot provide both :ignoredTargets and :ignored_targets' if attributes.key?(:'ignoredTargets') && attributes.key?(:'ignored_targets')

  self.ignored_targets = attributes[:'ignored_targets'] if attributes[:'ignored_targets']

  self.ignored_assessment_ids = attributes[:'ignoredAssessmentIds'] if attributes[:'ignoredAssessmentIds']

  raise 'You cannot provide both :ignoredAssessmentIds and :ignored_assessment_ids' if attributes.key?(:'ignoredAssessmentIds') && attributes.key?(:'ignored_assessment_ids')

  self.ignored_assessment_ids = attributes[:'ignored_assessment_ids'] if attributes[:'ignored_assessment_ids']

  self.is_baseline = attributes[:'isBaseline'] unless attributes[:'isBaseline'].nil?

  raise 'You cannot provide both :isBaseline and :is_baseline' if attributes.key?(:'isBaseline') && attributes.key?(:'is_baseline')

  self.is_baseline = attributes[:'is_baseline'] unless attributes[:'is_baseline'].nil?

  self.is_deviated_from_baseline = attributes[:'isDeviatedFromBaseline'] unless attributes[:'isDeviatedFromBaseline'].nil?

  raise 'You cannot provide both :isDeviatedFromBaseline and :is_deviated_from_baseline' if attributes.key?(:'isDeviatedFromBaseline') && attributes.key?(:'is_deviated_from_baseline')

  self.is_deviated_from_baseline = attributes[:'is_deviated_from_baseline'] unless attributes[:'is_deviated_from_baseline'].nil?

  self.last_compared_baseline_id = attributes[:'lastComparedBaselineId'] if attributes[:'lastComparedBaselineId']

  raise 'You cannot provide both :lastComparedBaselineId and :last_compared_baseline_id' if attributes.key?(:'lastComparedBaselineId') && attributes.key?(:'last_compared_baseline_id')

  self.last_compared_baseline_id = attributes[:'last_compared_baseline_id'] if attributes[:'last_compared_baseline_id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.schedule_assessment_id = attributes[:'scheduleAssessmentId'] if attributes[:'scheduleAssessmentId']

  raise 'You cannot provide both :scheduleAssessmentId and :schedule_assessment_id' if attributes.key?(:'scheduleAssessmentId') && attributes.key?(:'schedule_assessment_id')

  self.schedule_assessment_id = attributes[:'schedule_assessment_id'] if attributes[:'schedule_assessment_id']

  self.schedule = attributes[:'schedule'] if attributes[:'schedule']

  self.statistics = attributes[:'statistics'] if attributes[:'statistics']

  self.target_ids = attributes[:'targetIds'] if attributes[:'targetIds']

  raise 'You cannot provide both :targetIds and :target_ids' if attributes.key?(:'targetIds') && attributes.key?(:'target_ids')

  self.target_ids = attributes[:'target_ids'] if attributes[:'target_ids']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.triggered_by = attributes[:'triggeredBy'] if attributes[:'triggeredBy']

  raise 'You cannot provide both :triggeredBy and :triggered_by' if attributes.key?(:'triggeredBy') && attributes.key?(:'triggered_by')

  self.triggered_by = attributes[:'triggered_by'] if attributes[:'triggered_by']

  self.type = attributes[:'type'] if attributes[:'type']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the compartment that contains the user assessment.

Returns:

  • (String)


36
37
38
# File 'lib/oci/data_safe/models/user_assessment.rb', line 36

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


149
150
151
# File 'lib/oci/data_safe/models/user_assessment.rb', line 149

def defined_tags
  @defined_tags
end

#descriptionString

The description of the user assessment.

Returns:

  • (String)


40
41
42
# File 'lib/oci/data_safe/models/user_assessment.rb', line 40

def description
  @description
end

#display_nameString

[Required] The display name of the user assessment.

Returns:

  • (String)


44
45
46
# File 'lib/oci/data_safe/models/user_assessment.rb', line 44

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


142
143
144
# File 'lib/oci/data_safe/models/user_assessment.rb', line 142

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the user assessment.

Returns:

  • (String)


48
49
50
# File 'lib/oci/data_safe/models/user_assessment.rb', line 48

def id
  @id
end

#ignored_assessment_idsArray<Object>

List containing maps as values. Example: ‘[ {"CostCenter": "42" ] }`

Returns:

  • (Array<Object>)


60
61
62
# File 'lib/oci/data_safe/models/user_assessment.rb', line 60

def ignored_assessment_ids
  @ignored_assessment_ids
end

#ignored_targetsArray<Object>

List containing maps as values. Example: ‘[ {"CostCenter": "42" ] }`

Returns:

  • (Array<Object>)


54
55
56
# File 'lib/oci/data_safe/models/user_assessment.rb', line 54

def ignored_targets
  @ignored_targets
end

#is_baselineBOOLEAN

Indicates if the user assessment is set as a baseline. This is applicable only to saved user assessments.

Returns:

  • (BOOLEAN)


64
65
66
# File 'lib/oci/data_safe/models/user_assessment.rb', line 64

def is_baseline
  @is_baseline
end

#is_deviated_from_baselineBOOLEAN

Indicates if the user assessment deviates from the baseline.

Returns:

  • (BOOLEAN)


68
69
70
# File 'lib/oci/data_safe/models/user_assessment.rb', line 68

def is_deviated_from_baseline
  @is_deviated_from_baseline
end

#last_compared_baseline_idString

The OCID of the last user assessment baseline against which the latest assessment was compared.

Returns:

  • (String)


72
73
74
# File 'lib/oci/data_safe/models/user_assessment.rb', line 72

def last_compared_baseline_id
  @last_compared_baseline_id
end

#lifecycle_detailsString

Details about the current state of the user assessment.

Returns:

  • (String)


80
81
82
# File 'lib/oci/data_safe/models/user_assessment.rb', line 80

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the user assessment.

Returns:

  • (String)


76
77
78
# File 'lib/oci/data_safe/models/user_assessment.rb', line 76

def lifecycle_state
  @lifecycle_state
end

#scheduleString

Schedule of the assessment that runs periodically in this specified format:

<version-string>;<version-specific-schedule>

Allowed version strings - \"v1\"
v1's version specific schedule -<ss> <mm> <hh> <day-of-week> <day-of-month>
Each of the above fields potentially introduce constraints. A workrequest is created only
when clock time satisfies all the constraints. Constraints introduced:
1. seconds = <ss> (So, the allowed range for <ss> is [0, 59])
2. minutes = <mm> (So, the allowed range for <mm> is [0, 59])
3. hours = <hh> (So, the allowed range for <hh> is [0, 23])
<day-of-week> can be either '*' (without quotes or a number between 1(Monday) and 7(Sunday))
4. No constraint introduced when it is '*'. When not, day of week must equal the given value
<day-of-month> can be either '*' (without quotes or a number between 1 and 28)
5. No constraint introduced when it is '*'. When not, day of month must equal the given value

Returns:

  • (String)


102
103
104
# File 'lib/oci/data_safe/models/user_assessment.rb', line 102

def schedule
  @schedule
end

#schedule_assessment_idString

The OCID of the user assessment that is responsible for creating this scheduled save assessment.

Returns:

  • (String)


84
85
86
# File 'lib/oci/data_safe/models/user_assessment.rb', line 84

def schedule_assessment_id
  @schedule_assessment_id
end

#statisticsHash<String, Hash<String, Object>>

Map that contains maps of values.

Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

Returns:

  • (Hash<String, Hash<String, Object>>)


108
109
110
# File 'lib/oci/data_safe/models/user_assessment.rb', line 108

def statistics
  @statistics
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: ‘{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


155
156
157
# File 'lib/oci/data_safe/models/user_assessment.rb', line 155

def system_tags
  @system_tags
end

#target_idsArray<String>

Array of database target OCIDs.

Returns:

  • (Array<String>)


112
113
114
# File 'lib/oci/data_safe/models/user_assessment.rb', line 112

def target_ids
  @target_ids
end

#time_createdDateTime

[Required] The date and time the user assessment was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


116
117
118
# File 'lib/oci/data_safe/models/user_assessment.rb', line 116

def time_created
  @time_created
end

#time_updatedDateTime

[Required] The date and time the user assessment was last updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).

Returns:

  • (DateTime)


120
121
122
# File 'lib/oci/data_safe/models/user_assessment.rb', line 120

def time_updated
  @time_updated
end

#triggered_byString

Indicates whether the user assessment was created by system or user.

Returns:

  • (String)


124
125
126
# File 'lib/oci/data_safe/models/user_assessment.rb', line 124

def triggered_by
  @triggered_by
end

#typeString

[Required] Type of user assessment. Type can be:

LATEST: The most up-to-date assessment that is running automatically for a target. It is system generated. SAVED: A saved user assessment. LATEST assessments will always be saved to maintain the history of runs. A SAVED assessment is also generated by a ‘refresh’ action (triggered by the user). SAVE_SCHEDULE: A schedule to periodically save LATEST assessments. COMPARTMENT: An automatic managed assessment type that stores all details of targets in one compartment. This will keep an up-to-date status of all database risks in one compartment.

It is automatically updated once the latest assessment or refresh action is executed, as well as when a target is deleted or move to a different compartment.

Returns:

  • (String)


135
136
137
# File 'lib/oci/data_safe/models/user_assessment.rb', line 135

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/oci/data_safe/models/user_assessment.rb', line 158

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'description': :'description',
    'display_name': :'displayName',
    'id': :'id',
    'ignored_targets': :'ignoredTargets',
    'ignored_assessment_ids': :'ignoredAssessmentIds',
    'is_baseline': :'isBaseline',
    'is_deviated_from_baseline': :'isDeviatedFromBaseline',
    'last_compared_baseline_id': :'lastComparedBaselineId',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'schedule_assessment_id': :'scheduleAssessmentId',
    'schedule': :'schedule',
    'statistics': :'statistics',
    'target_ids': :'targetIds',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'triggered_by': :'triggeredBy',
    'type': :'type',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/oci/data_safe/models/user_assessment.rb', line 188

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'description': :'String',
    'display_name': :'String',
    'id': :'String',
    'ignored_targets': :'Array<Object>',
    'ignored_assessment_ids': :'Array<Object>',
    'is_baseline': :'BOOLEAN',
    'is_deviated_from_baseline': :'BOOLEAN',
    'last_compared_baseline_id': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'schedule_assessment_id': :'String',
    'schedule': :'String',
    'statistics': :'Hash<String, Hash<String, Object>>',
    'target_ids': :'Array<String>',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'triggered_by': :'String',
    'type': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/oci/data_safe/models/user_assessment.rb', line 410

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    description == other.description &&
    display_name == other.display_name &&
    id == other.id &&
    ignored_targets == other.ignored_targets &&
    ignored_assessment_ids == other.ignored_assessment_ids &&
    is_baseline == other.is_baseline &&
    is_deviated_from_baseline == other.is_deviated_from_baseline &&
    last_compared_baseline_id == other.last_compared_baseline_id &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    schedule_assessment_id == other.schedule_assessment_id &&
    schedule == other.schedule &&
    statistics == other.statistics &&
    target_ids == other.target_ids &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    triggered_by == other.triggered_by &&
    type == other.type &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/oci/data_safe/models/user_assessment.rb', line 461

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


441
442
443
# File 'lib/oci/data_safe/models/user_assessment.rb', line 441

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



450
451
452
# File 'lib/oci/data_safe/models/user_assessment.rb', line 450

def hash
  [compartment_id, description, display_name, id, ignored_targets, ignored_assessment_ids, is_baseline, is_deviated_from_baseline, last_compared_baseline_id, lifecycle_state, lifecycle_details, schedule_assessment_id, schedule, statistics, target_ids, time_created, time_updated, triggered_by, type, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



494
495
496
497
498
499
500
501
502
503
# File 'lib/oci/data_safe/models/user_assessment.rb', line 494

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



488
489
490
# File 'lib/oci/data_safe/models/user_assessment.rb', line 488

def to_s
  to_hash.to_s
end