Class: OCI::DataSafe::Models::UserAssessmentSummary
- Inherits:
-
Object
- Object
- OCI::DataSafe::Models::UserAssessmentSummary
- Defined in:
- lib/oci/data_safe/models/user_assessment_summary.rb
Overview
The summary of the user assessment.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TRIGGERED_BY_ENUM =
[ TRIGGERED_BY_USER = 'USER'.freeze, TRIGGERED_BY_SYSTEM = 'SYSTEM'.freeze, TRIGGERED_BY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TYPE_ENUM =
[ TYPE_LATEST = 'LATEST'.freeze, TYPE_SAVED = 'SAVED'.freeze, TYPE_SAVE_SCHEDULE = 'SAVE_SCHEDULE'.freeze, TYPE_COMPARTMENT = 'COMPARTMENT'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the user assessment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the user assessment.
-
#display_name ⇒ String
**[Required]** The display name of the user assessment.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the user assessment.
-
#ignored_assessment_ids ⇒ Array<Object>
List containing maps as values.
-
#ignored_targets ⇒ Array<Object>
List containing maps as values.
-
#is_baseline ⇒ BOOLEAN
Indicates if the assessment is a baseline assessment.
-
#is_deviated_from_baseline ⇒ BOOLEAN
Indicates if the assessment has deviated from the baseline.
-
#last_compared_baseline_id ⇒ String
The OCID of the last user assessment baseline against which the latest assessment was compared.
-
#lifecycle_details ⇒ String
Details about the current state of the user assessment.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the user assessment.
-
#schedule ⇒ String
Schedule to save the assessment periodically in the specified format: <version-string>;<version-specific-schedule>.
-
#schedule_assessment_id ⇒ String
The OCID of the user assessment that created this scheduled save assessment.
-
#statistics ⇒ Hash<String, Hash<String, Object>>
Map that contains maps of values.
-
#target_ids ⇒ Array<String>
Array of database target OCIDs.
-
#time_created ⇒ DateTime
**[Required]** The date and time when the user assessment was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
**[Required]** The last date and time when the user assessment was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#triggered_by ⇒ String
Indicates whether the user assessment was created by system or user.
-
#type ⇒ String
**[Required]** Type of user assessment.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserAssessmentSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UserAssessmentSummary
Initializes the object
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 237 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.ignored_targets = attributes[:'ignoredTargets'] if attributes[:'ignoredTargets'] raise 'You cannot provide both :ignoredTargets and :ignored_targets' if attributes.key?(:'ignoredTargets') && attributes.key?(:'ignored_targets') self.ignored_targets = attributes[:'ignored_targets'] if attributes[:'ignored_targets'] self.ignored_assessment_ids = attributes[:'ignoredAssessmentIds'] if attributes[:'ignoredAssessmentIds'] raise 'You cannot provide both :ignoredAssessmentIds and :ignored_assessment_ids' if attributes.key?(:'ignoredAssessmentIds') && attributes.key?(:'ignored_assessment_ids') self.ignored_assessment_ids = attributes[:'ignored_assessment_ids'] if attributes[:'ignored_assessment_ids'] self.is_baseline = attributes[:'isBaseline'] unless attributes[:'isBaseline'].nil? raise 'You cannot provide both :isBaseline and :is_baseline' if attributes.key?(:'isBaseline') && attributes.key?(:'is_baseline') self.is_baseline = attributes[:'is_baseline'] unless attributes[:'is_baseline'].nil? self.is_deviated_from_baseline = attributes[:'isDeviatedFromBaseline'] unless attributes[:'isDeviatedFromBaseline'].nil? raise 'You cannot provide both :isDeviatedFromBaseline and :is_deviated_from_baseline' if attributes.key?(:'isDeviatedFromBaseline') && attributes.key?(:'is_deviated_from_baseline') self.is_deviated_from_baseline = attributes[:'is_deviated_from_baseline'] unless attributes[:'is_deviated_from_baseline'].nil? self.last_compared_baseline_id = attributes[:'lastComparedBaselineId'] if attributes[:'lastComparedBaselineId'] raise 'You cannot provide both :lastComparedBaselineId and :last_compared_baseline_id' if attributes.key?(:'lastComparedBaselineId') && attributes.key?(:'last_compared_baseline_id') self.last_compared_baseline_id = attributes[:'last_compared_baseline_id'] if attributes[:'last_compared_baseline_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.schedule_assessment_id = attributes[:'scheduleAssessmentId'] if attributes[:'scheduleAssessmentId'] raise 'You cannot provide both :scheduleAssessmentId and :schedule_assessment_id' if attributes.key?(:'scheduleAssessmentId') && attributes.key?(:'schedule_assessment_id') self.schedule_assessment_id = attributes[:'schedule_assessment_id'] if attributes[:'schedule_assessment_id'] self.schedule = attributes[:'schedule'] if attributes[:'schedule'] self.statistics = attributes[:'statistics'] if attributes[:'statistics'] self.target_ids = attributes[:'targetIds'] if attributes[:'targetIds'] raise 'You cannot provide both :targetIds and :target_ids' if attributes.key?(:'targetIds') && attributes.key?(:'target_ids') self.target_ids = attributes[:'target_ids'] if attributes[:'target_ids'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.triggered_by = attributes[:'triggeredBy'] if attributes[:'triggeredBy'] raise 'You cannot provide both :triggeredBy and :triggered_by' if attributes.key?(:'triggeredBy') && attributes.key?(:'triggered_by') self.triggered_by = attributes[:'triggered_by'] if attributes[:'triggered_by'] self.type = attributes[:'type'] if attributes[:'type'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains the user assessment.
37 38 39 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 37 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: `{"CostCenter": "42"}`
150 151 152 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 150 def @defined_tags end |
#description ⇒ String
The description of the user assessment.
41 42 43 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 41 def description @description end |
#display_name ⇒ String
**[Required]** The display name of the user assessment.
45 46 47 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 45 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
Example: `"Finance"`
143 144 145 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 143 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the user assessment.
49 50 51 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 49 def id @id end |
#ignored_assessment_ids ⇒ Array<Object>
List containing maps as values. Example: `[ {"CostCenter": "42" ] }`
61 62 63 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 61 def ignored_assessment_ids @ignored_assessment_ids end |
#ignored_targets ⇒ Array<Object>
List containing maps as values. Example: `[ {"CostCenter": "42" ] }`
55 56 57 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 55 def ignored_targets @ignored_targets end |
#is_baseline ⇒ BOOLEAN
Indicates if the assessment is a baseline assessment. This applies to saved user assessments only.
65 66 67 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 65 def is_baseline @is_baseline end |
#is_deviated_from_baseline ⇒ BOOLEAN
Indicates if the assessment has deviated from the baseline.
69 70 71 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 69 def is_deviated_from_baseline @is_deviated_from_baseline end |
#last_compared_baseline_id ⇒ String
The OCID of the last user assessment baseline against which the latest assessment was compared.
73 74 75 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 73 def last_compared_baseline_id @last_compared_baseline_id end |
#lifecycle_details ⇒ String
Details about the current state of the user assessment.
81 82 83 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 81 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the user assessment.
77 78 79 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 77 def lifecycle_state @lifecycle_state end |
#schedule ⇒ String
Schedule to save the assessment periodically in the specified format: <version-string>;<version-specific-schedule>
Allowed version strings - "v1" v1's version specific schedule -<ss> <mm> <hh> <day-of-week> <day-of-month> Each of the above fields potentially introduce constraints. A workrequest is created only when clock time satisfies all the constraints. Constraints introduced:
-
seconds = <ss> (So, the allowed range for <ss> is [0, 59])
-
minutes = <mm> (So, the allowed range for <mm> is [0, 59])
-
hours = <hh> (So, the allowed range for <hh> is [0, 23])
<day-of-week> can be either '*' (without quotes or a number between 1(Monday) and 7(Sunday))
-
No constraint introduced when it is '*'. When not, day of week must equal the given value
<day-of-month> can be either '*' (without quotes or a number between 1 and 28)
-
No constraint introduced when it is '*'. When not, day of month must equal the given value
103 104 105 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 103 def schedule @schedule end |
#schedule_assessment_id ⇒ String
The OCID of the user assessment that created this scheduled save assessment.
85 86 87 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 85 def schedule_assessment_id @schedule_assessment_id end |
#statistics ⇒ Hash<String, Hash<String, Object>>
Map that contains maps of values.
Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`
109 110 111 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 109 def statistics @statistics end |
#target_ids ⇒ Array<String>
Array of database target OCIDs.
113 114 115 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 113 def target_ids @target_ids end |
#time_created ⇒ DateTime
**[Required]** The date and time when the user assessment was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
117 118 119 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 117 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The last date and time when the user assessment was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
121 122 123 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 121 def time_updated @time_updated end |
#triggered_by ⇒ String
Indicates whether the user assessment was created by system or user.
125 126 127 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 125 def triggered_by @triggered_by end |
#type ⇒ String
**[Required]** Type of user assessment. The possible types are:
LATEST: The most up-to-date assessment that is running automatically for a target. It is system generated. SAVED: A saved user assessment. LATEST assessments are always saved to maintain the history of runs. A SAVED assessment is also generated by a 'refresh' action (triggered by the user). SAVE_SCHEDULE: The schedule for periodic save of LATEST assessments. COMPARTMENT: An automatic managed assessment type that stores all details of targets in one compartment. This type keeps an up-to-date status of all database risks in one compartment.
It is automatically updated when the latest assessment or refresh action is executed. It is also automatically updated when a target is deleted or move to a different compartment.
136 137 138 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 136 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 153 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'description': :'description', 'display_name': :'displayName', 'id': :'id', 'ignored_targets': :'ignoredTargets', 'ignored_assessment_ids': :'ignoredAssessmentIds', 'is_baseline': :'isBaseline', 'is_deviated_from_baseline': :'isDeviatedFromBaseline', 'last_compared_baseline_id': :'lastComparedBaselineId', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'schedule_assessment_id': :'scheduleAssessmentId', 'schedule': :'schedule', 'statistics': :'statistics', 'target_ids': :'targetIds', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'triggered_by': :'triggeredBy', 'type': :'type', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 182 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'description': :'String', 'display_name': :'String', 'id': :'String', 'ignored_targets': :'Array<Object>', 'ignored_assessment_ids': :'Array<Object>', 'is_baseline': :'BOOLEAN', 'is_deviated_from_baseline': :'BOOLEAN', 'last_compared_baseline_id': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'schedule_assessment_id': :'String', 'schedule': :'String', 'statistics': :'Hash<String, Hash<String, Object>>', 'target_ids': :'Array<String>', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'triggered_by': :'String', 'type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 396 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && description == other.description && display_name == other.display_name && id == other.id && ignored_targets == other.ignored_targets && ignored_assessment_ids == other.ignored_assessment_ids && is_baseline == other.is_baseline && is_deviated_from_baseline == other.is_deviated_from_baseline && last_compared_baseline_id == other.last_compared_baseline_id && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && schedule_assessment_id == other.schedule_assessment_id && schedule == other.schedule && statistics == other.statistics && target_ids == other.target_ids && time_created == other.time_created && time_updated == other.time_updated && triggered_by == other.triggered_by && type == other.type && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 446 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
426 427 428 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 426 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
435 436 437 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 435 def hash [compartment_id, description, display_name, id, ignored_targets, ignored_assessment_ids, is_baseline, is_deviated_from_baseline, last_compared_baseline_id, lifecycle_state, lifecycle_details, schedule_assessment_id, schedule, statistics, target_ids, time_created, time_updated, triggered_by, type, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
479 480 481 482 483 484 485 486 487 488 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 479 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
473 474 475 |
# File 'lib/oci/data_safe/models/user_assessment_summary.rb', line 473 def to_s to_hash.to_s end |