Class: OCI::DataScience::Models::JobRun
- Inherits:
-
Object
- Object
- OCI::DataScience::Models::JobRun
- Defined in:
- lib/oci/data_science/models/job_run.rb
Overview
A job run.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the job.
-
#created_by ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the job run.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the job run.
-
#job_configuration_override_details ⇒ OCI::DataScience::Models::JobConfigurationDetails
This attribute is required.
-
#job_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the job run.
-
#job_infrastructure_configuration_details ⇒ OCI::DataScience::Models::JobInfrastructureConfigurationDetails
This attribute is required.
- #job_log_configuration_override_details ⇒ OCI::DataScience::Models::JobLogConfigurationDetails
-
#lifecycle_details ⇒ String
Details of the state of the job run.
-
#lifecycle_state ⇒ String
[Required] The state of the job run.
- #log_details ⇒ OCI::DataScience::Models::JobRunLogDetails
-
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate the job with.
-
#time_accepted ⇒ DateTime
[Required] The date and time the job run was accepted in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_finished ⇒ DateTime
The date and time the job run request was finished in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_started ⇒ DateTime
The date and time the job run request was started in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JobRun
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ JobRun
Initializes the object
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/data_science/models/job_run.rb', line 166 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] self.created_by = attributes[:'createdBy'] if attributes[:'createdBy'] raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] if attributes[:'created_by'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.job_id = attributes[:'jobId'] if attributes[:'jobId'] raise 'You cannot provide both :jobId and :job_id' if attributes.key?(:'jobId') && attributes.key?(:'job_id') self.job_id = attributes[:'job_id'] if attributes[:'job_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.job_configuration_override_details = attributes[:'jobConfigurationOverrideDetails'] if attributes[:'jobConfigurationOverrideDetails'] raise 'You cannot provide both :jobConfigurationOverrideDetails and :job_configuration_override_details' if attributes.key?(:'jobConfigurationOverrideDetails') && attributes.key?(:'job_configuration_override_details') self.job_configuration_override_details = attributes[:'job_configuration_override_details'] if attributes[:'job_configuration_override_details'] self.job_infrastructure_configuration_details = attributes[:'jobInfrastructureConfigurationDetails'] if attributes[:'jobInfrastructureConfigurationDetails'] raise 'You cannot provide both :jobInfrastructureConfigurationDetails and :job_infrastructure_configuration_details' if attributes.key?(:'jobInfrastructureConfigurationDetails') && attributes.key?(:'job_infrastructure_configuration_details') self.job_infrastructure_configuration_details = attributes[:'job_infrastructure_configuration_details'] if attributes[:'job_infrastructure_configuration_details'] self.job_log_configuration_override_details = attributes[:'jobLogConfigurationOverrideDetails'] if attributes[:'jobLogConfigurationOverrideDetails'] raise 'You cannot provide both :jobLogConfigurationOverrideDetails and :job_log_configuration_override_details' if attributes.key?(:'jobLogConfigurationOverrideDetails') && attributes.key?(:'job_log_configuration_override_details') self.job_log_configuration_override_details = attributes[:'job_log_configuration_override_details'] if attributes[:'job_log_configuration_override_details'] self.log_details = attributes[:'logDetails'] if attributes[:'logDetails'] raise 'You cannot provide both :logDetails and :log_details' if attributes.key?(:'logDetails') && attributes.key?(:'log_details') self.log_details = attributes[:'log_details'] if attributes[:'log_details'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the job.
49 50 51 |
# File 'lib/oci/data_science/models/job_run.rb', line 49 def compartment_id @compartment_id end |
#created_by ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the job run.
41 42 43 |
# File 'lib/oci/data_science/models/job_run.rb', line 41 def created_by @created_by end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
91 92 93 |
# File 'lib/oci/data_science/models/job_run.rb', line 91 def end |
#display_name ⇒ String
A user-friendly display name for the resource.
57 58 59 |
# File 'lib/oci/data_science/models/job_run.rb', line 57 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
85 86 87 |
# File 'lib/oci/data_science/models/job_run.rb', line 85 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the job run.
25 26 27 |
# File 'lib/oci/data_science/models/job_run.rb', line 25 def id @id end |
#job_configuration_override_details ⇒ OCI::DataScience::Models::JobConfigurationDetails
This attribute is required.
61 62 63 |
# File 'lib/oci/data_science/models/job_run.rb', line 61 def job_configuration_override_details @job_configuration_override_details end |
#job_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the job run.
53 54 55 |
# File 'lib/oci/data_science/models/job_run.rb', line 53 def job_id @job_id end |
#job_infrastructure_configuration_details ⇒ OCI::DataScience::Models::JobInfrastructureConfigurationDetails
This attribute is required.
65 66 67 |
# File 'lib/oci/data_science/models/job_run.rb', line 65 def job_infrastructure_configuration_details @job_infrastructure_configuration_details end |
#job_log_configuration_override_details ⇒ OCI::DataScience::Models::JobLogConfigurationDetails
68 69 70 |
# File 'lib/oci/data_science/models/job_run.rb', line 68 def job_log_configuration_override_details @job_log_configuration_override_details end |
#lifecycle_details ⇒ String
Details of the state of the job run.
79 80 81 |
# File 'lib/oci/data_science/models/job_run.rb', line 79 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The state of the job run.
75 76 77 |
# File 'lib/oci/data_science/models/job_run.rb', line 75 def lifecycle_state @lifecycle_state end |
#log_details ⇒ OCI::DataScience::Models::JobRunLogDetails
71 72 73 |
# File 'lib/oci/data_science/models/job_run.rb', line 71 def log_details @log_details end |
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project to associate the job with.
45 46 47 |
# File 'lib/oci/data_science/models/job_run.rb', line 45 def project_id @project_id end |
#time_accepted ⇒ DateTime
[Required] The date and time the job run was accepted in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
29 30 31 |
# File 'lib/oci/data_science/models/job_run.rb', line 29 def time_accepted @time_accepted end |
#time_finished ⇒ DateTime
The date and time the job run request was finished in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
37 38 39 |
# File 'lib/oci/data_science/models/job_run.rb', line 37 def time_finished @time_finished end |
#time_started ⇒ DateTime
The date and time the job run request was started in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
33 34 35 |
# File 'lib/oci/data_science/models/job_run.rb', line 33 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/data_science/models/job_run.rb', line 94 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'time_accepted': :'timeAccepted', 'time_started': :'timeStarted', 'time_finished': :'timeFinished', 'created_by': :'createdBy', 'project_id': :'projectId', 'compartment_id': :'compartmentId', 'job_id': :'jobId', 'display_name': :'displayName', 'job_configuration_override_details': :'jobConfigurationOverrideDetails', 'job_infrastructure_configuration_details': :'jobInfrastructureConfigurationDetails', 'job_log_configuration_override_details': :'jobLogConfigurationOverrideDetails', 'log_details': :'logDetails', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/data_science/models/job_run.rb', line 119 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'time_accepted': :'DateTime', 'time_started': :'DateTime', 'time_finished': :'DateTime', 'created_by': :'String', 'project_id': :'String', 'compartment_id': :'String', 'job_id': :'String', 'display_name': :'String', 'job_configuration_override_details': :'OCI::DataScience::Models::JobConfigurationDetails', 'job_infrastructure_configuration_details': :'OCI::DataScience::Models::JobInfrastructureConfigurationDetails', 'job_log_configuration_override_details': :'OCI::DataScience::Models::JobLogConfigurationDetails', 'log_details': :'OCI::DataScience::Models::JobRunLogDetails', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/oci/data_science/models/job_run.rb', line 291 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && time_accepted == other.time_accepted && time_started == other.time_started && time_finished == other.time_finished && created_by == other.created_by && project_id == other.project_id && compartment_id == other.compartment_id && job_id == other.job_id && display_name == other.display_name && job_configuration_override_details == other.job_configuration_override_details && job_infrastructure_configuration_details == other.job_infrastructure_configuration_details && job_log_configuration_override_details == other.job_log_configuration_override_details && log_details == other.log_details && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/oci/data_science/models/job_run.rb', line 337 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
317 318 319 |
# File 'lib/oci/data_science/models/job_run.rb', line 317 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
326 327 328 |
# File 'lib/oci/data_science/models/job_run.rb', line 326 def hash [id, time_accepted, time_started, time_finished, created_by, project_id, compartment_id, job_id, display_name, job_configuration_override_details, job_infrastructure_configuration_details, job_log_configuration_override_details, log_details, lifecycle_state, lifecycle_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
370 371 372 373 374 375 376 377 378 379 |
# File 'lib/oci/data_science/models/job_run.rb', line 370 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
364 365 366 |
# File 'lib/oci/data_science/models/job_run.rb', line 364 def to_s to_hash.to_s end |