Class: OCI::DataScience::Models::Model
- Inherits:
-
Object
- Object
- OCI::DataScience::Models::Model
- Defined in:
- lib/oci/data_science/models/model.rb
Overview
Models are mathematical representations of the relationships between data. Models are represented by their associated metadata and artifacts.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model’s compartment.
-
#created_by ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the model.
-
#custom_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of custom metadata details for the model.
-
#defined_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of defined metadata details for the model.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A short description of the model.
-
#display_name ⇒ String
[Required] A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
-
#input_schema ⇒ String
Input schema file content in String format.
-
#lifecycle_state ⇒ String
[Required] The state of the model.
-
#output_schema ⇒ String
Output schema file content in String format.
-
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project associated with the model.
-
#time_created ⇒ DateTime
[Required] The date and time the resource was created in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Model
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Model
Initializes the object
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/data_science/models/model.rb', line 145 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.created_by = attributes[:'createdBy'] if attributes[:'createdBy'] raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] if attributes[:'created_by'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'customMetadataList'] if attributes[:'customMetadataList'] raise 'You cannot provide both :customMetadataList and :custom_metadata_list' if attributes.key?(:'customMetadataList') && attributes.key?(:'custom_metadata_list') self. = attributes[:'custom_metadata_list'] if attributes[:'custom_metadata_list'] self. = attributes[:'definedMetadataList'] if attributes[:'definedMetadataList'] raise 'You cannot provide both :definedMetadataList and :defined_metadata_list' if attributes.key?(:'definedMetadataList') && attributes.key?(:'defined_metadata_list') self. = attributes[:'defined_metadata_list'] if attributes[:'defined_metadata_list'] self.input_schema = attributes[:'inputSchema'] if attributes[:'inputSchema'] raise 'You cannot provide both :inputSchema and :input_schema' if attributes.key?(:'inputSchema') && attributes.key?(:'input_schema') self.input_schema = attributes[:'input_schema'] if attributes[:'input_schema'] self.output_schema = attributes[:'outputSchema'] if attributes[:'outputSchema'] raise 'You cannot provide both :outputSchema and :output_schema' if attributes.key?(:'outputSchema') && attributes.key?(:'output_schema') self.output_schema = attributes[:'output_schema'] if attributes[:'output_schema'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model’s compartment.
25 26 27 |
# File 'lib/oci/data_science/models/model.rb', line 25 def compartment_id @compartment_id end |
#created_by ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the model.
51 52 53 |
# File 'lib/oci/data_science/models/model.rb', line 51 def created_by @created_by end |
#custom_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of custom metadata details for the model.
67 68 69 |
# File 'lib/oci/data_science/models/model.rb', line 67 def end |
#defined_metadata_list ⇒ Array<OCI::DataScience::Models::Metadata>
An array of defined metadata details for the model.
71 72 73 |
# File 'lib/oci/data_science/models/model.rb', line 71 def end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
63 64 65 |
# File 'lib/oci/data_science/models/model.rb', line 63 def end |
#description ⇒ String
A short description of the model.
37 38 39 |
# File 'lib/oci/data_science/models/model.rb', line 37 def description @description end |
#display_name ⇒ String
[Required] A user-friendly display name for the resource. It does not have to be unique and can be modified. Avoid entering confidential information.
33 34 35 |
# File 'lib/oci/data_science/models/model.rb', line 33 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
57 58 59 |
# File 'lib/oci/data_science/models/model.rb', line 57 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model.
21 22 23 |
# File 'lib/oci/data_science/models/model.rb', line 21 def id @id end |
#input_schema ⇒ String
Input schema file content in String format
75 76 77 |
# File 'lib/oci/data_science/models/model.rb', line 75 def input_schema @input_schema end |
#lifecycle_state ⇒ String
[Required] The state of the model.
41 42 43 |
# File 'lib/oci/data_science/models/model.rb', line 41 def lifecycle_state @lifecycle_state end |
#output_schema ⇒ String
Output schema file content in String format
79 80 81 |
# File 'lib/oci/data_science/models/model.rb', line 79 def output_schema @output_schema end |
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project associated with the model.
29 30 31 |
# File 'lib/oci/data_science/models/model.rb', line 29 def project_id @project_id end |
#time_created ⇒ DateTime
[Required] The date and time the resource was created in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-08-25T21:10:29.41Z
47 48 49 |
# File 'lib/oci/data_science/models/model.rb', line 47 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/data_science/models/model.rb', line 82 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'project_id': :'projectId', 'display_name': :'displayName', 'description': :'description', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'created_by': :'createdBy', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'custom_metadata_list': :'customMetadataList', 'defined_metadata_list': :'definedMetadataList', 'input_schema': :'inputSchema', 'output_schema': :'outputSchema' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/data_science/models/model.rb', line 104 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'project_id': :'String', 'display_name': :'String', 'description': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'created_by': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'custom_metadata_list': :'Array<OCI::DataScience::Models::Metadata>', 'defined_metadata_list': :'Array<OCI::DataScience::Models::Metadata>', 'input_schema': :'String', 'output_schema': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/data_science/models/model.rb', line 248 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && project_id == other.project_id && display_name == other.display_name && description == other.description && lifecycle_state == other.lifecycle_state && time_created == other.time_created && created_by == other.created_by && == other. && == other. && == other. && == other. && input_schema == other.input_schema && output_schema == other.output_schema end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/oci/data_science/models/model.rb', line 291 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
271 272 273 |
# File 'lib/oci/data_science/models/model.rb', line 271 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
280 281 282 |
# File 'lib/oci/data_science/models/model.rb', line 280 def hash [id, compartment_id, project_id, display_name, description, lifecycle_state, time_created, created_by, , , , , input_schema, output_schema].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
324 325 326 327 328 329 330 331 332 333 |
# File 'lib/oci/data_science/models/model.rb', line 324 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
318 319 320 |
# File 'lib/oci/data_science/models/model.rb', line 318 def to_s to_hash.to_s end |