Class: OCI::DataScience::Models::ModelDeploymentSummary
- Inherits:
-
Object
- Object
- OCI::DataScience::Models::ModelDeploymentSummary
- Defined in:
- lib/oci/data_science/models/model_deployment_summary.rb
Overview
Summary information for a model deployment.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #category_log_details ⇒ OCI::DataScience::Models::CategoryLogDetails
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model deployment’s compartment.
-
#created_by ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the model deployment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A short description of the model deployment.
-
#display_name ⇒ String
[Required] A user-friendly display name for the resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model deployment.
-
#lifecycle_state ⇒ String
[Required] The state of the model deployment.
- #model_deployment_configuration_details ⇒ OCI::DataScience::Models::ModelDeploymentConfigurationDetails
-
#model_deployment_url ⇒ String
[Required] The URL to interact with the model deployment.
-
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project associated with the model deployment.
-
#time_created ⇒ DateTime
[Required] The date and time the resource was created, in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelDeploymentSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ModelDeploymentSummary
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 142 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.created_by = attributes[:'createdBy'] if attributes[:'createdBy'] raise 'You cannot provide both :createdBy and :created_by' if attributes.key?(:'createdBy') && attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] if attributes[:'created_by'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.model_deployment_configuration_details = attributes[:'modelDeploymentConfigurationDetails'] if attributes[:'modelDeploymentConfigurationDetails'] raise 'You cannot provide both :modelDeploymentConfigurationDetails and :model_deployment_configuration_details' if attributes.key?(:'modelDeploymentConfigurationDetails') && attributes.key?(:'model_deployment_configuration_details') self.model_deployment_configuration_details = attributes[:'model_deployment_configuration_details'] if attributes[:'model_deployment_configuration_details'] self.category_log_details = attributes[:'categoryLogDetails'] if attributes[:'categoryLogDetails'] raise 'You cannot provide both :categoryLogDetails and :category_log_details' if attributes.key?(:'categoryLogDetails') && attributes.key?(:'category_log_details') self.category_log_details = attributes[:'category_log_details'] if attributes[:'category_log_details'] self.model_deployment_url = attributes[:'modelDeploymentUrl'] if attributes[:'modelDeploymentUrl'] raise 'You cannot provide both :modelDeploymentUrl and :model_deployment_url' if attributes.key?(:'modelDeploymentUrl') && attributes.key?(:'model_deployment_url') self.model_deployment_url = attributes[:'model_deployment_url'] if attributes[:'model_deployment_url'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#category_log_details ⇒ OCI::DataScience::Models::CategoryLogDetails
59 60 61 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 59 def category_log_details @category_log_details end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model deployment’s compartment.
53 54 55 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 53 def compartment_id @compartment_id end |
#created_by ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the model deployment.
49 50 51 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 49 def created_by @created_by end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
79 80 81 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 79 def @defined_tags end |
#description ⇒ String
A short description of the model deployment.
41 42 43 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 41 def description @description end |
#display_name ⇒ String
[Required] A user-friendly display name for the resource. Does not have to be unique, and can be modified. Avoid entering confidential information. Example: ‘My ModelDeployment`
37 38 39 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 37 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
73 74 75 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 73 def @freeform_tags end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the model deployment.
25 26 27 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 25 def id @id end |
#lifecycle_state ⇒ String
[Required] The state of the model deployment.
67 68 69 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 67 def lifecycle_state @lifecycle_state end |
#model_deployment_configuration_details ⇒ OCI::DataScience::Models::ModelDeploymentConfigurationDetails
56 57 58 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 56 def model_deployment_configuration_details @model_deployment_configuration_details end |
#model_deployment_url ⇒ String
[Required] The URL to interact with the model deployment.
63 64 65 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 63 def model_deployment_url @model_deployment_url end |
#project_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project associated with the model deployment.
45 46 47 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 45 def project_id @project_id end |
#time_created ⇒ DateTime
[Required] The date and time the resource was created, in the timestamp format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2019-08-25T21:10:29.41Z
31 32 33 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 31 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 82 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'time_created': :'timeCreated', 'display_name': :'displayName', 'description': :'description', 'project_id': :'projectId', 'created_by': :'createdBy', 'compartment_id': :'compartmentId', 'model_deployment_configuration_details': :'modelDeploymentConfigurationDetails', 'category_log_details': :'categoryLogDetails', 'model_deployment_url': :'modelDeploymentUrl', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 103 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'time_created': :'DateTime', 'display_name': :'String', 'description': :'String', 'project_id': :'String', 'created_by': :'String', 'compartment_id': :'String', 'model_deployment_configuration_details': :'OCI::DataScience::Models::ModelDeploymentConfigurationDetails', 'category_log_details': :'OCI::DataScience::Models::CategoryLogDetails', 'model_deployment_url': :'String', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 239 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && time_created == other.time_created && display_name == other.display_name && description == other.description && project_id == other.project_id && created_by == other.created_by && compartment_id == other.compartment_id && model_deployment_configuration_details == other.model_deployment_configuration_details && category_log_details == other.category_log_details && model_deployment_url == other.model_deployment_url && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 281 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
261 262 263 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 261 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
270 271 272 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 270 def hash [id, time_created, display_name, description, project_id, created_by, compartment_id, model_deployment_configuration_details, category_log_details, model_deployment_url, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
314 315 316 317 318 319 320 321 322 323 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 314 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
308 309 310 |
# File 'lib/oci/data_science/models/model_deployment_summary.rb', line 308 def to_s to_hash.to_s end |