Class: OCI::Database::Models::AutonomousContainerDatabase
- Inherits:
-
Object
- Object
- OCI::Database::Models::AutonomousContainerDatabase
- Defined in:
- lib/oci/database/models/autonomous_container_database.rb
Overview
AutonomousContainerDatabase model.
Constant Summary collapse
- SERVICE_LEVEL_AGREEMENT_TYPE_ENUM =
[ SERVICE_LEVEL_AGREEMENT_TYPE_STANDARD = 'STANDARD'.freeze, SERVICE_LEVEL_AGREEMENT_TYPE_MISSION_CRITICAL = 'MISSION_CRITICAL'.freeze, SERVICE_LEVEL_AGREEMENT_TYPE_AUTONOMOUS_DATAGUARD = 'AUTONOMOUS_DATAGUARD'.freeze, SERVICE_LEVEL_AGREEMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- INFRASTRUCTURE_TYPE_ENUM =
[ INFRASTRUCTURE_TYPE_CLOUD = 'CLOUD'.freeze, INFRASTRUCTURE_TYPE_CLOUD_AT_CUSTOMER = 'CLOUD_AT_CUSTOMER'.freeze, INFRASTRUCTURE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze, LIFECYCLE_STATE_RESTORING = 'RESTORING'.freeze, LIFECYCLE_STATE_RESTORE_FAILED = 'RESTORE_FAILED'.freeze, LIFECYCLE_STATE_RESTARTING = 'RESTARTING'.freeze, LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_ROLE_CHANGE_IN_PROGRESS = 'ROLE_CHANGE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_UNAVAILABLE = 'UNAVAILABLE'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- PATCH_MODEL_ENUM =
[ PATCH_MODEL_RELEASE_UPDATES = 'RELEASE_UPDATES'.freeze, PATCH_MODEL_RELEASE_UPDATE_REVISIONS = 'RELEASE_UPDATE_REVISIONS'.freeze, PATCH_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ROLE_ENUM =
[ ROLE_PRIMARY = 'PRIMARY'.freeze, ROLE_STANDBY = 'STANDBY'.freeze, ROLE_DISABLED_STANDBY = 'DISABLED_STANDBY'.freeze, ROLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#autonomous_exadata_infrastructure_id ⇒ String
The OCID of the Autonomous Exadata Infrastructure.
-
#autonomous_vm_cluster_id ⇒ String
The OCID of the Autonomous VM Cluster.
-
#availability_domain ⇒ String
The availability domain of the Autonomous Container Database.
- #backup_config ⇒ OCI::Database::Models::AutonomousContainerDatabaseBackupConfig
-
#cloud_autonomous_vm_cluster_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Autonomous Exadata VM Cluster.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment.
-
#db_unique_name ⇒ String
Deprecated. The
DB_UNIQUE_NAMEvalue is set by Oracle Cloud Infrastructure. -
#db_version ⇒ String
Oracle Database version of the Autonomous Container Database.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-provided name for the Autonomous Container Database.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the Autonomous Container Database.
-
#infrastructure_type ⇒ String
The infrastructure type this resource belongs to.
-
#key_history_entry ⇒ Array<OCI::Database::Models::AutonomousDatabaseKeyHistoryEntry>
Key History Entry.
-
#key_store_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the key store.
-
#key_store_wallet_name ⇒ String
The wallet name for Oracle Key Vault.
-
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
-
#kms_key_version_id ⇒ String
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions.
-
#last_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the Autonomous Container Database.
- #maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
-
#next_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.
-
#patch_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last patch applied on the system.
-
#patch_model ⇒ String
[Required] Database patch model preference.
-
#role ⇒ String
The role of the Autonomous Data Guard-enabled Autonomous Container Database.
-
#service_level_agreement_type ⇒ String
[Required] The service level agreement type of the container database.
-
#standby_maintenance_buffer_in_days ⇒ Integer
The scheduling detail for the quarterly maintenance window of the standby Autonomous Container Database.
-
#time_created ⇒ DateTime
The date and time the Autonomous Container Database was created.
-
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutonomousContainerDatabase
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutonomousContainerDatabase
Initializes the object
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 294 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.db_unique_name = attributes[:'dbUniqueName'] if attributes[:'dbUniqueName'] raise 'You cannot provide both :dbUniqueName and :db_unique_name' if attributes.key?(:'dbUniqueName') && attributes.key?(:'db_unique_name') self.db_unique_name = attributes[:'db_unique_name'] if attributes[:'db_unique_name'] self.service_level_agreement_type = attributes[:'serviceLevelAgreementType'] if attributes[:'serviceLevelAgreementType'] raise 'You cannot provide both :serviceLevelAgreementType and :service_level_agreement_type' if attributes.key?(:'serviceLevelAgreementType') && attributes.key?(:'service_level_agreement_type') self.service_level_agreement_type = attributes[:'service_level_agreement_type'] if attributes[:'service_level_agreement_type'] self.autonomous_exadata_infrastructure_id = attributes[:'autonomousExadataInfrastructureId'] if attributes[:'autonomousExadataInfrastructureId'] raise 'You cannot provide both :autonomousExadataInfrastructureId and :autonomous_exadata_infrastructure_id' if attributes.key?(:'autonomousExadataInfrastructureId') && attributes.key?(:'autonomous_exadata_infrastructure_id') self.autonomous_exadata_infrastructure_id = attributes[:'autonomous_exadata_infrastructure_id'] if attributes[:'autonomous_exadata_infrastructure_id'] self.autonomous_vm_cluster_id = attributes[:'autonomousVmClusterId'] if attributes[:'autonomousVmClusterId'] raise 'You cannot provide both :autonomousVmClusterId and :autonomous_vm_cluster_id' if attributes.key?(:'autonomousVmClusterId') && attributes.key?(:'autonomous_vm_cluster_id') self.autonomous_vm_cluster_id = attributes[:'autonomous_vm_cluster_id'] if attributes[:'autonomous_vm_cluster_id'] self.infrastructure_type = attributes[:'infrastructureType'] if attributes[:'infrastructureType'] raise 'You cannot provide both :infrastructureType and :infrastructure_type' if attributes.key?(:'infrastructureType') && attributes.key?(:'infrastructure_type') self.infrastructure_type = attributes[:'infrastructure_type'] if attributes[:'infrastructure_type'] self.cloud_autonomous_vm_cluster_id = attributes[:'cloudAutonomousVmClusterId'] if attributes[:'cloudAutonomousVmClusterId'] raise 'You cannot provide both :cloudAutonomousVmClusterId and :cloud_autonomous_vm_cluster_id' if attributes.key?(:'cloudAutonomousVmClusterId') && attributes.key?(:'cloud_autonomous_vm_cluster_id') self.cloud_autonomous_vm_cluster_id = attributes[:'cloud_autonomous_vm_cluster_id'] if attributes[:'cloud_autonomous_vm_cluster_id'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId'] raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id') self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id'] self.kms_key_version_id = attributes[:'kmsKeyVersionId'] if attributes[:'kmsKeyVersionId'] raise 'You cannot provide both :kmsKeyVersionId and :kms_key_version_id' if attributes.key?(:'kmsKeyVersionId') && attributes.key?(:'kms_key_version_id') self.kms_key_version_id = attributes[:'kms_key_version_id'] if attributes[:'kms_key_version_id'] self.key_history_entry = attributes[:'keyHistoryEntry'] if attributes[:'keyHistoryEntry'] raise 'You cannot provide both :keyHistoryEntry and :key_history_entry' if attributes.key?(:'keyHistoryEntry') && attributes.key?(:'key_history_entry') self.key_history_entry = attributes[:'key_history_entry'] if attributes[:'key_history_entry'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.patch_model = attributes[:'patchModel'] if attributes[:'patchModel'] raise 'You cannot provide both :patchModel and :patch_model' if attributes.key?(:'patchModel') && attributes.key?(:'patch_model') self.patch_model = attributes[:'patch_model'] if attributes[:'patch_model'] self.patch_id = attributes[:'patchId'] if attributes[:'patchId'] raise 'You cannot provide both :patchId and :patch_id' if attributes.key?(:'patchId') && attributes.key?(:'patch_id') self.patch_id = attributes[:'patch_id'] if attributes[:'patch_id'] self.last_maintenance_run_id = attributes[:'lastMaintenanceRunId'] if attributes[:'lastMaintenanceRunId'] raise 'You cannot provide both :lastMaintenanceRunId and :last_maintenance_run_id' if attributes.key?(:'lastMaintenanceRunId') && attributes.key?(:'last_maintenance_run_id') self.last_maintenance_run_id = attributes[:'last_maintenance_run_id'] if attributes[:'last_maintenance_run_id'] self.next_maintenance_run_id = attributes[:'nextMaintenanceRunId'] if attributes[:'nextMaintenanceRunId'] raise 'You cannot provide both :nextMaintenanceRunId and :next_maintenance_run_id' if attributes.key?(:'nextMaintenanceRunId') && attributes.key?(:'next_maintenance_run_id') self.next_maintenance_run_id = attributes[:'next_maintenance_run_id'] if attributes[:'next_maintenance_run_id'] self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow'] raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window') self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window'] self.standby_maintenance_buffer_in_days = attributes[:'standbyMaintenanceBufferInDays'] if attributes[:'standbyMaintenanceBufferInDays'] raise 'You cannot provide both :standbyMaintenanceBufferInDays and :standby_maintenance_buffer_in_days' if attributes.key?(:'standbyMaintenanceBufferInDays') && attributes.key?(:'standby_maintenance_buffer_in_days') self.standby_maintenance_buffer_in_days = attributes[:'standby_maintenance_buffer_in_days'] if attributes[:'standby_maintenance_buffer_in_days'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.role = attributes[:'role'] if attributes[:'role'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.db_version = attributes[:'dbVersion'] if attributes[:'dbVersion'] raise 'You cannot provide both :dbVersion and :db_version' if attributes.key?(:'dbVersion') && attributes.key?(:'db_version') self.db_version = attributes[:'db_version'] if attributes[:'db_version'] self.backup_config = attributes[:'backupConfig'] if attributes[:'backupConfig'] raise 'You cannot provide both :backupConfig and :backup_config' if attributes.key?(:'backupConfig') && attributes.key?(:'backup_config') self.backup_config = attributes[:'backup_config'] if attributes[:'backup_config'] self.key_store_id = attributes[:'keyStoreId'] if attributes[:'keyStoreId'] raise 'You cannot provide both :keyStoreId and :key_store_id' if attributes.key?(:'keyStoreId') && attributes.key?(:'key_store_id') self.key_store_id = attributes[:'key_store_id'] if attributes[:'key_store_id'] self.key_store_wallet_name = attributes[:'keyStoreWalletName'] if attributes[:'keyStoreWalletName'] raise 'You cannot provide both :keyStoreWalletName and :key_store_wallet_name' if attributes.key?(:'keyStoreWalletName') && attributes.key?(:'key_store_wallet_name') self.key_store_wallet_name = attributes[:'key_store_wallet_name'] if attributes[:'key_store_wallet_name'] end |
Instance Attribute Details
#autonomous_exadata_infrastructure_id ⇒ String
The OCID of the Autonomous Exadata Infrastructure.
77 78 79 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 77 def autonomous_exadata_infrastructure_id @autonomous_exadata_infrastructure_id end |
#autonomous_vm_cluster_id ⇒ String
The OCID of the Autonomous VM Cluster.
81 82 83 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 81 def autonomous_vm_cluster_id @autonomous_vm_cluster_id end |
#availability_domain ⇒ String
The availability domain of the Autonomous Container Database.
165 166 167 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 165 def availability_domain @availability_domain end |
#backup_config ⇒ OCI::Database::Models::AutonomousContainerDatabaseBackupConfig
172 173 174 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 172 def backup_config @backup_config end |
#cloud_autonomous_vm_cluster_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Autonomous Exadata VM Cluster.
89 90 91 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 89 def cloud_autonomous_vm_cluster_id @cloud_autonomous_vm_cluster_id end |
#compartment_id ⇒ String
[Required] The OCID of the compartment.
60 61 62 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 60 def compartment_id @compartment_id end |
#db_unique_name ⇒ String
Deprecated. The DB_UNIQUE_NAME value is set by Oracle Cloud Infrastructure. Do not specify a value for this parameter. Specifying a value for this field will cause Terraform operations to fail.
69 70 71 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 69 def db_unique_name @db_unique_name end |
#db_version ⇒ String
Oracle Database version of the Autonomous Container Database.
169 170 171 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 169 def db_version @db_version end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
157 158 159 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 157 def end |
#display_name ⇒ String
[Required] The user-provided name for the Autonomous Container Database.
64 65 66 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 64 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
151 152 153 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 151 def end |
#id ⇒ String
[Required] The OCID of the Autonomous Container Database.
56 57 58 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 56 def id @id end |
#infrastructure_type ⇒ String
The infrastructure type this resource belongs to.
85 86 87 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 85 def infrastructure_type @infrastructure_type end |
#key_history_entry ⇒ Array<OCI::Database::Models::AutonomousDatabaseKeyHistoryEntry>
Key History Entry.
106 107 108 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 106 def key_history_entry @key_history_entry end |
#key_store_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the key store.
176 177 178 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 176 def key_store_id @key_store_id end |
#key_store_wallet_name ⇒ String
The wallet name for Oracle Key Vault.
180 181 182 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 180 def key_store_wallet_name @key_store_wallet_name end |
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
93 94 95 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 93 def kms_key_id @kms_key_id end |
#kms_key_version_id ⇒ String
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.
102 103 104 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 102 def kms_key_version_id @kms_key_version_id end |
#last_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.
130 131 132 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 130 def last_maintenance_run_id @last_maintenance_run_id end |
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
114 115 116 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 114 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the Autonomous Container Database.
110 111 112 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 110 def lifecycle_state @lifecycle_state end |
#maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
137 138 139 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 137 def maintenance_window @maintenance_window end |
#next_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.
134 135 136 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 134 def next_maintenance_run_id @next_maintenance_run_id end |
#patch_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last patch applied on the system.
126 127 128 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 126 def patch_id @patch_id end |
#patch_model ⇒ String
[Required] Database patch model preference.
122 123 124 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 122 def patch_model @patch_model end |
#role ⇒ String
The role of the Autonomous Data Guard-enabled Autonomous Container Database.
161 162 163 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 161 def role @role end |
#service_level_agreement_type ⇒ String
[Required] The service level agreement type of the container database. The default is STANDARD.
73 74 75 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 73 def service_level_agreement_type @service_level_agreement_type end |
#standby_maintenance_buffer_in_days ⇒ Integer
The scheduling detail for the quarterly maintenance window of the standby Autonomous Container Database. This value represents the number of days before scheduled maintenance of the primary database.
143 144 145 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 143 def standby_maintenance_buffer_in_days @standby_maintenance_buffer_in_days end |
#time_created ⇒ DateTime
The date and time the Autonomous Container Database was created.
118 119 120 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 118 def time_created @time_created end |
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
97 98 99 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 97 def vault_id @vault_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 183 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'db_unique_name': :'dbUniqueName', 'service_level_agreement_type': :'serviceLevelAgreementType', 'autonomous_exadata_infrastructure_id': :'autonomousExadataInfrastructureId', 'autonomous_vm_cluster_id': :'autonomousVmClusterId', 'infrastructure_type': :'infrastructureType', 'cloud_autonomous_vm_cluster_id': :'cloudAutonomousVmClusterId', 'kms_key_id': :'kmsKeyId', 'vault_id': :'vaultId', 'kms_key_version_id': :'kmsKeyVersionId', 'key_history_entry': :'keyHistoryEntry', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated', 'patch_model': :'patchModel', 'patch_id': :'patchId', 'last_maintenance_run_id': :'lastMaintenanceRunId', 'next_maintenance_run_id': :'nextMaintenanceRunId', 'maintenance_window': :'maintenanceWindow', 'standby_maintenance_buffer_in_days': :'standbyMaintenanceBufferInDays', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'role': :'role', 'availability_domain': :'availabilityDomain', 'db_version': :'dbVersion', 'backup_config': :'backupConfig', 'key_store_id': :'keyStoreId', 'key_store_wallet_name': :'keyStoreWalletName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 221 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'db_unique_name': :'String', 'service_level_agreement_type': :'String', 'autonomous_exadata_infrastructure_id': :'String', 'autonomous_vm_cluster_id': :'String', 'infrastructure_type': :'String', 'cloud_autonomous_vm_cluster_id': :'String', 'kms_key_id': :'String', 'vault_id': :'String', 'kms_key_version_id': :'String', 'key_history_entry': :'Array<OCI::Database::Models::AutonomousDatabaseKeyHistoryEntry>', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime', 'patch_model': :'String', 'patch_id': :'String', 'last_maintenance_run_id': :'String', 'next_maintenance_run_id': :'String', 'maintenance_window': :'OCI::Database::Models::MaintenanceWindow', 'standby_maintenance_buffer_in_days': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'role': :'String', 'availability_domain': :'String', 'db_version': :'String', 'backup_config': :'OCI::Database::Models::AutonomousContainerDatabaseBackupConfig', 'key_store_id': :'String', 'key_store_wallet_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 542 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && db_unique_name == other.db_unique_name && service_level_agreement_type == other.service_level_agreement_type && autonomous_exadata_infrastructure_id == other.autonomous_exadata_infrastructure_id && autonomous_vm_cluster_id == other.autonomous_vm_cluster_id && infrastructure_type == other.infrastructure_type && cloud_autonomous_vm_cluster_id == other.cloud_autonomous_vm_cluster_id && kms_key_id == other.kms_key_id && vault_id == other.vault_id && kms_key_version_id == other.kms_key_version_id && key_history_entry == other.key_history_entry && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created && patch_model == other.patch_model && patch_id == other.patch_id && last_maintenance_run_id == other.last_maintenance_run_id && next_maintenance_run_id == other.next_maintenance_run_id && maintenance_window == other.maintenance_window && standby_maintenance_buffer_in_days == other.standby_maintenance_buffer_in_days && == other. && == other. && role == other.role && availability_domain == other.availability_domain && db_version == other.db_version && backup_config == other.backup_config && key_store_id == other.key_store_id && key_store_wallet_name == other.key_store_wallet_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 601 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
581 582 583 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 581 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
590 591 592 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 590 def hash [id, compartment_id, display_name, db_unique_name, service_level_agreement_type, autonomous_exadata_infrastructure_id, autonomous_vm_cluster_id, infrastructure_type, cloud_autonomous_vm_cluster_id, kms_key_id, vault_id, kms_key_version_id, key_history_entry, lifecycle_state, lifecycle_details, time_created, patch_model, patch_id, last_maintenance_run_id, next_maintenance_run_id, maintenance_window, standby_maintenance_buffer_in_days, , , role, availability_domain, db_version, backup_config, key_store_id, key_store_wallet_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
634 635 636 637 638 639 640 641 642 643 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 634 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
628 629 630 |
# File 'lib/oci/database/models/autonomous_container_database.rb', line 628 def to_s to_hash.to_s end |