Class: OCI::Database::Models::AutonomousDatabase
- Inherits:
-
Object
- Object
- OCI::Database::Models::AutonomousDatabase
- Defined in:
- lib/oci/database/models/autonomous_database.rb
Overview
An Oracle Autonomous Database.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LICENSE_MODEL_ENUM =
rubocop:disable Metrics/LineLength
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze, LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_STOPPING = 'STOPPING'.freeze, LIFECYCLE_STATE_STOPPED = 'STOPPED'.freeze, LIFECYCLE_STATE_STARTING = 'STARTING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNAVAILABLE = 'UNAVAILABLE'.freeze, LIFECYCLE_STATE_RESTORE_IN_PROGRESS = 'RESTORE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_RESTORE_FAILED = 'RESTORE_FAILED'.freeze, LIFECYCLE_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze, LIFECYCLE_STATE_SCALE_IN_PROGRESS = 'SCALE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_AVAILABLE_NEEDS_ATTENTION = 'AVAILABLE_NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#connection_strings ⇒ OCI::Database::Models::AutonomousDatabaseConnectionStrings
The connection string used to connect to the Autonomous Database.
-
#cpu_core_count ⇒ Integer
[Required] The number of CPU cores to be made available to the database.
-
#data_storage_size_in_tbs ⇒ Integer
[Required] The quantity of data in the database, in terabytes.
-
#db_name ⇒ String
[Required] The database name.
-
#db_version ⇒ String
A valid Oracle Database version for Autonomous Database.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The user-friendly name for the Autonomous Database.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the Autonomous Database.
-
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database.
-
#lifecycle_details ⇒ String
Information about the current lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the database.
-
#service_console_url ⇒ String
The URL of the Service Console for the Autonomous Database.
-
#time_created ⇒ DateTime
The date and time the database was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutonomousDatabase
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutonomousDatabase
Initializes the object
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/database/models/autonomous_database.rb', line 172 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.connection_strings = attributes[:'connectionStrings'] if attributes[:'connectionStrings'] raise 'You cannot provide both :connectionStrings and :connection_strings' if attributes.key?(:'connectionStrings') && attributes.key?(:'connection_strings') self.connection_strings = attributes[:'connection_strings'] if attributes[:'connection_strings'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.db_name = attributes[:'dbName'] if attributes[:'dbName'] raise 'You cannot provide both :dbName and :db_name' if attributes.key?(:'dbName') && attributes.key?(:'db_name') self.db_name = attributes[:'db_name'] if attributes[:'db_name'] self.db_version = attributes[:'dbVersion'] if attributes[:'dbVersion'] raise 'You cannot provide both :dbVersion and :db_version' if attributes.key?(:'dbVersion') && attributes.key?(:'db_version') self.db_version = attributes[:'db_version'] if attributes[:'db_version'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.service_console_url = attributes[:'serviceConsoleUrl'] if attributes[:'serviceConsoleUrl'] raise 'You cannot provide both :serviceConsoleUrl and :service_console_url' if attributes.key?(:'serviceConsoleUrl') && attributes.key?(:'service_console_url') self.service_console_url = attributes[:'service_console_url'] if attributes[:'service_console_url'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the compartment.
38 39 40 |
# File 'lib/oci/database/models/autonomous_database.rb', line 38 def compartment_id @compartment_id end |
#connection_strings ⇒ OCI::Database::Models::AutonomousDatabaseConnectionStrings
The connection string used to connect to the Autonomous Database. The username for the Service Console is ADMIN. Use the password you entered when creating the Autonomous Database for the password value.
42 43 44 |
# File 'lib/oci/database/models/autonomous_database.rb', line 42 def connection_strings @connection_strings end |
#cpu_core_count ⇒ Integer
[Required] The number of CPU cores to be made available to the database.
46 47 48 |
# File 'lib/oci/database/models/autonomous_database.rb', line 46 def cpu_core_count @cpu_core_count end |
#data_storage_size_in_tbs ⇒ Integer
[Required] The quantity of data in the database, in terabytes.
50 51 52 |
# File 'lib/oci/database/models/autonomous_database.rb', line 50 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_name ⇒ String
[Required] The database name.
54 55 56 |
# File 'lib/oci/database/models/autonomous_database.rb', line 54 def db_name @db_name end |
#db_version ⇒ String
A valid Oracle Database version for Autonomous Database.
58 59 60 |
# File 'lib/oci/database/models/autonomous_database.rb', line 58 def db_version @db_version end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
66 67 68 |
# File 'lib/oci/database/models/autonomous_database.rb', line 66 def end |
#display_name ⇒ String
The user-friendly name for the Autonomous Database. The name does not have to be unique.
70 71 72 |
# File 'lib/oci/database/models/autonomous_database.rb', line 70 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
78 79 80 |
# File 'lib/oci/database/models/autonomous_database.rb', line 78 def end |
#id ⇒ String
[Required] The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the Autonomous Database.
82 83 84 |
# File 'lib/oci/database/models/autonomous_database.rb', line 82 def id @id end |
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database. The default is BRING_YOUR_OWN_LICENSE.
87 88 89 |
# File 'lib/oci/database/models/autonomous_database.rb', line 87 def license_model @license_model end |
#lifecycle_details ⇒ String
Information about the current lifecycle state.
91 92 93 |
# File 'lib/oci/database/models/autonomous_database.rb', line 91 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the database.
95 96 97 |
# File 'lib/oci/database/models/autonomous_database.rb', line 95 def lifecycle_state @lifecycle_state end |
#service_console_url ⇒ String
The URL of the Service Console for the Autonomous Database.
99 100 101 |
# File 'lib/oci/database/models/autonomous_database.rb', line 99 def service_console_url @service_console_url end |
#time_created ⇒ DateTime
The date and time the database was created.
103 104 105 |
# File 'lib/oci/database/models/autonomous_database.rb', line 103 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/database/models/autonomous_database.rb', line 106 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'connection_strings': :'connectionStrings', 'cpu_core_count': :'cpuCoreCount', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'db_name': :'dbName', 'db_version': :'dbVersion', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'license_model': :'licenseModel', 'lifecycle_details': :'lifecycleDetails', 'lifecycle_state': :'lifecycleState', 'service_console_url': :'serviceConsoleUrl', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/database/models/autonomous_database.rb', line 129 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'connection_strings': :'OCI::Database::Models::AutonomousDatabaseConnectionStrings', 'cpu_core_count': :'Integer', 'data_storage_size_in_tbs': :'Integer', 'db_name': :'String', 'db_version': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'license_model': :'String', 'lifecycle_details': :'String', 'lifecycle_state': :'String', 'service_console_url': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/oci/database/models/autonomous_database.rb', line 302 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && connection_strings == other.connection_strings && cpu_core_count == other.cpu_core_count && data_storage_size_in_tbs == other.data_storage_size_in_tbs && db_name == other.db_name && db_version == other.db_version && == other. && display_name == other.display_name && == other. && id == other.id && license_model == other.license_model && lifecycle_details == other.lifecycle_details && lifecycle_state == other.lifecycle_state && service_console_url == other.service_console_url && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/oci/database/models/autonomous_database.rb', line 346 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
326 327 328 |
# File 'lib/oci/database/models/autonomous_database.rb', line 326 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
335 336 337 |
# File 'lib/oci/database/models/autonomous_database.rb', line 335 def hash [compartment_id, connection_strings, cpu_core_count, data_storage_size_in_tbs, db_name, db_version, , display_name, , id, license_model, lifecycle_details, lifecycle_state, service_console_url, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
379 380 381 382 383 384 385 386 387 388 |
# File 'lib/oci/database/models/autonomous_database.rb', line 379 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
373 374 375 |
# File 'lib/oci/database/models/autonomous_database.rb', line 373 def to_s to_hash.to_s end |