Class: OCI::Database::Models::AutonomousDatabaseBackupSummary
- Inherits:
-
Object
- Object
- OCI::Database::Models::AutonomousDatabaseBackupSummary
- Defined in:
- lib/oci/database/models/autonomous_database_backup_summary.rb
Overview
An Autonomous Database backup. To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_INCREMENTAL = 'INCREMENTAL'.freeze, TYPE_FULL = 'FULL'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#autonomous_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Database.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#database_size_in_tbs ⇒ Float
The size of the database in terabytes at the time the backup was taken.
-
#display_name ⇒ String
[Required] The user-friendly name for the backup.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Database backup.
-
#is_automatic ⇒ BOOLEAN
[Required] Indicates whether the backup is user-initiated or automatic.
-
#is_restorable ⇒ BOOLEAN
Indicates whether the backup can be used to restore the associated Autonomous Database.
-
#key_store_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the key store.
-
#key_store_wallet_name ⇒ String
The wallet name for Oracle Key Vault.
-
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the backup.
-
#time_ended ⇒ DateTime
The date and time the backup completed.
-
#time_started ⇒ DateTime
The date and time the backup started.
-
#type ⇒ String
[Required] The type of backup.
-
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutonomousDatabaseBackupSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutonomousDatabaseBackupSummary
Initializes the object
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 165 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.autonomous_database_id = attributes[:'autonomousDatabaseId'] if attributes[:'autonomousDatabaseId'] raise 'You cannot provide both :autonomousDatabaseId and :autonomous_database_id' if attributes.key?(:'autonomousDatabaseId') && attributes.key?(:'autonomous_database_id') self.autonomous_database_id = attributes[:'autonomous_database_id'] if attributes[:'autonomous_database_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.type = attributes[:'type'] if attributes[:'type'] self.is_automatic = attributes[:'isAutomatic'] unless attributes[:'isAutomatic'].nil? raise 'You cannot provide both :isAutomatic and :is_automatic' if attributes.key?(:'isAutomatic') && attributes.key?(:'is_automatic') self.is_automatic = attributes[:'is_automatic'] unless attributes[:'is_automatic'].nil? self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded'] raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended') self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.database_size_in_tbs = attributes[:'databaseSizeInTBs'] if attributes[:'databaseSizeInTBs'] raise 'You cannot provide both :databaseSizeInTBs and :database_size_in_tbs' if attributes.key?(:'databaseSizeInTBs') && attributes.key?(:'database_size_in_tbs') self.database_size_in_tbs = attributes[:'database_size_in_tbs'] if attributes[:'database_size_in_tbs'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.is_restorable = attributes[:'isRestorable'] unless attributes[:'isRestorable'].nil? self.is_restorable = true if is_restorable.nil? && !attributes.key?(:'isRestorable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isRestorable and :is_restorable' if attributes.key?(:'isRestorable') && attributes.key?(:'is_restorable') self.is_restorable = attributes[:'is_restorable'] unless attributes[:'is_restorable'].nil? self.is_restorable = true if is_restorable.nil? && !attributes.key?(:'isRestorable') && !attributes.key?(:'is_restorable') # rubocop:disable Style/StringLiterals self.key_store_id = attributes[:'keyStoreId'] if attributes[:'keyStoreId'] raise 'You cannot provide both :keyStoreId and :key_store_id' if attributes.key?(:'keyStoreId') && attributes.key?(:'key_store_id') self.key_store_id = attributes[:'key_store_id'] if attributes[:'key_store_id'] self.key_store_wallet_name = attributes[:'keyStoreWalletName'] if attributes[:'keyStoreWalletName'] raise 'You cannot provide both :keyStoreWalletName and :key_store_wallet_name' if attributes.key?(:'keyStoreWalletName') && attributes.key?(:'key_store_wallet_name') self.key_store_wallet_name = attributes[:'key_store_wallet_name'] if attributes[:'key_store_wallet_name'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId'] raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id') self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id'] end |
Instance Attribute Details
#autonomous_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Database.
40 41 42 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 40 def autonomous_database_id @autonomous_database_id end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
36 37 38 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 36 def compartment_id @compartment_id end |
#database_size_in_tbs ⇒ Float
The size of the database in terabytes at the time the backup was taken.
69 70 71 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 69 def database_size_in_tbs @database_size_in_tbs end |
#display_name ⇒ String
[Required] The user-friendly name for the backup. The name does not have to be unique.
44 45 46 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 44 def display_name @display_name end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Database backup.
32 33 34 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 32 def id @id end |
#is_automatic ⇒ BOOLEAN
[Required] Indicates whether the backup is user-initiated or automatic.
52 53 54 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 52 def is_automatic @is_automatic end |
#is_restorable ⇒ BOOLEAN
Indicates whether the backup can be used to restore the associated Autonomous Database.
77 78 79 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 77 def is_restorable @is_restorable end |
#key_store_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the key store.
81 82 83 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 81 def key_store_id @key_store_id end |
#key_store_wallet_name ⇒ String
The wallet name for Oracle Key Vault.
85 86 87 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 85 def key_store_wallet_name @key_store_wallet_name end |
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
89 90 91 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 89 def kms_key_id @kms_key_id end |
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
64 65 66 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 64 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the backup.
73 74 75 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 73 def lifecycle_state @lifecycle_state end |
#time_ended ⇒ DateTime
The date and time the backup completed.
60 61 62 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 60 def time_ended @time_ended end |
#time_started ⇒ DateTime
The date and time the backup started.
56 57 58 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 56 def time_started @time_started end |
#type ⇒ String
[Required] The type of backup.
48 49 50 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 48 def type @type end |
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
93 94 95 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 93 def vault_id @vault_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 96 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'autonomous_database_id': :'autonomousDatabaseId', 'display_name': :'displayName', 'type': :'type', 'is_automatic': :'isAutomatic', 'time_started': :'timeStarted', 'time_ended': :'timeEnded', 'lifecycle_details': :'lifecycleDetails', 'database_size_in_tbs': :'databaseSizeInTBs', 'lifecycle_state': :'lifecycleState', 'is_restorable': :'isRestorable', 'key_store_id': :'keyStoreId', 'key_store_wallet_name': :'keyStoreWalletName', 'kms_key_id': :'kmsKeyId', 'vault_id': :'vaultId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 120 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'autonomous_database_id': :'String', 'display_name': :'String', 'type': :'String', 'is_automatic': :'BOOLEAN', 'time_started': :'DateTime', 'time_ended': :'DateTime', 'lifecycle_details': :'String', 'database_size_in_tbs': :'Float', 'lifecycle_state': :'String', 'is_restorable': :'BOOLEAN', 'key_store_id': :'String', 'key_store_wallet_name': :'String', 'kms_key_id': :'String', 'vault_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 295 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && autonomous_database_id == other.autonomous_database_id && display_name == other.display_name && type == other.type && is_automatic == other.is_automatic && time_started == other.time_started && time_ended == other.time_ended && lifecycle_details == other.lifecycle_details && database_size_in_tbs == other.database_size_in_tbs && lifecycle_state == other.lifecycle_state && is_restorable == other.is_restorable && key_store_id == other.key_store_id && key_store_wallet_name == other.key_store_wallet_name && kms_key_id == other.kms_key_id && vault_id == other.vault_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 340 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
320 321 322 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 320 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
329 330 331 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 329 def hash [id, compartment_id, autonomous_database_id, display_name, type, is_automatic, time_started, time_ended, lifecycle_details, database_size_in_tbs, lifecycle_state, is_restorable, key_store_id, key_store_wallet_name, kms_key_id, vault_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
373 374 375 376 377 378 379 380 381 382 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 373 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
367 368 369 |
# File 'lib/oci/database/models/autonomous_database_backup_summary.rb', line 367 def to_s to_hash.to_s end |