Class: OCI::Database::Models::AutonomousDatabaseKeyHistoryEntry
- Inherits:
-
Object
- Object
- OCI::Database::Models::AutonomousDatabaseKeyHistoryEntry
- Defined in:
- lib/oci/database/models/autonomous_database_key_history_entry.rb
Overview
The Autonomous Database [Vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts) service key management history entry.
Instance Attribute Summary collapse
-
#id ⇒ String
[Required] The id of the Autonomous Database [Vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts) service key management history entry.
-
#kms_key_version_id ⇒ String
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions.
-
#time_activated ⇒ DateTime
The date and time the kms key activated.
-
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutonomousDatabaseKeyHistoryEntry
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutonomousDatabaseKeyHistoryEntry
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 62 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.kms_key_version_id = attributes[:'kmsKeyVersionId'] if attributes[:'kmsKeyVersionId'] raise 'You cannot provide both :kmsKeyVersionId and :kms_key_version_id' if attributes.key?(:'kmsKeyVersionId') && attributes.key?(:'kms_key_version_id') self.kms_key_version_id = attributes[:'kms_key_version_id'] if attributes[:'kms_key_version_id'] self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId'] raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id') self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id'] self.time_activated = attributes[:'timeActivated'] if attributes[:'timeActivated'] raise 'You cannot provide both :timeActivated and :time_activated' if attributes.key?(:'timeActivated') && attributes.key?(:'time_activated') self.time_activated = attributes[:'time_activated'] if attributes[:'time_activated'] end |
Instance Attribute Details
#id ⇒ String
[Required] The id of the Autonomous Database [Vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts) service key management history entry.
13 14 15 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 13 def id @id end |
#kms_key_version_id ⇒ String
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.
18 19 20 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 18 def kms_key_version_id @kms_key_version_id end |
#time_activated ⇒ DateTime
The date and time the kms key activated.
26 27 28 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 26 def time_activated @time_activated end |
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
22 23 24 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 22 def vault_id @vault_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'kms_key_version_id': :'kmsKeyVersionId', 'vault_id': :'vaultId', 'time_activated': :'timeActivated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'kms_key_version_id': :'String', 'vault_id': :'String', 'time_activated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 96 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && kms_key_version_id == other.kms_key_version_id && vault_id == other.vault_id && time_activated == other.time_activated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 129 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
109 110 111 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 109 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
118 119 120 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 118 def hash [id, kms_key_version_id, vault_id, time_activated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
156 157 158 |
# File 'lib/oci/database/models/autonomous_database_key_history_entry.rb', line 156 def to_s to_hash.to_s end |