Class: OCI::Database::Models::AutonomousExadataInfrastructureSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb

Overview

Infrastructure that enables the running of multiple Autonomous Databases within a dedicated DB system. For more information about Autonomous Exadata Infrastructure, see [Overview of Autonomous Database](docs.cloud.oracle.com/iaas/Content/Database/Concepts/adboverview.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

For information about access control and compartments, see [Overview of the Identity Service](docs.cloud.oracle.com/Content/Identity/Concepts/overview.htm).

For information about availability domains, see [Regions and Availability Domains](docs.cloud.oracle.com/Content/General/Concepts/regions.htm).

To get a list of availability domains, use the ListAvailabilityDomains operation in the Identity service API.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze,
  LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AutonomousExadataInfrastructureSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :availability_domain (String)

    The value to assign to the #availability_domain property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :nsg_ids (Array<String>)

    The value to assign to the #nsg_ids property

  • :shape (String)

    The value to assign to the #shape property

  • :hostname (String)

    The value to assign to the #hostname property

  • :domain (String)

    The value to assign to the #domain property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :license_model (String)

    The value to assign to the #license_model property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :maintenance_window (OCI::Database::Models::MaintenanceWindow)

    The value to assign to the #maintenance_window property

  • :last_maintenance_run_id (String)

    The value to assign to the #last_maintenance_run_id property

  • :next_maintenance_run_id (String)

    The value to assign to the #next_maintenance_run_id property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :scan_dns_name (String)

    The value to assign to the #scan_dns_name property

  • :zone_id (String)

    The value to assign to the #zone_id property



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 224

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.hostname = attributes[:'hostname'] if attributes[:'hostname']

  self.domain = attributes[:'domain'] if attributes[:'domain']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow']

  raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window')

  self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window']

  self.last_maintenance_run_id = attributes[:'lastMaintenanceRunId'] if attributes[:'lastMaintenanceRunId']

  raise 'You cannot provide both :lastMaintenanceRunId and :last_maintenance_run_id' if attributes.key?(:'lastMaintenanceRunId') && attributes.key?(:'last_maintenance_run_id')

  self.last_maintenance_run_id = attributes[:'last_maintenance_run_id'] if attributes[:'last_maintenance_run_id']

  self.next_maintenance_run_id = attributes[:'nextMaintenanceRunId'] if attributes[:'nextMaintenanceRunId']

  raise 'You cannot provide both :nextMaintenanceRunId and :next_maintenance_run_id' if attributes.key?(:'nextMaintenanceRunId') && attributes.key?(:'next_maintenance_run_id')

  self.next_maintenance_run_id = attributes[:'next_maintenance_run_id'] if attributes[:'next_maintenance_run_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.scan_dns_name = attributes[:'scanDnsName'] if attributes[:'scanDnsName']

  raise 'You cannot provide both :scanDnsName and :scan_dns_name' if attributes.key?(:'scanDnsName') && attributes.key?(:'scan_dns_name')

  self.scan_dns_name = attributes[:'scan_dns_name'] if attributes[:'scan_dns_name']

  self.zone_id = attributes[:'zoneId'] if attributes[:'zoneId']

  raise 'You cannot provide both :zoneId and :zone_id' if attributes.key?(:'zoneId') && attributes.key?(:'zone_id')

  self.zone_id = attributes[:'zone_id'] if attributes[:'zone_id']
end

Instance Attribute Details

#availability_domainString

[Required] The name of the availability domain that the Autonomous Exadata Infrastructure is located in.

Returns:

  • (String)


56
57
58
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 56

def availability_domain
  @availability_domain
end

#compartment_idString

[Required] The OCID of the compartment.

Returns:

  • (String)


48
49
50
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 48

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


130
131
132
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 130

def defined_tags
  @defined_tags
end

#display_nameString

[Required] The user-friendly name for the Autonomous Exadata Infrastructure.

Returns:

  • (String)


52
53
54
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 52

def display_name
  @display_name
end

#domainString

[Required] The domain name for the Autonomous Exadata Infrastructure.

Returns:

  • (String)


87
88
89
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 87

def domain
  @domain
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


124
125
126
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 124

def freeform_tags
  @freeform_tags
end

#hostnameString

[Required] The host name for the Autonomous Exadata Infrastructure node.

Returns:

  • (String)


83
84
85
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 83

def hostname
  @hostname
end

#idString

[Required] The OCID of the Autonomous Exadata Infrastructure.

Returns:

  • (String)


44
45
46
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 44

def id
  @id
end

#last_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.

Returns:

  • (String)


112
113
114
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 112

def last_maintenance_run_id
  @last_maintenance_run_id
end

#license_modelString

The Oracle license model that applies to all databases in the Autonomous Exadata Infrastructure. The default is BRING_YOUR_OWN_LICENSE.

Returns:

  • (String)


100
101
102
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 100

def license_model
  @license_model
end

#lifecycle_detailsString

Additional information about the current lifecycle state of the Autonomous Exadata Infrastructure.

Returns:

  • (String)


95
96
97
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 95

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current lifecycle state of the Autonomous Exadata Infrastructure.

Returns:

  • (String)


91
92
93
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 91

def lifecycle_state
  @lifecycle_state
end

#maintenance_windowOCI::Database::Models::MaintenanceWindow

This attribute is required.



108
109
110
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 108

def maintenance_window
  @maintenance_window
end

#next_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.

Returns:

  • (String)


116
117
118
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 116

def next_maintenance_run_id
  @next_maintenance_run_id
end

#nsg_idsArray<String>

A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**

  • Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

Returns:

  • (Array<String>)


75
76
77
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 75

def nsg_ids
  @nsg_ids
end

#scan_dns_nameString

The FQDN of the DNS record for the SCAN IP addresses that are associated with the Autonomous Exadata Infrastructure.

Returns:

  • (String)


135
136
137
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 135

def scan_dns_name
  @scan_dns_name
end

#shapeString

[Required] The shape of the Autonomous Exadata Infrastructure. The shape determines resources to allocate to the Autonomous Exadata Infrastructure (CPU cores, memory and storage).

Returns:

  • (String)


79
80
81
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 79

def shape
  @shape
end

#subnet_idString

[Required] The OCID of the subnet the Autonomous Exadata Infrastructure is associated with.

**Subnet Restrictions:**

  • For Autonomous Databases with Autonomous Exadata Infrastructure, do not use a subnet that overlaps with 192.168.128.0/20

These subnets are used by the Oracle Clusterware private interconnect on the database instance. Specifying an overlapping subnet will cause the private interconnect to malfunction. This restriction applies to both the client subnet and backup subnet.

Returns:

  • (String)


68
69
70
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 68

def subnet_id
  @subnet_id
end

#time_createdDateTime

The date and time the Autonomous Exadata Infrastructure was created.

Returns:

  • (DateTime)


104
105
106
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 104

def time_created
  @time_created
end

#zone_idString

The OCID of the zone the Autonomous Exadata Infrastructure is associated with.

Returns:

  • (String)


140
141
142
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 140

def zone_id
  @zone_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 143

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'availability_domain': :'availabilityDomain',
    'subnet_id': :'subnetId',
    'nsg_ids': :'nsgIds',
    'shape': :'shape',
    'hostname': :'hostname',
    'domain': :'domain',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'license_model': :'licenseModel',
    'time_created': :'timeCreated',
    'maintenance_window': :'maintenanceWindow',
    'last_maintenance_run_id': :'lastMaintenanceRunId',
    'next_maintenance_run_id': :'nextMaintenanceRunId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'scan_dns_name': :'scanDnsName',
    'zone_id': :'zoneId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 171

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'availability_domain': :'String',
    'subnet_id': :'String',
    'nsg_ids': :'Array<String>',
    'shape': :'String',
    'hostname': :'String',
    'domain': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'license_model': :'String',
    'time_created': :'DateTime',
    'maintenance_window': :'OCI::Database::Models::MaintenanceWindow',
    'last_maintenance_run_id': :'String',
    'next_maintenance_run_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'scan_dns_name': :'String',
    'zone_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 368

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    availability_domain == other.availability_domain &&
    subnet_id == other.subnet_id &&
    nsg_ids == other.nsg_ids &&
    shape == other.shape &&
    hostname == other.hostname &&
    domain == other.domain &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    license_model == other.license_model &&
    time_created == other.time_created &&
    maintenance_window == other.maintenance_window &&
    last_maintenance_run_id == other.last_maintenance_run_id &&
    next_maintenance_run_id == other.next_maintenance_run_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    scan_dns_name == other.scan_dns_name &&
    zone_id == other.zone_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 417

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


397
398
399
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 397

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



406
407
408
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 406

def hash
  [id, compartment_id, display_name, availability_domain, subnet_id, nsg_ids, shape, hostname, domain, lifecycle_state, lifecycle_details, license_model, time_created, maintenance_window, last_maintenance_run_id, next_maintenance_run_id, freeform_tags, defined_tags, scan_dns_name, zone_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



450
451
452
453
454
455
456
457
458
459
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 450

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



444
445
446
# File 'lib/oci/database/models/autonomous_exadata_infrastructure_summary.rb', line 444

def to_s
  to_hash.to_s
end