Class: OCI::Database::Models::AutonomousVmClusterSummary
- Inherits:
-
Object
- Object
- OCI::Database::Models::AutonomousVmClusterSummary
- Defined in:
- lib/oci/database/models/autonomous_vm_cluster_summary.rb
Overview
Details of the Autonomous VM cluster.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze, LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#autonomous_data_storage_size_in_tbs ⇒ Float
The data disk group size allocated for Autonomous Databases, in TBs.
-
#available_autonomous_data_storage_size_in_tbs ⇒ Float
The data disk group size available for Autonomous Databases, in TBs.
-
#available_container_databases ⇒ Integer
The number of Autonomous Container Databases that can be created with the currently available local storage.
-
#available_cpus ⇒ Integer
The numnber of CPU cores available.
-
#available_data_storage_size_in_tbs ⇒ Float
*Deprecated.* Use `availableAutonomousDataStorageSizeInTBs` for Autonomous Databases' data storage availability in TBs.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#cpu_core_count_per_node ⇒ Integer
The number of OCPU cores enabled per VM cluster node.
-
#cpus_enabled ⇒ Integer
The number of enabled CPU cores.
-
#data_storage_size_in_gbs ⇒ Float
The total data storage allocated in GBs.
-
#data_storage_size_in_tbs ⇒ Float
The total data storage allocated in TBs.
-
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage allocated in GBs.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** The user-friendly name for the Autonomous VM cluster.
-
#exadata_infrastructure_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous VM cluster.
-
#is_local_backup_enabled ⇒ BOOLEAN
If true, database backup on local Exadata storage is configured for the Autonomous VM cluster.
-
#last_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.
-
#license_model ⇒ String
The Oracle license model that applies to the Autonomous VM cluster.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the Autonomous VM cluster.
- #maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
-
#memory_per_oracle_compute_unit_in_gbs ⇒ Integer
The amount of memory (in GBs) enabled per each OCPU core.
-
#memory_size_in_gbs ⇒ Integer
The memory allocated in GBs.
-
#next_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.
-
#ocpus_enabled ⇒ Float
The number of enabled OCPU cores.
-
#reclaimable_cpus ⇒ Integer
CPU cores that continue to be included in the count of OCPUs available to the Autonomous Container Database even after one of its Autonomous Database is terminated or scaled down.
-
#time_created ⇒ DateTime
The date and time that the Autonomous VM cluster was created.
-
#time_zone ⇒ String
The time zone to use for the Autonomous VM cluster.
-
#total_container_databases ⇒ Integer
The total number of Autonomous Container Databases that can be created.
-
#vm_cluster_network_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster network.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AutonomousVmClusterSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AutonomousVmClusterSummary
Initializes the object
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 276 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone'] raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone'] self.exadata_infrastructure_id = attributes[:'exadataInfrastructureId'] if attributes[:'exadataInfrastructureId'] raise 'You cannot provide both :exadataInfrastructureId and :exadata_infrastructure_id' if attributes.key?(:'exadataInfrastructureId') && attributes.key?(:'exadata_infrastructure_id') self.exadata_infrastructure_id = attributes[:'exadata_infrastructure_id'] if attributes[:'exadata_infrastructure_id'] self.vm_cluster_network_id = attributes[:'vmClusterNetworkId'] if attributes[:'vmClusterNetworkId'] raise 'You cannot provide both :vmClusterNetworkId and :vm_cluster_network_id' if attributes.key?(:'vmClusterNetworkId') && attributes.key?(:'vm_cluster_network_id') self.vm_cluster_network_id = attributes[:'vm_cluster_network_id'] if attributes[:'vm_cluster_network_id'] self.is_local_backup_enabled = attributes[:'isLocalBackupEnabled'] unless attributes[:'isLocalBackupEnabled'].nil? raise 'You cannot provide both :isLocalBackupEnabled and :is_local_backup_enabled' if attributes.key?(:'isLocalBackupEnabled') && attributes.key?(:'is_local_backup_enabled') self.is_local_backup_enabled = attributes[:'is_local_backup_enabled'] unless attributes[:'is_local_backup_enabled'].nil? self.cpus_enabled = attributes[:'cpusEnabled'] if attributes[:'cpusEnabled'] raise 'You cannot provide both :cpusEnabled and :cpus_enabled' if attributes.key?(:'cpusEnabled') && attributes.key?(:'cpus_enabled') self.cpus_enabled = attributes[:'cpus_enabled'] if attributes[:'cpus_enabled'] self.ocpus_enabled = attributes[:'ocpusEnabled'] if attributes[:'ocpusEnabled'] raise 'You cannot provide both :ocpusEnabled and :ocpus_enabled' if attributes.key?(:'ocpusEnabled') && attributes.key?(:'ocpus_enabled') self.ocpus_enabled = attributes[:'ocpus_enabled'] if attributes[:'ocpus_enabled'] self.available_cpus = attributes[:'availableCpus'] if attributes[:'availableCpus'] raise 'You cannot provide both :availableCpus and :available_cpus' if attributes.key?(:'availableCpus') && attributes.key?(:'available_cpus') self.available_cpus = attributes[:'available_cpus'] if attributes[:'available_cpus'] self.total_container_databases = attributes[:'totalContainerDatabases'] if attributes[:'totalContainerDatabases'] raise 'You cannot provide both :totalContainerDatabases and :total_container_databases' if attributes.key?(:'totalContainerDatabases') && attributes.key?(:'total_container_databases') self.total_container_databases = attributes[:'total_container_databases'] if attributes[:'total_container_databases'] self.memory_per_oracle_compute_unit_in_gbs = attributes[:'memoryPerOracleComputeUnitInGBs'] if attributes[:'memoryPerOracleComputeUnitInGBs'] raise 'You cannot provide both :memoryPerOracleComputeUnitInGBs and :memory_per_oracle_compute_unit_in_gbs' if attributes.key?(:'memoryPerOracleComputeUnitInGBs') && attributes.key?(:'memory_per_oracle_compute_unit_in_gbs') self.memory_per_oracle_compute_unit_in_gbs = attributes[:'memory_per_oracle_compute_unit_in_gbs'] if attributes[:'memory_per_oracle_compute_unit_in_gbs'] self.cpu_core_count_per_node = attributes[:'cpuCoreCountPerNode'] if attributes[:'cpuCoreCountPerNode'] raise 'You cannot provide both :cpuCoreCountPerNode and :cpu_core_count_per_node' if attributes.key?(:'cpuCoreCountPerNode') && attributes.key?(:'cpu_core_count_per_node') self.cpu_core_count_per_node = attributes[:'cpu_core_count_per_node'] if attributes[:'cpu_core_count_per_node'] self.autonomous_data_storage_size_in_tbs = attributes[:'autonomousDataStorageSizeInTBs'] if attributes[:'autonomousDataStorageSizeInTBs'] raise 'You cannot provide both :autonomousDataStorageSizeInTBs and :autonomous_data_storage_size_in_tbs' if attributes.key?(:'autonomousDataStorageSizeInTBs') && attributes.key?(:'autonomous_data_storage_size_in_tbs') self.autonomous_data_storage_size_in_tbs = attributes[:'autonomous_data_storage_size_in_tbs'] if attributes[:'autonomous_data_storage_size_in_tbs'] self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow'] raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window') self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window'] self.last_maintenance_run_id = attributes[:'lastMaintenanceRunId'] if attributes[:'lastMaintenanceRunId'] raise 'You cannot provide both :lastMaintenanceRunId and :last_maintenance_run_id' if attributes.key?(:'lastMaintenanceRunId') && attributes.key?(:'last_maintenance_run_id') self.last_maintenance_run_id = attributes[:'last_maintenance_run_id'] if attributes[:'last_maintenance_run_id'] self.next_maintenance_run_id = attributes[:'nextMaintenanceRunId'] if attributes[:'nextMaintenanceRunId'] raise 'You cannot provide both :nextMaintenanceRunId and :next_maintenance_run_id' if attributes.key?(:'nextMaintenanceRunId') && attributes.key?(:'next_maintenance_run_id') self.next_maintenance_run_id = attributes[:'next_maintenance_run_id'] if attributes[:'next_maintenance_run_id'] self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs'] raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs') self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs'] self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs'] raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs') self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.available_data_storage_size_in_tbs = attributes[:'availableDataStorageSizeInTBs'] if attributes[:'availableDataStorageSizeInTBs'] raise 'You cannot provide both :availableDataStorageSizeInTBs and :available_data_storage_size_in_tbs' if attributes.key?(:'availableDataStorageSizeInTBs') && attributes.key?(:'available_data_storage_size_in_tbs') self.available_data_storage_size_in_tbs = attributes[:'available_data_storage_size_in_tbs'] if attributes[:'available_data_storage_size_in_tbs'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.reclaimable_cpus = attributes[:'reclaimableCpus'] if attributes[:'reclaimableCpus'] raise 'You cannot provide both :reclaimableCpus and :reclaimable_cpus' if attributes.key?(:'reclaimableCpus') && attributes.key?(:'reclaimable_cpus') self.reclaimable_cpus = attributes[:'reclaimable_cpus'] if attributes[:'reclaimable_cpus'] self.available_container_databases = attributes[:'availableContainerDatabases'] if attributes[:'availableContainerDatabases'] raise 'You cannot provide both :availableContainerDatabases and :available_container_databases' if attributes.key?(:'availableContainerDatabases') && attributes.key?(:'available_container_databases') self.available_container_databases = attributes[:'available_container_databases'] if attributes[:'available_container_databases'] self.available_autonomous_data_storage_size_in_tbs = attributes[:'availableAutonomousDataStorageSizeInTBs'] if attributes[:'availableAutonomousDataStorageSizeInTBs'] raise 'You cannot provide both :availableAutonomousDataStorageSizeInTBs and :available_autonomous_data_storage_size_in_tbs' if attributes.key?(:'availableAutonomousDataStorageSizeInTBs') && attributes.key?(:'available_autonomous_data_storage_size_in_tbs') self.available_autonomous_data_storage_size_in_tbs = attributes[:'available_autonomous_data_storage_size_in_tbs'] if attributes[:'available_autonomous_data_storage_size_in_tbs'] end |
Instance Attribute Details
#autonomous_data_storage_size_in_tbs ⇒ Float
The data disk group size allocated for Autonomous Databases, in TBs.
96 97 98 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 96 def autonomous_data_storage_size_in_tbs @autonomous_data_storage_size_in_tbs end |
#available_autonomous_data_storage_size_in_tbs ⇒ Float
The data disk group size available for Autonomous Databases, in TBs.
159 160 161 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 159 def available_autonomous_data_storage_size_in_tbs @available_autonomous_data_storage_size_in_tbs end |
#available_container_databases ⇒ Integer
The number of Autonomous Container Databases that can be created with the currently available local storage.
155 156 157 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 155 def available_container_databases @available_container_databases end |
#available_cpus ⇒ Integer
The numnber of CPU cores available.
80 81 82 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 80 def available_cpus @available_cpus end |
#available_data_storage_size_in_tbs ⇒ Float
*Deprecated.* Use `availableAutonomousDataStorageSizeInTBs` for Autonomous Databases' data storage availability in TBs.
128 129 130 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 128 def available_data_storage_size_in_tbs @available_data_storage_size_in_tbs end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
35 36 37 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 35 def compartment_id @compartment_id end |
#cpu_core_count_per_node ⇒ Integer
The number of OCPU cores enabled per VM cluster node.
92 93 94 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 92 def cpu_core_count_per_node @cpu_core_count_per_node end |
#cpus_enabled ⇒ Integer
The number of enabled CPU cores.
72 73 74 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 72 def cpus_enabled @cpus_enabled end |
#data_storage_size_in_gbs ⇒ Float
The total data storage allocated in GBs.
123 124 125 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 123 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#data_storage_size_in_tbs ⇒ Float
The total data storage allocated in TBs
119 120 121 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 119 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage allocated in GBs.
115 116 117 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 115 def db_node_storage_size_in_gbs @db_node_storage_size_in_gbs end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
147 148 149 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 147 def @defined_tags end |
#display_name ⇒ String
**[Required]** The user-friendly name for the Autonomous VM cluster. The name does not need to be unique.
39 40 41 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 39 def display_name @display_name end |
#exadata_infrastructure_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.
59 60 61 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 59 def exadata_infrastructure_id @exadata_infrastructure_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
141 142 143 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 141 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous VM cluster.
31 32 33 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 31 def id @id end |
#is_local_backup_enabled ⇒ BOOLEAN
If true, database backup on local Exadata storage is configured for the Autonomous VM cluster. If false, database backup on local Exadata storage is not available in the Autonomous VM cluster.
68 69 70 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 68 def is_local_backup_enabled @is_local_backup_enabled end |
#last_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.
103 104 105 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 103 def last_maintenance_run_id @last_maintenance_run_id end |
#license_model ⇒ String
The Oracle license model that applies to the Autonomous VM cluster. The default is LICENSE_INCLUDED.
133 134 135 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 133 def license_model @license_model end |
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
51 52 53 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 51 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the Autonomous VM cluster.
47 48 49 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 47 def lifecycle_state @lifecycle_state end |
#maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
99 100 101 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 99 def maintenance_window @maintenance_window end |
#memory_per_oracle_compute_unit_in_gbs ⇒ Integer
The amount of memory (in GBs) enabled per each OCPU core.
88 89 90 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 88 def memory_per_oracle_compute_unit_in_gbs @memory_per_oracle_compute_unit_in_gbs end |
#memory_size_in_gbs ⇒ Integer
The memory allocated in GBs.
111 112 113 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 111 def memory_size_in_gbs @memory_size_in_gbs end |
#next_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.
107 108 109 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 107 def next_maintenance_run_id @next_maintenance_run_id end |
#ocpus_enabled ⇒ Float
The number of enabled OCPU cores.
76 77 78 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 76 def ocpus_enabled @ocpus_enabled end |
#reclaimable_cpus ⇒ Integer
CPU cores that continue to be included in the count of OCPUs available to the Autonomous Container Database even after one of its Autonomous Database is terminated or scaled down. You can release them to the available OCPUs at its parent AVMC level by restarting the Autonomous Container Database.
151 152 153 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 151 def reclaimable_cpus @reclaimable_cpus end |
#time_created ⇒ DateTime
The date and time that the Autonomous VM cluster was created.
43 44 45 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 43 def time_created @time_created end |
#time_zone ⇒ String
The time zone to use for the Autonomous VM cluster. For details, see [DB System Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).
55 56 57 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 55 def time_zone @time_zone end |
#total_container_databases ⇒ Integer
The total number of Autonomous Container Databases that can be created.
84 85 86 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 84 def total_container_databases @total_container_databases end |
#vm_cluster_network_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster network.
63 64 65 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 63 def vm_cluster_network_id @vm_cluster_network_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 162 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_zone': :'timeZone', 'exadata_infrastructure_id': :'exadataInfrastructureId', 'vm_cluster_network_id': :'vmClusterNetworkId', 'is_local_backup_enabled': :'isLocalBackupEnabled', 'cpus_enabled': :'cpusEnabled', 'ocpus_enabled': :'ocpusEnabled', 'available_cpus': :'availableCpus', 'total_container_databases': :'totalContainerDatabases', 'memory_per_oracle_compute_unit_in_gbs': :'memoryPerOracleComputeUnitInGBs', 'cpu_core_count_per_node': :'cpuCoreCountPerNode', 'autonomous_data_storage_size_in_tbs': :'autonomousDataStorageSizeInTBs', 'maintenance_window': :'maintenanceWindow', 'last_maintenance_run_id': :'lastMaintenanceRunId', 'next_maintenance_run_id': :'nextMaintenanceRunId', 'memory_size_in_gbs': :'memorySizeInGBs', 'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'available_data_storage_size_in_tbs': :'availableDataStorageSizeInTBs', 'license_model': :'licenseModel', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'reclaimable_cpus': :'reclaimableCpus', 'available_container_databases': :'availableContainerDatabases', 'available_autonomous_data_storage_size_in_tbs': :'availableAutonomousDataStorageSizeInTBs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 201 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_zone': :'String', 'exadata_infrastructure_id': :'String', 'vm_cluster_network_id': :'String', 'is_local_backup_enabled': :'BOOLEAN', 'cpus_enabled': :'Integer', 'ocpus_enabled': :'Float', 'available_cpus': :'Integer', 'total_container_databases': :'Integer', 'memory_per_oracle_compute_unit_in_gbs': :'Integer', 'cpu_core_count_per_node': :'Integer', 'autonomous_data_storage_size_in_tbs': :'Float', 'maintenance_window': :'OCI::Database::Models::MaintenanceWindow', 'last_maintenance_run_id': :'String', 'next_maintenance_run_id': :'String', 'memory_size_in_gbs': :'Integer', 'db_node_storage_size_in_gbs': :'Integer', 'data_storage_size_in_tbs': :'Float', 'data_storage_size_in_gbs': :'Float', 'available_data_storage_size_in_tbs': :'Float', 'license_model': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'reclaimable_cpus': :'Integer', 'available_container_databases': :'Integer', 'available_autonomous_data_storage_size_in_tbs': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 498 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && time_created == other.time_created && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_zone == other.time_zone && exadata_infrastructure_id == other.exadata_infrastructure_id && vm_cluster_network_id == other.vm_cluster_network_id && is_local_backup_enabled == other.is_local_backup_enabled && cpus_enabled == other.cpus_enabled && ocpus_enabled == other.ocpus_enabled && available_cpus == other.available_cpus && total_container_databases == other.total_container_databases && memory_per_oracle_compute_unit_in_gbs == other.memory_per_oracle_compute_unit_in_gbs && cpu_core_count_per_node == other.cpu_core_count_per_node && autonomous_data_storage_size_in_tbs == other.autonomous_data_storage_size_in_tbs && maintenance_window == other.maintenance_window && last_maintenance_run_id == other.last_maintenance_run_id && next_maintenance_run_id == other.next_maintenance_run_id && memory_size_in_gbs == other.memory_size_in_gbs && db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs && data_storage_size_in_tbs == other.data_storage_size_in_tbs && data_storage_size_in_gbs == other.data_storage_size_in_gbs && available_data_storage_size_in_tbs == other.available_data_storage_size_in_tbs && license_model == other.license_model && == other. && == other. && reclaimable_cpus == other.reclaimable_cpus && available_container_databases == other.available_container_databases && available_autonomous_data_storage_size_in_tbs == other.available_autonomous_data_storage_size_in_tbs end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 558 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
538 539 540 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 538 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
547 548 549 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 547 def hash [id, compartment_id, display_name, time_created, lifecycle_state, lifecycle_details, time_zone, exadata_infrastructure_id, vm_cluster_network_id, is_local_backup_enabled, cpus_enabled, ocpus_enabled, available_cpus, total_container_databases, memory_per_oracle_compute_unit_in_gbs, cpu_core_count_per_node, autonomous_data_storage_size_in_tbs, maintenance_window, last_maintenance_run_id, next_maintenance_run_id, memory_size_in_gbs, db_node_storage_size_in_gbs, data_storage_size_in_tbs, data_storage_size_in_gbs, available_data_storage_size_in_tbs, license_model, , , reclaimable_cpus, available_container_databases, available_autonomous_data_storage_size_in_tbs].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
591 592 593 594 595 596 597 598 599 600 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 591 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
585 586 587 |
# File 'lib/oci/database/models/autonomous_vm_cluster_summary.rb', line 585 def to_s to_hash.to_s end |