Class: OCI::Database::Models::Backup
- Inherits:
-
Object
- Object
- OCI::Database::Models::Backup
- Defined in:
- lib/oci/database/models/backup.rb
Overview
A database backup. To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.us-phoenix-1.oraclecloud.com/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
rubocop:disable Metrics/LineLength
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_RESTORING = 'RESTORING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- TYPE_ENUM =
[ TYPE_INCREMENTAL = 'INCREMENTAL'.freeze, TYPE_FULL = 'FULL'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
The name of the availability domain where the database backup is stored.
-
#compartment_id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#database_edition ⇒ String
The Oracle Database edition of the DB system from which the database backup was taken.
-
#database_id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the database.
-
#db_data_size_in_mbs ⇒ Integer
Size of the database in megabytes (MB) at the time the backup was taken.
-
#display_name ⇒ String
The user-friendly name for the backup.
-
#id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the backup.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycleState.
-
#lifecycle_state ⇒ String
The current state of the backup.
-
#time_ended ⇒ DateTime
The date and time the backup was completed.
-
#time_started ⇒ DateTime
The date and time the backup started.
-
#type ⇒ String
The type of backup.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Backup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Backup
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/database/models/backup.rb', line 138 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.database_edition = attributes[:'databaseEdition'] if attributes[:'databaseEdition'] raise 'You cannot provide both :databaseEdition and :database_edition' if attributes.key?(:'databaseEdition') && attributes.key?(:'database_edition') self.database_edition = attributes[:'database_edition'] if attributes[:'database_edition'] self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.db_data_size_in_mbs = attributes[:'dbDataSizeInMBs'] if attributes[:'dbDataSizeInMBs'] raise 'You cannot provide both :dbDataSizeInMBs and :db_data_size_in_mbs' if attributes.key?(:'dbDataSizeInMBs') && attributes.key?(:'db_data_size_in_mbs') self.db_data_size_in_mbs = attributes[:'db_data_size_in_mbs'] if attributes[:'db_data_size_in_mbs'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded'] raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended') self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.type = attributes[:'type'] if attributes[:'type'] end |
Instance Attribute Details
#availability_domain ⇒ String
The name of the availability domain where the database backup is stored.
32 33 34 |
# File 'lib/oci/database/models/backup.rb', line 32 def availability_domain @availability_domain end |
#compartment_id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the compartment.
36 37 38 |
# File 'lib/oci/database/models/backup.rb', line 36 def compartment_id @compartment_id end |
#database_edition ⇒ String
The Oracle Database edition of the DB system from which the database backup was taken.
41 42 43 |
# File 'lib/oci/database/models/backup.rb', line 41 def database_edition @database_edition end |
#database_id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the database.
45 46 47 |
# File 'lib/oci/database/models/backup.rb', line 45 def database_id @database_id end |
#db_data_size_in_mbs ⇒ Integer
Size of the database in megabytes (MB) at the time the backup was taken.
50 51 52 |
# File 'lib/oci/database/models/backup.rb', line 50 def db_data_size_in_mbs @db_data_size_in_mbs end |
#display_name ⇒ String
The user-friendly name for the backup. The name does not have to be unique.
54 55 56 |
# File 'lib/oci/database/models/backup.rb', line 54 def display_name @display_name end |
#id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the backup.
58 59 60 |
# File 'lib/oci/database/models/backup.rb', line 58 def id @id end |
#lifecycle_details ⇒ String
Additional information about the current lifecycleState.
62 63 64 |
# File 'lib/oci/database/models/backup.rb', line 62 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the backup.
66 67 68 |
# File 'lib/oci/database/models/backup.rb', line 66 def lifecycle_state @lifecycle_state end |
#time_ended ⇒ DateTime
The date and time the backup was completed.
70 71 72 |
# File 'lib/oci/database/models/backup.rb', line 70 def time_ended @time_ended end |
#time_started ⇒ DateTime
The date and time the backup started.
74 75 76 |
# File 'lib/oci/database/models/backup.rb', line 74 def time_started @time_started end |
#type ⇒ String
The type of backup.
78 79 80 |
# File 'lib/oci/database/models/backup.rb', line 78 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/database/models/backup.rb', line 81 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'database_edition': :'databaseEdition', 'database_id': :'databaseId', 'db_data_size_in_mbs': :'dbDataSizeInMBs', 'display_name': :'displayName', 'id': :'id', 'lifecycle_details': :'lifecycleDetails', 'lifecycle_state': :'lifecycleState', 'time_ended': :'timeEnded', 'time_started': :'timeStarted', 'type': :'type' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/database/models/backup.rb', line 101 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'database_edition': :'String', 'database_id': :'String', 'db_data_size_in_mbs': :'Integer', 'display_name': :'String', 'id': :'String', 'lifecycle_details': :'String', 'lifecycle_state': :'String', 'time_ended': :'DateTime', 'time_started': :'DateTime', 'type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/database/models/backup.rb', line 246 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && database_edition == other.database_edition && database_id == other.database_id && db_data_size_in_mbs == other.db_data_size_in_mbs && display_name == other.display_name && id == other.id && lifecycle_details == other.lifecycle_details && lifecycle_state == other.lifecycle_state && time_ended == other.time_ended && time_started == other.time_started && type == other.type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/oci/database/models/backup.rb', line 286 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
266 267 268 |
# File 'lib/oci/database/models/backup.rb', line 266 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/oci/database/models/backup.rb', line 275 def hash [availability_domain, compartment_id, database_edition, database_id, db_data_size_in_mbs, display_name, id, lifecycle_details, lifecycle_state, time_ended, time_started, type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
318 319 320 321 322 323 324 325 326 |
# File 'lib/oci/database/models/backup.rb', line 318 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
312 313 314 |
# File 'lib/oci/database/models/backup.rb', line 312 def to_s to_hash.to_s end |