Class: OCI::Database::Models::CloudAutonomousVmCluster
- Inherits:
-
Object
- Object
- OCI::Database::Models::CloudAutonomousVmCluster
- Defined in:
- lib/oci/database/models/cloud_autonomous_vm_cluster.rb
Overview
Details of the cloud Autonomous VM cluster.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze, LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The name of the availability domain that the cloud Autonomous VM cluster is located in.
-
#cloud_exadata_infrastructure_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the cloud Autonomous VM cluster.
-
#data_storage_size_in_gbs ⇒ Float
The total data storage allocated, in gigabytes (GB).
-
#data_storage_size_in_tbs ⇒ Float
The total data storage allocated, in terabytes (TB).
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
User defined description of the cloud Autonomous VM cluster.
-
#display_name ⇒ String
[Required] The user-friendly name for the cloud Autonomous VM cluster.
-
#domain ⇒ String
The domain name for the cloud Autonomous VM cluster.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#hostname ⇒ String
The hostname for the cloud Autonomous VM cluster.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Cloud Autonomous VM cluster.
-
#last_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.
-
#last_update_history_entry_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance update history.
-
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the cloud Autonomous VM cluster.
-
#memory_size_in_gbs ⇒ Integer
The memory allocated in GBs.
-
#next_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.
-
#node_count ⇒ Integer
The number of database servers in the cloud VM cluster.
-
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to.
-
#ocpu_count ⇒ Float
The number of CPU cores enabled on the cloud Autonomous VM cluster.
-
#shape ⇒ String
The model name of the Exadata hardware running the cloud Autonomous VM cluster.
-
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet the cloud Autonomous VM Cluster is associated with.
-
#time_created ⇒ DateTime
The date and time that the cloud Autonomous VM cluster was created.
-
#time_updated ⇒ DateTime
The last date and time that the cloud Autonomous VM cluster was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CloudAutonomousVmCluster
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CloudAutonomousVmCluster
Initializes the object
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 263 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.last_update_history_entry_id = attributes[:'lastUpdateHistoryEntryId'] if attributes[:'lastUpdateHistoryEntryId'] raise 'You cannot provide both :lastUpdateHistoryEntryId and :last_update_history_entry_id' if attributes.key?(:'lastUpdateHistoryEntryId') && attributes.key?(:'last_update_history_entry_id') self.last_update_history_entry_id = attributes[:'last_update_history_entry_id'] if attributes[:'last_update_history_entry_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.hostname = attributes[:'hostname'] if attributes[:'hostname'] self.domain = attributes[:'domain'] if attributes[:'domain'] self.cloud_exadata_infrastructure_id = attributes[:'cloudExadataInfrastructureId'] if attributes[:'cloudExadataInfrastructureId'] raise 'You cannot provide both :cloudExadataInfrastructureId and :cloud_exadata_infrastructure_id' if attributes.key?(:'cloudExadataInfrastructureId') && attributes.key?(:'cloud_exadata_infrastructure_id') self.cloud_exadata_infrastructure_id = attributes[:'cloud_exadata_infrastructure_id'] if attributes[:'cloud_exadata_infrastructure_id'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.node_count = attributes[:'nodeCount'] if attributes[:'nodeCount'] raise 'You cannot provide both :nodeCount and :node_count' if attributes.key?(:'nodeCount') && attributes.key?(:'node_count') self.node_count = attributes[:'node_count'] if attributes[:'node_count'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.ocpu_count = attributes[:'ocpuCount'] if attributes[:'ocpuCount'] raise 'You cannot provide both :ocpuCount and :ocpu_count' if attributes.key?(:'ocpuCount') && attributes.key?(:'ocpu_count') self.ocpu_count = attributes[:'ocpu_count'] if attributes[:'ocpu_count'] self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs'] raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs') self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.last_maintenance_run_id = attributes[:'lastMaintenanceRunId'] if attributes[:'lastMaintenanceRunId'] raise 'You cannot provide both :lastMaintenanceRunId and :last_maintenance_run_id' if attributes.key?(:'lastMaintenanceRunId') && attributes.key?(:'last_maintenance_run_id') self.last_maintenance_run_id = attributes[:'last_maintenance_run_id'] if attributes[:'last_maintenance_run_id'] self.next_maintenance_run_id = attributes[:'nextMaintenanceRunId'] if attributes[:'nextMaintenanceRunId'] raise 'You cannot provide both :nextMaintenanceRunId and :next_maintenance_run_id' if attributes.key?(:'nextMaintenanceRunId') && attributes.key?(:'next_maintenance_run_id') self.next_maintenance_run_id = attributes[:'next_maintenance_run_id'] if attributes[:'next_maintenance_run_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The name of the availability domain that the cloud Autonomous VM cluster is located in.
43 44 45 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 43 def availability_domain @availability_domain end |
#cloud_exadata_infrastructure_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure.
98 99 100 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 98 def cloud_exadata_infrastructure_id @cloud_exadata_infrastructure_id end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
35 36 37 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 35 def compartment_id @compartment_id end |
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the cloud Autonomous VM cluster.
120 121 122 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 120 def cpu_core_count @cpu_core_count end |
#data_storage_size_in_gbs ⇒ Float
The total data storage allocated, in gigabytes (GB).
116 117 118 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 116 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#data_storage_size_in_tbs ⇒ Float
The total data storage allocated, in terabytes (TB).
112 113 114 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 112 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
158 159 160 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 158 def end |
#description ⇒ String
User defined description of the cloud Autonomous VM cluster.
39 40 41 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 39 def description @description end |
#display_name ⇒ String
[Required] The user-friendly name for the cloud Autonomous VM cluster. The name does not need to be unique.
74 75 76 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 74 def display_name @display_name end |
#domain ⇒ String
The domain name for the cloud Autonomous VM cluster.
94 95 96 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 94 def domain @domain end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
152 153 154 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 152 def end |
#hostname ⇒ String
The hostname for the cloud Autonomous VM cluster.
90 91 92 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 90 def hostname @hostname end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Cloud Autonomous VM cluster.
31 32 33 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 31 def id @id end |
#last_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.
140 141 142 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 140 def last_maintenance_run_id @last_maintenance_run_id end |
#last_update_history_entry_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance update history. This value is updated when a maintenance update starts.
66 67 68 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 66 def last_update_history_entry_id @last_update_history_entry_id end |
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database. Bring your own license (BYOL) allows you to apply your current on-premises Oracle software licenses to equivalent, highly automated Oracle PaaS and IaaS services in the cloud. License Included allows you to subscribe to new Oracle Database software licenses and the Database service. Note that when provisioning an Autonomous Database on [dedicated Exadata infrastructure](docs.oracle.com/en/cloud/paas/autonomous-database/index.html), this attribute must be null because the attribute is already set at the Autonomous Exadata Infrastructure level. When using [shared Exadata infrastructure](docs.oracle.com/en/cloud/paas/autonomous-database/index.html), if a value is not specified, the system will supply the value of BRING_YOUR_OWN_LICENSE.
136 137 138 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 136 def license_model @license_model end |
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
86 87 88 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 86 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the cloud Autonomous VM cluster.
70 71 72 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 70 def lifecycle_state @lifecycle_state end |
#memory_size_in_gbs ⇒ Integer
The memory allocated in GBs.
128 129 130 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 128 def memory_size_in_gbs @memory_size_in_gbs end |
#next_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.
144 145 146 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 144 def next_maintenance_run_id @next_maintenance_run_id end |
#node_count ⇒ Integer
The number of database servers in the cloud VM cluster.
108 109 110 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 108 def node_count @node_count end |
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**
-
Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.
62 63 64 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 62 def nsg_ids @nsg_ids end |
#ocpu_count ⇒ Float
The number of CPU cores enabled on the cloud Autonomous VM cluster. Only 1 decimal place is allowed for the fractional part.
124 125 126 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 124 def ocpu_count @ocpu_count end |
#shape ⇒ String
The model name of the Exadata hardware running the cloud Autonomous VM cluster.
103 104 105 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 103 def shape @shape end |
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet the cloud Autonomous VM Cluster is associated with.
**Subnet Restrictions:**
-
For Exadata and virtual machine 2-node RAC DB systems, do not use a subnet that overlaps with 192.168.128.0/20.
These subnets are used by the Oracle Clusterware private interconnect on the database instance. Specifying an overlapping subnet will cause the private interconnect to malfunction. This restriction applies to both the client subnet and backup subnet.
55 56 57 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 55 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
The date and time that the cloud Autonomous VM cluster was created.
78 79 80 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 78 def time_created @time_created end |
#time_updated ⇒ DateTime
The last date and time that the cloud Autonomous VM cluster was updated.
82 83 84 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 82 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 161 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'description': :'description', 'availability_domain': :'availabilityDomain', 'subnet_id': :'subnetId', 'nsg_ids': :'nsgIds', 'last_update_history_entry_id': :'lastUpdateHistoryEntryId', 'lifecycle_state': :'lifecycleState', 'display_name': :'displayName', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_details': :'lifecycleDetails', 'hostname': :'hostname', 'domain': :'domain', 'cloud_exadata_infrastructure_id': :'cloudExadataInfrastructureId', 'shape': :'shape', 'node_count': :'nodeCount', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'cpu_core_count': :'cpuCoreCount', 'ocpu_count': :'ocpuCount', 'memory_size_in_gbs': :'memorySizeInGBs', 'license_model': :'licenseModel', 'last_maintenance_run_id': :'lastMaintenanceRunId', 'next_maintenance_run_id': :'nextMaintenanceRunId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 196 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'description': :'String', 'availability_domain': :'String', 'subnet_id': :'String', 'nsg_ids': :'Array<String>', 'last_update_history_entry_id': :'String', 'lifecycle_state': :'String', 'display_name': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_details': :'String', 'hostname': :'String', 'domain': :'String', 'cloud_exadata_infrastructure_id': :'String', 'shape': :'String', 'node_count': :'Integer', 'data_storage_size_in_tbs': :'Float', 'data_storage_size_in_gbs': :'Float', 'cpu_core_count': :'Integer', 'ocpu_count': :'Float', 'memory_size_in_gbs': :'Integer', 'license_model': :'String', 'last_maintenance_run_id': :'String', 'next_maintenance_run_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 442 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && description == other.description && availability_domain == other.availability_domain && subnet_id == other.subnet_id && nsg_ids == other.nsg_ids && last_update_history_entry_id == other.last_update_history_entry_id && lifecycle_state == other.lifecycle_state && display_name == other.display_name && time_created == other.time_created && time_updated == other.time_updated && lifecycle_details == other.lifecycle_details && hostname == other.hostname && domain == other.domain && cloud_exadata_infrastructure_id == other.cloud_exadata_infrastructure_id && shape == other.shape && node_count == other.node_count && data_storage_size_in_tbs == other.data_storage_size_in_tbs && data_storage_size_in_gbs == other.data_storage_size_in_gbs && cpu_core_count == other.cpu_core_count && ocpu_count == other.ocpu_count && memory_size_in_gbs == other.memory_size_in_gbs && license_model == other.license_model && last_maintenance_run_id == other.last_maintenance_run_id && next_maintenance_run_id == other.next_maintenance_run_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 498 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
478 479 480 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 478 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
487 488 489 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 487 def hash [id, compartment_id, description, availability_domain, subnet_id, nsg_ids, last_update_history_entry_id, lifecycle_state, display_name, time_created, time_updated, lifecycle_details, hostname, domain, cloud_exadata_infrastructure_id, shape, node_count, data_storage_size_in_tbs, data_storage_size_in_gbs, cpu_core_count, ocpu_count, memory_size_in_gbs, license_model, last_maintenance_run_id, next_maintenance_run_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
531 532 533 534 535 536 537 538 539 540 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 531 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
525 526 527 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster.rb', line 525 def to_s to_hash.to_s end |