Class: OCI::Database::Models::CloudAutonomousVmClusterSummary
- Inherits:
-
Object
- Object
- OCI::Database::Models::CloudAutonomousVmClusterSummary
- Defined in:
- lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb
Overview
Details of the cloud Autonomous VM cluster.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze, LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#autonomous_data_storage_size_in_tbs ⇒ Float
The data disk group size allocated for Autonomous Databases, in TBs.
-
#availability_domain ⇒ String
**[Required]** The name of the availability domain that the cloud Autonomous VM cluster is located in.
-
#available_autonomous_data_storage_size_in_tbs ⇒ Float
The data disk group size available for Autonomous Databases, in TBs.
-
#available_container_databases ⇒ Integer
The number of Autonomous Container Databases that can be created with the currently available local storage.
-
#available_cpus ⇒ Float
CPU cores available for allocation to Autonomous Databases.
-
#cloud_exadata_infrastructure_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure.
-
#cluster_time_zone ⇒ String
The time zone of the Cloud Autonomous VM Cluster.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the cloud Autonomous VM cluster.
-
#data_storage_size_in_gbs ⇒ Float
The total data storage allocated, in gigabytes (GB).
-
#data_storage_size_in_tbs ⇒ Float
The total data storage allocated, in terabytes (TB).
-
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage allocated in GBs.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
User defined description of the cloud Autonomous VM cluster.
-
#display_name ⇒ String
**[Required]** The user-friendly name for the cloud Autonomous VM cluster.
-
#domain ⇒ String
The domain name for the cloud Autonomous VM cluster.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#hostname ⇒ String
The hostname for the cloud Autonomous VM cluster.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Cloud Autonomous VM cluster.
-
#last_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.
-
#last_update_history_entry_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance update history.
-
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the cloud Autonomous VM cluster.
-
#memory_per_oracle_compute_unit_in_gbs ⇒ Integer
The amount of memory (in GBs) enabled per each OCPU core.
-
#memory_size_in_gbs ⇒ Integer
The memory allocated in GBs.
-
#next_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.
-
#node_count ⇒ Integer
The number of database servers in the cloud VM cluster.
-
#nsg_ids ⇒ Array<String>
The list of [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) for the network security groups (NSGs) to which this resource belongs.
-
#ocpu_count ⇒ Float
The number of CPU cores enabled on the cloud Autonomous VM cluster.
-
#reclaimable_cpus ⇒ Float
CPU cores that continue to be included in the count of OCPUs available to the Autonomous Container Database even after one of its Autonomous Database is terminated or scaled down.
-
#shape ⇒ String
The model name of the Exadata hardware running the cloud Autonomous VM cluster.
-
#subnet_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet the cloud Autonomous VM Cluster is associated with.
-
#time_created ⇒ DateTime
The date and time that the cloud Autonomous VM cluster was created.
-
#time_updated ⇒ DateTime
The last date and time that the cloud Autonomous VM cluster was updated.
-
#total_container_databases ⇒ Integer
The total number of Autonomous Container Databases that can be created with the allocated local storage.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CloudAutonomousVmClusterSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CloudAutonomousVmClusterSummary
Initializes the object
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 326 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.last_update_history_entry_id = attributes[:'lastUpdateHistoryEntryId'] if attributes[:'lastUpdateHistoryEntryId'] raise 'You cannot provide both :lastUpdateHistoryEntryId and :last_update_history_entry_id' if attributes.key?(:'lastUpdateHistoryEntryId') && attributes.key?(:'last_update_history_entry_id') self.last_update_history_entry_id = attributes[:'last_update_history_entry_id'] if attributes[:'last_update_history_entry_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.cluster_time_zone = attributes[:'clusterTimeZone'] if attributes[:'clusterTimeZone'] raise 'You cannot provide both :clusterTimeZone and :cluster_time_zone' if attributes.key?(:'clusterTimeZone') && attributes.key?(:'cluster_time_zone') self.cluster_time_zone = attributes[:'cluster_time_zone'] if attributes[:'cluster_time_zone'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.hostname = attributes[:'hostname'] if attributes[:'hostname'] self.domain = attributes[:'domain'] if attributes[:'domain'] self.cloud_exadata_infrastructure_id = attributes[:'cloudExadataInfrastructureId'] if attributes[:'cloudExadataInfrastructureId'] raise 'You cannot provide both :cloudExadataInfrastructureId and :cloud_exadata_infrastructure_id' if attributes.key?(:'cloudExadataInfrastructureId') && attributes.key?(:'cloud_exadata_infrastructure_id') self.cloud_exadata_infrastructure_id = attributes[:'cloud_exadata_infrastructure_id'] if attributes[:'cloud_exadata_infrastructure_id'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.node_count = attributes[:'nodeCount'] if attributes[:'nodeCount'] raise 'You cannot provide both :nodeCount and :node_count' if attributes.key?(:'nodeCount') && attributes.key?(:'node_count') self.node_count = attributes[:'node_count'] if attributes[:'node_count'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.ocpu_count = attributes[:'ocpuCount'] if attributes[:'ocpuCount'] raise 'You cannot provide both :ocpuCount and :ocpu_count' if attributes.key?(:'ocpuCount') && attributes.key?(:'ocpu_count') self.ocpu_count = attributes[:'ocpu_count'] if attributes[:'ocpu_count'] self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs'] raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs') self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.last_maintenance_run_id = attributes[:'lastMaintenanceRunId'] if attributes[:'lastMaintenanceRunId'] raise 'You cannot provide both :lastMaintenanceRunId and :last_maintenance_run_id' if attributes.key?(:'lastMaintenanceRunId') && attributes.key?(:'last_maintenance_run_id') self.last_maintenance_run_id = attributes[:'last_maintenance_run_id'] if attributes[:'last_maintenance_run_id'] self.next_maintenance_run_id = attributes[:'nextMaintenanceRunId'] if attributes[:'nextMaintenanceRunId'] raise 'You cannot provide both :nextMaintenanceRunId and :next_maintenance_run_id' if attributes.key?(:'nextMaintenanceRunId') && attributes.key?(:'next_maintenance_run_id') self.next_maintenance_run_id = attributes[:'next_maintenance_run_id'] if attributes[:'next_maintenance_run_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.available_cpus = attributes[:'availableCpus'] if attributes[:'availableCpus'] raise 'You cannot provide both :availableCpus and :available_cpus' if attributes.key?(:'availableCpus') && attributes.key?(:'available_cpus') self.available_cpus = attributes[:'available_cpus'] if attributes[:'available_cpus'] self.reclaimable_cpus = attributes[:'reclaimableCpus'] if attributes[:'reclaimableCpus'] raise 'You cannot provide both :reclaimableCpus and :reclaimable_cpus' if attributes.key?(:'reclaimableCpus') && attributes.key?(:'reclaimable_cpus') self.reclaimable_cpus = attributes[:'reclaimable_cpus'] if attributes[:'reclaimable_cpus'] self.available_container_databases = attributes[:'availableContainerDatabases'] if attributes[:'availableContainerDatabases'] raise 'You cannot provide both :availableContainerDatabases and :available_container_databases' if attributes.key?(:'availableContainerDatabases') && attributes.key?(:'available_container_databases') self.available_container_databases = attributes[:'available_container_databases'] if attributes[:'available_container_databases'] self.total_container_databases = attributes[:'totalContainerDatabases'] if attributes[:'totalContainerDatabases'] raise 'You cannot provide both :totalContainerDatabases and :total_container_databases' if attributes.key?(:'totalContainerDatabases') && attributes.key?(:'total_container_databases') self.total_container_databases = attributes[:'total_container_databases'] if attributes[:'total_container_databases'] self.available_autonomous_data_storage_size_in_tbs = attributes[:'availableAutonomousDataStorageSizeInTBs'] if attributes[:'availableAutonomousDataStorageSizeInTBs'] raise 'You cannot provide both :availableAutonomousDataStorageSizeInTBs and :available_autonomous_data_storage_size_in_tbs' if attributes.key?(:'availableAutonomousDataStorageSizeInTBs') && attributes.key?(:'available_autonomous_data_storage_size_in_tbs') self.available_autonomous_data_storage_size_in_tbs = attributes[:'available_autonomous_data_storage_size_in_tbs'] if attributes[:'available_autonomous_data_storage_size_in_tbs'] self.autonomous_data_storage_size_in_tbs = attributes[:'autonomousDataStorageSizeInTBs'] if attributes[:'autonomousDataStorageSizeInTBs'] raise 'You cannot provide both :autonomousDataStorageSizeInTBs and :autonomous_data_storage_size_in_tbs' if attributes.key?(:'autonomousDataStorageSizeInTBs') && attributes.key?(:'autonomous_data_storage_size_in_tbs') self.autonomous_data_storage_size_in_tbs = attributes[:'autonomous_data_storage_size_in_tbs'] if attributes[:'autonomous_data_storage_size_in_tbs'] self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs'] raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs') self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs'] self.memory_per_oracle_compute_unit_in_gbs = attributes[:'memoryPerOracleComputeUnitInGBs'] if attributes[:'memoryPerOracleComputeUnitInGBs'] raise 'You cannot provide both :memoryPerOracleComputeUnitInGBs and :memory_per_oracle_compute_unit_in_gbs' if attributes.key?(:'memoryPerOracleComputeUnitInGBs') && attributes.key?(:'memory_per_oracle_compute_unit_in_gbs') self.memory_per_oracle_compute_unit_in_gbs = attributes[:'memory_per_oracle_compute_unit_in_gbs'] if attributes[:'memory_per_oracle_compute_unit_in_gbs'] end |
Instance Attribute Details
#autonomous_data_storage_size_in_tbs ⇒ Float
The data disk group size allocated for Autonomous Databases, in TBs.
186 187 188 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 186 def autonomous_data_storage_size_in_tbs @autonomous_data_storage_size_in_tbs end |
#availability_domain ⇒ String
**[Required]** The name of the availability domain that the cloud Autonomous VM cluster is located in.
43 44 45 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 43 def availability_domain @availability_domain end |
#available_autonomous_data_storage_size_in_tbs ⇒ Float
The data disk group size available for Autonomous Databases, in TBs.
182 183 184 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 182 def available_autonomous_data_storage_size_in_tbs @available_autonomous_data_storage_size_in_tbs end |
#available_container_databases ⇒ Integer
The number of Autonomous Container Databases that can be created with the currently available local storage.
174 175 176 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 174 def available_container_databases @available_container_databases end |
#available_cpus ⇒ Float
CPU cores available for allocation to Autonomous Databases.
166 167 168 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 166 def available_cpus @available_cpus end |
#cloud_exadata_infrastructure_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure.
102 103 104 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 102 def cloud_exadata_infrastructure_id @cloud_exadata_infrastructure_id end |
#cluster_time_zone ⇒ String
The time zone of the Cloud Autonomous VM Cluster.
86 87 88 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 86 def cluster_time_zone @cluster_time_zone end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
35 36 37 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 35 def compartment_id @compartment_id end |
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the cloud Autonomous VM cluster.
124 125 126 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 124 def cpu_core_count @cpu_core_count end |
#data_storage_size_in_gbs ⇒ Float
The total data storage allocated, in gigabytes (GB).
120 121 122 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 120 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#data_storage_size_in_tbs ⇒ Float
The total data storage allocated, in terabytes (TB).
116 117 118 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 116 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage allocated in GBs.
190 191 192 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 190 def db_node_storage_size_in_gbs @db_node_storage_size_in_gbs end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
162 163 164 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 162 def @defined_tags end |
#description ⇒ String
User defined description of the cloud Autonomous VM cluster.
39 40 41 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 39 def description @description end |
#display_name ⇒ String
**[Required]** The user-friendly name for the cloud Autonomous VM cluster. The name does not need to be unique.
74 75 76 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 74 def display_name @display_name end |
#domain ⇒ String
The domain name for the cloud Autonomous VM cluster.
98 99 100 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 98 def domain @domain end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
156 157 158 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 156 def @freeform_tags end |
#hostname ⇒ String
The hostname for the cloud Autonomous VM cluster.
94 95 96 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 94 def hostname @hostname end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Cloud Autonomous VM cluster.
31 32 33 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 31 def id @id end |
#last_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.
144 145 146 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 144 def last_maintenance_run_id @last_maintenance_run_id end |
#last_update_history_entry_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance update history. This value is updated when a maintenance update starts.
66 67 68 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 66 def last_update_history_entry_id @last_update_history_entry_id end |
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database. Bring your own license (BYOL) allows you to apply your current on-premises Oracle software licenses to equivalent, highly automated Oracle PaaS and IaaS services in the cloud. License Included allows you to subscribe to new Oracle Database software licenses and the Database service. Note that when provisioning an Autonomous Database on [dedicated Exadata infrastructure](docs.oracle.com/en/cloud/paas/autonomous-database/index.html), this attribute must be null because the attribute is already set at the Autonomous Exadata Infrastructure level. When using [shared Exadata infrastructure](docs.oracle.com/en/cloud/paas/autonomous-database/index.html), if a value is not specified, the system will supply the value of `BRING_YOUR_OWN_LICENSE`.
140 141 142 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 140 def license_model @license_model end |
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
90 91 92 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 90 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the cloud Autonomous VM cluster.
70 71 72 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 70 def lifecycle_state @lifecycle_state end |
#memory_per_oracle_compute_unit_in_gbs ⇒ Integer
The amount of memory (in GBs) enabled per each OCPU core.
194 195 196 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 194 def memory_per_oracle_compute_unit_in_gbs @memory_per_oracle_compute_unit_in_gbs end |
#memory_size_in_gbs ⇒ Integer
The memory allocated in GBs.
132 133 134 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 132 def memory_size_in_gbs @memory_size_in_gbs end |
#next_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.
148 149 150 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 148 def next_maintenance_run_id @next_maintenance_run_id end |
#node_count ⇒ Integer
The number of database servers in the cloud VM cluster.
112 113 114 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 112 def node_count @node_count end |
#nsg_ids ⇒ Array<String>
The list of [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) for the network security groups (NSGs) to which this resource belongs. Setting this to an empty list removes all resources from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**
-
A network security group (NSG) is optional for Autonomous Databases with private access. The nsgIds list can be empty.
62 63 64 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 62 def nsg_ids @nsg_ids end |
#ocpu_count ⇒ Float
The number of CPU cores enabled on the cloud Autonomous VM cluster. Only 1 decimal place is allowed for the fractional part.
128 129 130 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 128 def ocpu_count @ocpu_count end |
#reclaimable_cpus ⇒ Float
CPU cores that continue to be included in the count of OCPUs available to the Autonomous Container Database even after one of its Autonomous Database is terminated or scaled down. You can release them to the available OCPUs at its parent AVMC level by restarting the Autonomous Container Database.
170 171 172 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 170 def reclaimable_cpus @reclaimable_cpus end |
#shape ⇒ String
The model name of the Exadata hardware running the cloud Autonomous VM cluster.
107 108 109 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 107 def shape @shape end |
#subnet_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet the cloud Autonomous VM Cluster is associated with.
**Subnet Restrictions:**
-
For Exadata and virtual machine 2-node RAC DB systems, do not use a subnet that overlaps with 192.168.128.0/20.
These subnets are used by the Oracle Clusterware private interconnect on the database instance. Specifying an overlapping subnet will cause the private interconnect to malfunction. This restriction applies to both the client subnet and backup subnet.
55 56 57 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 55 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
The date and time that the cloud Autonomous VM cluster was created.
78 79 80 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 78 def time_created @time_created end |
#time_updated ⇒ DateTime
The last date and time that the cloud Autonomous VM cluster was updated.
82 83 84 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 82 def time_updated @time_updated end |
#total_container_databases ⇒ Integer
The total number of Autonomous Container Databases that can be created with the allocated local storage.
178 179 180 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 178 def total_container_databases @total_container_databases end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 197 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'description': :'description', 'availability_domain': :'availabilityDomain', 'subnet_id': :'subnetId', 'nsg_ids': :'nsgIds', 'last_update_history_entry_id': :'lastUpdateHistoryEntryId', 'lifecycle_state': :'lifecycleState', 'display_name': :'displayName', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'cluster_time_zone': :'clusterTimeZone', 'lifecycle_details': :'lifecycleDetails', 'hostname': :'hostname', 'domain': :'domain', 'cloud_exadata_infrastructure_id': :'cloudExadataInfrastructureId', 'shape': :'shape', 'node_count': :'nodeCount', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'cpu_core_count': :'cpuCoreCount', 'ocpu_count': :'ocpuCount', 'memory_size_in_gbs': :'memorySizeInGBs', 'license_model': :'licenseModel', 'last_maintenance_run_id': :'lastMaintenanceRunId', 'next_maintenance_run_id': :'nextMaintenanceRunId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'available_cpus': :'availableCpus', 'reclaimable_cpus': :'reclaimableCpus', 'available_container_databases': :'availableContainerDatabases', 'total_container_databases': :'totalContainerDatabases', 'available_autonomous_data_storage_size_in_tbs': :'availableAutonomousDataStorageSizeInTBs', 'autonomous_data_storage_size_in_tbs': :'autonomousDataStorageSizeInTBs', 'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs', 'memory_per_oracle_compute_unit_in_gbs': :'memoryPerOracleComputeUnitInGBs' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 241 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'description': :'String', 'availability_domain': :'String', 'subnet_id': :'String', 'nsg_ids': :'Array<String>', 'last_update_history_entry_id': :'String', 'lifecycle_state': :'String', 'display_name': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'cluster_time_zone': :'String', 'lifecycle_details': :'String', 'hostname': :'String', 'domain': :'String', 'cloud_exadata_infrastructure_id': :'String', 'shape': :'String', 'node_count': :'Integer', 'data_storage_size_in_tbs': :'Float', 'data_storage_size_in_gbs': :'Float', 'cpu_core_count': :'Integer', 'ocpu_count': :'Float', 'memory_size_in_gbs': :'Integer', 'license_model': :'String', 'last_maintenance_run_id': :'String', 'next_maintenance_run_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'available_cpus': :'Float', 'reclaimable_cpus': :'Float', 'available_container_databases': :'Integer', 'total_container_databases': :'Integer', 'available_autonomous_data_storage_size_in_tbs': :'Float', 'autonomous_data_storage_size_in_tbs': :'Float', 'db_node_storage_size_in_gbs': :'Integer', 'memory_per_oracle_compute_unit_in_gbs': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 562 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && description == other.description && availability_domain == other.availability_domain && subnet_id == other.subnet_id && nsg_ids == other.nsg_ids && last_update_history_entry_id == other.last_update_history_entry_id && lifecycle_state == other.lifecycle_state && display_name == other.display_name && time_created == other.time_created && time_updated == other.time_updated && cluster_time_zone == other.cluster_time_zone && lifecycle_details == other.lifecycle_details && hostname == other.hostname && domain == other.domain && cloud_exadata_infrastructure_id == other.cloud_exadata_infrastructure_id && shape == other.shape && node_count == other.node_count && data_storage_size_in_tbs == other.data_storage_size_in_tbs && data_storage_size_in_gbs == other.data_storage_size_in_gbs && cpu_core_count == other.cpu_core_count && ocpu_count == other.ocpu_count && memory_size_in_gbs == other.memory_size_in_gbs && license_model == other.license_model && last_maintenance_run_id == other.last_maintenance_run_id && next_maintenance_run_id == other.next_maintenance_run_id && == other. && == other. && available_cpus == other.available_cpus && reclaimable_cpus == other.reclaimable_cpus && available_container_databases == other.available_container_databases && total_container_databases == other.total_container_databases && available_autonomous_data_storage_size_in_tbs == other.available_autonomous_data_storage_size_in_tbs && autonomous_data_storage_size_in_tbs == other.autonomous_data_storage_size_in_tbs && db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs && memory_per_oracle_compute_unit_in_gbs == other.memory_per_oracle_compute_unit_in_gbs end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 627 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
607 608 609 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 607 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
616 617 618 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 616 def hash [id, compartment_id, description, availability_domain, subnet_id, nsg_ids, last_update_history_entry_id, lifecycle_state, display_name, time_created, time_updated, cluster_time_zone, lifecycle_details, hostname, domain, cloud_exadata_infrastructure_id, shape, node_count, data_storage_size_in_tbs, data_storage_size_in_gbs, cpu_core_count, ocpu_count, memory_size_in_gbs, license_model, last_maintenance_run_id, next_maintenance_run_id, , , available_cpus, reclaimable_cpus, available_container_databases, total_container_databases, available_autonomous_data_storage_size_in_tbs, autonomous_data_storage_size_in_tbs, db_node_storage_size_in_gbs, memory_per_oracle_compute_unit_in_gbs].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
660 661 662 663 664 665 666 667 668 669 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 660 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
654 655 656 |
# File 'lib/oci/database/models/cloud_autonomous_vm_cluster_summary.rb', line 654 def to_s to_hash.to_s end |