Class: OCI::Database::Models::CloudVmCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/cloud_vm_cluster.rb

Overview

Details of the cloud VM cluster. Applies to Exadata Cloud Service instances only.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze,
  LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DISK_REDUNDANCY_ENUM =
[
  DISK_REDUNDANCY_HIGH = 'HIGH'.freeze,
  DISK_REDUNDANCY_NORMAL = 'NORMAL'.freeze,
  DISK_REDUNDANCY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CloudVmCluster

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :iorm_config_cache (OCI::Database::Models::ExadataIormConfig)

    The value to assign to the #iorm_config_cache property

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :availability_domain (String)

    The value to assign to the #availability_domain property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :backup_subnet_id (String)

    The value to assign to the #backup_subnet_id property

  • :nsg_ids (Array<String>)

    The value to assign to the #nsg_ids property

  • :backup_network_nsg_ids (Array<String>)

    The value to assign to the #backup_network_nsg_ids property

  • :last_update_history_entry_id (String)

    The value to assign to the #last_update_history_entry_id property

  • :shape (String)

    The value to assign to the #shape property

  • :listener_port (Integer)

    The value to assign to the #listener_port property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :node_count (Integer)

    The value to assign to the #node_count property

  • :storage_size_in_gbs (Integer)

    The value to assign to the #storage_size_in_gbs property

  • :display_name (String)

    The value to assign to the #display_name property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :time_zone (String)

    The value to assign to the #time_zone property

  • :hostname (String)

    The value to assign to the #hostname property

  • :domain (String)

    The value to assign to the #domain property

  • :cpu_core_count (Integer)

    The value to assign to the #cpu_core_count property

  • :cluster_name (String)

    The value to assign to the #cluster_name property

  • :data_storage_percentage (Integer)

    The value to assign to the #data_storage_percentage property

  • :is_local_backup_enabled (BOOLEAN)

    The value to assign to the #is_local_backup_enabled property

  • :cloud_exadata_infrastructure_id (String)

    The value to assign to the #cloud_exadata_infrastructure_id property

  • :is_sparse_diskgroup_enabled (BOOLEAN)

    The value to assign to the #is_sparse_diskgroup_enabled property

  • :gi_version (String)

    The value to assign to the #gi_version property

  • :system_version (String)

    The value to assign to the #system_version property

  • :ssh_public_keys (Array<String>)

    The value to assign to the #ssh_public_keys property

  • :license_model (String)

    The value to assign to the #license_model property

  • :disk_redundancy (String)

    The value to assign to the #disk_redundancy property

  • :scan_ip_ids (Array<String>)

    The value to assign to the #scan_ip_ids property

  • :vip_ids (Array<String>)

    The value to assign to the #vip_ids property

  • :scan_dns_record_id (String)

    The value to assign to the #scan_dns_record_id property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :scan_dns_name (String)

    The value to assign to the #scan_dns_name property

  • :zone_id (String)

    The value to assign to the #zone_id property



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 367

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.iorm_config_cache = attributes[:'iormConfigCache'] if attributes[:'iormConfigCache']

  raise 'You cannot provide both :iormConfigCache and :iorm_config_cache' if attributes.key?(:'iormConfigCache') && attributes.key?(:'iorm_config_cache')

  self.iorm_config_cache = attributes[:'iorm_config_cache'] if attributes[:'iorm_config_cache']

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.backup_subnet_id = attributes[:'backupSubnetId'] if attributes[:'backupSubnetId']

  raise 'You cannot provide both :backupSubnetId and :backup_subnet_id' if attributes.key?(:'backupSubnetId') && attributes.key?(:'backup_subnet_id')

  self.backup_subnet_id = attributes[:'backup_subnet_id'] if attributes[:'backup_subnet_id']

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.backup_network_nsg_ids = attributes[:'backupNetworkNsgIds'] if attributes[:'backupNetworkNsgIds']

  raise 'You cannot provide both :backupNetworkNsgIds and :backup_network_nsg_ids' if attributes.key?(:'backupNetworkNsgIds') && attributes.key?(:'backup_network_nsg_ids')

  self.backup_network_nsg_ids = attributes[:'backup_network_nsg_ids'] if attributes[:'backup_network_nsg_ids']

  self.last_update_history_entry_id = attributes[:'lastUpdateHistoryEntryId'] if attributes[:'lastUpdateHistoryEntryId']

  raise 'You cannot provide both :lastUpdateHistoryEntryId and :last_update_history_entry_id' if attributes.key?(:'lastUpdateHistoryEntryId') && attributes.key?(:'last_update_history_entry_id')

  self.last_update_history_entry_id = attributes[:'last_update_history_entry_id'] if attributes[:'last_update_history_entry_id']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.listener_port = attributes[:'listenerPort'] if attributes[:'listenerPort']

  raise 'You cannot provide both :listenerPort and :listener_port' if attributes.key?(:'listenerPort') && attributes.key?(:'listener_port')

  self.listener_port = attributes[:'listener_port'] if attributes[:'listener_port']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.node_count = attributes[:'nodeCount'] if attributes[:'nodeCount']

  raise 'You cannot provide both :nodeCount and :node_count' if attributes.key?(:'nodeCount') && attributes.key?(:'node_count')

  self.node_count = attributes[:'node_count'] if attributes[:'node_count']

  self.storage_size_in_gbs = attributes[:'storageSizeInGBs'] if attributes[:'storageSizeInGBs']

  raise 'You cannot provide both :storageSizeInGBs and :storage_size_in_gbs' if attributes.key?(:'storageSizeInGBs') && attributes.key?(:'storage_size_in_gbs')

  self.storage_size_in_gbs = attributes[:'storage_size_in_gbs'] if attributes[:'storage_size_in_gbs']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone']

  raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone')

  self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone']

  self.hostname = attributes[:'hostname'] if attributes[:'hostname']

  self.domain = attributes[:'domain'] if attributes[:'domain']

  self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount']

  raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count')

  self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count']

  self.cluster_name = attributes[:'clusterName'] if attributes[:'clusterName']

  raise 'You cannot provide both :clusterName and :cluster_name' if attributes.key?(:'clusterName') && attributes.key?(:'cluster_name')

  self.cluster_name = attributes[:'cluster_name'] if attributes[:'cluster_name']

  self.data_storage_percentage = attributes[:'dataStoragePercentage'] if attributes[:'dataStoragePercentage']

  raise 'You cannot provide both :dataStoragePercentage and :data_storage_percentage' if attributes.key?(:'dataStoragePercentage') && attributes.key?(:'data_storage_percentage')

  self.data_storage_percentage = attributes[:'data_storage_percentage'] if attributes[:'data_storage_percentage']

  self.is_local_backup_enabled = attributes[:'isLocalBackupEnabled'] unless attributes[:'isLocalBackupEnabled'].nil?

  raise 'You cannot provide both :isLocalBackupEnabled and :is_local_backup_enabled' if attributes.key?(:'isLocalBackupEnabled') && attributes.key?(:'is_local_backup_enabled')

  self.is_local_backup_enabled = attributes[:'is_local_backup_enabled'] unless attributes[:'is_local_backup_enabled'].nil?

  self.cloud_exadata_infrastructure_id = attributes[:'cloudExadataInfrastructureId'] if attributes[:'cloudExadataInfrastructureId']

  raise 'You cannot provide both :cloudExadataInfrastructureId and :cloud_exadata_infrastructure_id' if attributes.key?(:'cloudExadataInfrastructureId') && attributes.key?(:'cloud_exadata_infrastructure_id')

  self.cloud_exadata_infrastructure_id = attributes[:'cloud_exadata_infrastructure_id'] if attributes[:'cloud_exadata_infrastructure_id']

  self.is_sparse_diskgroup_enabled = attributes[:'isSparseDiskgroupEnabled'] unless attributes[:'isSparseDiskgroupEnabled'].nil?

  raise 'You cannot provide both :isSparseDiskgroupEnabled and :is_sparse_diskgroup_enabled' if attributes.key?(:'isSparseDiskgroupEnabled') && attributes.key?(:'is_sparse_diskgroup_enabled')

  self.is_sparse_diskgroup_enabled = attributes[:'is_sparse_diskgroup_enabled'] unless attributes[:'is_sparse_diskgroup_enabled'].nil?

  self.gi_version = attributes[:'giVersion'] if attributes[:'giVersion']

  raise 'You cannot provide both :giVersion and :gi_version' if attributes.key?(:'giVersion') && attributes.key?(:'gi_version')

  self.gi_version = attributes[:'gi_version'] if attributes[:'gi_version']

  self.system_version = attributes[:'systemVersion'] if attributes[:'systemVersion']

  raise 'You cannot provide both :systemVersion and :system_version' if attributes.key?(:'systemVersion') && attributes.key?(:'system_version')

  self.system_version = attributes[:'system_version'] if attributes[:'system_version']

  self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys']

  raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys')

  self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys']

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.disk_redundancy = attributes[:'diskRedundancy'] if attributes[:'diskRedundancy']

  raise 'You cannot provide both :diskRedundancy and :disk_redundancy' if attributes.key?(:'diskRedundancy') && attributes.key?(:'disk_redundancy')

  self.disk_redundancy = attributes[:'disk_redundancy'] if attributes[:'disk_redundancy']

  self.scan_ip_ids = attributes[:'scanIpIds'] if attributes[:'scanIpIds']

  raise 'You cannot provide both :scanIpIds and :scan_ip_ids' if attributes.key?(:'scanIpIds') && attributes.key?(:'scan_ip_ids')

  self.scan_ip_ids = attributes[:'scan_ip_ids'] if attributes[:'scan_ip_ids']

  self.vip_ids = attributes[:'vipIds'] if attributes[:'vipIds']

  raise 'You cannot provide both :vipIds and :vip_ids' if attributes.key?(:'vipIds') && attributes.key?(:'vip_ids')

  self.vip_ids = attributes[:'vip_ids'] if attributes[:'vip_ids']

  self.scan_dns_record_id = attributes[:'scanDnsRecordId'] if attributes[:'scanDnsRecordId']

  raise 'You cannot provide both :scanDnsRecordId and :scan_dns_record_id' if attributes.key?(:'scanDnsRecordId') && attributes.key?(:'scan_dns_record_id')

  self.scan_dns_record_id = attributes[:'scan_dns_record_id'] if attributes[:'scan_dns_record_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.scan_dns_name = attributes[:'scanDnsName'] if attributes[:'scanDnsName']

  raise 'You cannot provide both :scanDnsName and :scan_dns_name' if attributes.key?(:'scanDnsName') && attributes.key?(:'scan_dns_name')

  self.scan_dns_name = attributes[:'scan_dns_name'] if attributes[:'scan_dns_name']

  self.zone_id = attributes[:'zoneId'] if attributes[:'zoneId']

  raise 'You cannot provide both :zoneId and :zone_id' if attributes.key?(:'zoneId') && attributes.key?(:'zone_id')

  self.zone_id = attributes[:'zone_id'] if attributes[:'zone_id']
end

Instance Attribute Details

#availability_domainString

[Required] The name of the availability domain that the cloud Exadata infrastructure resource is located in.

Returns:

  • (String)


48
49
50
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 48

def availability_domain
  @availability_domain
end

#backup_network_nsg_idsArray<String>

A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). Applicable only to Exadata systems.

Returns:

  • (Array<String>)


79
80
81
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 79

def backup_network_nsg_ids
  @backup_network_nsg_ids
end

#backup_subnet_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup network subnet associated with the cloud VM cluster.

**Subnet Restriction:** See the subnet restrictions information for subnetId.

Returns:

  • (String)


67
68
69
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 67

def backup_subnet_id
  @backup_subnet_id
end

#cloud_exadata_infrastructure_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure.

Returns:

  • (String)


153
154
155
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 153

def cloud_exadata_infrastructure_id
  @cloud_exadata_infrastructure_id
end

#cluster_nameString

The cluster name for cloud VM cluster. The cluster name must begin with an alphabetic character, and may contain hyphens (-). Underscores (_) are not permitted. The cluster name can be no longer than 11 characters and is not case sensitive.

Returns:

  • (String)


138
139
140
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 138

def cluster_name
  @cluster_name
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


44
45
46
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 44

def compartment_id
  @compartment_id
end

#cpu_core_countInteger

[Required] The number of CPU cores enabled on the cloud VM cluster.

Returns:

  • (Integer)


133
134
135
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 133

def cpu_core_count
  @cpu_core_count
end

#data_storage_percentageInteger

The percentage assigned to DATA storage (user data and database files). The remaining percentage is assigned to RECO storage (database redo logs, archive logs, and recovery manager backups). Accepted values are 35, 40, 60 and 80. The default is 80 percent assigned to DATA storage. See [Storage Configuration](docs.cloud.oracle.com/Content/Database/Concepts/exaoverview.htm#Exadata) in the Exadata documentation for details on the impact of the configuration settings on storage.

Returns:

  • (Integer)


144
145
146
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 144

def data_storage_percentage
  @data_storage_percentage
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


219
220
221
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 219

def defined_tags
  @defined_tags
end

#disk_redundancyString

The type of redundancy configured for the cloud Vm cluster. NORMAL is 2-way redundancy. HIGH is 3-way redundancy.

Returns:

  • (String)


182
183
184
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 182

def disk_redundancy
  @disk_redundancy
end

#display_nameString

[Required] The user-friendly name for the cloud VM cluster. The name does not need to be unique.

Returns:

  • (String)


109
110
111
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 109

def display_name
  @display_name
end

#domainString

[Required] The domain name for the cloud VM cluster.

Returns:

  • (String)


129
130
131
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 129

def domain
  @domain
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


213
214
215
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 213

def freeform_tags
  @freeform_tags
end

#gi_versionString

A valid Oracle Grid Infrastructure (GI) software version.

Returns:

  • (String)


162
163
164
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 162

def gi_version
  @gi_version
end

#hostnameString

[Required] The hostname for the cloud VM cluster.

Returns:

  • (String)


125
126
127
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 125

def hostname
  @hostname
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud VM cluster.

Returns:

  • (String)


40
41
42
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 40

def id
  @id
end

#iorm_config_cacheOCI::Database::Models::ExadataIormConfig



36
37
38
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 36

def iorm_config_cache
  @iorm_config_cache
end

#is_local_backup_enabledBOOLEAN

If true, database backup on local Exadata storage is configured for the cloud VM cluster. If false, database backup on local Exadata storage is not available in the cloud VM cluster.

Returns:

  • (BOOLEAN)


149
150
151
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 149

def is_local_backup_enabled
  @is_local_backup_enabled
end

#is_sparse_diskgroup_enabledBOOLEAN

If true, sparse disk group is configured for the cloud VM cluster. If false, sparse disk group is not created.

Returns:

  • (BOOLEAN)


158
159
160
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 158

def is_sparse_diskgroup_enabled
  @is_sparse_diskgroup_enabled
end

#last_update_history_entry_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance update history entry. This value is updated when a maintenance update starts.

Returns:

  • (String)


83
84
85
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 83

def last_update_history_entry_id
  @last_update_history_entry_id
end

#license_modelString

The Oracle license model that applies to the cloud VM cluster. The default is LICENSE_INCLUDED.

Returns:

  • (String)


175
176
177
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 175

def license_model
  @license_model
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


117
118
119
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 117

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the cloud VM cluster.

Returns:

  • (String)


96
97
98
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 96

def lifecycle_state
  @lifecycle_state
end

#listener_portInteger

The port number configured for the listener on the cloud VM cluster.

Returns:

  • (Integer)


92
93
94
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 92

def listener_port
  @listener_port
end

#node_countInteger

The number of nodes in the cloud VM cluster.

Returns:

  • (Integer)


101
102
103
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 101

def node_count
  @node_count
end

#nsg_idsArray<String>

A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**

  • Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

Returns:

  • (Array<String>)


74
75
76
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 74

def nsg_ids
  @nsg_ids
end

#scan_dns_nameString

The FQDN of the DNS record for the SCAN IP addresses that are associated with the cloud VM cluster.

Returns:

  • (String)


224
225
226
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 224

def scan_dns_name
  @scan_dns_name
end

#scan_dns_record_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DNS record for the SCAN IP addresses that are associated with the cloud VM cluster.

Returns:

  • (String)


205
206
207
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 205

def scan_dns_record_id
  @scan_dns_record_id
end

#scan_ip_idsArray<String>

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Single Client Access Name (SCAN) IP addresses associated with the cloud VM cluster. SCAN IP addresses are typically used for load balancing and are not assigned to any interface. Oracle Clusterware directs the requests to the appropriate nodes in the cluster.

Note: For a single-node DB system, this list is empty.

Returns:

  • (Array<String>)


191
192
193
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 191

def scan_ip_ids
  @scan_ip_ids
end

#shapeString

[Required] The model name of the Exadata hardware running the cloud VM cluster.

Returns:

  • (String)


88
89
90
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 88

def shape
  @shape
end

#ssh_public_keysArray<String>

[Required] The public key portion of one or more key pairs used for SSH access to the cloud VM cluster.

Returns:

  • (Array<String>)


170
171
172
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 170

def ssh_public_keys
  @ssh_public_keys
end

#storage_size_in_gbsInteger

The storage allocation for the disk group, in gigabytes (GB).

Returns:

  • (Integer)


105
106
107
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 105

def storage_size_in_gbs
  @storage_size_in_gbs
end

#subnet_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet associated with the cloud VM cluster.

**Subnet Restrictions:**

  • For Exadata and virtual machine 2-node RAC systems, do not use a subnet that overlaps with 192.168.128.0/20.

These subnets are used by the Oracle Clusterware private interconnect on the database instance. Specifying an overlapping subnet will cause the private interconnect to malfunction. This restriction applies to both the client subnet and backup subnet.

Returns:

  • (String)


60
61
62
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 60

def subnet_id
  @subnet_id
end

#system_versionString

Operating system version of the image.

Returns:

  • (String)


166
167
168
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 166

def system_version
  @system_version
end

#time_createdDateTime

The date and time that the cloud VM cluster was created.

Returns:

  • (DateTime)


113
114
115
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 113

def time_created
  @time_created
end

#time_zoneString

The time zone of the cloud VM cluster. For details, see [Exadata Infrastructure Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).

Returns:

  • (String)


121
122
123
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 121

def time_zone
  @time_zone
end

#vip_idsArray<String>

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the virtual IP (VIP) addresses associated with the cloud VM cluster. The Cluster Ready Services (CRS) creates and maintains one VIP address for each node in the Exadata Cloud Service instance to enable failover. If one node fails, the VIP is reassigned to another active node in the cluster.

Note: For a single-node DB system, this list is empty.

Returns:

  • (Array<String>)


200
201
202
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 200

def vip_ids
  @vip_ids
end

#zone_idString

The OCID of the zone the cloud VM cluster is associated with.

Returns:

  • (String)


229
230
231
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 229

def zone_id
  @zone_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 232

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'iorm_config_cache': :'iormConfigCache',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'availability_domain': :'availabilityDomain',
    'subnet_id': :'subnetId',
    'backup_subnet_id': :'backupSubnetId',
    'nsg_ids': :'nsgIds',
    'backup_network_nsg_ids': :'backupNetworkNsgIds',
    'last_update_history_entry_id': :'lastUpdateHistoryEntryId',
    'shape': :'shape',
    'listener_port': :'listenerPort',
    'lifecycle_state': :'lifecycleState',
    'node_count': :'nodeCount',
    'storage_size_in_gbs': :'storageSizeInGBs',
    'display_name': :'displayName',
    'time_created': :'timeCreated',
    'lifecycle_details': :'lifecycleDetails',
    'time_zone': :'timeZone',
    'hostname': :'hostname',
    'domain': :'domain',
    'cpu_core_count': :'cpuCoreCount',
    'cluster_name': :'clusterName',
    'data_storage_percentage': :'dataStoragePercentage',
    'is_local_backup_enabled': :'isLocalBackupEnabled',
    'cloud_exadata_infrastructure_id': :'cloudExadataInfrastructureId',
    'is_sparse_diskgroup_enabled': :'isSparseDiskgroupEnabled',
    'gi_version': :'giVersion',
    'system_version': :'systemVersion',
    'ssh_public_keys': :'sshPublicKeys',
    'license_model': :'licenseModel',
    'disk_redundancy': :'diskRedundancy',
    'scan_ip_ids': :'scanIpIds',
    'vip_ids': :'vipIds',
    'scan_dns_record_id': :'scanDnsRecordId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'scan_dns_name': :'scanDnsName',
    'zone_id': :'zoneId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 278

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'iorm_config_cache': :'OCI::Database::Models::ExadataIormConfig',
    'id': :'String',
    'compartment_id': :'String',
    'availability_domain': :'String',
    'subnet_id': :'String',
    'backup_subnet_id': :'String',
    'nsg_ids': :'Array<String>',
    'backup_network_nsg_ids': :'Array<String>',
    'last_update_history_entry_id': :'String',
    'shape': :'String',
    'listener_port': :'Integer',
    'lifecycle_state': :'String',
    'node_count': :'Integer',
    'storage_size_in_gbs': :'Integer',
    'display_name': :'String',
    'time_created': :'DateTime',
    'lifecycle_details': :'String',
    'time_zone': :'String',
    'hostname': :'String',
    'domain': :'String',
    'cpu_core_count': :'Integer',
    'cluster_name': :'String',
    'data_storage_percentage': :'Integer',
    'is_local_backup_enabled': :'BOOLEAN',
    'cloud_exadata_infrastructure_id': :'String',
    'is_sparse_diskgroup_enabled': :'BOOLEAN',
    'gi_version': :'String',
    'system_version': :'String',
    'ssh_public_keys': :'Array<String>',
    'license_model': :'String',
    'disk_redundancy': :'String',
    'scan_ip_ids': :'Array<String>',
    'vip_ids': :'Array<String>',
    'scan_dns_record_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'scan_dns_name': :'String',
    'zone_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 632

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    iorm_config_cache == other.iorm_config_cache &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    availability_domain == other.availability_domain &&
    subnet_id == other.subnet_id &&
    backup_subnet_id == other.backup_subnet_id &&
    nsg_ids == other.nsg_ids &&
    backup_network_nsg_ids == other.backup_network_nsg_ids &&
    last_update_history_entry_id == other.last_update_history_entry_id &&
    shape == other.shape &&
    listener_port == other.listener_port &&
    lifecycle_state == other.lifecycle_state &&
    node_count == other.node_count &&
    storage_size_in_gbs == other.storage_size_in_gbs &&
    display_name == other.display_name &&
    time_created == other.time_created &&
    lifecycle_details == other.lifecycle_details &&
    time_zone == other.time_zone &&
    hostname == other.hostname &&
    domain == other.domain &&
    cpu_core_count == other.cpu_core_count &&
    cluster_name == other.cluster_name &&
    data_storage_percentage == other.data_storage_percentage &&
    is_local_backup_enabled == other.is_local_backup_enabled &&
    cloud_exadata_infrastructure_id == other.cloud_exadata_infrastructure_id &&
    is_sparse_diskgroup_enabled == other.is_sparse_diskgroup_enabled &&
    gi_version == other.gi_version &&
    system_version == other.system_version &&
    ssh_public_keys == other.ssh_public_keys &&
    license_model == other.license_model &&
    disk_redundancy == other.disk_redundancy &&
    scan_ip_ids == other.scan_ip_ids &&
    vip_ids == other.vip_ids &&
    scan_dns_record_id == other.scan_dns_record_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    scan_dns_name == other.scan_dns_name &&
    zone_id == other.zone_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 699

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


679
680
681
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 679

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



688
689
690
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 688

def hash
  [iorm_config_cache, id, compartment_id, availability_domain, subnet_id, backup_subnet_id, nsg_ids, backup_network_nsg_ids, last_update_history_entry_id, shape, listener_port, lifecycle_state, node_count, storage_size_in_gbs, display_name, time_created, lifecycle_details, time_zone, hostname, domain, cpu_core_count, cluster_name, data_storage_percentage, is_local_backup_enabled, cloud_exadata_infrastructure_id, is_sparse_diskgroup_enabled, gi_version, system_version, ssh_public_keys, license_model, disk_redundancy, scan_ip_ids, vip_ids, scan_dns_record_id, freeform_tags, defined_tags, scan_dns_name, zone_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



732
733
734
735
736
737
738
739
740
741
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 732

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



726
727
728
# File 'lib/oci/database/models/cloud_vm_cluster.rb', line 726

def to_s
  to_hash.to_s
end