Class: OCI::Database::Models::CreateAutonomousContainerDatabaseDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateAutonomousContainerDatabaseDetails
- Defined in:
- lib/oci/database/models/create_autonomous_container_database_details.rb
Overview
Describes the required parameters for the creation of an Autonomous Container Database.
Constant Summary collapse
- SERVICE_LEVEL_AGREEMENT_TYPE_ENUM =
[ SERVICE_LEVEL_AGREEMENT_TYPE_STANDARD = 'STANDARD'.freeze, SERVICE_LEVEL_AGREEMENT_TYPE_AUTONOMOUS_DATAGUARD = 'AUTONOMOUS_DATAGUARD'.freeze ].freeze
- PROTECTION_MODE_ENUM =
[ PROTECTION_MODE_MAXIMUM_AVAILABILITY = 'MAXIMUM_AVAILABILITY'.freeze, PROTECTION_MODE_MAXIMUM_PERFORMANCE = 'MAXIMUM_PERFORMANCE'.freeze ].freeze
- PATCH_MODEL_ENUM =
[ PATCH_MODEL_RELEASE_UPDATES = 'RELEASE_UPDATES'.freeze, PATCH_MODEL_RELEASE_UPDATE_REVISIONS = 'RELEASE_UPDATE_REVISIONS'.freeze ].freeze
Instance Attribute Summary collapse
-
#autonomous_exadata_infrastructure_id ⇒ String
The OCID of the Autonomous Exadata Infrastructure.
-
#autonomous_vm_cluster_id ⇒ String
The OCID of the Autonomous VM Cluster.
- #backup_config ⇒ OCI::Database::Models::AutonomousContainerDatabaseBackupConfig
-
#cloud_autonomous_vm_cluster_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Autonomous Exadata VM Cluster.
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the Autonomous Container Database.
-
#db_unique_name ⇒ String
Deprecated. The
DB_UNIQUE_NAMEvalue is set by Oracle Cloud Infrastructure. -
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The display name for the Autonomous Container Database.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_automatic_failover_enabled ⇒ BOOLEAN
Indicates whether Automatic Failover is enabled for Autonomous Container Database Dataguard Association.
-
#key_store_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the key store.
-
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
-
#kms_key_version_id ⇒ String
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions.
- #maintenance_window_details ⇒ OCI::Database::Models::MaintenanceWindow
-
#patch_model ⇒ String
[Required] Database Patch model preference.
- #peer_autonomous_container_database_backup_config ⇒ OCI::Database::Models::PeerAutonomousContainerDatabaseBackupConfig
-
#peer_autonomous_container_database_compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the standby Autonomous Container Database will be created.
-
#peer_autonomous_container_database_display_name ⇒ String
The display name for the peer Autonomous Container Database.
-
#peer_autonomous_exadata_infrastructure_id ⇒ String
The OCID of the peer Autonomous Exadata Infrastructure for Autonomous Data Guard.
-
#peer_autonomous_vm_cluster_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the peer Autonomous VM cluster for Autonomous Data Guard.
-
#peer_cloud_autonomous_vm_cluster_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the peer cloud Autonomous Exadata VM Cluster.
-
#peer_db_unique_name ⇒ String
Deprecated. The
DB_UNIQUE_NAMEof the peer Autonomous Container Database in a Data Guard association is set by Oracle Cloud Infrastructure. -
#protection_mode ⇒ String
The protection mode of this Autonomous Data Guard association.
-
#service_level_agreement_type ⇒ String
The service level agreement type of the Autonomous Container Database.
-
#standby_maintenance_buffer_in_days ⇒ Integer
The scheduling detail for the quarterly maintenance window of the standby Autonomous Container Database.
-
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAutonomousContainerDatabaseDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAutonomousContainerDatabaseDetails
Initializes the object
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 245 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.db_unique_name = attributes[:'dbUniqueName'] if attributes[:'dbUniqueName'] raise 'You cannot provide both :dbUniqueName and :db_unique_name' if attributes.key?(:'dbUniqueName') && attributes.key?(:'db_unique_name') self.db_unique_name = attributes[:'db_unique_name'] if attributes[:'db_unique_name'] self.service_level_agreement_type = attributes[:'serviceLevelAgreementType'] if attributes[:'serviceLevelAgreementType'] raise 'You cannot provide both :serviceLevelAgreementType and :service_level_agreement_type' if attributes.key?(:'serviceLevelAgreementType') && attributes.key?(:'service_level_agreement_type') self.service_level_agreement_type = attributes[:'service_level_agreement_type'] if attributes[:'service_level_agreement_type'] self.autonomous_exadata_infrastructure_id = attributes[:'autonomousExadataInfrastructureId'] if attributes[:'autonomousExadataInfrastructureId'] raise 'You cannot provide both :autonomousExadataInfrastructureId and :autonomous_exadata_infrastructure_id' if attributes.key?(:'autonomousExadataInfrastructureId') && attributes.key?(:'autonomous_exadata_infrastructure_id') self.autonomous_exadata_infrastructure_id = attributes[:'autonomous_exadata_infrastructure_id'] if attributes[:'autonomous_exadata_infrastructure_id'] self.peer_autonomous_exadata_infrastructure_id = attributes[:'peerAutonomousExadataInfrastructureId'] if attributes[:'peerAutonomousExadataInfrastructureId'] raise 'You cannot provide both :peerAutonomousExadataInfrastructureId and :peer_autonomous_exadata_infrastructure_id' if attributes.key?(:'peerAutonomousExadataInfrastructureId') && attributes.key?(:'peer_autonomous_exadata_infrastructure_id') self.peer_autonomous_exadata_infrastructure_id = attributes[:'peer_autonomous_exadata_infrastructure_id'] if attributes[:'peer_autonomous_exadata_infrastructure_id'] self.peer_autonomous_container_database_display_name = attributes[:'peerAutonomousContainerDatabaseDisplayName'] if attributes[:'peerAutonomousContainerDatabaseDisplayName'] raise 'You cannot provide both :peerAutonomousContainerDatabaseDisplayName and :peer_autonomous_container_database_display_name' if attributes.key?(:'peerAutonomousContainerDatabaseDisplayName') && attributes.key?(:'peer_autonomous_container_database_display_name') self.peer_autonomous_container_database_display_name = attributes[:'peer_autonomous_container_database_display_name'] if attributes[:'peer_autonomous_container_database_display_name'] self.protection_mode = attributes[:'protectionMode'] if attributes[:'protectionMode'] raise 'You cannot provide both :protectionMode and :protection_mode' if attributes.key?(:'protectionMode') && attributes.key?(:'protection_mode') self.protection_mode = attributes[:'protection_mode'] if attributes[:'protection_mode'] self.is_automatic_failover_enabled = attributes[:'isAutomaticFailoverEnabled'] unless attributes[:'isAutomaticFailoverEnabled'].nil? raise 'You cannot provide both :isAutomaticFailoverEnabled and :is_automatic_failover_enabled' if attributes.key?(:'isAutomaticFailoverEnabled') && attributes.key?(:'is_automatic_failover_enabled') self.is_automatic_failover_enabled = attributes[:'is_automatic_failover_enabled'] unless attributes[:'is_automatic_failover_enabled'].nil? self.peer_cloud_autonomous_vm_cluster_id = attributes[:'peerCloudAutonomousVmClusterId'] if attributes[:'peerCloudAutonomousVmClusterId'] raise 'You cannot provide both :peerCloudAutonomousVmClusterId and :peer_cloud_autonomous_vm_cluster_id' if attributes.key?(:'peerCloudAutonomousVmClusterId') && attributes.key?(:'peer_cloud_autonomous_vm_cluster_id') self.peer_cloud_autonomous_vm_cluster_id = attributes[:'peer_cloud_autonomous_vm_cluster_id'] if attributes[:'peer_cloud_autonomous_vm_cluster_id'] self.peer_autonomous_vm_cluster_id = attributes[:'peerAutonomousVmClusterId'] if attributes[:'peerAutonomousVmClusterId'] raise 'You cannot provide both :peerAutonomousVmClusterId and :peer_autonomous_vm_cluster_id' if attributes.key?(:'peerAutonomousVmClusterId') && attributes.key?(:'peer_autonomous_vm_cluster_id') self.peer_autonomous_vm_cluster_id = attributes[:'peer_autonomous_vm_cluster_id'] if attributes[:'peer_autonomous_vm_cluster_id'] self.peer_autonomous_container_database_compartment_id = attributes[:'peerAutonomousContainerDatabaseCompartmentId'] if attributes[:'peerAutonomousContainerDatabaseCompartmentId'] raise 'You cannot provide both :peerAutonomousContainerDatabaseCompartmentId and :peer_autonomous_container_database_compartment_id' if attributes.key?(:'peerAutonomousContainerDatabaseCompartmentId') && attributes.key?(:'peer_autonomous_container_database_compartment_id') self.peer_autonomous_container_database_compartment_id = attributes[:'peer_autonomous_container_database_compartment_id'] if attributes[:'peer_autonomous_container_database_compartment_id'] self.peer_autonomous_container_database_backup_config = attributes[:'peerAutonomousContainerDatabaseBackupConfig'] if attributes[:'peerAutonomousContainerDatabaseBackupConfig'] raise 'You cannot provide both :peerAutonomousContainerDatabaseBackupConfig and :peer_autonomous_container_database_backup_config' if attributes.key?(:'peerAutonomousContainerDatabaseBackupConfig') && attributes.key?(:'peer_autonomous_container_database_backup_config') self.peer_autonomous_container_database_backup_config = attributes[:'peer_autonomous_container_database_backup_config'] if attributes[:'peer_autonomous_container_database_backup_config'] self.peer_db_unique_name = attributes[:'peerDbUniqueName'] if attributes[:'peerDbUniqueName'] raise 'You cannot provide both :peerDbUniqueName and :peer_db_unique_name' if attributes.key?(:'peerDbUniqueName') && attributes.key?(:'peer_db_unique_name') self.peer_db_unique_name = attributes[:'peer_db_unique_name'] if attributes[:'peer_db_unique_name'] self.autonomous_vm_cluster_id = attributes[:'autonomousVmClusterId'] if attributes[:'autonomousVmClusterId'] raise 'You cannot provide both :autonomousVmClusterId and :autonomous_vm_cluster_id' if attributes.key?(:'autonomousVmClusterId') && attributes.key?(:'autonomous_vm_cluster_id') self.autonomous_vm_cluster_id = attributes[:'autonomous_vm_cluster_id'] if attributes[:'autonomous_vm_cluster_id'] self.cloud_autonomous_vm_cluster_id = attributes[:'cloudAutonomousVmClusterId'] if attributes[:'cloudAutonomousVmClusterId'] raise 'You cannot provide both :cloudAutonomousVmClusterId and :cloud_autonomous_vm_cluster_id' if attributes.key?(:'cloudAutonomousVmClusterId') && attributes.key?(:'cloud_autonomous_vm_cluster_id') self.cloud_autonomous_vm_cluster_id = attributes[:'cloud_autonomous_vm_cluster_id'] if attributes[:'cloud_autonomous_vm_cluster_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.patch_model = attributes[:'patchModel'] if attributes[:'patchModel'] raise 'You cannot provide both :patchModel and :patch_model' if attributes.key?(:'patchModel') && attributes.key?(:'patch_model') self.patch_model = attributes[:'patch_model'] if attributes[:'patch_model'] self.maintenance_window_details = attributes[:'maintenanceWindowDetails'] if attributes[:'maintenanceWindowDetails'] raise 'You cannot provide both :maintenanceWindowDetails and :maintenance_window_details' if attributes.key?(:'maintenanceWindowDetails') && attributes.key?(:'maintenance_window_details') self.maintenance_window_details = attributes[:'maintenance_window_details'] if attributes[:'maintenance_window_details'] self.standby_maintenance_buffer_in_days = attributes[:'standbyMaintenanceBufferInDays'] if attributes[:'standbyMaintenanceBufferInDays'] raise 'You cannot provide both :standbyMaintenanceBufferInDays and :standby_maintenance_buffer_in_days' if attributes.key?(:'standbyMaintenanceBufferInDays') && attributes.key?(:'standby_maintenance_buffer_in_days') self.standby_maintenance_buffer_in_days = attributes[:'standby_maintenance_buffer_in_days'] if attributes[:'standby_maintenance_buffer_in_days'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.backup_config = attributes[:'backupConfig'] if attributes[:'backupConfig'] raise 'You cannot provide both :backupConfig and :backup_config' if attributes.key?(:'backupConfig') && attributes.key?(:'backup_config') self.backup_config = attributes[:'backup_config'] if attributes[:'backup_config'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.kms_key_version_id = attributes[:'kmsKeyVersionId'] if attributes[:'kmsKeyVersionId'] raise 'You cannot provide both :kmsKeyVersionId and :kms_key_version_id' if attributes.key?(:'kmsKeyVersionId') && attributes.key?(:'kms_key_version_id') self.kms_key_version_id = attributes[:'kms_key_version_id'] if attributes[:'kms_key_version_id'] self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId'] raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id') self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id'] self.key_store_id = attributes[:'keyStoreId'] if attributes[:'keyStoreId'] raise 'You cannot provide both :keyStoreId and :key_store_id' if attributes.key?(:'keyStoreId') && attributes.key?(:'key_store_id') self.key_store_id = attributes[:'key_store_id'] if attributes[:'key_store_id'] end |
Instance Attribute Details
#autonomous_exadata_infrastructure_id ⇒ String
The OCID of the Autonomous Exadata Infrastructure.
41 42 43 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 41 def autonomous_exadata_infrastructure_id @autonomous_exadata_infrastructure_id end |
#autonomous_vm_cluster_id ⇒ String
The OCID of the Autonomous VM Cluster.
88 89 90 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 88 def autonomous_vm_cluster_id @autonomous_vm_cluster_id end |
#backup_config ⇒ OCI::Database::Models::AutonomousContainerDatabaseBackupConfig
126 127 128 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 126 def backup_config @backup_config end |
#cloud_autonomous_vm_cluster_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Autonomous Exadata VM Cluster.
92 93 94 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 92 def cloud_autonomous_vm_cluster_id @cloud_autonomous_vm_cluster_id end |
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the Autonomous Container Database.
96 97 98 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 96 def compartment_id @compartment_id end |
#db_unique_name ⇒ String
Deprecated. The DB_UNIQUE_NAME value is set by Oracle Cloud Infrastructure. Do not specify a value for this parameter. Specifying a value for this field will cause Terraform operations to fail.
33 34 35 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 33 def db_unique_name @db_unique_name end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
123 124 125 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 123 def end |
#display_name ⇒ String
[Required] The display name for the Autonomous Container Database.
28 29 30 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 28 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
117 118 119 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 117 def end |
#is_automatic_failover_enabled ⇒ BOOLEAN
Indicates whether Automatic Failover is enabled for Autonomous Container Database Dataguard Association
61 62 63 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 61 def is_automatic_failover_enabled @is_automatic_failover_enabled end |
#key_store_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the key store.
143 144 145 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 143 def key_store_id @key_store_id end |
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
130 131 132 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 130 def kms_key_id @kms_key_id end |
#kms_key_version_id ⇒ String
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.
135 136 137 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 135 def kms_key_version_id @kms_key_version_id end |
#maintenance_window_details ⇒ OCI::Database::Models::MaintenanceWindow
103 104 105 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 103 def maintenance_window_details @maintenance_window_details end |
#patch_model ⇒ String
[Required] Database Patch model preference.
100 101 102 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 100 def patch_model @patch_model end |
#peer_autonomous_container_database_backup_config ⇒ OCI::Database::Models::PeerAutonomousContainerDatabaseBackupConfig
79 80 81 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 79 def peer_autonomous_container_database_backup_config @peer_autonomous_container_database_backup_config end |
#peer_autonomous_container_database_compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the standby Autonomous Container Database will be created.
76 77 78 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 76 def peer_autonomous_container_database_compartment_id @peer_autonomous_container_database_compartment_id end |
#peer_autonomous_container_database_display_name ⇒ String
The display name for the peer Autonomous Container Database.
49 50 51 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 49 def peer_autonomous_container_database_display_name @peer_autonomous_container_database_display_name end |
#peer_autonomous_exadata_infrastructure_id ⇒ String
The OCID of the peer Autonomous Exadata Infrastructure for Autonomous Data Guard.
45 46 47 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 45 def peer_autonomous_exadata_infrastructure_id @peer_autonomous_exadata_infrastructure_id end |
#peer_autonomous_vm_cluster_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the peer Autonomous VM cluster for Autonomous Data Guard. Required to enable Data Guard.
70 71 72 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 70 def peer_autonomous_vm_cluster_id @peer_autonomous_vm_cluster_id end |
#peer_cloud_autonomous_vm_cluster_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the peer cloud Autonomous Exadata VM Cluster.
65 66 67 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 65 def peer_cloud_autonomous_vm_cluster_id @peer_cloud_autonomous_vm_cluster_id end |
#peer_db_unique_name ⇒ String
Deprecated. The DB_UNIQUE_NAME of the peer Autonomous Container Database in a Data Guard association is set by Oracle Cloud Infrastructure. Do not specify a value for this parameter. Specifying a value for this field will cause Terraform operations to fail.
84 85 86 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 84 def peer_db_unique_name @peer_db_unique_name end |
#protection_mode ⇒ String
The protection mode of this Autonomous Data Guard association. For more information, see [Oracle Data Guard Protection Modes](docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000) in the Oracle Data Guard documentation.
56 57 58 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 56 def protection_mode @protection_mode end |
#service_level_agreement_type ⇒ String
The service level agreement type of the Autonomous Container Database. The default is STANDARD. For an autonomous dataguard Autonomous Container Database, the specified Autonomous Exadata Infrastructure must be associated with a remote Autonomous Exadata Infrastructure.
37 38 39 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 37 def service_level_agreement_type @service_level_agreement_type end |
#standby_maintenance_buffer_in_days ⇒ Integer
The scheduling detail for the quarterly maintenance window of the standby Autonomous Container Database. This value represents the number of days before scheduled maintenance of the primary database.
109 110 111 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 109 def standby_maintenance_buffer_in_days @standby_maintenance_buffer_in_days end |
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
139 140 141 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 139 def vault_id @vault_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 146 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'db_unique_name': :'dbUniqueName', 'service_level_agreement_type': :'serviceLevelAgreementType', 'autonomous_exadata_infrastructure_id': :'autonomousExadataInfrastructureId', 'peer_autonomous_exadata_infrastructure_id': :'peerAutonomousExadataInfrastructureId', 'peer_autonomous_container_database_display_name': :'peerAutonomousContainerDatabaseDisplayName', 'protection_mode': :'protectionMode', 'is_automatic_failover_enabled': :'isAutomaticFailoverEnabled', 'peer_cloud_autonomous_vm_cluster_id': :'peerCloudAutonomousVmClusterId', 'peer_autonomous_vm_cluster_id': :'peerAutonomousVmClusterId', 'peer_autonomous_container_database_compartment_id': :'peerAutonomousContainerDatabaseCompartmentId', 'peer_autonomous_container_database_backup_config': :'peerAutonomousContainerDatabaseBackupConfig', 'peer_db_unique_name': :'peerDbUniqueName', 'autonomous_vm_cluster_id': :'autonomousVmClusterId', 'cloud_autonomous_vm_cluster_id': :'cloudAutonomousVmClusterId', 'compartment_id': :'compartmentId', 'patch_model': :'patchModel', 'maintenance_window_details': :'maintenanceWindowDetails', 'standby_maintenance_buffer_in_days': :'standbyMaintenanceBufferInDays', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'backup_config': :'backupConfig', 'kms_key_id': :'kmsKeyId', 'kms_key_version_id': :'kmsKeyVersionId', 'vault_id': :'vaultId', 'key_store_id': :'keyStoreId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 180 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'db_unique_name': :'String', 'service_level_agreement_type': :'String', 'autonomous_exadata_infrastructure_id': :'String', 'peer_autonomous_exadata_infrastructure_id': :'String', 'peer_autonomous_container_database_display_name': :'String', 'protection_mode': :'String', 'is_automatic_failover_enabled': :'BOOLEAN', 'peer_cloud_autonomous_vm_cluster_id': :'String', 'peer_autonomous_vm_cluster_id': :'String', 'peer_autonomous_container_database_compartment_id': :'String', 'peer_autonomous_container_database_backup_config': :'OCI::Database::Models::PeerAutonomousContainerDatabaseBackupConfig', 'peer_db_unique_name': :'String', 'autonomous_vm_cluster_id': :'String', 'cloud_autonomous_vm_cluster_id': :'String', 'compartment_id': :'String', 'patch_model': :'String', 'maintenance_window_details': :'OCI::Database::Models::MaintenanceWindow', 'standby_maintenance_buffer_in_days': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'backup_config': :'OCI::Database::Models::AutonomousContainerDatabaseBackupConfig', 'kms_key_id': :'String', 'kms_key_version_id': :'String', 'vault_id': :'String', 'key_store_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 439 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && db_unique_name == other.db_unique_name && service_level_agreement_type == other.service_level_agreement_type && autonomous_exadata_infrastructure_id == other.autonomous_exadata_infrastructure_id && peer_autonomous_exadata_infrastructure_id == other.peer_autonomous_exadata_infrastructure_id && peer_autonomous_container_database_display_name == other.peer_autonomous_container_database_display_name && protection_mode == other.protection_mode && is_automatic_failover_enabled == other.is_automatic_failover_enabled && peer_cloud_autonomous_vm_cluster_id == other.peer_cloud_autonomous_vm_cluster_id && peer_autonomous_vm_cluster_id == other.peer_autonomous_vm_cluster_id && peer_autonomous_container_database_compartment_id == other.peer_autonomous_container_database_compartment_id && peer_autonomous_container_database_backup_config == other.peer_autonomous_container_database_backup_config && peer_db_unique_name == other.peer_db_unique_name && autonomous_vm_cluster_id == other.autonomous_vm_cluster_id && cloud_autonomous_vm_cluster_id == other.cloud_autonomous_vm_cluster_id && compartment_id == other.compartment_id && patch_model == other.patch_model && maintenance_window_details == other.maintenance_window_details && standby_maintenance_buffer_in_days == other.standby_maintenance_buffer_in_days && == other. && == other. && backup_config == other.backup_config && kms_key_id == other.kms_key_id && kms_key_version_id == other.kms_key_version_id && vault_id == other.vault_id && key_store_id == other.key_store_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 494 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
474 475 476 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 474 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
483 484 485 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 483 def hash [display_name, db_unique_name, service_level_agreement_type, autonomous_exadata_infrastructure_id, peer_autonomous_exadata_infrastructure_id, peer_autonomous_container_database_display_name, protection_mode, is_automatic_failover_enabled, peer_cloud_autonomous_vm_cluster_id, peer_autonomous_vm_cluster_id, peer_autonomous_container_database_compartment_id, peer_autonomous_container_database_backup_config, peer_db_unique_name, autonomous_vm_cluster_id, cloud_autonomous_vm_cluster_id, compartment_id, patch_model, maintenance_window_details, standby_maintenance_buffer_in_days, , , backup_config, kms_key_id, kms_key_version_id, vault_id, key_store_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
527 528 529 530 531 532 533 534 535 536 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 527 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
521 522 523 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 521 def to_s to_hash.to_s end |