Class: OCI::Database::Models::CreateAutonomousContainerDatabaseDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateAutonomousContainerDatabaseDetails
- Defined in:
- lib/oci/database/models/create_autonomous_container_database_details.rb
Overview
Describes the required parameters for the creation of an Autonomous Container Database.
Constant Summary collapse
- SERVICE_LEVEL_AGREEMENT_TYPE_ENUM =
[ SERVICE_LEVEL_AGREEMENT_TYPE_STANDARD = 'STANDARD'.freeze ].freeze
- PATCH_MODEL_ENUM =
[ PATCH_MODEL_RELEASE_UPDATES = 'RELEASE_UPDATES'.freeze, PATCH_MODEL_RELEASE_UPDATE_REVISIONS = 'RELEASE_UPDATE_REVISIONS'.freeze ].freeze
Instance Attribute Summary collapse
-
#autonomous_exadata_infrastructure_id ⇒ String
The OCID of the Autonomous Exadata Infrastructure.
-
#autonomous_vm_cluster_id ⇒ String
The OCID of the Autonomous VM Cluster.
- #backup_config ⇒ OCI::Database::Models::AutonomousContainerDatabaseBackupConfig
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the Autonomous Container Database.
-
#db_unique_name ⇒ String
The
DB_UNIQUE_NAMEof the Oracle Database being backed up. -
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The display name for the Autonomous Container Database.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
-
#kms_key_version_id ⇒ String
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions.
- #maintenance_window_details ⇒ OCI::Database::Models::MaintenanceWindow
-
#patch_model ⇒ String
[Required] Database Patch model preference.
-
#service_level_agreement_type ⇒ String
The service level agreement type of the Autonomous Container Database.
-
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAutonomousContainerDatabaseDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAutonomousContainerDatabaseDetails
Initializes the object
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 145 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.db_unique_name = attributes[:'dbUniqueName'] if attributes[:'dbUniqueName'] raise 'You cannot provide both :dbUniqueName and :db_unique_name' if attributes.key?(:'dbUniqueName') && attributes.key?(:'db_unique_name') self.db_unique_name = attributes[:'db_unique_name'] if attributes[:'db_unique_name'] self.service_level_agreement_type = attributes[:'serviceLevelAgreementType'] if attributes[:'serviceLevelAgreementType'] raise 'You cannot provide both :serviceLevelAgreementType and :service_level_agreement_type' if attributes.key?(:'serviceLevelAgreementType') && attributes.key?(:'service_level_agreement_type') self.service_level_agreement_type = attributes[:'service_level_agreement_type'] if attributes[:'service_level_agreement_type'] self.autonomous_exadata_infrastructure_id = attributes[:'autonomousExadataInfrastructureId'] if attributes[:'autonomousExadataInfrastructureId'] raise 'You cannot provide both :autonomousExadataInfrastructureId and :autonomous_exadata_infrastructure_id' if attributes.key?(:'autonomousExadataInfrastructureId') && attributes.key?(:'autonomous_exadata_infrastructure_id') self.autonomous_exadata_infrastructure_id = attributes[:'autonomous_exadata_infrastructure_id'] if attributes[:'autonomous_exadata_infrastructure_id'] self.autonomous_vm_cluster_id = attributes[:'autonomousVmClusterId'] if attributes[:'autonomousVmClusterId'] raise 'You cannot provide both :autonomousVmClusterId and :autonomous_vm_cluster_id' if attributes.key?(:'autonomousVmClusterId') && attributes.key?(:'autonomous_vm_cluster_id') self.autonomous_vm_cluster_id = attributes[:'autonomous_vm_cluster_id'] if attributes[:'autonomous_vm_cluster_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.patch_model = attributes[:'patchModel'] if attributes[:'patchModel'] raise 'You cannot provide both :patchModel and :patch_model' if attributes.key?(:'patchModel') && attributes.key?(:'patch_model') self.patch_model = attributes[:'patch_model'] if attributes[:'patch_model'] self.maintenance_window_details = attributes[:'maintenanceWindowDetails'] if attributes[:'maintenanceWindowDetails'] raise 'You cannot provide both :maintenanceWindowDetails and :maintenance_window_details' if attributes.key?(:'maintenanceWindowDetails') && attributes.key?(:'maintenance_window_details') self.maintenance_window_details = attributes[:'maintenance_window_details'] if attributes[:'maintenance_window_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.backup_config = attributes[:'backupConfig'] if attributes[:'backupConfig'] raise 'You cannot provide both :backupConfig and :backup_config' if attributes.key?(:'backupConfig') && attributes.key?(:'backup_config') self.backup_config = attributes[:'backup_config'] if attributes[:'backup_config'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.kms_key_version_id = attributes[:'kmsKeyVersionId'] if attributes[:'kmsKeyVersionId'] raise 'You cannot provide both :kmsKeyVersionId and :kms_key_version_id' if attributes.key?(:'kmsKeyVersionId') && attributes.key?(:'kms_key_version_id') self.kms_key_version_id = attributes[:'kms_key_version_id'] if attributes[:'kms_key_version_id'] self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId'] raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id') self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id'] end |
Instance Attribute Details
#autonomous_exadata_infrastructure_id ⇒ String
The OCID of the Autonomous Exadata Infrastructure.
34 35 36 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 34 def autonomous_exadata_infrastructure_id @autonomous_exadata_infrastructure_id end |
#autonomous_vm_cluster_id ⇒ String
The OCID of the Autonomous VM Cluster.
38 39 40 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 38 def autonomous_vm_cluster_id @autonomous_vm_cluster_id end |
#backup_config ⇒ OCI::Database::Models::AutonomousContainerDatabaseBackupConfig
66 67 68 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 66 def backup_config @backup_config end |
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the Autonomous Container Database.
42 43 44 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 42 def compartment_id @compartment_id end |
#db_unique_name ⇒ String
The DB_UNIQUE_NAME of the Oracle Database being backed up.
26 27 28 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 26 def db_unique_name @db_unique_name end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
63 64 65 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 63 def @defined_tags end |
#display_name ⇒ String
[Required] The display name for the Autonomous Container Database.
22 23 24 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 22 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘\“Finance\”`
57 58 59 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 57 def @freeform_tags end |
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
70 71 72 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 70 def kms_key_id @kms_key_id end |
#kms_key_version_id ⇒ String
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.
75 76 77 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 75 def kms_key_version_id @kms_key_version_id end |
#maintenance_window_details ⇒ OCI::Database::Models::MaintenanceWindow
49 50 51 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 49 def maintenance_window_details @maintenance_window_details end |
#patch_model ⇒ String
[Required] Database Patch model preference.
46 47 48 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 46 def patch_model @patch_model end |
#service_level_agreement_type ⇒ String
The service level agreement type of the Autonomous Container Database. The default is STANDARD. For an autonomous dataguard Autonomous Container Database, the specified Autonomous Exadata Infrastructure must be associated with a remote Autonomous Exadata Infrastructure.
30 31 32 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 30 def service_level_agreement_type @service_level_agreement_type end |
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Oracle Cloud Infrastructure [vault](docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
79 80 81 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 79 def vault_id @vault_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 82 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'db_unique_name': :'dbUniqueName', 'service_level_agreement_type': :'serviceLevelAgreementType', 'autonomous_exadata_infrastructure_id': :'autonomousExadataInfrastructureId', 'autonomous_vm_cluster_id': :'autonomousVmClusterId', 'compartment_id': :'compartmentId', 'patch_model': :'patchModel', 'maintenance_window_details': :'maintenanceWindowDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'backup_config': :'backupConfig', 'kms_key_id': :'kmsKeyId', 'kms_key_version_id': :'kmsKeyVersionId', 'vault_id': :'vaultId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 104 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'db_unique_name': :'String', 'service_level_agreement_type': :'String', 'autonomous_exadata_infrastructure_id': :'String', 'autonomous_vm_cluster_id': :'String', 'compartment_id': :'String', 'patch_model': :'String', 'maintenance_window_details': :'OCI::Database::Models::MaintenanceWindow', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'backup_config': :'OCI::Database::Models::AutonomousContainerDatabaseBackupConfig', 'kms_key_id': :'String', 'kms_key_version_id': :'String', 'vault_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 259 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && db_unique_name == other.db_unique_name && service_level_agreement_type == other.service_level_agreement_type && autonomous_exadata_infrastructure_id == other.autonomous_exadata_infrastructure_id && autonomous_vm_cluster_id == other.autonomous_vm_cluster_id && compartment_id == other.compartment_id && patch_model == other.patch_model && maintenance_window_details == other.maintenance_window_details && == other. && == other. && backup_config == other.backup_config && kms_key_id == other.kms_key_id && kms_key_version_id == other.kms_key_version_id && vault_id == other.vault_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 302 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
282 283 284 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 282 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
291 292 293 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 291 def hash [display_name, db_unique_name, service_level_agreement_type, autonomous_exadata_infrastructure_id, autonomous_vm_cluster_id, compartment_id, patch_model, maintenance_window_details, , , backup_config, kms_key_id, kms_key_version_id, vault_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 344 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
329 330 331 |
# File 'lib/oci/database/models/create_autonomous_container_database_details.rb', line 329 def to_s to_hash.to_s end |