Class: OCI::Database::Models::CreateAutonomousDatabaseBase
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateAutonomousDatabaseBase
- Defined in:
- lib/oci/database/models/create_autonomous_database_base.rb
Overview
Details to create an Oracle Autonomous Database.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateAutonomousDatabaseCloneDetails, CreateAutonomousDatabaseDetails, CreateAutonomousDatabaseFromBackupDetails, CreateAutonomousDatabaseFromBackupTimestampDetails, CreateRefreshableAutonomousDatabaseCloneDetails
Constant Summary collapse
- DB_WORKLOAD_ENUM =
[ DB_WORKLOAD_OLTP = 'OLTP'.freeze, DB_WORKLOAD_DW = 'DW'.freeze, DB_WORKLOAD_AJD = 'AJD'.freeze, DB_WORKLOAD_APEX = 'APEX'.freeze ].freeze
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
- SOURCE_ENUM =
[ SOURCE_NONE = 'NONE'.freeze, SOURCE_DATABASE = 'DATABASE'.freeze, SOURCE_BACKUP_FROM_ID = 'BACKUP_FROM_ID'.freeze, SOURCE_BACKUP_FROM_TIMESTAMP = 'BACKUP_FROM_TIMESTAMP'.freeze, SOURCE_CLONE_TO_REFRESHABLE = 'CLONE_TO_REFRESHABLE'.freeze ].freeze
Instance Attribute Summary collapse
-
#admin_password ⇒ String
The password must be between 12 and 30 characters long, and must contain at least 1 uppercase, 1 lowercase, and 1 numeric character.
-
#are_primary_whitelisted_ips_used ⇒ BOOLEAN
This field will be null if the Autonomous Database is not Data Guard enabled or Access Control is disabled.
-
#autonomous_container_database_id ⇒ String
The Autonomous Container Database [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment of the Autonomous Database.
-
#cpu_core_count ⇒ Integer
[Required] The number of OCPU cores to be made available to the database.
-
#customer_contacts ⇒ Array<OCI::Database::Models::CustomerContact>
Customer Contacts.
-
#data_storage_size_in_tbs ⇒ Integer
The size, in terabytes, of the data volume that will be created and attached to the database.
-
#db_name ⇒ String
[Required] The database name.
-
#db_version ⇒ String
A valid Oracle Database version for Autonomous Database.
-
#db_workload ⇒ String
The Autonomous Database workload type.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The user-friendly name for the Autonomous Database.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_access_control_enabled ⇒ BOOLEAN
Indicates if the database-level access control is enabled.
-
#is_auto_scaling_enabled ⇒ BOOLEAN
Indicates if auto scaling is enabled for the Autonomous Database OCPU core count.
-
#is_data_guard_enabled ⇒ BOOLEAN
Indicates whether the Autonomous Database has Data Guard enabled.
-
#is_dedicated ⇒ BOOLEAN
True if the database is on [dedicated Exadata infrastructure](docs.cloud.oracle.com/Content/Database/Concepts/adbddoverview.htm).
-
#is_free_tier ⇒ BOOLEAN
Indicates if this is an Always Free resource.
-
#is_preview_version_with_service_terms_accepted ⇒ BOOLEAN
If set to
TRUE, indicates that an Autonomous Database preview version is being provisioned, and that the preview version’s terms of service have been accepted. -
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database.
-
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to.
-
#private_endpoint_label ⇒ String
The private endpoint label for the resource.
-
#source ⇒ String
The source of the database: Use
NONEfor creating a new Autonomous Database. -
#standby_whitelisted_ips ⇒ Array<String>
The client IP access control list (ACL).
-
#subnet_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet the resource is associated with.
-
#whitelisted_ips ⇒ Array<String>
The client IP access control list (ACL).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAutonomousDatabaseBase
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAutonomousDatabaseBase
Initializes the object
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 324 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.db_name = attributes[:'dbName'] if attributes[:'dbName'] raise 'You cannot provide both :dbName and :db_name' if attributes.key?(:'dbName') && attributes.key?(:'db_name') self.db_name = attributes[:'db_name'] if attributes[:'db_name'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.db_workload = attributes[:'dbWorkload'] if attributes[:'dbWorkload'] raise 'You cannot provide both :dbWorkload and :db_workload' if attributes.key?(:'dbWorkload') && attributes.key?(:'db_workload') self.db_workload = attributes[:'db_workload'] if attributes[:'db_workload'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.is_free_tier = attributes[:'isFreeTier'] unless attributes[:'isFreeTier'].nil? self.is_free_tier = false if is_free_tier.nil? && !attributes.key?(:'isFreeTier') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isFreeTier and :is_free_tier' if attributes.key?(:'isFreeTier') && attributes.key?(:'is_free_tier') self.is_free_tier = attributes[:'is_free_tier'] unless attributes[:'is_free_tier'].nil? self.is_free_tier = false if is_free_tier.nil? && !attributes.key?(:'isFreeTier') && !attributes.key?(:'is_free_tier') # rubocop:disable Style/StringLiterals self.admin_password = attributes[:'adminPassword'] if attributes[:'adminPassword'] raise 'You cannot provide both :adminPassword and :admin_password' if attributes.key?(:'adminPassword') && attributes.key?(:'admin_password') self.admin_password = attributes[:'admin_password'] if attributes[:'admin_password'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.is_preview_version_with_service_terms_accepted = attributes[:'isPreviewVersionWithServiceTermsAccepted'] unless attributes[:'isPreviewVersionWithServiceTermsAccepted'].nil? self.is_preview_version_with_service_terms_accepted = false if is_preview_version_with_service_terms_accepted.nil? && !attributes.key?(:'isPreviewVersionWithServiceTermsAccepted') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPreviewVersionWithServiceTermsAccepted and :is_preview_version_with_service_terms_accepted' if attributes.key?(:'isPreviewVersionWithServiceTermsAccepted') && attributes.key?(:'is_preview_version_with_service_terms_accepted') self.is_preview_version_with_service_terms_accepted = attributes[:'is_preview_version_with_service_terms_accepted'] unless attributes[:'is_preview_version_with_service_terms_accepted'].nil? self.is_preview_version_with_service_terms_accepted = false if is_preview_version_with_service_terms_accepted.nil? && !attributes.key?(:'isPreviewVersionWithServiceTermsAccepted') && !attributes.key?(:'is_preview_version_with_service_terms_accepted') # rubocop:disable Style/StringLiterals self.is_auto_scaling_enabled = attributes[:'isAutoScalingEnabled'] unless attributes[:'isAutoScalingEnabled'].nil? self.is_auto_scaling_enabled = false if is_auto_scaling_enabled.nil? && !attributes.key?(:'isAutoScalingEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isAutoScalingEnabled and :is_auto_scaling_enabled' if attributes.key?(:'isAutoScalingEnabled') && attributes.key?(:'is_auto_scaling_enabled') self.is_auto_scaling_enabled = attributes[:'is_auto_scaling_enabled'] unless attributes[:'is_auto_scaling_enabled'].nil? self.is_auto_scaling_enabled = false if is_auto_scaling_enabled.nil? && !attributes.key?(:'isAutoScalingEnabled') && !attributes.key?(:'is_auto_scaling_enabled') # rubocop:disable Style/StringLiterals self.is_dedicated = attributes[:'isDedicated'] unless attributes[:'isDedicated'].nil? raise 'You cannot provide both :isDedicated and :is_dedicated' if attributes.key?(:'isDedicated') && attributes.key?(:'is_dedicated') self.is_dedicated = attributes[:'is_dedicated'] unless attributes[:'is_dedicated'].nil? self.autonomous_container_database_id = attributes[:'autonomousContainerDatabaseId'] if attributes[:'autonomousContainerDatabaseId'] raise 'You cannot provide both :autonomousContainerDatabaseId and :autonomous_container_database_id' if attributes.key?(:'autonomousContainerDatabaseId') && attributes.key?(:'autonomous_container_database_id') self.autonomous_container_database_id = attributes[:'autonomous_container_database_id'] if attributes[:'autonomous_container_database_id'] self.is_access_control_enabled = attributes[:'isAccessControlEnabled'] unless attributes[:'isAccessControlEnabled'].nil? raise 'You cannot provide both :isAccessControlEnabled and :is_access_control_enabled' if attributes.key?(:'isAccessControlEnabled') && attributes.key?(:'is_access_control_enabled') self.is_access_control_enabled = attributes[:'is_access_control_enabled'] unless attributes[:'is_access_control_enabled'].nil? self.whitelisted_ips = attributes[:'whitelistedIps'] if attributes[:'whitelistedIps'] raise 'You cannot provide both :whitelistedIps and :whitelisted_ips' if attributes.key?(:'whitelistedIps') && attributes.key?(:'whitelisted_ips') self.whitelisted_ips = attributes[:'whitelisted_ips'] if attributes[:'whitelisted_ips'] self.are_primary_whitelisted_ips_used = attributes[:'arePrimaryWhitelistedIpsUsed'] unless attributes[:'arePrimaryWhitelistedIpsUsed'].nil? raise 'You cannot provide both :arePrimaryWhitelistedIpsUsed and :are_primary_whitelisted_ips_used' if attributes.key?(:'arePrimaryWhitelistedIpsUsed') && attributes.key?(:'are_primary_whitelisted_ips_used') self.are_primary_whitelisted_ips_used = attributes[:'are_primary_whitelisted_ips_used'] unless attributes[:'are_primary_whitelisted_ips_used'].nil? self.standby_whitelisted_ips = attributes[:'standbyWhitelistedIps'] if attributes[:'standbyWhitelistedIps'] raise 'You cannot provide both :standbyWhitelistedIps and :standby_whitelisted_ips' if attributes.key?(:'standbyWhitelistedIps') && attributes.key?(:'standby_whitelisted_ips') self.standby_whitelisted_ips = attributes[:'standby_whitelisted_ips'] if attributes[:'standby_whitelisted_ips'] self.is_data_guard_enabled = attributes[:'isDataGuardEnabled'] unless attributes[:'isDataGuardEnabled'].nil? raise 'You cannot provide both :isDataGuardEnabled and :is_data_guard_enabled' if attributes.key?(:'isDataGuardEnabled') && attributes.key?(:'is_data_guard_enabled') self.is_data_guard_enabled = attributes[:'is_data_guard_enabled'] unless attributes[:'is_data_guard_enabled'].nil? self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.private_endpoint_label = attributes[:'privateEndpointLabel'] if attributes[:'privateEndpointLabel'] raise 'You cannot provide both :privateEndpointLabel and :private_endpoint_label' if attributes.key?(:'privateEndpointLabel') && attributes.key?(:'private_endpoint_label') self.private_endpoint_label = attributes[:'private_endpoint_label'] if attributes[:'private_endpoint_label'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.db_version = attributes[:'dbVersion'] if attributes[:'dbVersion'] raise 'You cannot provide both :dbVersion and :db_version' if attributes.key?(:'dbVersion') && attributes.key?(:'db_version') self.db_version = attributes[:'db_version'] if attributes[:'db_version'] self.source = attributes[:'source'] if attributes[:'source'] self.source = "NONE" if source.nil? && !attributes.key?(:'source') # rubocop:disable Style/StringLiterals self.customer_contacts = attributes[:'customerContacts'] if attributes[:'customerContacts'] raise 'You cannot provide both :customerContacts and :customer_contacts' if attributes.key?(:'customerContacts') && attributes.key?(:'customer_contacts') self.customer_contacts = attributes[:'customer_contacts'] if attributes[:'customer_contacts'] end |
Instance Attribute Details
#admin_password ⇒ String
The password must be between 12 and 30 characters long, and must contain at least 1 uppercase, 1 lowercase, and 1 numeric character. It cannot contain the double quote symbol (") or the username "admin", regardless of casing.
68 69 70 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 68 def admin_password @admin_password end |
#are_primary_whitelisted_ips_used ⇒ BOOLEAN
This field will be null if the Autonomous Database is not Data Guard enabled or Access Control is disabled. It’s value would be TRUE if Autonomous Database is Data Guard enabled and Access Control is enabled and if the Autonomous Database uses primary IP access control list (ACL) for standby. It’s value would be FALSE if Autonomous Database is Data Guard enabled and Access Control is enabled and if the Autonomous Database uses different IP access control list (ACL) for standby compared to primary.
131 132 133 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 131 def are_primary_whitelisted_ips_used @are_primary_whitelisted_ips_used end |
#autonomous_container_database_id ⇒ String
The Autonomous Container Database [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
99 100 101 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 99 def autonomous_container_database_id @autonomous_container_database_id end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment of the Autonomous Database.
36 37 38 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 36 def compartment_id @compartment_id end |
#cpu_core_count ⇒ Integer
[Required] The number of OCPU cores to be made available to the database.
44 45 46 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 44 def cpu_core_count @cpu_core_count end |
#customer_contacts ⇒ Array<OCI::Database::Models::CustomerContact>
Customer Contacts.
203 204 205 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 203 def customer_contacts @customer_contacts end |
#data_storage_size_in_tbs ⇒ Integer
The size, in terabytes, of the data volume that will be created and attached to the database. This storage can later be scaled up if needed.
59 60 61 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 59 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_name ⇒ String
[Required] The database name. The name must begin with an alphabetic character and can contain a maximum of 14 alphanumeric characters. Special characters are not permitted. The database name must be unique in the tenancy.
40 41 42 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 40 def db_name @db_name end |
#db_version ⇒ String
A valid Oracle Database version for Autonomous Database.
192 193 194 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 192 def db_version @db_version end |
#db_workload ⇒ String
The Autonomous Database workload type. The following values are valid:
-
OLTP - indicates an Autonomous Transaction Processing database
-
DW - indicates an Autonomous Data Warehouse database
-
AJD - indicates an Autonomous JSON Database
-
APEX - indicates an Autonomous Database with the Oracle APEX Application Development workload type.
54 55 56 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 54 def db_workload @db_workload end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
188 189 190 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 188 def end |
#display_name ⇒ String
The user-friendly name for the Autonomous Database. The name does not have to be unique.
72 73 74 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 72 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
182 183 184 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 182 def end |
#is_access_control_enabled ⇒ BOOLEAN
Indicates if the database-level access control is enabled. If disabled, database access is defined by the network security rules. If enabled, database access is restricted to the IP addresses defined by the rules specified with the whitelistedIps property. While specifying whitelistedIps rules is optional,
if database-level access control is enabled and no rules are specified, the database will become inaccessible. The rules can be added later using the `UpdateAutonomousDatabase` API operation or edit option in console.
When creating a database clone, the desired access control setting should be specified. By default, database-level access control will be disabled for the clone.
This property is applicable only to Autonomous Databases on the Exadata Cloud@Customer platform.
110 111 112 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 110 def is_access_control_enabled @is_access_control_enabled end |
#is_auto_scaling_enabled ⇒ BOOLEAN
Indicates if auto scaling is enabled for the Autonomous Database OCPU core count. The default value is FALSE.
90 91 92 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 90 def is_auto_scaling_enabled @is_auto_scaling_enabled end |
#is_data_guard_enabled ⇒ BOOLEAN
Indicates whether the Autonomous Database has Data Guard enabled.
149 150 151 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 149 def is_data_guard_enabled @is_data_guard_enabled end |
#is_dedicated ⇒ BOOLEAN
True if the database is on [dedicated Exadata infrastructure](docs.cloud.oracle.com/Content/Database/Concepts/adbddoverview.htm).
95 96 97 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 95 def is_dedicated @is_dedicated end |
#is_free_tier ⇒ BOOLEAN
Indicates if this is an Always Free resource. The default value is false. Note that Always Free Autonomous Databases have 1 CPU and 20GB of memory. For Always Free databases, memory and CPU cannot be scaled.
64 65 66 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 64 def is_free_tier @is_free_tier end |
#is_preview_version_with_service_terms_accepted ⇒ BOOLEAN
If set to TRUE, indicates that an Autonomous Database preview version is being provisioned, and that the preview version’s terms of service have been accepted. Note that preview version software is only available for databases on [shared Exadata infrastructure](docs.cloud.oracle.com/Content/Database/Concepts/adboverview.htm#AEI).
85 86 87 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 85 def is_preview_version_with_service_terms_accepted @is_preview_version_with_service_terms_accepted end |
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database. Bring your own license (BYOL) allows you to apply your current on-premises Oracle software licenses to equivalent, highly automated Oracle PaaS and IaaS services in the cloud. License Included allows you to subscribe to new Oracle Database software licenses and the Database service. Note that when provisioning an Autonomous Database on [dedicated Exadata infrastructure](docs.cloud.oracle.com/Content/Database/Concepts/adbddoverview.htm), this attribute must be null because the attribute is already set at the Autonomous Exadata Infrastructure level. When using [shared Exadata infrastructure](docs.cloud.oracle.com/Content/Database/Concepts/adboverview.htm#AEI), if a value is not specified, the system will supply the value of BRING_YOUR_OWN_LICENSE.
80 81 82 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 80 def license_model @license_model end |
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**
-
Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.
170 171 172 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 170 def nsg_ids @nsg_ids end |
#private_endpoint_label ⇒ String
The private endpoint label for the resource. Setting this to an empty string, after the private endpoint database gets created, will change the same private endpoint database to the public endpoint database.
174 175 176 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 174 def private_endpoint_label @private_endpoint_label end |
#source ⇒ String
The source of the database: Use NONE for creating a new Autonomous Database. Use DATABASE for creating a new Autonomous Database by cloning an existing Autonomous Database.
For Autonomous Databases on [shared Exadata infrastructure](docs.cloud.oracle.com/Content/Database/Concepts/adboverview.htm#AEI), the following cloning options are available: Use BACKUP_FROM_ID for creating a new Autonomous Database from a specified backup. Use BACKUP_FROM_TIMESTAMP for creating a point-in-time Autonomous Database clone using backups. For more information, see [Cloning an Autonomous Database](docs.cloud.oracle.com/Content/Database/Tasks/adbcloning.htm).
199 200 201 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 199 def source @source end |
#standby_whitelisted_ips ⇒ Array<String>
The client IP access control list (ACL). This feature is available for autonomous databases on [shared Exadata infrastructure](docs.cloud.oracle.com/Content/Database/Concepts/adboverview.htm#AEI) and on Exadata Cloud@Customer. Only clients connecting from an IP address included in the ACL may access the Autonomous Database instance.
For shared Exadata infrastructure, this is an array of CIDR (Classless Inter-Domain Routing) notations for a subnet or VCN OCID. Use a semicolon (;) as a deliminator between the VCN-specific subnets or IPs. Example: ‘["1.1.1.1","1.1.1.0/24","ocid1.vcn.oc1.sea.<unique_id>","ocid1.vcn.oc1.sea.<unique_id1>;1.1.1.1","ocid1.vcn.oc1.sea.<unique_id2>;1.1.0.0/16"]` For Exadata Cloud@Customer, this is an array of IP addresses or CIDR (Classless Inter-Domain Routing) notations. Example: `["1.1.1.1","1.1.1.0/24","1.1.2.25"]`
For an update operation, if you want to delete all the IPs in the ACL, use an array with a single empty string entry.
145 146 147 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 145 def standby_whitelisted_ips @standby_whitelisted_ips end |
#subnet_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet the resource is associated with.
**Subnet Restrictions:**
-
For bare metal DB systems and for single node virtual machine DB systems, do not use a subnet that overlaps with 192.168.16.16/28.
-
For Exadata and virtual machine 2-node RAC systems, do not use a subnet that overlaps with 192.168.128.0/20.
-
For Autonomous Database, setting this will disable public secure access to the database.
These subnets are used by the Oracle Clusterware private interconnect on the database instance. Specifying an overlapping subnet will cause the private interconnect to malfunction. This restriction applies to both the client subnet and the backup subnet.
163 164 165 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 163 def subnet_id @subnet_id end |
#whitelisted_ips ⇒ Array<String>
The client IP access control list (ACL). This feature is available for autonomous databases on [shared Exadata infrastructure](docs.cloud.oracle.com/Content/Database/Concepts/adboverview.htm#AEI) and on Exadata Cloud@Customer. Only clients connecting from an IP address included in the ACL may access the Autonomous Database instance.
For shared Exadata infrastructure, this is an array of CIDR (Classless Inter-Domain Routing) notations for a subnet or VCN OCID. Use a semicolon (;) as a deliminator between the VCN-specific subnets or IPs. Example: ‘["1.1.1.1","1.1.1.0/24","ocid1.vcn.oc1.sea.<unique_id>","ocid1.vcn.oc1.sea.<unique_id1>;1.1.1.1","ocid1.vcn.oc1.sea.<unique_id2>;1.1.0.0/16"]` For Exadata Cloud@Customer, this is an array of IP addresses or CIDR (Classless Inter-Domain Routing) notations. Example: `["1.1.1.1","1.1.1.0/24","1.1.2.25"]`
For an update operation, if you want to delete all the IPs in the ACL, use an array with a single empty string entry.
124 125 126 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 124 def whitelisted_ips @whitelisted_ips end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 206 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'db_name': :'dbName', 'cpu_core_count': :'cpuCoreCount', 'db_workload': :'dbWorkload', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'is_free_tier': :'isFreeTier', 'admin_password': :'adminPassword', 'display_name': :'displayName', 'license_model': :'licenseModel', 'is_preview_version_with_service_terms_accepted': :'isPreviewVersionWithServiceTermsAccepted', 'is_auto_scaling_enabled': :'isAutoScalingEnabled', 'is_dedicated': :'isDedicated', 'autonomous_container_database_id': :'autonomousContainerDatabaseId', 'is_access_control_enabled': :'isAccessControlEnabled', 'whitelisted_ips': :'whitelistedIps', 'are_primary_whitelisted_ips_used': :'arePrimaryWhitelistedIpsUsed', 'standby_whitelisted_ips': :'standbyWhitelistedIps', 'is_data_guard_enabled': :'isDataGuardEnabled', 'subnet_id': :'subnetId', 'nsg_ids': :'nsgIds', 'private_endpoint_label': :'privateEndpointLabel', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'db_version': :'dbVersion', 'source': :'source', 'customer_contacts': :'customerContacts' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 278 def self.get_subtype(object_hash) type = object_hash[:'source'] # rubocop:disable Style/SymbolLiteral return 'OCI::Database::Models::CreateAutonomousDatabaseCloneDetails' if type == 'DATABASE' return 'OCI::Database::Models::CreateRefreshableAutonomousDatabaseCloneDetails' if type == 'CLONE_TO_REFRESHABLE' return 'OCI::Database::Models::CreateAutonomousDatabaseFromBackupDetails' if type == 'BACKUP_FROM_ID' return 'OCI::Database::Models::CreateAutonomousDatabaseFromBackupTimestampDetails' if type == 'BACKUP_FROM_TIMESTAMP' return 'OCI::Database::Models::CreateAutonomousDatabaseDetails' if type == 'NONE' # TODO: Log a warning when the subtype is not found. 'OCI::Database::Models::CreateAutonomousDatabaseBase' end |
.swagger_types ⇒ Object
Attribute type mapping.
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 240 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'db_name': :'String', 'cpu_core_count': :'Integer', 'db_workload': :'String', 'data_storage_size_in_tbs': :'Integer', 'is_free_tier': :'BOOLEAN', 'admin_password': :'String', 'display_name': :'String', 'license_model': :'String', 'is_preview_version_with_service_terms_accepted': :'BOOLEAN', 'is_auto_scaling_enabled': :'BOOLEAN', 'is_dedicated': :'BOOLEAN', 'autonomous_container_database_id': :'String', 'is_access_control_enabled': :'BOOLEAN', 'whitelisted_ips': :'Array<String>', 'are_primary_whitelisted_ips_used': :'BOOLEAN', 'standby_whitelisted_ips': :'Array<String>', 'is_data_guard_enabled': :'BOOLEAN', 'subnet_id': :'String', 'nsg_ids': :'Array<String>', 'private_endpoint_label': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'db_version': :'String', 'source': :'String', 'customer_contacts': :'Array<OCI::Database::Models::CustomerContact>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 521 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && db_name == other.db_name && cpu_core_count == other.cpu_core_count && db_workload == other.db_workload && data_storage_size_in_tbs == other.data_storage_size_in_tbs && is_free_tier == other.is_free_tier && admin_password == other.admin_password && display_name == other.display_name && license_model == other.license_model && is_preview_version_with_service_terms_accepted == other.is_preview_version_with_service_terms_accepted && is_auto_scaling_enabled == other.is_auto_scaling_enabled && is_dedicated == other.is_dedicated && autonomous_container_database_id == other.autonomous_container_database_id && is_access_control_enabled == other.is_access_control_enabled && whitelisted_ips == other.whitelisted_ips && are_primary_whitelisted_ips_used == other.are_primary_whitelisted_ips_used && standby_whitelisted_ips == other.standby_whitelisted_ips && is_data_guard_enabled == other.is_data_guard_enabled && subnet_id == other.subnet_id && nsg_ids == other.nsg_ids && private_endpoint_label == other.private_endpoint_label && == other. && == other. && db_version == other.db_version && source == other.source && customer_contacts == other.customer_contacts end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 576 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
556 557 558 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 556 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
565 566 567 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 565 def hash [compartment_id, db_name, cpu_core_count, db_workload, data_storage_size_in_tbs, is_free_tier, admin_password, display_name, license_model, is_preview_version_with_service_terms_accepted, is_auto_scaling_enabled, is_dedicated, autonomous_container_database_id, is_access_control_enabled, whitelisted_ips, are_primary_whitelisted_ips_used, standby_whitelisted_ips, is_data_guard_enabled, subnet_id, nsg_ids, private_endpoint_label, , , db_version, source, customer_contacts].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
609 610 611 612 613 614 615 616 617 618 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 609 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
603 604 605 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 603 def to_s to_hash.to_s end |