Class: OCI::Database::Models::CreateAutonomousDatabaseBase
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateAutonomousDatabaseBase
- Defined in:
- lib/oci/database/models/create_autonomous_database_base.rb
Overview
Details to create an Oracle Autonomous Database.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateAutonomousDatabaseCloneDetails, CreateAutonomousDatabaseDetails
Constant Summary collapse
- DB_WORKLOAD_ENUM =
[ DB_WORKLOAD_OLTP = 'OLTP'.freeze, DB_WORKLOAD_DW = 'DW'.freeze ].freeze
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
- SOURCE_ENUM =
[ SOURCE_NONE = 'NONE'.freeze, SOURCE_DATABASE = 'DATABASE'.freeze ].freeze
Instance Attribute Summary collapse
-
#admin_password ⇒ String
[Required] The password must be between 12 and 30 characters long, and must contain at least 1 uppercase, 1 lowercase, and 1 numeric character.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment of the autonomous database.
-
#cpu_core_count ⇒ Integer
[Required] The number of CPU Cores to be made available to the database.
-
#data_storage_size_in_tbs ⇒ Integer
[Required] The size, in terabytes, of the data volume that will be created and attached to the database.
-
#db_name ⇒ String
[Required] The database name.
-
#db_workload ⇒ String
The autonomous database workload type.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The user-friendly name for the Autonomous Database.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_auto_scaling_enabled ⇒ BOOLEAN
Indicates if auto scaling is enabled for the Autonomous Database CPU core count.
-
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database.
-
#source ⇒ String
The source of the database: Use NONE for creating a new Autonomous Database.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAutonomousDatabaseBase
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAutonomousDatabaseBase
Initializes the object
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 162 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.db_name = attributes[:'dbName'] if attributes[:'dbName'] raise 'You cannot provide both :dbName and :db_name' if attributes.key?(:'dbName') && attributes.key?(:'db_name') self.db_name = attributes[:'db_name'] if attributes[:'db_name'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.db_workload = attributes[:'dbWorkload'] if attributes[:'dbWorkload'] raise 'You cannot provide both :dbWorkload and :db_workload' if attributes.key?(:'dbWorkload') && attributes.key?(:'db_workload') self.db_workload = attributes[:'db_workload'] if attributes[:'db_workload'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.admin_password = attributes[:'adminPassword'] if attributes[:'adminPassword'] raise 'You cannot provide both :adminPassword and :admin_password' if attributes.key?(:'adminPassword') && attributes.key?(:'admin_password') self.admin_password = attributes[:'admin_password'] if attributes[:'admin_password'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.is_auto_scaling_enabled = attributes[:'isAutoScalingEnabled'] unless attributes[:'isAutoScalingEnabled'].nil? self.is_auto_scaling_enabled = false if is_auto_scaling_enabled.nil? && !attributes.key?(:'isAutoScalingEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isAutoScalingEnabled and :is_auto_scaling_enabled' if attributes.key?(:'isAutoScalingEnabled') && attributes.key?(:'is_auto_scaling_enabled') self.is_auto_scaling_enabled = attributes[:'is_auto_scaling_enabled'] unless attributes[:'is_auto_scaling_enabled'].nil? self.is_auto_scaling_enabled = false if is_auto_scaling_enabled.nil? && !attributes.key?(:'isAutoScalingEnabled') && !attributes.key?(:'is_auto_scaling_enabled') # rubocop:disable Style/StringLiterals self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.source = attributes[:'source'] if attributes[:'source'] self.source = "NONE" if source.nil? && !attributes.key?(:'source') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#admin_password ⇒ String
[Required] The password must be between 12 and 30 characters long, and must contain at least 1 uppercase, 1 lowercase, and 1 numeric character. It cannot contain the double quote symbol (") or the username "admin", regardless of casing.
51 52 53 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 51 def admin_password @admin_password end |
#compartment_id ⇒ String
[Required] The OCID of the compartment of the autonomous database.
30 31 32 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 30 def compartment_id @compartment_id end |
#cpu_core_count ⇒ Integer
[Required] The number of CPU Cores to be made available to the database.
38 39 40 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 38 def cpu_core_count @cpu_core_count end |
#data_storage_size_in_tbs ⇒ Integer
[Required] The size, in terabytes, of the data volume that will be created and attached to the database. This storage can later be scaled up if needed.
47 48 49 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 47 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_name ⇒ String
[Required] The database name. The name must begin with an alphabetic character and can contain a maximum of 14 alphanumeric characters. Special characters are not permitted. The database name must be unique in the tenancy.
34 35 36 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 34 def db_name @db_name end |
#db_workload ⇒ String
The autonomous database workload type. OLTP indicates an Autonomous Transaction Processing database and DW indicates an Autonomous Data Warehouse. The default is OLTP.
42 43 44 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 42 def db_workload @db_workload end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
Example: {\"Operations\": {\"CostCenter\": \"42\"}}
81 82 83 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 81 def @defined_tags end |
#display_name ⇒ String
The user-friendly name for the Autonomous Database. The name does not have to be unique.
55 56 57 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 55 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see Resource Tags.
Example: {\"Department\": \"Finance\"}
73 74 75 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 73 def @freeform_tags end |
#is_auto_scaling_enabled ⇒ BOOLEAN
Indicates if auto scaling is enabled for the Autonomous Database CPU core count. The default value is false.
65 66 67 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 65 def is_auto_scaling_enabled @is_auto_scaling_enabled end |
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database. The default is BRING_YOUR_OWN_LICENSE.
60 61 62 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 60 def license_model @license_model end |
#source ⇒ String
The source of the database: Use NONE for creating a new Autonomous Database. Use DATABASE for creating a new Autonomous Database by cloning an existing Autonomous Database.
86 87 88 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 86 def source @source end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 89 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'db_name': :'dbName', 'cpu_core_count': :'cpuCoreCount', 'db_workload': :'dbWorkload', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'admin_password': :'adminPassword', 'display_name': :'displayName', 'license_model': :'licenseModel', 'is_auto_scaling_enabled': :'isAutoScalingEnabled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'source': :'source' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 133 def self.get_subtype(object_hash) type = object_hash[:'source'] # rubocop:disable Style/SymbolLiteral return 'OCI::Database::Models::CreateAutonomousDatabaseCloneDetails' if type == 'DATABASE' return 'OCI::Database::Models::CreateAutonomousDatabaseDetails' if type == 'NONE' # TODO: Log a warning when the subtype is not found. 'OCI::Database::Models::CreateAutonomousDatabaseBase' end |
.swagger_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 109 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'db_name': :'String', 'cpu_core_count': :'Integer', 'db_workload': :'String', 'data_storage_size_in_tbs': :'Integer', 'admin_password': :'String', 'display_name': :'String', 'license_model': :'String', 'is_auto_scaling_enabled': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'source': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 271 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && db_name == other.db_name && cpu_core_count == other.cpu_core_count && db_workload == other.db_workload && data_storage_size_in_tbs == other.data_storage_size_in_tbs && admin_password == other.admin_password && display_name == other.display_name && license_model == other.license_model && is_auto_scaling_enabled == other.is_auto_scaling_enabled && == other. && == other. && source == other.source end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 312 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
292 293 294 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 292 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
301 302 303 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 301 def hash [compartment_id, db_name, cpu_core_count, db_workload, data_storage_size_in_tbs, admin_password, display_name, license_model, is_auto_scaling_enabled, , , source].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
345 346 347 348 349 350 351 352 353 354 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 345 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
339 340 341 |
# File 'lib/oci/database/models/create_autonomous_database_base.rb', line 339 def to_s to_hash.to_s end |