Class: OCI::Database::Models::CreateAutonomousDatabaseDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/create_autonomous_database_details.rb

Overview

Details to create an Oracle Autonomous Database.

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

DB_WORKLOAD_ENUM =

rubocop:disable Metrics/LineLength

[
  DB_WORKLOAD_OLTP = 'OLTP'.freeze,
  DB_WORKLOAD_DW = 'DW'.freeze
].freeze
LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateAutonomousDatabaseDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :db_name (String)

    The value to assign to the #db_name property

  • :cpu_core_count (Integer)

    The value to assign to the #cpu_core_count property

  • :db_workload (String)

    The value to assign to the #db_workload property

  • :data_storage_size_in_tbs (Integer)

    The value to assign to the #data_storage_size_in_tbs property

  • :admin_password (String)

    The value to assign to the #admin_password property

  • :display_name (String)

    The value to assign to the #display_name property

  • :license_model (String)

    The value to assign to the #license_model property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 124

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.db_name = attributes[:'dbName'] if attributes[:'dbName']

  raise 'You cannot provide both :dbName and :db_name' if attributes.key?(:'dbName') && attributes.key?(:'db_name')

  self.db_name = attributes[:'db_name'] if attributes[:'db_name']

  self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount']

  raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count')

  self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count']

  self.db_workload = attributes[:'dbWorkload'] if attributes[:'dbWorkload']

  raise 'You cannot provide both :dbWorkload and :db_workload' if attributes.key?(:'dbWorkload') && attributes.key?(:'db_workload')

  self.db_workload = attributes[:'db_workload'] if attributes[:'db_workload']

  self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs']

  raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs')

  self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs']

  self.admin_password = attributes[:'adminPassword'] if attributes[:'adminPassword']

  raise 'You cannot provide both :adminPassword and :admin_password' if attributes.key?(:'adminPassword') && attributes.key?(:'admin_password')

  self.admin_password = attributes[:'admin_password'] if attributes[:'admin_password']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#admin_passwordString

[Required] The password must be between 12 and 30 characters long, and must contain at least 1 uppercase, 1 lowercase, and 1 numeric character. It cannot contain the double quote symbol (") or the username "admin", regardless of casing.

Returns:

  • (String)


45
46
47
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 45

def admin_password
  @admin_password
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment of the autonomous database.

Returns:

  • (String)


24
25
26
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 24

def compartment_id
  @compartment_id
end

#cpu_core_countInteger

[Required] The number of CPU Cores to be made available to the database.

Returns:

  • (Integer)


32
33
34
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 32

def cpu_core_count
  @cpu_core_count
end

#data_storage_size_in_tbsInteger

[Required] The size, in terabytes, of the data volume that will be created and attached to the database. This storage can later be scaled up if needed.

Returns:

  • (Integer)


41
42
43
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 41

def data_storage_size_in_tbs
  @data_storage_size_in_tbs
end

#db_nameString

[Required] The database name. The name must begin with an alphabetic character and can contain a maximum of 14 alphanumeric characters. Special characters are not permitted. The database name must be unique in the tenancy.

Returns:

  • (String)


28
29
30
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 28

def db_name
  @db_name
end

#db_workloadString

The autonomous database workload type.

Returns:

  • (String)


36
37
38
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 36

def db_workload
  @db_workload
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


70
71
72
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 70

def defined_tags
  @defined_tags
end

#display_nameString

The user-friendly name for the Autonomous Database. The name does not have to be unique.

Returns:

  • (String)


49
50
51
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 49

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


62
63
64
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 62

def freeform_tags
  @freeform_tags
end

#license_modelString

The Oracle license model that applies to the Oracle Autonomous Database. The default is BRING_YOUR_OWN_LICENSE.

Returns:

  • (String)


54
55
56
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 54

def license_model
  @license_model
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 73

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'db_name': :'dbName',
    'cpu_core_count': :'cpuCoreCount',
    'db_workload': :'dbWorkload',
    'data_storage_size_in_tbs': :'dataStorageSizeInTBs',
    'admin_password': :'adminPassword',
    'display_name': :'displayName',
    'license_model': :'licenseModel',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 91

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'db_name': :'String',
    'cpu_core_count': :'Integer',
    'db_workload': :'String',
    'data_storage_size_in_tbs': :'Integer',
    'admin_password': :'String',
    'display_name': :'String',
    'license_model': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 218

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    db_name == other.db_name &&
    cpu_core_count == other.cpu_core_count &&
    db_workload == other.db_workload &&
    data_storage_size_in_tbs == other.data_storage_size_in_tbs &&
    admin_password == other.admin_password &&
    display_name == other.display_name &&
    license_model == other.license_model &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 257

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


237
238
239
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 237

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



246
247
248
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 246

def hash
  [compartment_id, db_name, cpu_core_count, db_workload, data_storage_size_in_tbs, admin_password, display_name, license_model, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



290
291
292
293
294
295
296
297
298
299
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 290

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



284
285
286
# File 'lib/oci/database/models/create_autonomous_database_details.rb', line 284

def to_s
  to_hash.to_s
end