Class: OCI::Database::Models::CreateCloudAutonomousVmClusterDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateCloudAutonomousVmClusterDetails
- Defined in:
- lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb
Overview
Details for the create cloud Autonomous VM cluster operation.
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cloud_exadata_infrastructure_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
User defined description of the cloud Autonomous VM cluster.
-
#display_name ⇒ String
[Required] The user-friendly name for the cloud Autonomous VM cluster.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database.
-
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to.
-
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet the cloud Autonomous VM Cluster is associated with.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCloudAutonomousVmClusterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateCloudAutonomousVmClusterDetails
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.description = attributes[:'description'] if attributes[:'description'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.cloud_exadata_infrastructure_id = attributes[:'cloudExadataInfrastructureId'] if attributes[:'cloudExadataInfrastructureId'] raise 'You cannot provide both :cloudExadataInfrastructureId and :cloud_exadata_infrastructure_id' if attributes.key?(:'cloudExadataInfrastructureId') && attributes.key?(:'cloud_exadata_infrastructure_id') self.cloud_exadata_infrastructure_id = attributes[:'cloud_exadata_infrastructure_id'] if attributes[:'cloud_exadata_infrastructure_id'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#cloud_exadata_infrastructure_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure.
35 36 37 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 35 def cloud_exadata_infrastructure_id @cloud_exadata_infrastructure_id end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
18 19 20 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 18 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
64 65 66 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 64 def end |
#description ⇒ String
User defined description of the cloud Autonomous VM cluster.
22 23 24 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 22 def description @description end |
#display_name ⇒ String
[Required] The user-friendly name for the cloud Autonomous VM cluster. The name does not need to be unique.
31 32 33 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 31 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
58 59 60 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 58 def end |
#license_model ⇒ String
The Oracle license model that applies to the Oracle Autonomous Database. Bring your own license (BYOL) allows you to apply your current on-premises Oracle software licenses to equivalent, highly automated Oracle PaaS and IaaS services in the cloud. License Included allows you to subscribe to new Oracle Database software licenses and the Database service. Note that when provisioning an Autonomous Database on [dedicated Exadata infrastructure](docs.oracle.com/en/cloud/paas/autonomous-database/index.html), this attribute must be null because the attribute is already set at the Autonomous Exadata Infrastructure level. When using [shared Exadata infrastructure](docs.oracle.com/en/cloud/paas/autonomous-database/index.html), if a value is not specified, the system will supply the value of BRING_YOUR_OWN_LICENSE.
43 44 45 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 43 def license_model @license_model end |
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**
-
Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.
50 51 52 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 50 def nsg_ids @nsg_ids end |
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet the cloud Autonomous VM Cluster is associated with.
27 28 29 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 27 def subnet_id @subnet_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 67 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'description': :'description', 'subnet_id': :'subnetId', 'display_name': :'displayName', 'cloud_exadata_infrastructure_id': :'cloudExadataInfrastructureId', 'license_model': :'licenseModel', 'nsg_ids': :'nsgIds', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 84 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'description': :'String', 'subnet_id': :'String', 'display_name': :'String', 'cloud_exadata_infrastructure_id': :'String', 'license_model': :'String', 'nsg_ids': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 187 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && description == other.description && subnet_id == other.subnet_id && display_name == other.display_name && cloud_exadata_infrastructure_id == other.cloud_exadata_infrastructure_id && license_model == other.license_model && nsg_ids == other.nsg_ids && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 225 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
205 206 207 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 205 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 214 def hash [compartment_id, description, subnet_id, display_name, cloud_exadata_infrastructure_id, license_model, nsg_ids, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
252 253 254 |
# File 'lib/oci/database/models/create_cloud_autonomous_vm_cluster_details.rb', line 252 def to_s to_hash.to_s end |