Class: OCI::Database::Models::CreateCloudVmClusterDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateCloudVmClusterDetails
- Defined in:
- lib/oci/database/models/create_cloud_vm_cluster_details.rb
Overview
Details for the create cloud VM cluster operation. Applies to Exadata Cloud Service instances only.
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#backup_network_nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that the backup network of this DB system belongs to.
-
#backup_subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup network subnet associated with the cloud VM cluster.
-
#cloud_exadata_infrastructure_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure resource.
-
#cluster_name ⇒ String
The cluster name for cloud VM cluster.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#cpu_core_count ⇒ Integer
[Required] The number of CPU cores to enable for a cloud VM cluster.
-
#data_storage_percentage ⇒ Integer
The percentage assigned to DATA storage (user data and database files).
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly name for the cloud VM cluster.
-
#domain ⇒ String
A domain name used for the cloud VM cluster.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#gi_version ⇒ String
[Required] A valid Oracle Grid Infrastructure (GI) software version.
-
#hostname ⇒ String
[Required] The hostname for the cloud VM cluster.
-
#is_local_backup_enabled ⇒ BOOLEAN
If true, database backup on local Exadata storage is configured for the cloud VM cluster.
-
#is_sparse_diskgroup_enabled ⇒ BOOLEAN
If true, the sparse disk group is configured for the cloud VM cluster.
-
#license_model ⇒ String
The Oracle license model that applies to the cloud VM cluster.
-
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to.
-
#ssh_public_keys ⇒ Array<String>
[Required] The public key portion of one or more key pairs used for SSH access to the cloud VM cluster.
-
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet associated with the cloud VM cluster.
-
#time_zone ⇒ String
The time zone to use for the cloud VM cluster.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCloudVmClusterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateCloudVmClusterDetails
Initializes the object
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 217 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.backup_subnet_id = attributes[:'backupSubnetId'] if attributes[:'backupSubnetId'] raise 'You cannot provide both :backupSubnetId and :backup_subnet_id' if attributes.key?(:'backupSubnetId') && attributes.key?(:'backup_subnet_id') self.backup_subnet_id = attributes[:'backup_subnet_id'] if attributes[:'backup_subnet_id'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.cluster_name = attributes[:'clusterName'] if attributes[:'clusterName'] raise 'You cannot provide both :clusterName and :cluster_name' if attributes.key?(:'clusterName') && attributes.key?(:'cluster_name') self.cluster_name = attributes[:'cluster_name'] if attributes[:'cluster_name'] self.data_storage_percentage = attributes[:'dataStoragePercentage'] if attributes[:'dataStoragePercentage'] raise 'You cannot provide both :dataStoragePercentage and :data_storage_percentage' if attributes.key?(:'dataStoragePercentage') && attributes.key?(:'data_storage_percentage') self.data_storage_percentage = attributes[:'data_storage_percentage'] if attributes[:'data_storage_percentage'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.cloud_exadata_infrastructure_id = attributes[:'cloudExadataInfrastructureId'] if attributes[:'cloudExadataInfrastructureId'] raise 'You cannot provide both :cloudExadataInfrastructureId and :cloud_exadata_infrastructure_id' if attributes.key?(:'cloudExadataInfrastructureId') && attributes.key?(:'cloud_exadata_infrastructure_id') self.cloud_exadata_infrastructure_id = attributes[:'cloud_exadata_infrastructure_id'] if attributes[:'cloud_exadata_infrastructure_id'] self.hostname = attributes[:'hostname'] if attributes[:'hostname'] self.domain = attributes[:'domain'] if attributes[:'domain'] self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys'] raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys') self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.is_sparse_diskgroup_enabled = attributes[:'isSparseDiskgroupEnabled'] unless attributes[:'isSparseDiskgroupEnabled'].nil? raise 'You cannot provide both :isSparseDiskgroupEnabled and :is_sparse_diskgroup_enabled' if attributes.key?(:'isSparseDiskgroupEnabled') && attributes.key?(:'is_sparse_diskgroup_enabled') self.is_sparse_diskgroup_enabled = attributes[:'is_sparse_diskgroup_enabled'] unless attributes[:'is_sparse_diskgroup_enabled'].nil? self.is_local_backup_enabled = attributes[:'isLocalBackupEnabled'] unless attributes[:'isLocalBackupEnabled'].nil? raise 'You cannot provide both :isLocalBackupEnabled and :is_local_backup_enabled' if attributes.key?(:'isLocalBackupEnabled') && attributes.key?(:'is_local_backup_enabled') self.is_local_backup_enabled = attributes[:'is_local_backup_enabled'] unless attributes[:'is_local_backup_enabled'].nil? self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone'] raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.backup_network_nsg_ids = attributes[:'backupNetworkNsgIds'] if attributes[:'backupNetworkNsgIds'] raise 'You cannot provide both :backupNetworkNsgIds and :backup_network_nsg_ids' if attributes.key?(:'backupNetworkNsgIds') && attributes.key?(:'backup_network_nsg_ids') self.backup_network_nsg_ids = attributes[:'backup_network_nsg_ids'] if attributes[:'backup_network_nsg_ids'] self.gi_version = attributes[:'giVersion'] if attributes[:'giVersion'] raise 'You cannot provide both :giVersion and :gi_version' if attributes.key?(:'giVersion') && attributes.key?(:'gi_version') self.gi_version = attributes[:'gi_version'] if attributes[:'gi_version'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#backup_network_nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). Applicable only to Exadata systems.
115 116 117 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 115 def backup_network_nsg_ids @backup_network_nsg_ids end |
#backup_subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup network subnet associated with the cloud VM cluster.
28 29 30 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 28 def backup_subnet_id @backup_subnet_id end |
#cloud_exadata_infrastructure_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the cloud Exadata infrastructure resource.
60 61 62 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 60 def cloud_exadata_infrastructure_id @cloud_exadata_infrastructure_id end |
#cluster_name ⇒ String
The cluster name for cloud VM cluster. The cluster name must begin with an alphabetic character, and may contain hyphens (-). Underscores (_) are not permitted. The cluster name can be no longer than 11 characters and is not case sensitive.
46 47 48 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 46 def cluster_name @cluster_name end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
18 19 20 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 18 def compartment_id @compartment_id end |
#cpu_core_count ⇒ Integer
[Required] The number of CPU cores to enable for a cloud VM cluster. Valid values depend on the specified shape:
-
Exadata.Base.48 - Specify a multiple of 2, from 0 to 48.
-
Exadata.Quarter1.84 - Specify a multiple of 2, from 22 to 84.
-
Exadata.Half1.168 - Specify a multiple of 4, from 44 to 168.
-
Exadata.Full1.336 - Specify a multiple of 8, from 88 to 336.
-
Exadata.Quarter2.92 - Specify a multiple of 2, from 0 to 92.
-
Exadata.Half2.184 - Specify a multiple of 4, from 0 to 184.
-
Exadata.Full2.368 - Specify a multiple of 8, from 0 to 368.
41 42 43 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 41 def cpu_core_count @cpu_core_count end |
#data_storage_percentage ⇒ Integer
The percentage assigned to DATA storage (user data and database files). The remaining percentage is assigned to RECO storage (database redo logs, archive logs, and recovery manager backups). Accepted values are 35, 40, 60 and 80. The default is 80 percent assigned to DATA storage. See [Storage Configuration](docs.cloud.oracle.com/Content/Database/Concepts/exaoverview.htm#Exadata) in the Exadata documentation for details on the impact of the configuration settings on storage.
52 53 54 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 52 def data_storage_percentage @data_storage_percentage end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
133 134 135 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 133 def @defined_tags end |
#display_name ⇒ String
[Required] The user-friendly name for the cloud VM cluster. The name does not need to be unique.
56 57 58 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 56 def display_name @display_name end |
#domain ⇒ String
A domain name used for the cloud VM cluster. If the Oracle-provided internet and VCN resolver is enabled for the specified subnet, the domain name for the subnet is used (do not provide one). Otherwise, provide a valid DNS domain name. Hyphens (-) are not permitted. Applies to Exadata Cloud Service instances only.
79 80 81 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 79 def domain @domain end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
127 128 129 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 127 def @freeform_tags end |
#gi_version ⇒ String
[Required] A valid Oracle Grid Infrastructure (GI) software version.
119 120 121 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 119 def gi_version @gi_version end |
#hostname ⇒ String
[Required] The hostname for the cloud VM cluster. The hostname must begin with an alphabetic character, and can contain alphanumeric characters and hyphens (-). The maximum length of the hostname is 16 characters for bare metal and virtual machine DB systems, and 12 characters for Exadata systems.
The maximum length of the combined hostname and domain is 63 characters.
Note: The hostname must be unique within the subnet. If it is not unique, the cloud VM Cluster will fail to provision.
71 72 73 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 71 def hostname @hostname end |
#is_local_backup_enabled ⇒ BOOLEAN
If true, database backup on local Exadata storage is configured for the cloud VM cluster. If false, database backup on local Exadata storage is not available in the cloud VM cluster.
98 99 100 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 98 def is_local_backup_enabled @is_local_backup_enabled end |
#is_sparse_diskgroup_enabled ⇒ BOOLEAN
If true, the sparse disk group is configured for the cloud VM cluster. If false, the sparse disk group is not created.
93 94 95 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 93 def is_sparse_diskgroup_enabled @is_sparse_diskgroup_enabled end |
#license_model ⇒ String
The Oracle license model that applies to the cloud VM cluster. The default is BRING_YOUR_OWN_LICENSE.
88 89 90 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 88 def license_model @license_model end |
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**
-
Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.
110 111 112 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 110 def nsg_ids @nsg_ids end |
#ssh_public_keys ⇒ Array<String>
[Required] The public key portion of one or more key pairs used for SSH access to the cloud VM cluster.
83 84 85 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 83 def ssh_public_keys @ssh_public_keys end |
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet associated with the cloud VM cluster.
23 24 25 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 23 def subnet_id @subnet_id end |
#time_zone ⇒ String
The time zone to use for the cloud VM cluster. For details, see [Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).
103 104 105 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 103 def time_zone @time_zone end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 136 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'subnet_id': :'subnetId', 'backup_subnet_id': :'backupSubnetId', 'cpu_core_count': :'cpuCoreCount', 'cluster_name': :'clusterName', 'data_storage_percentage': :'dataStoragePercentage', 'display_name': :'displayName', 'cloud_exadata_infrastructure_id': :'cloudExadataInfrastructureId', 'hostname': :'hostname', 'domain': :'domain', 'ssh_public_keys': :'sshPublicKeys', 'license_model': :'licenseModel', 'is_sparse_diskgroup_enabled': :'isSparseDiskgroupEnabled', 'is_local_backup_enabled': :'isLocalBackupEnabled', 'time_zone': :'timeZone', 'nsg_ids': :'nsgIds', 'backup_network_nsg_ids': :'backupNetworkNsgIds', 'gi_version': :'giVersion', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 164 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'subnet_id': :'String', 'backup_subnet_id': :'String', 'cpu_core_count': :'Integer', 'cluster_name': :'String', 'data_storage_percentage': :'Integer', 'display_name': :'String', 'cloud_exadata_infrastructure_id': :'String', 'hostname': :'String', 'domain': :'String', 'ssh_public_keys': :'Array<String>', 'license_model': :'String', 'is_sparse_diskgroup_enabled': :'BOOLEAN', 'is_local_backup_enabled': :'BOOLEAN', 'time_zone': :'String', 'nsg_ids': :'Array<String>', 'backup_network_nsg_ids': :'Array<String>', 'gi_version': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 351 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && subnet_id == other.subnet_id && backup_subnet_id == other.backup_subnet_id && cpu_core_count == other.cpu_core_count && cluster_name == other.cluster_name && data_storage_percentage == other.data_storage_percentage && display_name == other.display_name && cloud_exadata_infrastructure_id == other.cloud_exadata_infrastructure_id && hostname == other.hostname && domain == other.domain && ssh_public_keys == other.ssh_public_keys && license_model == other.license_model && is_sparse_diskgroup_enabled == other.is_sparse_diskgroup_enabled && is_local_backup_enabled == other.is_local_backup_enabled && time_zone == other.time_zone && nsg_ids == other.nsg_ids && backup_network_nsg_ids == other.backup_network_nsg_ids && gi_version == other.gi_version && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 400 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
380 381 382 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 380 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
389 390 391 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 389 def hash [compartment_id, subnet_id, backup_subnet_id, cpu_core_count, cluster_name, data_storage_percentage, display_name, cloud_exadata_infrastructure_id, hostname, domain, ssh_public_keys, license_model, is_sparse_diskgroup_enabled, is_local_backup_enabled, time_zone, nsg_ids, backup_network_nsg_ids, gi_version, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
433 434 435 436 437 438 439 440 441 442 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 433 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
427 428 429 |
# File 'lib/oci/database/models/create_cloud_vm_cluster_details.rb', line 427 def to_s to_hash.to_s end |