Class: OCI::Database::Models::CreateDataGuardAssociationDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateDataGuardAssociationDetails
- Defined in:
- lib/oci/database/models/create_data_guard_association_details.rb
Overview
The configuration details for creating a Data Guard association between databases.
NOTE: "ExistingDbSystem" is the only supported creationType value. Therefore, all create_data_guard_association requests must include the peerDbSystemId parameter found in the create_data_guard_association_to_existing_db_system_details object.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- PROTECTION_MODE_ENUM =
rubocop:disable Metrics/LineLength
[ PROTECTION_MODE_MAXIMUM_AVAILABILITY = 'MAXIMUM_AVAILABILITY'.freeze, PROTECTION_MODE_MAXIMUM_PERFORMANCE = 'MAXIMUM_PERFORMANCE'.freeze, PROTECTION_MODE_MAXIMUM_PROTECTION = 'MAXIMUM_PROTECTION'.freeze ].freeze
- TRANSPORT_TYPE_ENUM =
[ TRANSPORT_TYPE_SYNC = 'SYNC'.freeze, TRANSPORT_TYPE_ASYNC = 'ASYNC'.freeze, TRANSPORT_TYPE_FASTSYNC = 'FASTSYNC'.freeze ].freeze
Instance Attribute Summary collapse
-
#creation_type ⇒ String
[Required] Specifies where to create the associated database.
-
#database_admin_password ⇒ String
[Required] A strong password for the
SYS,SYSTEM, and ‘PDB Admin` users to apply during standby creation. -
#protection_mode ⇒ String
[Required] The protection mode to set up between the primary and standby databases.
-
#transport_type ⇒ String
[Required] The redo transport type to use for this Data Guard association.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDataGuardAssociationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDataGuardAssociationDetails
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 126 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.creation_type = attributes[:'creationType'] if attributes[:'creationType'] raise 'You cannot provide both :creationType and :creation_type' if attributes.key?(:'creationType') && attributes.key?(:'creation_type') self.creation_type = attributes[:'creation_type'] if attributes[:'creation_type'] self.database_admin_password = attributes[:'databaseAdminPassword'] if attributes[:'databaseAdminPassword'] raise 'You cannot provide both :databaseAdminPassword and :database_admin_password' if attributes.key?(:'databaseAdminPassword') && attributes.key?(:'database_admin_password') self.database_admin_password = attributes[:'database_admin_password'] if attributes[:'database_admin_password'] self.protection_mode = attributes[:'protectionMode'] if attributes[:'protectionMode'] raise 'You cannot provide both :protectionMode and :protection_mode' if attributes.key?(:'protectionMode') && attributes.key?(:'protection_mode') self.protection_mode = attributes[:'protection_mode'] if attributes[:'protection_mode'] self.transport_type = attributes[:'transportType'] if attributes[:'transportType'] raise 'You cannot provide both :transportType and :transport_type' if attributes.key?(:'transportType') && attributes.key?(:'transport_type') self.transport_type = attributes[:'transport_type'] if attributes[:'transport_type'] end |
Instance Attribute Details
#creation_type ⇒ String
[Required] Specifies where to create the associated database. "ExistingDbSystem" is the only supported creationType value.
34 35 36 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 34 def creation_type @creation_type end |
#database_admin_password ⇒ String
[Required] A strong password for the SYS, SYSTEM, and ‘PDB Admin` users to apply during standby creation.
The password must contain no fewer than nine characters and include:
-
At least two uppercase characters.
-
At least two lowercase characters.
-
At least two numeric characters.
-
At least two special characters. Valid special characters include "_", "#", and "-" only.
**The password MUST be the same as the primary admin password.**
51 52 53 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 51 def database_admin_password @database_admin_password end |
#protection_mode ⇒ String
[Required] The protection mode to set up between the primary and standby databases. For more information, see [Oracle Data Guard Protection Modes](docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000) in the Oracle Data Guard documentation.
IMPORTANT - The only protection mode currently supported by the Database Service is MAXIMUM_PERFORMANCE.
60 61 62 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 60 def protection_mode @protection_mode end |
#transport_type ⇒ String
[Required] The redo transport type to use for this Data Guard association. Valid values depend on the specified protectionMode:
-
MAXIMUM_AVAILABILITY - SYNC or FASTSYNC
-
MAXIMUM_PERFORMANCE - ASYNC
-
MAXIMUM_PROTECTION - SYNC
For more information, see [Redo Transport Services](docs.oracle.com/database/122/SBYDB/oracle-data-guard-redo-transport-services.htm#SBYDB00400) in the Oracle Data Guard documentation.
IMPORTANT - The only transport type currently supported by the Database Service is ASYNC.
75 76 77 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 75 def transport_type @transport_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 78 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'creation_type': :'creationType', 'database_admin_password': :'databaseAdminPassword', 'protection_mode': :'protectionMode', 'transport_type': :'transportType' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
106 107 108 109 110 111 112 113 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 106 def self.get_subtype(object_hash) type = object_hash[:'creationType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Database::Models::CreateDataGuardAssociationToExistingDbSystemDetails' if type == 'ExistingDbSystem' # TODO: Log a warning when the subtype is not found. 'OCI::Database::Models::CreateDataGuardAssociationDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 90 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'creation_type': :'String', 'database_admin_password': :'String', 'protection_mode': :'String', 'transport_type': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 184 def ==(other) return true if equal?(other) self.class == other.class && creation_type == other.creation_type && database_admin_password == other.database_admin_password && protection_mode == other.protection_mode && transport_type == other.transport_type end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 217 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
197 198 199 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 197 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 206 def hash [creation_type, database_admin_password, protection_mode, transport_type].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
244 245 246 |
# File 'lib/oci/database/models/create_data_guard_association_details.rb', line 244 def to_s to_hash.to_s end |