Class: OCI::Database::Models::CreateExadataInfrastructureDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateExadataInfrastructureDetails
- Defined in:
- lib/oci/database/models/create_exadata_infrastructure_details.rb
Overview
Request to create Exadata infrastructure resource. Applies to Exadata Cloud@Customer instances only. See create_cloud_exadata_infrastructure_details for information on creating a cloud Exadata infrastructure resource in an Exadata Cloud Service instance.
Instance Attribute Summary collapse
-
#admin_network_cidr ⇒ String
**[Required]** The CIDR block for the Exadata administration network.
-
#cloud_control_plane_server1 ⇒ String
**[Required]** The IP address for the first control plane server.
-
#cloud_control_plane_server2 ⇒ String
**[Required]** The IP address for the second control plane server.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#compute_count ⇒ Integer
The number of compute servers for the Exadata infrastructure.
-
#contacts ⇒ Array<OCI::Database::Models::ExadataInfrastructureContact>
The list of contacts for the Exadata infrastructure.
-
#corporate_proxy ⇒ String
The corporate network proxy for access to the control plane network.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** The user-friendly name for the Exadata infrastructure.
-
#dns_server ⇒ Array<String>
**[Required]** The list of DNS server IP addresses.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#gateway ⇒ String
**[Required]** The gateway for the control plane network.
-
#infini_band_network_cidr ⇒ String
**[Required]** The CIDR block for the Exadata InfiniBand interconnect.
-
#is_cps_offline_report_enabled ⇒ BOOLEAN
Indicates whether cps offline diagnostic report is enabled for this Exadata infrastructure.
- #maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
-
#netmask ⇒ String
**[Required]** The netmask for the control plane network.
-
#ntp_server ⇒ Array<String>
**[Required]** The list of NTP server IP addresses.
-
#shape ⇒ String
**[Required]** The shape of the Exadata infrastructure.
-
#storage_count ⇒ Integer
The number of storage servers for the Exadata infrastructure.
-
#time_zone ⇒ String
**[Required]** The time zone of the Exadata infrastructure.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateExadataInfrastructureDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateExadataInfrastructureDetails
Initializes the object
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 188 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone'] raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone'] self.cloud_control_plane_server1 = attributes[:'cloudControlPlaneServer1'] if attributes[:'cloudControlPlaneServer1'] raise 'You cannot provide both :cloudControlPlaneServer1 and :cloud_control_plane_server1' if attributes.key?(:'cloudControlPlaneServer1') && attributes.key?(:'cloud_control_plane_server1') self.cloud_control_plane_server1 = attributes[:'cloud_control_plane_server1'] if attributes[:'cloud_control_plane_server1'] self.cloud_control_plane_server2 = attributes[:'cloudControlPlaneServer2'] if attributes[:'cloudControlPlaneServer2'] raise 'You cannot provide both :cloudControlPlaneServer2 and :cloud_control_plane_server2' if attributes.key?(:'cloudControlPlaneServer2') && attributes.key?(:'cloud_control_plane_server2') self.cloud_control_plane_server2 = attributes[:'cloud_control_plane_server2'] if attributes[:'cloud_control_plane_server2'] self.netmask = attributes[:'netmask'] if attributes[:'netmask'] self.gateway = attributes[:'gateway'] if attributes[:'gateway'] self.admin_network_cidr = attributes[:'adminNetworkCIDR'] if attributes[:'adminNetworkCIDR'] raise 'You cannot provide both :adminNetworkCIDR and :admin_network_cidr' if attributes.key?(:'adminNetworkCIDR') && attributes.key?(:'admin_network_cidr') self.admin_network_cidr = attributes[:'admin_network_cidr'] if attributes[:'admin_network_cidr'] self.infini_band_network_cidr = attributes[:'infiniBandNetworkCIDR'] if attributes[:'infiniBandNetworkCIDR'] raise 'You cannot provide both :infiniBandNetworkCIDR and :infini_band_network_cidr' if attributes.key?(:'infiniBandNetworkCIDR') && attributes.key?(:'infini_band_network_cidr') self.infini_band_network_cidr = attributes[:'infini_band_network_cidr'] if attributes[:'infini_band_network_cidr'] self.corporate_proxy = attributes[:'corporateProxy'] if attributes[:'corporateProxy'] raise 'You cannot provide both :corporateProxy and :corporate_proxy' if attributes.key?(:'corporateProxy') && attributes.key?(:'corporate_proxy') self.corporate_proxy = attributes[:'corporate_proxy'] if attributes[:'corporate_proxy'] self.contacts = attributes[:'contacts'] if attributes[:'contacts'] self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow'] raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window') self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window'] self.storage_count = attributes[:'storageCount'] if attributes[:'storageCount'] raise 'You cannot provide both :storageCount and :storage_count' if attributes.key?(:'storageCount') && attributes.key?(:'storage_count') self.storage_count = attributes[:'storage_count'] if attributes[:'storage_count'] self.compute_count = attributes[:'computeCount'] if attributes[:'computeCount'] raise 'You cannot provide both :computeCount and :compute_count' if attributes.key?(:'computeCount') && attributes.key?(:'compute_count') self.compute_count = attributes[:'compute_count'] if attributes[:'compute_count'] self.dns_server = attributes[:'dnsServer'] if attributes[:'dnsServer'] raise 'You cannot provide both :dnsServer and :dns_server' if attributes.key?(:'dnsServer') && attributes.key?(:'dns_server') self.dns_server = attributes[:'dns_server'] if attributes[:'dns_server'] self.ntp_server = attributes[:'ntpServer'] if attributes[:'ntpServer'] raise 'You cannot provide both :ntpServer and :ntp_server' if attributes.key?(:'ntpServer') && attributes.key?(:'ntp_server') self.ntp_server = attributes[:'ntp_server'] if attributes[:'ntp_server'] self.is_cps_offline_report_enabled = attributes[:'isCpsOfflineReportEnabled'] unless attributes[:'isCpsOfflineReportEnabled'].nil? raise 'You cannot provide both :isCpsOfflineReportEnabled and :is_cps_offline_report_enabled' if attributes.key?(:'isCpsOfflineReportEnabled') && attributes.key?(:'is_cps_offline_report_enabled') self.is_cps_offline_report_enabled = attributes[:'is_cps_offline_report_enabled'] unless attributes[:'is_cps_offline_report_enabled'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#admin_network_cidr ⇒ String
**[Required]** The CIDR block for the Exadata administration network.
50 51 52 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 50 def admin_network_cidr @admin_network_cidr end |
#cloud_control_plane_server1 ⇒ String
**[Required]** The IP address for the first control plane server.
34 35 36 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 34 def cloud_control_plane_server1 @cloud_control_plane_server1 end |
#cloud_control_plane_server2 ⇒ String
**[Required]** The IP address for the second control plane server.
38 39 40 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 38 def cloud_control_plane_server2 @cloud_control_plane_server2 end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
15 16 17 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 15 def compartment_id @compartment_id end |
#compute_count ⇒ Integer
The number of compute servers for the Exadata infrastructure.
75 76 77 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 75 def compute_count @compute_count end |
#contacts ⇒ Array<OCI::Database::Models::ExadataInfrastructureContact>
The list of contacts for the Exadata infrastructure.
64 65 66 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 64 def contacts @contacts end |
#corporate_proxy ⇒ String
The corporate network proxy for access to the control plane network. Oracle recommends using an HTTPS proxy when possible for enhanced security.
60 61 62 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 60 def corporate_proxy @corporate_proxy end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
104 105 106 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 104 def @defined_tags end |
#display_name ⇒ String
**[Required]** The user-friendly name for the Exadata infrastructure. The name does not need to be unique.
20 21 22 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 20 def display_name @display_name end |
#dns_server ⇒ Array<String>
**[Required]** The list of DNS server IP addresses. Maximum of 3 allowed.
79 80 81 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 79 def dns_server @dns_server end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
98 99 100 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 98 def @freeform_tags end |
#gateway ⇒ String
**[Required]** The gateway for the control plane network.
46 47 48 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 46 def gateway @gateway end |
#infini_band_network_cidr ⇒ String
**[Required]** The CIDR block for the Exadata InfiniBand interconnect.
54 55 56 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 54 def infini_band_network_cidr @infini_band_network_cidr end |
#is_cps_offline_report_enabled ⇒ BOOLEAN
Indicates whether cps offline diagnostic report is enabled for this Exadata infrastructure. This will allow a customer to quickly check status themselves and fix problems on their end, saving time and frustration for both Oracle and the customer when they find the CPS in a disconnected state.You can enable offline diagnostic report during Exadata infrastructure provisioning. You can also disable or enable it at any time using the UpdateExadatainfrastructure API.
90 91 92 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 90 def is_cps_offline_report_enabled @is_cps_offline_report_enabled end |
#maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
67 68 69 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 67 def maintenance_window @maintenance_window end |
#netmask ⇒ String
**[Required]** The netmask for the control plane network.
42 43 44 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 42 def netmask @netmask end |
#ntp_server ⇒ Array<String>
**[Required]** The list of NTP server IP addresses. Maximum of 3 allowed.
83 84 85 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 83 def ntp_server @ntp_server end |
#shape ⇒ String
**[Required]** The shape of the Exadata infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.
25 26 27 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 25 def shape @shape end |
#storage_count ⇒ Integer
The number of storage servers for the Exadata infrastructure.
71 72 73 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 71 def storage_count @storage_count end |
#time_zone ⇒ String
**[Required]** The time zone of the Exadata infrastructure. For details, see [Exadata Infrastructure Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).
30 31 32 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 30 def time_zone @time_zone end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 107 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'shape': :'shape', 'time_zone': :'timeZone', 'cloud_control_plane_server1': :'cloudControlPlaneServer1', 'cloud_control_plane_server2': :'cloudControlPlaneServer2', 'netmask': :'netmask', 'gateway': :'gateway', 'admin_network_cidr': :'adminNetworkCIDR', 'infini_band_network_cidr': :'infiniBandNetworkCIDR', 'corporate_proxy': :'corporateProxy', 'contacts': :'contacts', 'maintenance_window': :'maintenanceWindow', 'storage_count': :'storageCount', 'compute_count': :'computeCount', 'dns_server': :'dnsServer', 'ntp_server': :'ntpServer', 'is_cps_offline_report_enabled': :'isCpsOfflineReportEnabled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 135 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'shape': :'String', 'time_zone': :'String', 'cloud_control_plane_server1': :'String', 'cloud_control_plane_server2': :'String', 'netmask': :'String', 'gateway': :'String', 'admin_network_cidr': :'String', 'infini_band_network_cidr': :'String', 'corporate_proxy': :'String', 'contacts': :'Array<OCI::Database::Models::ExadataInfrastructureContact>', 'maintenance_window': :'OCI::Database::Models::MaintenanceWindow', 'storage_count': :'Integer', 'compute_count': :'Integer', 'dns_server': :'Array<String>', 'ntp_server': :'Array<String>', 'is_cps_offline_report_enabled': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 306 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && shape == other.shape && time_zone == other.time_zone && cloud_control_plane_server1 == other.cloud_control_plane_server1 && cloud_control_plane_server2 == other.cloud_control_plane_server2 && netmask == other.netmask && gateway == other.gateway && admin_network_cidr == other.admin_network_cidr && infini_band_network_cidr == other.infini_band_network_cidr && corporate_proxy == other.corporate_proxy && contacts == other.contacts && maintenance_window == other.maintenance_window && storage_count == other.storage_count && compute_count == other.compute_count && dns_server == other.dns_server && ntp_server == other.ntp_server && is_cps_offline_report_enabled == other.is_cps_offline_report_enabled && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 355 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
335 336 337 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 335 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
344 345 346 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 344 def hash [compartment_id, display_name, shape, time_zone, cloud_control_plane_server1, cloud_control_plane_server2, netmask, gateway, admin_network_cidr, infini_band_network_cidr, corporate_proxy, contacts, maintenance_window, storage_count, compute_count, dns_server, ntp_server, is_cps_offline_report_enabled, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
388 389 390 391 392 393 394 395 396 397 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 388 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
382 383 384 |
# File 'lib/oci/database/models/create_exadata_infrastructure_details.rb', line 382 def to_s to_hash.to_s end |