Class: OCI::Database::Models::CreatePluggableDatabaseDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreatePluggableDatabaseDetails
- Defined in:
- lib/oci/database/models/create_pluggable_database_details.rb
Overview
Parameters for creating a pluggable database in a specified container database (CDB).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Instance Attribute Summary collapse
-
#container_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the CDB.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#pdb_admin_password ⇒ String
[Required] A strong password for PDB Admin.
-
#pdb_name ⇒ String
[Required] The name for the pluggable database (PDB).
-
#tde_wallet_password ⇒ String
[Required] The existing TDE wallet password of the CDB.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePluggableDatabaseDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreatePluggableDatabaseDetails
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.pdb_name = attributes[:'pdbName'] if attributes[:'pdbName'] raise 'You cannot provide both :pdbName and :pdb_name' if attributes.key?(:'pdbName') && attributes.key?(:'pdb_name') self.pdb_name = attributes[:'pdb_name'] if attributes[:'pdb_name'] self.container_database_id = attributes[:'containerDatabaseId'] if attributes[:'containerDatabaseId'] raise 'You cannot provide both :containerDatabaseId and :container_database_id' if attributes.key?(:'containerDatabaseId') && attributes.key?(:'container_database_id') self.container_database_id = attributes[:'container_database_id'] if attributes[:'container_database_id'] self.pdb_admin_password = attributes[:'pdbAdminPassword'] if attributes[:'pdbAdminPassword'] raise 'You cannot provide both :pdbAdminPassword and :pdb_admin_password' if attributes.key?(:'pdbAdminPassword') && attributes.key?(:'pdb_admin_password') self.pdb_admin_password = attributes[:'pdb_admin_password'] if attributes[:'pdb_admin_password'] self.tde_wallet_password = attributes[:'tdeWalletPassword'] if attributes[:'tdeWalletPassword'] raise 'You cannot provide both :tdeWalletPassword and :tde_wallet_password' if attributes.key?(:'tdeWalletPassword') && attributes.key?(:'tde_wallet_password') self.tde_wallet_password = attributes[:'tde_wallet_password'] if attributes[:'tde_wallet_password'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#container_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the CDB
19 20 21 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 19 def container_database_id @container_database_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
41 42 43 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 41 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
35 36 37 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 35 def @freeform_tags end |
#pdb_admin_password ⇒ String
[Required] A strong password for PDB Admin. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \#, or -.
23 24 25 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 23 def pdb_admin_password @pdb_admin_password end |
#pdb_name ⇒ String
[Required] The name for the pluggable database (PDB). The name is unique in the context of a Database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.
15 16 17 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 15 def pdb_name @pdb_name end |
#tde_wallet_password ⇒ String
[Required] The existing TDE wallet password of the CDB.
27 28 29 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 27 def tde_wallet_password @tde_wallet_password end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'pdb_name': :'pdbName', 'container_database_id': :'containerDatabaseId', 'pdb_admin_password': :'pdbAdminPassword', 'tde_wallet_password': :'tdeWalletPassword', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'pdb_name': :'String', 'container_database_id': :'String', 'pdb_admin_password': :'String', 'tde_wallet_password': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 133 def ==(other) return true if equal?(other) self.class == other.class && pdb_name == other.pdb_name && container_database_id == other.container_database_id && pdb_admin_password == other.pdb_admin_password && tde_wallet_password == other.tde_wallet_password && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 157 def hash [pdb_name, container_database_id, pdb_admin_password, tde_wallet_password, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/database/models/create_pluggable_database_details.rb', line 195 def to_s to_hash.to_s end |