Class: OCI::Database::Models::CreateVmClusterDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::CreateVmClusterDetails
- Defined in:
- lib/oci/database/models/create_vm_cluster_details.rb
Overview
Details for the create Exadata VM cluster operation. Applies to Exadata Cloud@Customer instances only. For details on the create cloud Exadata VM cluster operation used with Exadata Cloud Service instances, see create_cloud_vm_cluster_details
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#cpu_core_count ⇒ Integer
[Required] The number of CPU cores to enable for the VM cluster.
-
#data_storage_size_in_gbs ⇒ Float
The data disk group size to be allocated in GBs.
-
#data_storage_size_in_tbs ⇒ Float
The data disk group size to be allocated in TBs.
-
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage to be allocated in GBs.
-
#db_servers ⇒ Array<String>
The list of Db server.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly name for the VM cluster.
-
#exadata_infrastructure_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#gi_version ⇒ String
[Required] The Oracle Grid Infrastructure software version for the VM cluster.
-
#is_local_backup_enabled ⇒ BOOLEAN
If true, database backup on local Exadata storage is configured for the VM cluster.
-
#is_sparse_diskgroup_enabled ⇒ BOOLEAN
If true, the sparse disk group is configured for the VM cluster.
-
#license_model ⇒ String
The Oracle license model that applies to the VM cluster.
-
#memory_size_in_gbs ⇒ Integer
The memory to be allocated in GBs.
-
#ocpu_count ⇒ Float
The number of OCPU cores to enable for the VM cluster.
-
#ssh_public_keys ⇒ Array<String>
[Required] The public key portion of one or more key pairs used for SSH access to the VM cluster.
-
#time_zone ⇒ String
The time zone to use for the VM cluster.
-
#vm_cluster_network_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster network.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateVmClusterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateVmClusterDetails
Initializes the object
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 181 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.exadata_infrastructure_id = attributes[:'exadataInfrastructureId'] if attributes[:'exadataInfrastructureId'] raise 'You cannot provide both :exadataInfrastructureId and :exadata_infrastructure_id' if attributes.key?(:'exadataInfrastructureId') && attributes.key?(:'exadata_infrastructure_id') self.exadata_infrastructure_id = attributes[:'exadata_infrastructure_id'] if attributes[:'exadata_infrastructure_id'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.ocpu_count = attributes[:'ocpuCount'] if attributes[:'ocpuCount'] raise 'You cannot provide both :ocpuCount and :ocpu_count' if attributes.key?(:'ocpuCount') && attributes.key?(:'ocpu_count') self.ocpu_count = attributes[:'ocpu_count'] if attributes[:'ocpu_count'] self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs'] raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs') self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs'] self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs'] raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs') self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys'] raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys') self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys'] self.vm_cluster_network_id = attributes[:'vmClusterNetworkId'] if attributes[:'vmClusterNetworkId'] raise 'You cannot provide both :vmClusterNetworkId and :vm_cluster_network_id' if attributes.key?(:'vmClusterNetworkId') && attributes.key?(:'vm_cluster_network_id') self.vm_cluster_network_id = attributes[:'vm_cluster_network_id'] if attributes[:'vm_cluster_network_id'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.is_sparse_diskgroup_enabled = attributes[:'isSparseDiskgroupEnabled'] unless attributes[:'isSparseDiskgroupEnabled'].nil? raise 'You cannot provide both :isSparseDiskgroupEnabled and :is_sparse_diskgroup_enabled' if attributes.key?(:'isSparseDiskgroupEnabled') && attributes.key?(:'is_sparse_diskgroup_enabled') self.is_sparse_diskgroup_enabled = attributes[:'is_sparse_diskgroup_enabled'] unless attributes[:'is_sparse_diskgroup_enabled'].nil? self.is_local_backup_enabled = attributes[:'isLocalBackupEnabled'] unless attributes[:'isLocalBackupEnabled'].nil? raise 'You cannot provide both :isLocalBackupEnabled and :is_local_backup_enabled' if attributes.key?(:'isLocalBackupEnabled') && attributes.key?(:'is_local_backup_enabled') self.is_local_backup_enabled = attributes[:'is_local_backup_enabled'] unless attributes[:'is_local_backup_enabled'].nil? self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone'] raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone'] self.gi_version = attributes[:'giVersion'] if attributes[:'giVersion'] raise 'You cannot provide both :giVersion and :gi_version' if attributes.key?(:'giVersion') && attributes.key?(:'gi_version') self.gi_version = attributes[:'gi_version'] if attributes[:'gi_version'] self.db_servers = attributes[:'dbServers'] if attributes[:'dbServers'] raise 'You cannot provide both :dbServers and :db_servers' if attributes.key?(:'dbServers') && attributes.key?(:'db_servers') self.db_servers = attributes[:'db_servers'] if attributes[:'db_servers'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
19 20 21 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 19 def compartment_id @compartment_id end |
#cpu_core_count ⇒ Integer
[Required] The number of CPU cores to enable for the VM cluster.
31 32 33 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 31 def cpu_core_count @cpu_core_count end |
#data_storage_size_in_gbs ⇒ Float
The data disk group size to be allocated in GBs.
51 52 53 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 51 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#data_storage_size_in_tbs ⇒ Float
The data disk group size to be allocated in TBs.
47 48 49 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 47 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage to be allocated in GBs.
43 44 45 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 43 def db_node_storage_size_in_gbs @db_node_storage_size_in_gbs end |
#db_servers ⇒ Array<String>
The list of Db server.
86 87 88 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 86 def db_servers @db_servers end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
100 101 102 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 100 def @defined_tags end |
#display_name ⇒ String
[Required] The user-friendly name for the VM cluster. The name does not need to be unique.
23 24 25 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 23 def display_name @display_name end |
#exadata_infrastructure_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.
27 28 29 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 27 def exadata_infrastructure_id @exadata_infrastructure_id end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
94 95 96 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 94 def @freeform_tags end |
#gi_version ⇒ String
[Required] The Oracle Grid Infrastructure software version for the VM cluster.
82 83 84 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 82 def gi_version @gi_version end |
#is_local_backup_enabled ⇒ BOOLEAN
If true, database backup on local Exadata storage is configured for the VM cluster. If false, database backup on local Exadata storage is not available in the VM cluster.
74 75 76 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 74 def is_local_backup_enabled @is_local_backup_enabled end |
#is_sparse_diskgroup_enabled ⇒ BOOLEAN
If true, the sparse disk group is configured for the VM cluster. If false, the sparse disk group is not created.
69 70 71 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 69 def is_sparse_diskgroup_enabled @is_sparse_diskgroup_enabled end |
#license_model ⇒ String
The Oracle license model that applies to the VM cluster. The default is BRING_YOUR_OWN_LICENSE.
64 65 66 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 64 def license_model @license_model end |
#memory_size_in_gbs ⇒ Integer
The memory to be allocated in GBs.
39 40 41 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 39 def memory_size_in_gbs @memory_size_in_gbs end |
#ocpu_count ⇒ Float
The number of OCPU cores to enable for the VM cluster. Only one decimal place is allowed for the fractional part.
35 36 37 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 35 def ocpu_count @ocpu_count end |
#ssh_public_keys ⇒ Array<String>
[Required] The public key portion of one or more key pairs used for SSH access to the VM cluster.
55 56 57 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 55 def ssh_public_keys @ssh_public_keys end |
#time_zone ⇒ String
The time zone to use for the VM cluster. For details, see [DB System Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).
78 79 80 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 78 def time_zone @time_zone end |
#vm_cluster_network_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster network.
59 60 61 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 59 def vm_cluster_network_id @vm_cluster_network_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 103 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'exadata_infrastructure_id': :'exadataInfrastructureId', 'cpu_core_count': :'cpuCoreCount', 'ocpu_count': :'ocpuCount', 'memory_size_in_gbs': :'memorySizeInGBs', 'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'ssh_public_keys': :'sshPublicKeys', 'vm_cluster_network_id': :'vmClusterNetworkId', 'license_model': :'licenseModel', 'is_sparse_diskgroup_enabled': :'isSparseDiskgroupEnabled', 'is_local_backup_enabled': :'isLocalBackupEnabled', 'time_zone': :'timeZone', 'gi_version': :'giVersion', 'db_servers': :'dbServers', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 130 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'exadata_infrastructure_id': :'String', 'cpu_core_count': :'Integer', 'ocpu_count': :'Float', 'memory_size_in_gbs': :'Integer', 'db_node_storage_size_in_gbs': :'Integer', 'data_storage_size_in_tbs': :'Float', 'data_storage_size_in_gbs': :'Float', 'ssh_public_keys': :'Array<String>', 'vm_cluster_network_id': :'String', 'license_model': :'String', 'is_sparse_diskgroup_enabled': :'BOOLEAN', 'is_local_backup_enabled': :'BOOLEAN', 'time_zone': :'String', 'gi_version': :'String', 'db_servers': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 317 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && exadata_infrastructure_id == other.exadata_infrastructure_id && cpu_core_count == other.cpu_core_count && ocpu_count == other.ocpu_count && memory_size_in_gbs == other.memory_size_in_gbs && db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs && data_storage_size_in_tbs == other.data_storage_size_in_tbs && data_storage_size_in_gbs == other.data_storage_size_in_gbs && ssh_public_keys == other.ssh_public_keys && vm_cluster_network_id == other.vm_cluster_network_id && license_model == other.license_model && is_sparse_diskgroup_enabled == other.is_sparse_diskgroup_enabled && is_local_backup_enabled == other.is_local_backup_enabled && time_zone == other.time_zone && gi_version == other.gi_version && db_servers == other.db_servers && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 365 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
345 346 347 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 345 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
354 355 356 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 354 def hash [compartment_id, display_name, exadata_infrastructure_id, cpu_core_count, ocpu_count, memory_size_in_gbs, db_node_storage_size_in_gbs, data_storage_size_in_tbs, data_storage_size_in_gbs, ssh_public_keys, vm_cluster_network_id, license_model, is_sparse_diskgroup_enabled, is_local_backup_enabled, time_zone, gi_version, db_servers, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
398 399 400 401 402 403 404 405 406 407 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 398 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
392 393 394 |
# File 'lib/oci/database/models/create_vm_cluster_details.rb', line 392 def to_s to_hash.to_s end |