Class: OCI::Database::Models::Database
- Inherits:
-
Object
- Object
- OCI::Database::Models::Database
- Defined in:
- lib/oci/database/models/database.rb
Overview
Database model.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze, LIFECYCLE_STATE_UPGRADING = 'UPGRADING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_RESTORE_FAILED = 'RESTORE_FAILED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#character_set ⇒ String
The character set for the database.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#connection_strings ⇒ OCI::Database::Models::DatabaseConnectionStrings
The Connection strings used to connect to the Oracle Database.
-
#database_software_image_id ⇒ String
The database software image [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
- #db_backup_config ⇒ OCI::Database::Models::DbBackupConfig
-
#db_home_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Database Home.
-
#db_name ⇒ String
[Required] The database name.
-
#db_system_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system.
-
#db_unique_name ⇒ String
[Required] A system-generated name for the database to ensure uniqueness within an Oracle Data Guard group (a primary database and its standby databases).
-
#db_workload ⇒ String
The database workload type.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database.
-
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
-
#last_backup_timestamp ⇒ DateTime
The date and time when the latest database backup was created.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the database.
-
#ncharacter_set ⇒ String
The national character set for the database.
-
#pdb_name ⇒ String
The name of the pluggable database.
-
#source_database_point_in_time_recovery_timestamp ⇒ DateTime
Point in time recovery timeStamp of the source database at which cloned database system is cloned from the source database system, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
-
#time_created ⇒ DateTime
The date and time the database was created.
-
#vm_cluster_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Database
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Database
Initializes the object
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/oci/database/models/database.rb', line 206 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.character_set = attributes[:'characterSet'] if attributes[:'characterSet'] raise 'You cannot provide both :characterSet and :character_set' if attributes.key?(:'characterSet') && attributes.key?(:'character_set') self.character_set = attributes[:'character_set'] if attributes[:'character_set'] self.ncharacter_set = attributes[:'ncharacterSet'] if attributes[:'ncharacterSet'] raise 'You cannot provide both :ncharacterSet and :ncharacter_set' if attributes.key?(:'ncharacterSet') && attributes.key?(:'ncharacter_set') self.ncharacter_set = attributes[:'ncharacter_set'] if attributes[:'ncharacter_set'] self.db_home_id = attributes[:'dbHomeId'] if attributes[:'dbHomeId'] raise 'You cannot provide both :dbHomeId and :db_home_id' if attributes.key?(:'dbHomeId') && attributes.key?(:'db_home_id') self.db_home_id = attributes[:'db_home_id'] if attributes[:'db_home_id'] self.db_system_id = attributes[:'dbSystemId'] if attributes[:'dbSystemId'] raise 'You cannot provide both :dbSystemId and :db_system_id' if attributes.key?(:'dbSystemId') && attributes.key?(:'db_system_id') self.db_system_id = attributes[:'db_system_id'] if attributes[:'db_system_id'] self.vm_cluster_id = attributes[:'vmClusterId'] if attributes[:'vmClusterId'] raise 'You cannot provide both :vmClusterId and :vm_cluster_id' if attributes.key?(:'vmClusterId') && attributes.key?(:'vm_cluster_id') self.vm_cluster_id = attributes[:'vm_cluster_id'] if attributes[:'vm_cluster_id'] self.db_name = attributes[:'dbName'] if attributes[:'dbName'] raise 'You cannot provide both :dbName and :db_name' if attributes.key?(:'dbName') && attributes.key?(:'db_name') self.db_name = attributes[:'db_name'] if attributes[:'db_name'] self.pdb_name = attributes[:'pdbName'] if attributes[:'pdbName'] raise 'You cannot provide both :pdbName and :pdb_name' if attributes.key?(:'pdbName') && attributes.key?(:'pdb_name') self.pdb_name = attributes[:'pdb_name'] if attributes[:'pdb_name'] self.db_workload = attributes[:'dbWorkload'] if attributes[:'dbWorkload'] raise 'You cannot provide both :dbWorkload and :db_workload' if attributes.key?(:'dbWorkload') && attributes.key?(:'db_workload') self.db_workload = attributes[:'db_workload'] if attributes[:'db_workload'] self.db_unique_name = attributes[:'dbUniqueName'] if attributes[:'dbUniqueName'] raise 'You cannot provide both :dbUniqueName and :db_unique_name' if attributes.key?(:'dbUniqueName') && attributes.key?(:'db_unique_name') self.db_unique_name = attributes[:'db_unique_name'] if attributes[:'db_unique_name'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self. = attributes[:'lastBackupTimestamp'] if attributes[:'lastBackupTimestamp'] raise 'You cannot provide both :lastBackupTimestamp and :last_backup_timestamp' if attributes.key?(:'lastBackupTimestamp') && attributes.key?(:'last_backup_timestamp') self. = attributes[:'last_backup_timestamp'] if attributes[:'last_backup_timestamp'] self.db_backup_config = attributes[:'dbBackupConfig'] if attributes[:'dbBackupConfig'] raise 'You cannot provide both :dbBackupConfig and :db_backup_config' if attributes.key?(:'dbBackupConfig') && attributes.key?(:'db_backup_config') self.db_backup_config = attributes[:'db_backup_config'] if attributes[:'db_backup_config'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.connection_strings = attributes[:'connectionStrings'] if attributes[:'connectionStrings'] raise 'You cannot provide both :connectionStrings and :connection_strings' if attributes.key?(:'connectionStrings') && attributes.key?(:'connection_strings') self.connection_strings = attributes[:'connection_strings'] if attributes[:'connection_strings'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self. = attributes[:'sourceDatabasePointInTimeRecoveryTimestamp'] if attributes[:'sourceDatabasePointInTimeRecoveryTimestamp'] raise 'You cannot provide both :sourceDatabasePointInTimeRecoveryTimestamp and :source_database_point_in_time_recovery_timestamp' if attributes.key?(:'sourceDatabasePointInTimeRecoveryTimestamp') && attributes.key?(:'source_database_point_in_time_recovery_timestamp') self. = attributes[:'source_database_point_in_time_recovery_timestamp'] if attributes[:'source_database_point_in_time_recovery_timestamp'] self.database_software_image_id = attributes[:'databaseSoftwareImageId'] if attributes[:'databaseSoftwareImageId'] raise 'You cannot provide both :databaseSoftwareImageId and :database_software_image_id' if attributes.key?(:'databaseSoftwareImageId') && attributes.key?(:'database_software_image_id') self.database_software_image_id = attributes[:'database_software_image_id'] if attributes[:'database_software_image_id'] end |
Instance Attribute Details
#character_set ⇒ String
The character set for the database.
34 35 36 |
# File 'lib/oci/database/models/database.rb', line 34 def character_set @character_set end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
30 31 32 |
# File 'lib/oci/database/models/database.rb', line 30 def compartment_id @compartment_id end |
#connection_strings ⇒ OCI::Database::Models::DatabaseConnectionStrings
The Connection strings used to connect to the Oracle Database.
104 105 106 |
# File 'lib/oci/database/models/database.rb', line 104 def connection_strings @connection_strings end |
#database_software_image_id ⇒ String
The database software image [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)
116 117 118 |
# File 'lib/oci/database/models/database.rb', line 116 def database_software_image_id @database_software_image_id end |
#db_backup_config ⇒ OCI::Database::Models::DbBackupConfig
86 87 88 |
# File 'lib/oci/database/models/database.rb', line 86 def db_backup_config @db_backup_config end |
#db_home_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Database Home.
42 43 44 |
# File 'lib/oci/database/models/database.rb', line 42 def db_home_id @db_home_id end |
#db_name ⇒ String
[Required] The database name.
54 55 56 |
# File 'lib/oci/database/models/database.rb', line 54 def db_name @db_name end |
#db_system_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system.
46 47 48 |
# File 'lib/oci/database/models/database.rb', line 46 def db_system_id @db_system_id end |
#db_unique_name ⇒ String
[Required] A system-generated name for the database to ensure uniqueness within an Oracle Data Guard group (a primary database and its standby databases). The unique name cannot be changed.
67 68 69 |
# File 'lib/oci/database/models/database.rb', line 67 def db_unique_name @db_unique_name end |
#db_workload ⇒ String
The database workload type.
62 63 64 |
# File 'lib/oci/database/models/database.rb', line 62 def db_workload @db_workload end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
100 101 102 |
# File 'lib/oci/database/models/database.rb', line 100 def end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
94 95 96 |
# File 'lib/oci/database/models/database.rb', line 94 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database.
26 27 28 |
# File 'lib/oci/database/models/database.rb', line 26 def id @id end |
#kms_key_id ⇒ String
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
108 109 110 |
# File 'lib/oci/database/models/database.rb', line 108 def kms_key_id @kms_key_id end |
#last_backup_timestamp ⇒ DateTime
The date and time when the latest database backup was created.
83 84 85 |
# File 'lib/oci/database/models/database.rb', line 83 def end |
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
71 72 73 |
# File 'lib/oci/database/models/database.rb', line 71 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the database.
75 76 77 |
# File 'lib/oci/database/models/database.rb', line 75 def lifecycle_state @lifecycle_state end |
#ncharacter_set ⇒ String
The national character set for the database.
38 39 40 |
# File 'lib/oci/database/models/database.rb', line 38 def ncharacter_set @ncharacter_set end |
#pdb_name ⇒ String
The name of the pluggable database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. Pluggable database should not be same as database name.
58 59 60 |
# File 'lib/oci/database/models/database.rb', line 58 def pdb_name @pdb_name end |
#source_database_point_in_time_recovery_timestamp ⇒ DateTime
Point in time recovery timeStamp of the source database at which cloned database system is cloned from the source database system, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)
112 113 114 |
# File 'lib/oci/database/models/database.rb', line 112 def end |
#time_created ⇒ DateTime
The date and time the database was created.
79 80 81 |
# File 'lib/oci/database/models/database.rb', line 79 def time_created @time_created end |
#vm_cluster_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster.
50 51 52 |
# File 'lib/oci/database/models/database.rb', line 50 def vm_cluster_id @vm_cluster_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/database/models/database.rb', line 119 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'character_set': :'characterSet', 'ncharacter_set': :'ncharacterSet', 'db_home_id': :'dbHomeId', 'db_system_id': :'dbSystemId', 'vm_cluster_id': :'vmClusterId', 'db_name': :'dbName', 'pdb_name': :'pdbName', 'db_workload': :'dbWorkload', 'db_unique_name': :'dbUniqueName', 'lifecycle_details': :'lifecycleDetails', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'last_backup_timestamp': :'lastBackupTimestamp', 'db_backup_config': :'dbBackupConfig', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'connection_strings': :'connectionStrings', 'kms_key_id': :'kmsKeyId', 'source_database_point_in_time_recovery_timestamp': :'sourceDatabasePointInTimeRecoveryTimestamp', 'database_software_image_id': :'databaseSoftwareImageId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/database/models/database.rb', line 149 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'character_set': :'String', 'ncharacter_set': :'String', 'db_home_id': :'String', 'db_system_id': :'String', 'vm_cluster_id': :'String', 'db_name': :'String', 'pdb_name': :'String', 'db_workload': :'String', 'db_unique_name': :'String', 'lifecycle_details': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'last_backup_timestamp': :'DateTime', 'db_backup_config': :'OCI::Database::Models::DbBackupConfig', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'connection_strings': :'OCI::Database::Models::DatabaseConnectionStrings', 'kms_key_id': :'String', 'source_database_point_in_time_recovery_timestamp': :'DateTime', 'database_software_image_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/oci/database/models/database.rb', line 358 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && character_set == other.character_set && ncharacter_set == other.ncharacter_set && db_home_id == other.db_home_id && db_system_id == other.db_system_id && vm_cluster_id == other.vm_cluster_id && db_name == other.db_name && pdb_name == other.pdb_name && db_workload == other.db_workload && db_unique_name == other.db_unique_name && lifecycle_details == other.lifecycle_details && lifecycle_state == other.lifecycle_state && time_created == other.time_created && == other. && db_backup_config == other.db_backup_config && == other. && == other. && connection_strings == other.connection_strings && kms_key_id == other.kms_key_id && == other. && database_software_image_id == other.database_software_image_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/oci/database/models/database.rb', line 409 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
389 390 391 |
# File 'lib/oci/database/models/database.rb', line 389 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
398 399 400 |
# File 'lib/oci/database/models/database.rb', line 398 def hash [id, compartment_id, character_set, ncharacter_set, db_home_id, db_system_id, vm_cluster_id, db_name, pdb_name, db_workload, db_unique_name, lifecycle_details, lifecycle_state, time_created, , db_backup_config, , , connection_strings, kms_key_id, , database_software_image_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
442 443 444 445 446 447 448 449 450 451 |
# File 'lib/oci/database/models/database.rb', line 442 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
436 437 438 |
# File 'lib/oci/database/models/database.rb', line 436 def to_s to_hash.to_s end |