Class: OCI::Database::Models::DatabaseConnectionCredentailsByName
- Inherits:
-
DatabaseConnectionCredentials
- Object
- DatabaseConnectionCredentials
- OCI::Database::Models::DatabaseConnectionCredentailsByName
- Defined in:
- lib/oci/database/models/database_connection_credentails_by_name.rb
Overview
Existing named credential used to connect to the database.
Constant Summary
Constants inherited from DatabaseConnectionCredentials
OCI::Database::Models::DatabaseConnectionCredentials::CREDENTIAL_TYPE_ENUM
Instance Attribute Summary collapse
-
#credential_name ⇒ String
[Required] The name of the credential information that used to connect to the database.
Attributes inherited from DatabaseConnectionCredentials
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseConnectionCredentailsByName
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DatabaseConnectionCredentials
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseConnectionCredentailsByName
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/database/models/database_connection_credentails_by_name.rb', line 52 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['credentialType'] = 'NAME_REFERENCE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.credential_name = attributes[:'credentialName'] if attributes[:'credentialName'] raise 'You cannot provide both :credentialName and :credential_name' if attributes.key?(:'credentialName') && attributes.key?(:'credential_name') self.credential_name = attributes[:'credential_name'] if attributes[:'credential_name'] end |
Instance Attribute Details
#credential_name ⇒ String
[Required] The name of the credential information that used to connect to the database. The name should be in "x.y" format, where the length of "x" has a maximum of 64 characters, and length of "y" has a maximum of 199 characters. The name strings can contain letters, numbers and the underscore character only. Other characters are not valid, except for the "." character that separates the "x" and "y" portions of the name. IMPORTANT - The name must be unique within the OCI region the credential is being created in. If you specify a name that duplicates the name of another credential within the same OCI region, you may overwrite or corrupt the credential that is already using the name.
For example: inventorydb.abc112233445566778899
23 24 25 |
# File 'lib/oci/database/models/database_connection_credentails_by_name.rb', line 23 def credential_name @credential_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 |
# File 'lib/oci/database/models/database_connection_credentails_by_name.rb', line 26 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'credential_type': :'credentialType', 'credential_name': :'credentialName' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 42 43 |
# File 'lib/oci/database/models/database_connection_credentails_by_name.rb', line 36 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'credential_type': :'String', 'credential_name': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
76 77 78 79 80 81 82 |
# File 'lib/oci/database/models/database_connection_credentails_by_name.rb', line 76 def ==(other) return true if equal?(other) self.class == other.class && credential_type == other.credential_type && credential_name == other.credential_name end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/database/models/database_connection_credentails_by_name.rb', line 107 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
87 88 89 |
# File 'lib/oci/database/models/database_connection_credentails_by_name.rb', line 87 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
96 97 98 |
# File 'lib/oci/database/models/database_connection_credentails_by_name.rb', line 96 def hash [credential_type, credential_name].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
140 141 142 143 144 145 146 147 148 149 |
# File 'lib/oci/database/models/database_connection_credentails_by_name.rb', line 140 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
134 135 136 |
# File 'lib/oci/database/models/database_connection_credentails_by_name.rb', line 134 def to_s to_hash.to_s end |