Class: OCI::Database::Models::DatabaseSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/database_summary.rb

Overview

An Oracle Database on a bare metal or virtual machine DB system. For more information, see [Bare Metal and Virtual Machine DB Systems](docs.cloud.oracle.com/Content/Database/Concepts/overview.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_UPGRADING = 'UPGRADING'.freeze,
  LIFECYCLE_STATE_CONVERTING = 'CONVERTING'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_RESTORE_FAILED = 'RESTORE_FAILED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DatabaseSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/oci/database/models/database_summary.rb', line 233

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.character_set = attributes[:'characterSet'] if attributes[:'characterSet']

  raise 'You cannot provide both :characterSet and :character_set' if attributes.key?(:'characterSet') && attributes.key?(:'character_set')

  self.character_set = attributes[:'character_set'] if attributes[:'character_set']

  self.ncharacter_set = attributes[:'ncharacterSet'] if attributes[:'ncharacterSet']

  raise 'You cannot provide both :ncharacterSet and :ncharacter_set' if attributes.key?(:'ncharacterSet') && attributes.key?(:'ncharacter_set')

  self.ncharacter_set = attributes[:'ncharacter_set'] if attributes[:'ncharacter_set']

  self.db_home_id = attributes[:'dbHomeId'] if attributes[:'dbHomeId']

  raise 'You cannot provide both :dbHomeId and :db_home_id' if attributes.key?(:'dbHomeId') && attributes.key?(:'db_home_id')

  self.db_home_id = attributes[:'db_home_id'] if attributes[:'db_home_id']

  self.db_system_id = attributes[:'dbSystemId'] if attributes[:'dbSystemId']

  raise 'You cannot provide both :dbSystemId and :db_system_id' if attributes.key?(:'dbSystemId') && attributes.key?(:'db_system_id')

  self.db_system_id = attributes[:'db_system_id'] if attributes[:'db_system_id']

  self.vm_cluster_id = attributes[:'vmClusterId'] if attributes[:'vmClusterId']

  raise 'You cannot provide both :vmClusterId and :vm_cluster_id' if attributes.key?(:'vmClusterId') && attributes.key?(:'vm_cluster_id')

  self.vm_cluster_id = attributes[:'vm_cluster_id'] if attributes[:'vm_cluster_id']

  self.db_name = attributes[:'dbName'] if attributes[:'dbName']

  raise 'You cannot provide both :dbName and :db_name' if attributes.key?(:'dbName') && attributes.key?(:'db_name')

  self.db_name = attributes[:'db_name'] if attributes[:'db_name']

  self.pdb_name = attributes[:'pdbName'] if attributes[:'pdbName']

  raise 'You cannot provide both :pdbName and :pdb_name' if attributes.key?(:'pdbName') && attributes.key?(:'pdb_name')

  self.pdb_name = attributes[:'pdb_name'] if attributes[:'pdb_name']

  self.db_workload = attributes[:'dbWorkload'] if attributes[:'dbWorkload']

  raise 'You cannot provide both :dbWorkload and :db_workload' if attributes.key?(:'dbWorkload') && attributes.key?(:'db_workload')

  self.db_workload = attributes[:'db_workload'] if attributes[:'db_workload']

  self.db_unique_name = attributes[:'dbUniqueName'] if attributes[:'dbUniqueName']

  raise 'You cannot provide both :dbUniqueName and :db_unique_name' if attributes.key?(:'dbUniqueName') && attributes.key?(:'db_unique_name')

  self.db_unique_name = attributes[:'db_unique_name'] if attributes[:'db_unique_name']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.last_backup_timestamp = attributes[:'lastBackupTimestamp'] if attributes[:'lastBackupTimestamp']

  raise 'You cannot provide both :lastBackupTimestamp and :last_backup_timestamp' if attributes.key?(:'lastBackupTimestamp') && attributes.key?(:'last_backup_timestamp')

  self.last_backup_timestamp = attributes[:'last_backup_timestamp'] if attributes[:'last_backup_timestamp']

  self.db_backup_config = attributes[:'dbBackupConfig'] if attributes[:'dbBackupConfig']

  raise 'You cannot provide both :dbBackupConfig and :db_backup_config' if attributes.key?(:'dbBackupConfig') && attributes.key?(:'db_backup_config')

  self.db_backup_config = attributes[:'db_backup_config'] if attributes[:'db_backup_config']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.connection_strings = attributes[:'connectionStrings'] if attributes[:'connectionStrings']

  raise 'You cannot provide both :connectionStrings and :connection_strings' if attributes.key?(:'connectionStrings') && attributes.key?(:'connection_strings')

  self.connection_strings = attributes[:'connection_strings'] if attributes[:'connection_strings']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.source_database_point_in_time_recovery_timestamp = attributes[:'sourceDatabasePointInTimeRecoveryTimestamp'] if attributes[:'sourceDatabasePointInTimeRecoveryTimestamp']

  raise 'You cannot provide both :sourceDatabasePointInTimeRecoveryTimestamp and :source_database_point_in_time_recovery_timestamp' if attributes.key?(:'sourceDatabasePointInTimeRecoveryTimestamp') && attributes.key?(:'source_database_point_in_time_recovery_timestamp')

  self.source_database_point_in_time_recovery_timestamp = attributes[:'source_database_point_in_time_recovery_timestamp'] if attributes[:'source_database_point_in_time_recovery_timestamp']

  self.database_software_image_id = attributes[:'databaseSoftwareImageId'] if attributes[:'databaseSoftwareImageId']

  raise 'You cannot provide both :databaseSoftwareImageId and :database_software_image_id' if attributes.key?(:'databaseSoftwareImageId') && attributes.key?(:'database_software_image_id')

  self.database_software_image_id = attributes[:'database_software_image_id'] if attributes[:'database_software_image_id']

  self.is_cdb = attributes[:'isCdb'] unless attributes[:'isCdb'].nil?

  raise 'You cannot provide both :isCdb and :is_cdb' if attributes.key?(:'isCdb') && attributes.key?(:'is_cdb')

  self.is_cdb = attributes[:'is_cdb'] unless attributes[:'is_cdb'].nil?

  self.database_management_config = attributes[:'databaseManagementConfig'] if attributes[:'databaseManagementConfig']

  raise 'You cannot provide both :databaseManagementConfig and :database_management_config' if attributes.key?(:'databaseManagementConfig') && attributes.key?(:'database_management_config')

  self.database_management_config = attributes[:'database_management_config'] if attributes[:'database_management_config']

  self.sid_prefix = attributes[:'sidPrefix'] if attributes[:'sidPrefix']

  raise 'You cannot provide both :sidPrefix and :sid_prefix' if attributes.key?(:'sidPrefix') && attributes.key?(:'sid_prefix')

  self.sid_prefix = attributes[:'sid_prefix'] if attributes[:'sid_prefix']
end

Instance Attribute Details

#character_setString

The character set for the database.

Returns:

  • (String)


40
41
42
# File 'lib/oci/database/models/database_summary.rb', line 40

def character_set
  @character_set
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


36
37
38
# File 'lib/oci/database/models/database_summary.rb', line 36

def compartment_id
  @compartment_id
end

#connection_stringsOCI::Database::Models::DatabaseConnectionStrings

The Connection strings used to connect to the Oracle Database.



110
111
112
# File 'lib/oci/database/models/database_summary.rb', line 110

def connection_strings
  @connection_strings
end

#database_management_configOCI::Database::Models::CloudDatabaseManagementConfig



129
130
131
# File 'lib/oci/database/models/database_summary.rb', line 129

def database_management_config
  @database_management_config
end

#database_software_image_idString

Returns:

  • (String)


122
123
124
# File 'lib/oci/database/models/database_summary.rb', line 122

def database_software_image_id
  @database_software_image_id
end

#db_backup_configOCI::Database::Models::DbBackupConfig



92
93
94
# File 'lib/oci/database/models/database_summary.rb', line 92

def db_backup_config
  @db_backup_config
end

#db_home_idString

Returns:

  • (String)


48
49
50
# File 'lib/oci/database/models/database_summary.rb', line 48

def db_home_id
  @db_home_id
end

#db_nameString

[Required] The database name.

Returns:

  • (String)


60
61
62
# File 'lib/oci/database/models/database_summary.rb', line 60

def db_name
  @db_name
end

#db_system_idString

Returns:

  • (String)


52
53
54
# File 'lib/oci/database/models/database_summary.rb', line 52

def db_system_id
  @db_system_id
end

#db_unique_nameString

[Required] A system-generated name for the database to ensure uniqueness within an Oracle Data Guard group (a primary database and its standby databases). The unique name cannot be changed.

Returns:

  • (String)


73
74
75
# File 'lib/oci/database/models/database_summary.rb', line 73

def db_unique_name
  @db_unique_name
end

#db_workloadString

The database workload type.

Returns:

  • (String)


68
69
70
# File 'lib/oci/database/models/database_summary.rb', line 68

def db_workload
  @db_workload
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


106
107
108
# File 'lib/oci/database/models/database_summary.rb', line 106

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


100
101
102
# File 'lib/oci/database/models/database_summary.rb', line 100

def freeform_tags
  @freeform_tags
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database.

Returns:

  • (String)


32
33
34
# File 'lib/oci/database/models/database_summary.rb', line 32

def id
  @id
end

#is_cdbBOOLEAN

True if the database is a container database.

Returns:

  • (BOOLEAN)


126
127
128
# File 'lib/oci/database/models/database_summary.rb', line 126

def is_cdb
  @is_cdb
end

#kms_key_idString

The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.

Returns:

  • (String)


114
115
116
# File 'lib/oci/database/models/database_summary.rb', line 114

def kms_key_id
  @kms_key_id
end

#last_backup_timestampDateTime

The date and time when the latest database backup was created.

Returns:

  • (DateTime)


89
90
91
# File 'lib/oci/database/models/database_summary.rb', line 89

def last_backup_timestamp
  @last_backup_timestamp
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


77
78
79
# File 'lib/oci/database/models/database_summary.rb', line 77

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the database.

Returns:

  • (String)


81
82
83
# File 'lib/oci/database/models/database_summary.rb', line 81

def lifecycle_state
  @lifecycle_state
end

#ncharacter_setString

The national character set for the database.

Returns:

  • (String)


44
45
46
# File 'lib/oci/database/models/database_summary.rb', line 44

def ncharacter_set
  @ncharacter_set
end

#pdb_nameString

The name of the pluggable database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. Pluggable database should not be same as database name.

Returns:

  • (String)


64
65
66
# File 'lib/oci/database/models/database_summary.rb', line 64

def pdb_name
  @pdb_name
end

#sid_prefixString

Specifies a prefix for the ‘Oracle SID` of the database to be created.

Returns:

  • (String)


134
135
136
# File 'lib/oci/database/models/database_summary.rb', line 134

def sid_prefix
  @sid_prefix
end

#source_database_point_in_time_recovery_timestampDateTime

Point in time recovery timeStamp of the source database at which cloned database system is cloned from the source database system, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)

Returns:

  • (DateTime)


118
119
120
# File 'lib/oci/database/models/database_summary.rb', line 118

def source_database_point_in_time_recovery_timestamp
  @source_database_point_in_time_recovery_timestamp
end

#time_createdDateTime

The date and time the database was created.

Returns:

  • (DateTime)


85
86
87
# File 'lib/oci/database/models/database_summary.rb', line 85

def time_created
  @time_created
end

#vm_cluster_idString

Returns:

  • (String)


56
57
58
# File 'lib/oci/database/models/database_summary.rb', line 56

def vm_cluster_id
  @vm_cluster_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/database/models/database_summary.rb', line 137

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'character_set': :'characterSet',
    'ncharacter_set': :'ncharacterSet',
    'db_home_id': :'dbHomeId',
    'db_system_id': :'dbSystemId',
    'vm_cluster_id': :'vmClusterId',
    'db_name': :'dbName',
    'pdb_name': :'pdbName',
    'db_workload': :'dbWorkload',
    'db_unique_name': :'dbUniqueName',
    'lifecycle_details': :'lifecycleDetails',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'last_backup_timestamp': :'lastBackupTimestamp',
    'db_backup_config': :'dbBackupConfig',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'connection_strings': :'connectionStrings',
    'kms_key_id': :'kmsKeyId',
    'source_database_point_in_time_recovery_timestamp': :'sourceDatabasePointInTimeRecoveryTimestamp',
    'database_software_image_id': :'databaseSoftwareImageId',
    'is_cdb': :'isCdb',
    'database_management_config': :'databaseManagementConfig',
    'sid_prefix': :'sidPrefix'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/oci/database/models/database_summary.rb', line 170

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'character_set': :'String',
    'ncharacter_set': :'String',
    'db_home_id': :'String',
    'db_system_id': :'String',
    'vm_cluster_id': :'String',
    'db_name': :'String',
    'pdb_name': :'String',
    'db_workload': :'String',
    'db_unique_name': :'String',
    'lifecycle_details': :'String',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'last_backup_timestamp': :'DateTime',
    'db_backup_config': :'OCI::Database::Models::DbBackupConfig',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'connection_strings': :'OCI::Database::Models::DatabaseConnectionStrings',
    'kms_key_id': :'String',
    'source_database_point_in_time_recovery_timestamp': :'DateTime',
    'database_software_image_id': :'String',
    'is_cdb': :'BOOLEAN',
    'database_management_config': :'OCI::Database::Models::CloudDatabaseManagementConfig',
    'sid_prefix': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/oci/database/models/database_summary.rb', line 406

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    character_set == other.character_set &&
    ncharacter_set == other.ncharacter_set &&
    db_home_id == other.db_home_id &&
    db_system_id == other.db_system_id &&
    vm_cluster_id == other.vm_cluster_id &&
    db_name == other.db_name &&
    pdb_name == other.pdb_name &&
    db_workload == other.db_workload &&
    db_unique_name == other.db_unique_name &&
    lifecycle_details == other.lifecycle_details &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    last_backup_timestamp == other.last_backup_timestamp &&
    db_backup_config == other.db_backup_config &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    connection_strings == other.connection_strings &&
    kms_key_id == other.kms_key_id &&
    source_database_point_in_time_recovery_timestamp == other.source_database_point_in_time_recovery_timestamp &&
    database_software_image_id == other.database_software_image_id &&
    is_cdb == other.is_cdb &&
    database_management_config == other.database_management_config &&
    sid_prefix == other.sid_prefix
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/oci/database/models/database_summary.rb', line 460

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


440
441
442
# File 'lib/oci/database/models/database_summary.rb', line 440

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



449
450
451
# File 'lib/oci/database/models/database_summary.rb', line 449

def hash
  [id, compartment_id, character_set, ncharacter_set, db_home_id, db_system_id, vm_cluster_id, db_name, pdb_name, db_workload, db_unique_name, lifecycle_details, lifecycle_state, time_created, last_backup_timestamp, db_backup_config, freeform_tags, defined_tags, connection_strings, kms_key_id, source_database_point_in_time_recovery_timestamp, database_software_image_id, is_cdb, database_management_config, sid_prefix].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



493
494
495
496
497
498
499
500
501
502
# File 'lib/oci/database/models/database_summary.rb', line 493

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



487
488
489
# File 'lib/oci/database/models/database_summary.rb', line 487

def to_s
  to_hash.to_s
end