Class: OCI::Database::Models::DatabaseUpgradeSourceBase
- Inherits:
-
Object
- Object
- OCI::Database::Models::DatabaseUpgradeSourceBase
- Defined in:
- lib/oci/database/models/database_upgrade_source_base.rb
Overview
Details for the database upgrade source.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
DatabaseUpgradeWithDatabaseSoftwareImageDetails, DatabaseUpgradeWithDbHomeDetails, DatabaseUpgradeWithDbVersionDetails
Constant Summary collapse
- SOURCE_ENUM =
[ SOURCE_DB_HOME = 'DB_HOME'.freeze, SOURCE_DB_VERSION = 'DB_VERSION'.freeze, SOURCE_DB_SOFTWARE_IMAGE = 'DB_SOFTWARE_IMAGE'.freeze ].freeze
Instance Attribute Summary collapse
-
#options ⇒ String
Additional upgrade options supported by DBUA(Database Upgrade Assistant).
-
#source ⇒ String
The source of the Oracle Database software to be used for the upgrade.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseUpgradeSourceBase
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseUpgradeSourceBase
Initializes the object
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 77 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.source = attributes[:'source'] if attributes[:'source'] self. = attributes[:'options'] if attributes[:'options'] end |
Instance Attribute Details
#options ⇒ String
Additional upgrade options supported by DBUA(Database Upgrade Assistant). Example: "-upgradeTimezone false -keepEvents"
30 31 32 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 30 def end |
#source ⇒ String
The source of the Oracle Database software to be used for the upgrade.
- Use `DB_HOME` to specify an existing Database Home to upgrade the database. The database is moved to the target Database Home and makes use of the Oracle Database software version of the target Database Home.
- Use `DB_VERSION` to specify a generally-available Oracle Database software version to upgrade the database.
- Use `DB_SOFTWARE_IMAGE` to specify a [database software image](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/databasesoftwareimage.htm) to upgrade the database.
24 25 26 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 24 def source @source end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'source': :'source', 'options': :'options' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 57 def self.get_subtype(object_hash) type = object_hash[:'source'] # rubocop:disable Style/SymbolLiteral return 'OCI::Database::Models::DatabaseUpgradeWithDbHomeDetails' if type == 'DB_HOME' return 'OCI::Database::Models::DatabaseUpgradeWithDatabaseSoftwareImageDetails' if type == 'DB_SOFTWARE_IMAGE' return 'OCI::Database::Models::DatabaseUpgradeWithDbVersionDetails' if type == 'DB_VERSION' # TODO: Log a warning when the subtype is not found. 'OCI::Database::Models::DatabaseUpgradeSourceBase' end |
.swagger_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 43 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'source': :'String', 'options': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 109 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 103 def ==(other) return true if equal?(other) self.class == other.class && source == other.source && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 134 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
114 115 116 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 114 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
123 124 125 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 123 def hash [source, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 167 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
161 162 163 |
# File 'lib/oci/database/models/database_upgrade_source_base.rb', line 161 def to_s to_hash.to_s end |