Class: OCI::Database::Models::DbNode
- Inherits:
-
Object
- Object
- OCI::Database::Models::DbNode
- Defined in:
- lib/oci/database/models/db_node.rb
Overview
DbNode model.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_STOPPING = 'STOPPING'.freeze, LIFECYCLE_STATE_STOPPED = 'STOPPED'.freeze, LIFECYCLE_STATE_STARTING = 'STARTING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- MAINTENANCE_TYPE_ENUM =
[ MAINTENANCE_TYPE_VMDB_REBOOT_MIGRATION = 'VMDB_REBOOT_MIGRATION'.freeze, MAINTENANCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#additional_details ⇒ String
Additional information about the planned maintenance.
-
#backup_ip_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup IP address associated with the database node.
-
#backup_vnic2_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the second backup VNIC.
-
#backup_vnic_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup VNIC.
-
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the Db node.
-
#db_node_storage_size_in_gbs ⇒ Integer
The allocated local node storage in GBs on the Db node.
-
#db_server_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exacc Db server associated with the database node.
-
#db_system_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system.
-
#fault_domain ⇒ String
The name of the Fault Domain the instance is contained in.
-
#host_ip_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the host IP address associated with the database node.
-
#hostname ⇒ String
The host name for the database node.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database node.
-
#lifecycle_state ⇒ String
[Required] The current state of the database node.
-
#maintenance_type ⇒ String
The type of database node maintenance.
-
#memory_size_in_gbs ⇒ Integer
The allocated memory in GBs on the Db node.
-
#software_storage_size_in_gb ⇒ Integer
The size (in GB) of the block storage volume allocation for the DB system.
-
#time_created ⇒ DateTime
[Required] The date and time that the database node was created.
-
#time_maintenance_window_end ⇒ DateTime
End date and time of maintenance window.
-
#time_maintenance_window_start ⇒ DateTime
Start date and time of maintenance window.
-
#vnic2_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the second VNIC.
-
#vnic_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VNIC.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbNode
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbNode
Initializes the object
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/oci/database/models/db_node.rb', line 211 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.db_system_id = attributes[:'dbSystemId'] if attributes[:'dbSystemId'] raise 'You cannot provide both :dbSystemId and :db_system_id' if attributes.key?(:'dbSystemId') && attributes.key?(:'db_system_id') self.db_system_id = attributes[:'db_system_id'] if attributes[:'db_system_id'] self.vnic_id = attributes[:'vnicId'] if attributes[:'vnicId'] raise 'You cannot provide both :vnicId and :vnic_id' if attributes.key?(:'vnicId') && attributes.key?(:'vnic_id') self.vnic_id = attributes[:'vnic_id'] if attributes[:'vnic_id'] self.backup_vnic_id = attributes[:'backupVnicId'] if attributes[:'backupVnicId'] raise 'You cannot provide both :backupVnicId and :backup_vnic_id' if attributes.key?(:'backupVnicId') && attributes.key?(:'backup_vnic_id') self.backup_vnic_id = attributes[:'backup_vnic_id'] if attributes[:'backup_vnic_id'] self.host_ip_id = attributes[:'hostIpId'] if attributes[:'hostIpId'] raise 'You cannot provide both :hostIpId and :host_ip_id' if attributes.key?(:'hostIpId') && attributes.key?(:'host_ip_id') self.host_ip_id = attributes[:'host_ip_id'] if attributes[:'host_ip_id'] self.backup_ip_id = attributes[:'backupIpId'] if attributes[:'backupIpId'] raise 'You cannot provide both :backupIpId and :backup_ip_id' if attributes.key?(:'backupIpId') && attributes.key?(:'backup_ip_id') self.backup_ip_id = attributes[:'backup_ip_id'] if attributes[:'backup_ip_id'] self.vnic2_id = attributes[:'vnic2Id'] if attributes[:'vnic2Id'] raise 'You cannot provide both :vnic2Id and :vnic2_id' if attributes.key?(:'vnic2Id') && attributes.key?(:'vnic2_id') self.vnic2_id = attributes[:'vnic2_id'] if attributes[:'vnic2_id'] self.backup_vnic2_id = attributes[:'backupVnic2Id'] if attributes[:'backupVnic2Id'] raise 'You cannot provide both :backupVnic2Id and :backup_vnic2_id' if attributes.key?(:'backupVnic2Id') && attributes.key?(:'backup_vnic2_id') self.backup_vnic2_id = attributes[:'backup_vnic2_id'] if attributes[:'backup_vnic2_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.hostname = attributes[:'hostname'] if attributes[:'hostname'] self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain'] raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain') self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.software_storage_size_in_gb = attributes[:'softwareStorageSizeInGB'] if attributes[:'softwareStorageSizeInGB'] raise 'You cannot provide both :softwareStorageSizeInGB and :software_storage_size_in_gb' if attributes.key?(:'softwareStorageSizeInGB') && attributes.key?(:'software_storage_size_in_gb') self.software_storage_size_in_gb = attributes[:'software_storage_size_in_gb'] if attributes[:'software_storage_size_in_gb'] self.maintenance_type = attributes[:'maintenanceType'] if attributes[:'maintenanceType'] raise 'You cannot provide both :maintenanceType and :maintenance_type' if attributes.key?(:'maintenanceType') && attributes.key?(:'maintenance_type') self.maintenance_type = attributes[:'maintenance_type'] if attributes[:'maintenance_type'] self.time_maintenance_window_start = attributes[:'timeMaintenanceWindowStart'] if attributes[:'timeMaintenanceWindowStart'] raise 'You cannot provide both :timeMaintenanceWindowStart and :time_maintenance_window_start' if attributes.key?(:'timeMaintenanceWindowStart') && attributes.key?(:'time_maintenance_window_start') self.time_maintenance_window_start = attributes[:'time_maintenance_window_start'] if attributes[:'time_maintenance_window_start'] self.time_maintenance_window_end = attributes[:'timeMaintenanceWindowEnd'] if attributes[:'timeMaintenanceWindowEnd'] raise 'You cannot provide both :timeMaintenanceWindowEnd and :time_maintenance_window_end' if attributes.key?(:'timeMaintenanceWindowEnd') && attributes.key?(:'time_maintenance_window_end') self.time_maintenance_window_end = attributes[:'time_maintenance_window_end'] if attributes[:'time_maintenance_window_end'] self.additional_details = attributes[:'additionalDetails'] if attributes[:'additionalDetails'] raise 'You cannot provide both :additionalDetails and :additional_details' if attributes.key?(:'additionalDetails') && attributes.key?(:'additional_details') self.additional_details = attributes[:'additional_details'] if attributes[:'additional_details'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs'] raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs') self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs'] self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs'] raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs') self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs'] self.db_server_id = attributes[:'dbServerId'] if attributes[:'dbServerId'] raise 'You cannot provide both :dbServerId and :db_server_id' if attributes.key?(:'dbServerId') && attributes.key?(:'db_server_id') self.db_server_id = attributes[:'db_server_id'] if attributes[:'db_server_id'] end |
Instance Attribute Details
#additional_details ⇒ String
Additional information about the planned maintenance.
108 109 110 |
# File 'lib/oci/database/models/db_node.rb', line 108 def additional_details @additional_details end |
#backup_ip_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup IP address associated with the database node.
Note: Applies only to Exadata Cloud Service.
57 58 59 |
# File 'lib/oci/database/models/db_node.rb', line 57 def backup_ip_id @backup_ip_id end |
#backup_vnic2_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the second backup VNIC.
Note: Applies only to Exadata Cloud Service.
71 72 73 |
# File 'lib/oci/database/models/db_node.rb', line 71 def backup_vnic2_id @backup_vnic2_id end |
#backup_vnic_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup VNIC.
43 44 45 |
# File 'lib/oci/database/models/db_node.rb', line 43 def backup_vnic_id @backup_vnic_id end |
#cpu_core_count ⇒ Integer
The number of CPU cores enabled on the Db node.
112 113 114 |
# File 'lib/oci/database/models/db_node.rb', line 112 def cpu_core_count @cpu_core_count end |
#db_node_storage_size_in_gbs ⇒ Integer
The allocated local node storage in GBs on the Db node.
120 121 122 |
# File 'lib/oci/database/models/db_node.rb', line 120 def db_node_storage_size_in_gbs @db_node_storage_size_in_gbs end |
#db_server_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exacc Db server associated with the database node.
124 125 126 |
# File 'lib/oci/database/models/db_node.rb', line 124 def db_server_id @db_server_id end |
#db_system_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system.
35 36 37 |
# File 'lib/oci/database/models/db_node.rb', line 35 def db_system_id @db_system_id end |
#fault_domain ⇒ String
The name of the Fault Domain the instance is contained in.
83 84 85 |
# File 'lib/oci/database/models/db_node.rb', line 83 def fault_domain @fault_domain end |
#host_ip_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the host IP address associated with the database node.
Note: Applies only to Exadata Cloud Service.
50 51 52 |
# File 'lib/oci/database/models/db_node.rb', line 50 def host_ip_id @host_ip_id end |
#hostname ⇒ String
The host name for the database node.
79 80 81 |
# File 'lib/oci/database/models/db_node.rb', line 79 def hostname @hostname end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database node.
31 32 33 |
# File 'lib/oci/database/models/db_node.rb', line 31 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of the database node.
75 76 77 |
# File 'lib/oci/database/models/db_node.rb', line 75 def lifecycle_state @lifecycle_state end |
#maintenance_type ⇒ String
The type of database node maintenance.
96 97 98 |
# File 'lib/oci/database/models/db_node.rb', line 96 def maintenance_type @maintenance_type end |
#memory_size_in_gbs ⇒ Integer
The allocated memory in GBs on the Db node.
116 117 118 |
# File 'lib/oci/database/models/db_node.rb', line 116 def memory_size_in_gbs @memory_size_in_gbs end |
#software_storage_size_in_gb ⇒ Integer
The size (in GB) of the block storage volume allocation for the DB system. This attribute applies only for virtual machine DB systems.
92 93 94 |
# File 'lib/oci/database/models/db_node.rb', line 92 def software_storage_size_in_gb @software_storage_size_in_gb end |
#time_created ⇒ DateTime
[Required] The date and time that the database node was created.
87 88 89 |
# File 'lib/oci/database/models/db_node.rb', line 87 def time_created @time_created end |
#time_maintenance_window_end ⇒ DateTime
End date and time of maintenance window.
104 105 106 |
# File 'lib/oci/database/models/db_node.rb', line 104 def time_maintenance_window_end @time_maintenance_window_end end |
#time_maintenance_window_start ⇒ DateTime
Start date and time of maintenance window.
100 101 102 |
# File 'lib/oci/database/models/db_node.rb', line 100 def time_maintenance_window_start @time_maintenance_window_start end |
#vnic2_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the second VNIC.
Note: Applies only to Exadata Cloud Service.
64 65 66 |
# File 'lib/oci/database/models/db_node.rb', line 64 def vnic2_id @vnic2_id end |
#vnic_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VNIC.
39 40 41 |
# File 'lib/oci/database/models/db_node.rb', line 39 def vnic_id @vnic_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/database/models/db_node.rb', line 127 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'db_system_id': :'dbSystemId', 'vnic_id': :'vnicId', 'backup_vnic_id': :'backupVnicId', 'host_ip_id': :'hostIpId', 'backup_ip_id': :'backupIpId', 'vnic2_id': :'vnic2Id', 'backup_vnic2_id': :'backupVnic2Id', 'lifecycle_state': :'lifecycleState', 'hostname': :'hostname', 'fault_domain': :'faultDomain', 'time_created': :'timeCreated', 'software_storage_size_in_gb': :'softwareStorageSizeInGB', 'maintenance_type': :'maintenanceType', 'time_maintenance_window_start': :'timeMaintenanceWindowStart', 'time_maintenance_window_end': :'timeMaintenanceWindowEnd', 'additional_details': :'additionalDetails', 'cpu_core_count': :'cpuCoreCount', 'memory_size_in_gbs': :'memorySizeInGBs', 'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs', 'db_server_id': :'dbServerId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/database/models/db_node.rb', line 156 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'db_system_id': :'String', 'vnic_id': :'String', 'backup_vnic_id': :'String', 'host_ip_id': :'String', 'backup_ip_id': :'String', 'vnic2_id': :'String', 'backup_vnic2_id': :'String', 'lifecycle_state': :'String', 'hostname': :'String', 'fault_domain': :'String', 'time_created': :'DateTime', 'software_storage_size_in_gb': :'Integer', 'maintenance_type': :'String', 'time_maintenance_window_start': :'DateTime', 'time_maintenance_window_end': :'DateTime', 'additional_details': :'String', 'cpu_core_count': :'Integer', 'memory_size_in_gbs': :'Integer', 'db_node_storage_size_in_gbs': :'Integer', 'db_server_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/oci/database/models/db_node.rb', line 366 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && db_system_id == other.db_system_id && vnic_id == other.vnic_id && backup_vnic_id == other.backup_vnic_id && host_ip_id == other.host_ip_id && backup_ip_id == other.backup_ip_id && vnic2_id == other.vnic2_id && backup_vnic2_id == other.backup_vnic2_id && lifecycle_state == other.lifecycle_state && hostname == other.hostname && fault_domain == other.fault_domain && time_created == other.time_created && software_storage_size_in_gb == other.software_storage_size_in_gb && maintenance_type == other.maintenance_type && time_maintenance_window_start == other.time_maintenance_window_start && time_maintenance_window_end == other.time_maintenance_window_end && additional_details == other.additional_details && cpu_core_count == other.cpu_core_count && memory_size_in_gbs == other.memory_size_in_gbs && db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs && db_server_id == other.db_server_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/oci/database/models/db_node.rb', line 416 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
396 397 398 |
# File 'lib/oci/database/models/db_node.rb', line 396 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
405 406 407 |
# File 'lib/oci/database/models/db_node.rb', line 405 def hash [id, db_system_id, vnic_id, backup_vnic_id, host_ip_id, backup_ip_id, vnic2_id, backup_vnic2_id, lifecycle_state, hostname, fault_domain, time_created, software_storage_size_in_gb, maintenance_type, time_maintenance_window_start, time_maintenance_window_end, additional_details, cpu_core_count, memory_size_in_gbs, db_node_storage_size_in_gbs, db_server_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
449 450 451 452 453 454 455 456 457 458 |
# File 'lib/oci/database/models/db_node.rb', line 449 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
443 444 445 |
# File 'lib/oci/database/models/db_node.rb', line 443 def to_s to_hash.to_s end |