Class: OCI::Database::Models::DbNodeSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/db_node_summary.rb

Overview

A server where Oracle Database software is running.

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_STOPPING = 'STOPPING'.freeze,
  LIFECYCLE_STATE_STOPPED = 'STOPPED'.freeze,
  LIFECYCLE_STATE_STARTING = 'STARTING'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
MAINTENANCE_TYPE_ENUM =
[
  MAINTENANCE_TYPE_VMDB_REBOOT_MIGRATION = 'VMDB_REBOOT_MIGRATION'.freeze,
  MAINTENANCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DbNodeSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :db_system_id (String)

    The value to assign to the #db_system_id property

  • :vnic_id (String)

    The value to assign to the #vnic_id property

  • :backup_vnic_id (String)

    The value to assign to the #backup_vnic_id property

  • :host_ip_id (String)

    The value to assign to the #host_ip_id property

  • :backup_ip_id (String)

    The value to assign to the #backup_ip_id property

  • :vnic2_id (String)

    The value to assign to the #vnic2_id property

  • :backup_vnic2_id (String)

    The value to assign to the #backup_vnic2_id property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :hostname (String)

    The value to assign to the #hostname property

  • :fault_domain (String)

    The value to assign to the #fault_domain property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :software_storage_size_in_gb (Integer)

    The value to assign to the #software_storage_size_in_gb property

  • :maintenance_type (String)

    The value to assign to the #maintenance_type property

  • :time_maintenance_window_start (DateTime)

    The value to assign to the #time_maintenance_window_start property

  • :time_maintenance_window_end (DateTime)

    The value to assign to the #time_maintenance_window_end property

  • :additional_details (String)

    The value to assign to the #additional_details property



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/oci/database/models/db_node_summary.rb', line 188

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.db_system_id = attributes[:'dbSystemId'] if attributes[:'dbSystemId']

  raise 'You cannot provide both :dbSystemId and :db_system_id' if attributes.key?(:'dbSystemId') && attributes.key?(:'db_system_id')

  self.db_system_id = attributes[:'db_system_id'] if attributes[:'db_system_id']

  self.vnic_id = attributes[:'vnicId'] if attributes[:'vnicId']

  raise 'You cannot provide both :vnicId and :vnic_id' if attributes.key?(:'vnicId') && attributes.key?(:'vnic_id')

  self.vnic_id = attributes[:'vnic_id'] if attributes[:'vnic_id']

  self.backup_vnic_id = attributes[:'backupVnicId'] if attributes[:'backupVnicId']

  raise 'You cannot provide both :backupVnicId and :backup_vnic_id' if attributes.key?(:'backupVnicId') && attributes.key?(:'backup_vnic_id')

  self.backup_vnic_id = attributes[:'backup_vnic_id'] if attributes[:'backup_vnic_id']

  self.host_ip_id = attributes[:'hostIpId'] if attributes[:'hostIpId']

  raise 'You cannot provide both :hostIpId and :host_ip_id' if attributes.key?(:'hostIpId') && attributes.key?(:'host_ip_id')

  self.host_ip_id = attributes[:'host_ip_id'] if attributes[:'host_ip_id']

  self.backup_ip_id = attributes[:'backupIpId'] if attributes[:'backupIpId']

  raise 'You cannot provide both :backupIpId and :backup_ip_id' if attributes.key?(:'backupIpId') && attributes.key?(:'backup_ip_id')

  self.backup_ip_id = attributes[:'backup_ip_id'] if attributes[:'backup_ip_id']

  self.vnic2_id = attributes[:'vnic2Id'] if attributes[:'vnic2Id']

  raise 'You cannot provide both :vnic2Id and :vnic2_id' if attributes.key?(:'vnic2Id') && attributes.key?(:'vnic2_id')

  self.vnic2_id = attributes[:'vnic2_id'] if attributes[:'vnic2_id']

  self.backup_vnic2_id = attributes[:'backupVnic2Id'] if attributes[:'backupVnic2Id']

  raise 'You cannot provide both :backupVnic2Id and :backup_vnic2_id' if attributes.key?(:'backupVnic2Id') && attributes.key?(:'backup_vnic2_id')

  self.backup_vnic2_id = attributes[:'backup_vnic2_id'] if attributes[:'backup_vnic2_id']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.hostname = attributes[:'hostname'] if attributes[:'hostname']

  self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain']

  raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain')

  self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.software_storage_size_in_gb = attributes[:'softwareStorageSizeInGB'] if attributes[:'softwareStorageSizeInGB']

  raise 'You cannot provide both :softwareStorageSizeInGB and :software_storage_size_in_gb' if attributes.key?(:'softwareStorageSizeInGB') && attributes.key?(:'software_storage_size_in_gb')

  self.software_storage_size_in_gb = attributes[:'software_storage_size_in_gb'] if attributes[:'software_storage_size_in_gb']

  self.maintenance_type = attributes[:'maintenanceType'] if attributes[:'maintenanceType']

  raise 'You cannot provide both :maintenanceType and :maintenance_type' if attributes.key?(:'maintenanceType') && attributes.key?(:'maintenance_type')

  self.maintenance_type = attributes[:'maintenance_type'] if attributes[:'maintenance_type']

  self.time_maintenance_window_start = attributes[:'timeMaintenanceWindowStart'] if attributes[:'timeMaintenanceWindowStart']

  raise 'You cannot provide both :timeMaintenanceWindowStart and :time_maintenance_window_start' if attributes.key?(:'timeMaintenanceWindowStart') && attributes.key?(:'time_maintenance_window_start')

  self.time_maintenance_window_start = attributes[:'time_maintenance_window_start'] if attributes[:'time_maintenance_window_start']

  self.time_maintenance_window_end = attributes[:'timeMaintenanceWindowEnd'] if attributes[:'timeMaintenanceWindowEnd']

  raise 'You cannot provide both :timeMaintenanceWindowEnd and :time_maintenance_window_end' if attributes.key?(:'timeMaintenanceWindowEnd') && attributes.key?(:'time_maintenance_window_end')

  self.time_maintenance_window_end = attributes[:'time_maintenance_window_end'] if attributes[:'time_maintenance_window_end']

  self.additional_details = attributes[:'additionalDetails'] if attributes[:'additionalDetails']

  raise 'You cannot provide both :additionalDetails and :additional_details' if attributes.key?(:'additionalDetails') && attributes.key?(:'additional_details')

  self.additional_details = attributes[:'additional_details'] if attributes[:'additional_details']
end

Instance Attribute Details

#additional_detailsString

Additional information about the planned maintenance.

Returns:

  • (String)


113
114
115
# File 'lib/oci/database/models/db_node_summary.rb', line 113

def additional_details
  @additional_details
end

#backup_ip_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup IP address associated with the database node.

Note: Applies only to Exadata Cloud Service.

Returns:

  • (String)


62
63
64
# File 'lib/oci/database/models/db_node_summary.rb', line 62

def backup_ip_id
  @backup_ip_id
end

#backup_vnic2_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the second backup VNIC.

Note: Applies only to Exadata Cloud Service.

Returns:

  • (String)


76
77
78
# File 'lib/oci/database/models/db_node_summary.rb', line 76

def backup_vnic2_id
  @backup_vnic2_id
end

#backup_vnic_idString

Returns:

  • (String)


48
49
50
# File 'lib/oci/database/models/db_node_summary.rb', line 48

def backup_vnic_id
  @backup_vnic_id
end

#db_system_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system.

Returns:

  • (String)


40
41
42
# File 'lib/oci/database/models/db_node_summary.rb', line 40

def db_system_id
  @db_system_id
end

#fault_domainString

The name of the Fault Domain the instance is contained in.

Returns:

  • (String)


88
89
90
# File 'lib/oci/database/models/db_node_summary.rb', line 88

def fault_domain
  @fault_domain
end

#host_ip_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the host IP address associated with the database node.

Note: Applies only to Exadata Cloud Service.

Returns:

  • (String)


55
56
57
# File 'lib/oci/database/models/db_node_summary.rb', line 55

def host_ip_id
  @host_ip_id
end

#hostnameString

The host name for the database node.

Returns:

  • (String)


84
85
86
# File 'lib/oci/database/models/db_node_summary.rb', line 84

def hostname
  @hostname
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database node.

Returns:

  • (String)


36
37
38
# File 'lib/oci/database/models/db_node_summary.rb', line 36

def id
  @id
end

#lifecycle_stateString

[Required] The current state of the database node.

Returns:

  • (String)


80
81
82
# File 'lib/oci/database/models/db_node_summary.rb', line 80

def lifecycle_state
  @lifecycle_state
end

#maintenance_typeString

The type of database node maintenance.

Returns:

  • (String)


101
102
103
# File 'lib/oci/database/models/db_node_summary.rb', line 101

def maintenance_type
  @maintenance_type
end

#software_storage_size_in_gbInteger

The size (in GB) of the block storage volume allocation for the DB system. This attribute applies only for virtual machine DB systems.

Returns:

  • (Integer)


97
98
99
# File 'lib/oci/database/models/db_node_summary.rb', line 97

def software_storage_size_in_gb
  @software_storage_size_in_gb
end

#time_createdDateTime

[Required] The date and time that the database node was created.

Returns:

  • (DateTime)


92
93
94
# File 'lib/oci/database/models/db_node_summary.rb', line 92

def time_created
  @time_created
end

#time_maintenance_window_endDateTime

End date and time of maintenance window.

Returns:

  • (DateTime)


109
110
111
# File 'lib/oci/database/models/db_node_summary.rb', line 109

def time_maintenance_window_end
  @time_maintenance_window_end
end

#time_maintenance_window_startDateTime

Start date and time of maintenance window.

Returns:

  • (DateTime)


105
106
107
# File 'lib/oci/database/models/db_node_summary.rb', line 105

def time_maintenance_window_start
  @time_maintenance_window_start
end

#vnic2_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the second VNIC.

Note: Applies only to Exadata Cloud Service.

Returns:

  • (String)


69
70
71
# File 'lib/oci/database/models/db_node_summary.rb', line 69

def vnic2_id
  @vnic2_id
end

#vnic_idString

Returns:

  • (String)


44
45
46
# File 'lib/oci/database/models/db_node_summary.rb', line 44

def vnic_id
  @vnic_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/oci/database/models/db_node_summary.rb', line 116

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'db_system_id': :'dbSystemId',
    'vnic_id': :'vnicId',
    'backup_vnic_id': :'backupVnicId',
    'host_ip_id': :'hostIpId',
    'backup_ip_id': :'backupIpId',
    'vnic2_id': :'vnic2Id',
    'backup_vnic2_id': :'backupVnic2Id',
    'lifecycle_state': :'lifecycleState',
    'hostname': :'hostname',
    'fault_domain': :'faultDomain',
    'time_created': :'timeCreated',
    'software_storage_size_in_gb': :'softwareStorageSizeInGB',
    'maintenance_type': :'maintenanceType',
    'time_maintenance_window_start': :'timeMaintenanceWindowStart',
    'time_maintenance_window_end': :'timeMaintenanceWindowEnd',
    'additional_details': :'additionalDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/database/models/db_node_summary.rb', line 141

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'db_system_id': :'String',
    'vnic_id': :'String',
    'backup_vnic_id': :'String',
    'host_ip_id': :'String',
    'backup_ip_id': :'String',
    'vnic2_id': :'String',
    'backup_vnic2_id': :'String',
    'lifecycle_state': :'String',
    'hostname': :'String',
    'fault_domain': :'String',
    'time_created': :'DateTime',
    'software_storage_size_in_gb': :'Integer',
    'maintenance_type': :'String',
    'time_maintenance_window_start': :'DateTime',
    'time_maintenance_window_end': :'DateTime',
    'additional_details': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/oci/database/models/db_node_summary.rb', line 322

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    db_system_id == other.db_system_id &&
    vnic_id == other.vnic_id &&
    backup_vnic_id == other.backup_vnic_id &&
    host_ip_id == other.host_ip_id &&
    backup_ip_id == other.backup_ip_id &&
    vnic2_id == other.vnic2_id &&
    backup_vnic2_id == other.backup_vnic2_id &&
    lifecycle_state == other.lifecycle_state &&
    hostname == other.hostname &&
    fault_domain == other.fault_domain &&
    time_created == other.time_created &&
    software_storage_size_in_gb == other.software_storage_size_in_gb &&
    maintenance_type == other.maintenance_type &&
    time_maintenance_window_start == other.time_maintenance_window_start &&
    time_maintenance_window_end == other.time_maintenance_window_end &&
    additional_details == other.additional_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/oci/database/models/db_node_summary.rb', line 368

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


348
349
350
# File 'lib/oci/database/models/db_node_summary.rb', line 348

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



357
358
359
# File 'lib/oci/database/models/db_node_summary.rb', line 357

def hash
  [id, db_system_id, vnic_id, backup_vnic_id, host_ip_id, backup_ip_id, vnic2_id, backup_vnic2_id, lifecycle_state, hostname, fault_domain, time_created, software_storage_size_in_gb, maintenance_type, time_maintenance_window_start, time_maintenance_window_end, additional_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



401
402
403
404
405
406
407
408
409
410
# File 'lib/oci/database/models/db_node_summary.rb', line 401

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



395
396
397
# File 'lib/oci/database/models/db_node_summary.rb', line 395

def to_s
  to_hash.to_s
end