Class: OCI::Database::Models::DbServerSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/db_server_summary.rb

Overview

Details of the Exadata Cloud@Customer Db server.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_UNAVAILABLE = 'UNAVAILABLE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DbServerSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :exadata_infrastructure_id (String)

    The value to assign to the #exadata_infrastructure_id property

  • :cpu_core_count (Integer)

    The value to assign to the #cpu_core_count property

  • :memory_size_in_gbs (Integer)

    The value to assign to the #memory_size_in_gbs property

  • :db_node_storage_size_in_gbs (Integer)

    The value to assign to the #db_node_storage_size_in_gbs property

  • :vm_cluster_ids (Array<String>)

    The value to assign to the #vm_cluster_ids property

  • :db_node_ids (Array<String>)

    The value to assign to the #db_node_ids property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :max_cpu_count (Integer)

    The value to assign to the #max_cpu_count property

  • :max_memory_in_gbs (Integer)

    The value to assign to the #max_memory_in_gbs property

  • :max_db_node_storage_in_gbs (Integer)

    The value to assign to the #max_db_node_storage_in_gbs property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/oci/database/models/db_server_summary.rb', line 171

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.exadata_infrastructure_id = attributes[:'exadataInfrastructureId'] if attributes[:'exadataInfrastructureId']

  raise 'You cannot provide both :exadataInfrastructureId and :exadata_infrastructure_id' if attributes.key?(:'exadataInfrastructureId') && attributes.key?(:'exadata_infrastructure_id')

  self.exadata_infrastructure_id = attributes[:'exadata_infrastructure_id'] if attributes[:'exadata_infrastructure_id']

  self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount']

  raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count')

  self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count']

  self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs']

  raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs')

  self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs']

  self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs']

  raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs')

  self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs']

  self.vm_cluster_ids = attributes[:'vmClusterIds'] if attributes[:'vmClusterIds']

  raise 'You cannot provide both :vmClusterIds and :vm_cluster_ids' if attributes.key?(:'vmClusterIds') && attributes.key?(:'vm_cluster_ids')

  self.vm_cluster_ids = attributes[:'vm_cluster_ids'] if attributes[:'vm_cluster_ids']

  self.db_node_ids = attributes[:'dbNodeIds'] if attributes[:'dbNodeIds']

  raise 'You cannot provide both :dbNodeIds and :db_node_ids' if attributes.key?(:'dbNodeIds') && attributes.key?(:'db_node_ids')

  self.db_node_ids = attributes[:'db_node_ids'] if attributes[:'db_node_ids']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.max_cpu_count = attributes[:'maxCpuCount'] if attributes[:'maxCpuCount']

  raise 'You cannot provide both :maxCpuCount and :max_cpu_count' if attributes.key?(:'maxCpuCount') && attributes.key?(:'max_cpu_count')

  self.max_cpu_count = attributes[:'max_cpu_count'] if attributes[:'max_cpu_count']

  self.max_memory_in_gbs = attributes[:'maxMemoryInGBs'] if attributes[:'maxMemoryInGBs']

  raise 'You cannot provide both :maxMemoryInGBs and :max_memory_in_gbs' if attributes.key?(:'maxMemoryInGBs') && attributes.key?(:'max_memory_in_gbs')

  self.max_memory_in_gbs = attributes[:'max_memory_in_gbs'] if attributes[:'max_memory_in_gbs']

  self.max_db_node_storage_in_gbs = attributes[:'maxDbNodeStorageInGBs'] if attributes[:'maxDbNodeStorageInGBs']

  raise 'You cannot provide both :maxDbNodeStorageInGBs and :max_db_node_storage_in_gbs' if attributes.key?(:'maxDbNodeStorageInGBs') && attributes.key?(:'max_db_node_storage_in_gbs')

  self.max_db_node_storage_in_gbs = attributes[:'max_db_node_storage_in_gbs'] if attributes[:'max_db_node_storage_in_gbs']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

Returns:

  • (String)


32
33
34
# File 'lib/oci/database/models/db_server_summary.rb', line 32

def compartment_id
  @compartment_id
end

#cpu_core_countInteger

The number of CPU cores enabled on the Db server.

Returns:

  • (Integer)


40
41
42
# File 'lib/oci/database/models/db_server_summary.rb', line 40

def cpu_core_count
  @cpu_core_count
end

#db_node_idsArray<String>

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Db nodes associated with the Db server.

Returns:

  • (Array<String>)


58
59
60
# File 'lib/oci/database/models/db_server_summary.rb', line 58

def db_node_ids
  @db_node_ids
end

#db_node_storage_size_in_gbsInteger

The allocated local node storage in GBs on the Db server.

Returns:

  • (Integer)


48
49
50
# File 'lib/oci/database/models/db_server_summary.rb', line 48

def db_node_storage_size_in_gbs
  @db_node_storage_size_in_gbs
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


96
97
98
# File 'lib/oci/database/models/db_server_summary.rb', line 96

def defined_tags
  @defined_tags
end

#display_nameString

The user-friendly name for the Db server. The name does not need to be unique.

Returns:

  • (String)


28
29
30
# File 'lib/oci/database/models/db_server_summary.rb', line 28

def display_name
  @display_name
end

#exadata_infrastructure_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.

Returns:

  • (String)


36
37
38
# File 'lib/oci/database/models/db_server_summary.rb', line 36

def exadata_infrastructure_id
  @exadata_infrastructure_id
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


90
91
92
# File 'lib/oci/database/models/db_server_summary.rb', line 90

def freeform_tags
  @freeform_tags
end

#idString

Returns:

  • (String)


24
25
26
# File 'lib/oci/database/models/db_server_summary.rb', line 24

def id
  @id
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


66
67
68
# File 'lib/oci/database/models/db_server_summary.rb', line 66

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

The current state of the Db server.

Returns:

  • (String)


62
63
64
# File 'lib/oci/database/models/db_server_summary.rb', line 62

def lifecycle_state
  @lifecycle_state
end

#max_cpu_countInteger

The total number of CPU cores available.

Returns:

  • (Integer)


70
71
72
# File 'lib/oci/database/models/db_server_summary.rb', line 70

def max_cpu_count
  @max_cpu_count
end

#max_db_node_storage_in_gbsInteger

The total local node storage available in GBs.

Returns:

  • (Integer)


78
79
80
# File 'lib/oci/database/models/db_server_summary.rb', line 78

def max_db_node_storage_in_gbs
  @max_db_node_storage_in_gbs
end

#max_memory_in_gbsInteger

The total memory available in GBs.

Returns:

  • (Integer)


74
75
76
# File 'lib/oci/database/models/db_server_summary.rb', line 74

def max_memory_in_gbs
  @max_memory_in_gbs
end

#memory_size_in_gbsInteger

The allocated memory in GBs on the Db server.

Returns:

  • (Integer)


44
45
46
# File 'lib/oci/database/models/db_server_summary.rb', line 44

def memory_size_in_gbs
  @memory_size_in_gbs
end

#time_createdDateTime

The date and time that the Db Server was created.

Returns:

  • (DateTime)


82
83
84
# File 'lib/oci/database/models/db_server_summary.rb', line 82

def time_created
  @time_created
end

#vm_cluster_idsArray<String>

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM Clusters associated with the Db server.

Returns:

  • (Array<String>)


53
54
55
# File 'lib/oci/database/models/db_server_summary.rb', line 53

def vm_cluster_ids
  @vm_cluster_ids
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/database/models/db_server_summary.rb', line 99

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'compartment_id': :'compartmentId',
    'exadata_infrastructure_id': :'exadataInfrastructureId',
    'cpu_core_count': :'cpuCoreCount',
    'memory_size_in_gbs': :'memorySizeInGBs',
    'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs',
    'vm_cluster_ids': :'vmClusterIds',
    'db_node_ids': :'dbNodeIds',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'max_cpu_count': :'maxCpuCount',
    'max_memory_in_gbs': :'maxMemoryInGBs',
    'max_db_node_storage_in_gbs': :'maxDbNodeStorageInGBs',
    'time_created': :'timeCreated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/database/models/db_server_summary.rb', line 124

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'compartment_id': :'String',
    'exadata_infrastructure_id': :'String',
    'cpu_core_count': :'Integer',
    'memory_size_in_gbs': :'Integer',
    'db_node_storage_size_in_gbs': :'Integer',
    'vm_cluster_ids': :'Array<String>',
    'db_node_ids': :'Array<String>',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'max_cpu_count': :'Integer',
    'max_memory_in_gbs': :'Integer',
    'max_db_node_storage_in_gbs': :'Integer',
    'time_created': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/oci/database/models/db_server_summary.rb', line 296

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    compartment_id == other.compartment_id &&
    exadata_infrastructure_id == other.exadata_infrastructure_id &&
    cpu_core_count == other.cpu_core_count &&
    memory_size_in_gbs == other.memory_size_in_gbs &&
    db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs &&
    vm_cluster_ids == other.vm_cluster_ids &&
    db_node_ids == other.db_node_ids &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    max_cpu_count == other.max_cpu_count &&
    max_memory_in_gbs == other.max_memory_in_gbs &&
    max_db_node_storage_in_gbs == other.max_db_node_storage_in_gbs &&
    time_created == other.time_created &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/oci/database/models/db_server_summary.rb', line 342

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


322
323
324
# File 'lib/oci/database/models/db_server_summary.rb', line 322

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



331
332
333
# File 'lib/oci/database/models/db_server_summary.rb', line 331

def hash
  [id, display_name, compartment_id, exadata_infrastructure_id, cpu_core_count, memory_size_in_gbs, db_node_storage_size_in_gbs, vm_cluster_ids, db_node_ids, lifecycle_state, lifecycle_details, max_cpu_count, max_memory_in_gbs, max_db_node_storage_in_gbs, time_created, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



375
376
377
378
379
380
381
382
383
384
# File 'lib/oci/database/models/db_server_summary.rb', line 375

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



369
370
371
# File 'lib/oci/database/models/db_server_summary.rb', line 369

def to_s
  to_hash.to_s
end