Class: OCI::Database::Models::DbSystem
- Inherits:
-
Object
- Object
- OCI::Database::Models::DbSystem
- Defined in:
- lib/oci/database/models/db_system.rb
Overview
DbSystem model.
Constant Summary collapse
- DATABASE_EDITION_ENUM =
rubocop:disable Metrics/LineLength
[ DATABASE_EDITION_STANDARD_EDITION = 'STANDARD_EDITION'.freeze, DATABASE_EDITION_ENTERPRISE_EDITION = 'ENTERPRISE_EDITION'.freeze, DATABASE_EDITION_ENTERPRISE_EDITION_HIGH_PERFORMANCE = 'ENTERPRISE_EDITION_HIGH_PERFORMANCE'.freeze, DATABASE_EDITION_ENTERPRISE_EDITION_EXTREME_PERFORMANCE = 'ENTERPRISE_EDITION_EXTREME_PERFORMANCE'.freeze, DATABASE_EDITION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DISK_REDUNDANCY_ENUM =
[ DISK_REDUNDANCY_HIGH = 'HIGH'.freeze, DISK_REDUNDANCY_NORMAL = 'NORMAL'.freeze, DISK_REDUNDANCY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze, LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
[Required] The name of the availability domain that the DB system is located in.
-
#backup_subnet_id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the backup network subnet the DB system is associated with.
-
#cluster_name ⇒ String
The cluster name for Exadata and 2-node RAC virtual machine DB systems.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#cpu_core_count ⇒ Integer
[Required] The number of CPU cores enabled on the DB system.
-
#data_storage_percentage ⇒ Integer
The percentage assigned to DATA storage (user data and database files).
-
#data_storage_size_in_gbs ⇒ Integer
The data storage size, in gigabytes, that is currently available to the DB system.
-
#database_edition ⇒ String
[Required] The Oracle Database edition that applies to all the databases on the DB system.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#disk_redundancy ⇒ String
The type of redundancy configured for the DB system.
-
#display_name ⇒ String
[Required] The user-friendly name for the DB system.
-
#domain ⇒ String
[Required] The domain name for the DB system.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#hostname ⇒ String
[Required] The hostname for the DB system.
-
#id ⇒ String
[Required] The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the DB system.
-
#last_patch_history_entry_id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the last patch history.
-
#license_model ⇒ String
The Oracle license model that applies to all the databases on the DB system.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycleState.
-
#lifecycle_state ⇒ String
[Required] The current state of the DB system.
-
#listener_port ⇒ Integer
The port number configured for the listener on the DB system.
-
#node_count ⇒ Integer
The number of nodes in the DB system.
-
#reco_storage_size_in_gb ⇒ Integer
The RECO/REDO storage size, in gigabytes, that is currently allocated to the DB system.
-
#scan_dns_record_id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the DNS record for the SCAN IP addresses that are associated with the DB system.
-
#scan_ip_ids ⇒ Array<String>
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the Single Client Access Name (SCAN) IP addresses associated with the DB system.
-
#shape ⇒ String
[Required] The shape of the DB system.
-
#sparse_diskgroup ⇒ BOOLEAN
True, if Sparse Diskgroup is configured for Exadata dbsystem, False, if Sparse diskgroup was not configured.
-
#ssh_public_keys ⇒ Array<String>
[Required] The public key portion of one or more key pairs used for SSH access to the DB system.
-
#subnet_id ⇒ String
[Required] The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the subnet the DB system is associated with.
-
#time_created ⇒ DateTime
The date and time the DB system was created.
-
#version ⇒ String
The Oracle Database version of the DB system.
-
#vip_ids ⇒ Array<String>
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the virtual IP (VIP) addresses associated with the DB system.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbSystem
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbSystem
Initializes the object
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/oci/database/models/db_system.rb', line 325 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.backup_subnet_id = attributes[:'backupSubnetId'] if attributes[:'backupSubnetId'] raise 'You cannot provide both :backupSubnetId and :backup_subnet_id' if attributes.key?(:'backupSubnetId') && attributes.key?(:'backup_subnet_id') self.backup_subnet_id = attributes[:'backup_subnet_id'] if attributes[:'backup_subnet_id'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys'] raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys') self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys'] self.hostname = attributes[:'hostname'] if attributes[:'hostname'] self.domain = attributes[:'domain'] if attributes[:'domain'] self.version = attributes[:'version'] if attributes[:'version'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.cluster_name = attributes[:'clusterName'] if attributes[:'clusterName'] raise 'You cannot provide both :clusterName and :cluster_name' if attributes.key?(:'clusterName') && attributes.key?(:'cluster_name') self.cluster_name = attributes[:'cluster_name'] if attributes[:'cluster_name'] self.data_storage_percentage = attributes[:'dataStoragePercentage'] if attributes[:'dataStoragePercentage'] raise 'You cannot provide both :dataStoragePercentage and :data_storage_percentage' if attributes.key?(:'dataStoragePercentage') && attributes.key?(:'data_storage_percentage') self.data_storage_percentage = attributes[:'data_storage_percentage'] if attributes[:'data_storage_percentage'] self.database_edition = attributes[:'databaseEdition'] if attributes[:'databaseEdition'] raise 'You cannot provide both :databaseEdition and :database_edition' if attributes.key?(:'databaseEdition') && attributes.key?(:'database_edition') self.database_edition = attributes[:'database_edition'] if attributes[:'database_edition'] self.last_patch_history_entry_id = attributes[:'lastPatchHistoryEntryId'] if attributes[:'lastPatchHistoryEntryId'] raise 'You cannot provide both :lastPatchHistoryEntryId and :last_patch_history_entry_id' if attributes.key?(:'lastPatchHistoryEntryId') && attributes.key?(:'last_patch_history_entry_id') self.last_patch_history_entry_id = attributes[:'last_patch_history_entry_id'] if attributes[:'last_patch_history_entry_id'] self.listener_port = attributes[:'listenerPort'] if attributes[:'listenerPort'] raise 'You cannot provide both :listenerPort and :listener_port' if attributes.key?(:'listenerPort') && attributes.key?(:'listener_port') self.listener_port = attributes[:'listener_port'] if attributes[:'listener_port'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.disk_redundancy = attributes[:'diskRedundancy'] if attributes[:'diskRedundancy'] raise 'You cannot provide both :diskRedundancy and :disk_redundancy' if attributes.key?(:'diskRedundancy') && attributes.key?(:'disk_redundancy') self.disk_redundancy = attributes[:'disk_redundancy'] if attributes[:'disk_redundancy'] self.sparse_diskgroup = attributes[:'sparseDiskgroup'] unless attributes[:'sparseDiskgroup'].nil? raise 'You cannot provide both :sparseDiskgroup and :sparse_diskgroup' if attributes.key?(:'sparseDiskgroup') && attributes.key?(:'sparse_diskgroup') self.sparse_diskgroup = attributes[:'sparse_diskgroup'] unless attributes[:'sparse_diskgroup'].nil? self.scan_ip_ids = attributes[:'scanIpIds'] if attributes[:'scanIpIds'] raise 'You cannot provide both :scanIpIds and :scan_ip_ids' if attributes.key?(:'scanIpIds') && attributes.key?(:'scan_ip_ids') self.scan_ip_ids = attributes[:'scan_ip_ids'] if attributes[:'scan_ip_ids'] self.vip_ids = attributes[:'vipIds'] if attributes[:'vipIds'] raise 'You cannot provide both :vipIds and :vip_ids' if attributes.key?(:'vipIds') && attributes.key?(:'vip_ids') self.vip_ids = attributes[:'vip_ids'] if attributes[:'vip_ids'] self.scan_dns_record_id = attributes[:'scanDnsRecordId'] if attributes[:'scanDnsRecordId'] raise 'You cannot provide both :scanDnsRecordId and :scan_dns_record_id' if attributes.key?(:'scanDnsRecordId') && attributes.key?(:'scan_dns_record_id') self.scan_dns_record_id = attributes[:'scan_dns_record_id'] if attributes[:'scan_dns_record_id'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.reco_storage_size_in_gb = attributes[:'recoStorageSizeInGB'] if attributes[:'recoStorageSizeInGB'] raise 'You cannot provide both :recoStorageSizeInGB and :reco_storage_size_in_gb' if attributes.key?(:'recoStorageSizeInGB') && attributes.key?(:'reco_storage_size_in_gb') self.reco_storage_size_in_gb = attributes[:'reco_storage_size_in_gb'] if attributes[:'reco_storage_size_in_gb'] self.node_count = attributes[:'nodeCount'] if attributes[:'nodeCount'] raise 'You cannot provide both :nodeCount and :node_count' if attributes.key?(:'nodeCount') && attributes.key?(:'node_count') self.node_count = attributes[:'node_count'] if attributes[:'node_count'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#availability_domain ⇒ String
[Required] The name of the availability domain that the DB system is located in.
54 55 56 |
# File 'lib/oci/database/models/db_system.rb', line 54 def availability_domain @availability_domain end |
#backup_subnet_id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the backup network subnet the DB system is associated with. Applicable only to Exadata DB systems.
**Subnet Restriction:** See the subnet restrictions information for subnetId.
74 75 76 |
# File 'lib/oci/database/models/db_system.rb', line 74 def backup_subnet_id @backup_subnet_id end |
#cluster_name ⇒ String
The cluster name for Exadata and 2-node RAC virtual machine DB systems. The cluster name must begin with an an alphabetic character, and may contain hyphens (-). Underscores (_) are not permitted. The cluster name can be no longer than 11 characters and is not case sensitive.
106 107 108 |
# File 'lib/oci/database/models/db_system.rb', line 106 def cluster_name @cluster_name end |
#compartment_id ⇒ String
[Required] The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the compartment.
46 47 48 |
# File 'lib/oci/database/models/db_system.rb', line 46 def compartment_id @compartment_id end |
#cpu_core_count ⇒ Integer
[Required] The number of CPU cores enabled on the DB system.
101 102 103 |
# File 'lib/oci/database/models/db_system.rb', line 101 def cpu_core_count @cpu_core_count end |
#data_storage_percentage ⇒ Integer
The percentage assigned to DATA storage (user data and database files). The remaining percentage is assigned to RECO storage (database redo logs, archive logs, and recovery manager backups). Accepted values are 40 and 80. The default is 80 percent assigned to DATA storage. Not applicable for virtual machine DB systems.
112 113 114 |
# File 'lib/oci/database/models/db_system.rb', line 112 def data_storage_percentage @data_storage_percentage end |
#data_storage_size_in_gbs ⇒ Integer
The data storage size, in gigabytes, that is currently available to the DB system. Applies only for virtual machine DB systems.
177 178 179 |
# File 'lib/oci/database/models/db_system.rb', line 177 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#database_edition ⇒ String
[Required] The Oracle Database edition that applies to all the databases on the DB system.
117 118 119 |
# File 'lib/oci/database/models/db_system.rb', line 117 def database_edition @database_edition end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
208 209 210 |
# File 'lib/oci/database/models/db_system.rb', line 208 def end |
#disk_redundancy ⇒ String
The type of redundancy configured for the DB system. NORMAL is 2-way redundancy. HIGH is 3-way redundancy.
144 145 146 |
# File 'lib/oci/database/models/db_system.rb', line 144 def disk_redundancy @disk_redundancy end |
#display_name ⇒ String
[Required] The user-friendly name for the DB system. The name does not have to be unique.
50 51 52 |
# File 'lib/oci/database/models/db_system.rb', line 50 def display_name @display_name end |
#domain ⇒ String
[Required] The domain name for the DB system.
93 94 95 |
# File 'lib/oci/database/models/db_system.rb', line 93 def domain @domain end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
200 201 202 |
# File 'lib/oci/database/models/db_system.rb', line 200 def end |
#hostname ⇒ String
[Required] The hostname for the DB system.
89 90 91 |
# File 'lib/oci/database/models/db_system.rb', line 89 def hostname @hostname end |
#id ⇒ String
[Required] The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the DB system.
42 43 44 |
# File 'lib/oci/database/models/db_system.rb', line 42 def id @id end |
#last_patch_history_entry_id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the last patch history. This value is updated as soon as a patch operation starts.
121 122 123 |
# File 'lib/oci/database/models/db_system.rb', line 121 def last_patch_history_entry_id @last_patch_history_entry_id end |
#license_model ⇒ String
The Oracle license model that applies to all the databases on the DB system. The default is LICENSE_INCLUDED.
192 193 194 |
# File 'lib/oci/database/models/db_system.rb', line 192 def license_model @license_model end |
#lifecycle_details ⇒ String
Additional information about the current lifecycleState.
137 138 139 |
# File 'lib/oci/database/models/db_system.rb', line 137 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the DB system.
129 130 131 |
# File 'lib/oci/database/models/db_system.rb', line 129 def lifecycle_state @lifecycle_state end |
#listener_port ⇒ Integer
The port number configured for the listener on the DB system.
125 126 127 |
# File 'lib/oci/database/models/db_system.rb', line 125 def listener_port @listener_port end |
#node_count ⇒ Integer
The number of nodes in the DB system. For RAC DB systems, the value is greater than 1.
187 188 189 |
# File 'lib/oci/database/models/db_system.rb', line 187 def node_count @node_count end |
#reco_storage_size_in_gb ⇒ Integer
The RECO/REDO storage size, in gigabytes, that is currently allocated to the DB system. Applies only for virtual machine DB systems.
182 183 184 |
# File 'lib/oci/database/models/db_system.rb', line 182 def reco_storage_size_in_gb @reco_storage_size_in_gb end |
#scan_dns_record_id ⇒ String
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the DNS record for the SCAN IP addresses that are associated with the DB system.
172 173 174 |
# File 'lib/oci/database/models/db_system.rb', line 172 def scan_dns_record_id @scan_dns_record_id end |
#scan_ip_ids ⇒ Array<String>
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the Single Client Access Name (SCAN) IP addresses associated with the DB system. SCAN IP addresses are typically used for load balancing and are not assigned to any interface. Oracle Clusterware directs the requests to the appropriate nodes in the cluster.
Note: For a single-node DB system, this list is empty.
158 159 160 |
# File 'lib/oci/database/models/db_system.rb', line 158 def scan_ip_ids @scan_ip_ids end |
#shape ⇒ String
[Required] The shape of the DB system. The shape determines resources to allocate to the DB system.
-
For virtual machine shapes, the number of CPU cores and memory
-
For bare metal and Exadata shapes, the number of CPU cores, storage, and memory
81 82 83 |
# File 'lib/oci/database/models/db_system.rb', line 81 def shape @shape end |
#sparse_diskgroup ⇒ BOOLEAN
True, if Sparse Diskgroup is configured for Exadata dbsystem, False, if Sparse diskgroup was not configured.
149 150 151 |
# File 'lib/oci/database/models/db_system.rb', line 149 def sparse_diskgroup @sparse_diskgroup end |
#ssh_public_keys ⇒ Array<String>
[Required] The public key portion of one or more key pairs used for SSH access to the DB system.
85 86 87 |
# File 'lib/oci/database/models/db_system.rb', line 85 def ssh_public_keys @ssh_public_keys end |
#subnet_id ⇒ String
[Required] The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the subnet the DB system is associated with.
**Subnet Restrictions:**
-
For bare metal DB systems and for single node virtual machine DB systems, do not use a subnet that overlaps with 192.168.16.16/28.
-
For Exadata and virtual machine 2-node RAC DB systems, do not use a subnet that overlaps with 192.168.128.0/20.
These subnets are used by the Oracle Clusterware private interconnect on the database instance. Specifying an overlapping subnet will cause the private interconnect to malfunction. This restriction applies to both the client subnet and backup subnet.
67 68 69 |
# File 'lib/oci/database/models/db_system.rb', line 67 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
The date and time the DB system was created.
133 134 135 |
# File 'lib/oci/database/models/db_system.rb', line 133 def time_created @time_created end |
#version ⇒ String
The Oracle Database version of the DB system.
97 98 99 |
# File 'lib/oci/database/models/db_system.rb', line 97 def version @version end |
#vip_ids ⇒ Array<String>
The [OCID](docs.us-phoenix-1.oraclecloud.com/Content/General/Concepts/identifiers.htm) of the virtual IP (VIP) addresses associated with the DB system. The Cluster Ready Services (CRS) creates and maintains one VIP address for each node in the DB system to enable failover. If one node fails, the VIP is reassigned to another active node in the cluster.
Note: For a single-node DB system, this list is empty.
167 168 169 |
# File 'lib/oci/database/models/db_system.rb', line 167 def vip_ids @vip_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/database/models/db_system.rb', line 211 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'availability_domain': :'availabilityDomain', 'subnet_id': :'subnetId', 'backup_subnet_id': :'backupSubnetId', 'shape': :'shape', 'ssh_public_keys': :'sshPublicKeys', 'hostname': :'hostname', 'domain': :'domain', 'version': :'version', 'cpu_core_count': :'cpuCoreCount', 'cluster_name': :'clusterName', 'data_storage_percentage': :'dataStoragePercentage', 'database_edition': :'databaseEdition', 'last_patch_history_entry_id': :'lastPatchHistoryEntryId', 'listener_port': :'listenerPort', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'lifecycle_details': :'lifecycleDetails', 'disk_redundancy': :'diskRedundancy', 'sparse_diskgroup': :'sparseDiskgroup', 'scan_ip_ids': :'scanIpIds', 'vip_ids': :'vipIds', 'scan_dns_record_id': :'scanDnsRecordId', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'reco_storage_size_in_gb': :'recoStorageSizeInGB', 'node_count': :'nodeCount', 'license_model': :'licenseModel', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/oci/database/models/db_system.rb', line 250 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'availability_domain': :'String', 'subnet_id': :'String', 'backup_subnet_id': :'String', 'shape': :'String', 'ssh_public_keys': :'Array<String>', 'hostname': :'String', 'domain': :'String', 'version': :'String', 'cpu_core_count': :'Integer', 'cluster_name': :'String', 'data_storage_percentage': :'Integer', 'database_edition': :'String', 'last_patch_history_entry_id': :'String', 'listener_port': :'Integer', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'lifecycle_details': :'String', 'disk_redundancy': :'String', 'sparse_diskgroup': :'BOOLEAN', 'scan_ip_ids': :'Array<String>', 'vip_ids': :'Array<String>', 'scan_dns_record_id': :'String', 'data_storage_size_in_gbs': :'Integer', 'reco_storage_size_in_gb': :'Integer', 'node_count': :'Integer', 'license_model': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'lib/oci/database/models/db_system.rb', line 562 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && availability_domain == other.availability_domain && subnet_id == other.subnet_id && backup_subnet_id == other.backup_subnet_id && shape == other.shape && ssh_public_keys == other.ssh_public_keys && hostname == other.hostname && domain == other.domain && version == other.version && cpu_core_count == other.cpu_core_count && cluster_name == other.cluster_name && data_storage_percentage == other.data_storage_percentage && database_edition == other.database_edition && last_patch_history_entry_id == other.last_patch_history_entry_id && listener_port == other.listener_port && lifecycle_state == other.lifecycle_state && time_created == other.time_created && lifecycle_details == other.lifecycle_details && disk_redundancy == other.disk_redundancy && sparse_diskgroup == other.sparse_diskgroup && scan_ip_ids == other.scan_ip_ids && vip_ids == other.vip_ids && scan_dns_record_id == other.scan_dns_record_id && data_storage_size_in_gbs == other.data_storage_size_in_gbs && reco_storage_size_in_gb == other.reco_storage_size_in_gb && node_count == other.node_count && license_model == other.license_model && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 |
# File 'lib/oci/database/models/db_system.rb', line 622 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
602 603 604 |
# File 'lib/oci/database/models/db_system.rb', line 602 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
611 612 613 |
# File 'lib/oci/database/models/db_system.rb', line 611 def hash [id, compartment_id, display_name, availability_domain, subnet_id, backup_subnet_id, shape, ssh_public_keys, hostname, domain, version, cpu_core_count, cluster_name, data_storage_percentage, database_edition, last_patch_history_entry_id, listener_port, lifecycle_state, time_created, lifecycle_details, disk_redundancy, sparse_diskgroup, scan_ip_ids, vip_ids, scan_dns_record_id, data_storage_size_in_gbs, reco_storage_size_in_gb, node_count, license_model, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
655 656 657 658 659 660 661 662 663 664 |
# File 'lib/oci/database/models/db_system.rb', line 655 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
649 650 651 |
# File 'lib/oci/database/models/db_system.rb', line 649 def to_s to_hash.to_s end |