Class: OCI::Database::Models::DbSystemSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/db_system_summary.rb

Overview

The Database Service supports several types of DB systems, ranging in size, price, and performance. For details about each type of system, see [Bare Metal and Virtual Machine DB Systems](docs.cloud.oracle.com/Content/Database/Concepts/overview.htm).

Note: Deprecated for Exadata Cloud Service instances using the new [resource model](docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem.htm#exaflexsystem_topic-resource_model). To provision and manage new Exadata Cloud Service systems, use the CloudExadataInfrastructure and CloudVmCluster. See [Exadata Cloud Service](docs.cloud.oracle.com/Content/Database/Concepts/exaoverview.htm) for more information on Exadata systems.

For Exadata Cloud Service instances, support for this API will end on May 15th, 2021. See [Switching an Exadata DB System to the New Resource Model and APIs](docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem_topic-resource_model_conversion.htm) for details on converting existing Exadata DB systems to the new resource model.

To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

For information about access control and compartments, see [Overview of the Identity Service](docs.cloud.oracle.com/Content/Identity/Concepts/overview.htm).

For information about availability domains, see [Regions and Availability Domains](docs.cloud.oracle.com/Content/General/Concepts/regions.htm).

To get a list of availability domains, use the ListAvailabilityDomains operation in the Identity Service API.

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

DATABASE_EDITION_ENUM =
[
  DATABASE_EDITION_STANDARD_EDITION = 'STANDARD_EDITION'.freeze,
  DATABASE_EDITION_ENTERPRISE_EDITION = 'ENTERPRISE_EDITION'.freeze,
  DATABASE_EDITION_ENTERPRISE_EDITION_HIGH_PERFORMANCE = 'ENTERPRISE_EDITION_HIGH_PERFORMANCE'.freeze,
  DATABASE_EDITION_ENTERPRISE_EDITION_EXTREME_PERFORMANCE = 'ENTERPRISE_EDITION_EXTREME_PERFORMANCE'.freeze,
  DATABASE_EDITION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
  LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_MIGRATED = 'MIGRATED'.freeze,
  LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze,
  LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DISK_REDUNDANCY_ENUM =
[
  DISK_REDUNDANCY_HIGH = 'HIGH'.freeze,
  DISK_REDUNDANCY_NORMAL = 'NORMAL'.freeze,
  DISK_REDUNDANCY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LICENSE_MODEL_ENUM =
[
  LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze,
  LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze,
  LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DbSystemSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/oci/database/models/db_system_summary.rb', line 444

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.fault_domains = attributes[:'faultDomains'] if attributes[:'faultDomains']

  raise 'You cannot provide both :faultDomains and :fault_domains' if attributes.key?(:'faultDomains') && attributes.key?(:'fault_domains')

  self.fault_domains = attributes[:'fault_domains'] if attributes[:'fault_domains']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.backup_subnet_id = attributes[:'backupSubnetId'] if attributes[:'backupSubnetId']

  raise 'You cannot provide both :backupSubnetId and :backup_subnet_id' if attributes.key?(:'backupSubnetId') && attributes.key?(:'backup_subnet_id')

  self.backup_subnet_id = attributes[:'backup_subnet_id'] if attributes[:'backup_subnet_id']

  self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds']

  raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids')

  self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids']

  self.backup_network_nsg_ids = attributes[:'backupNetworkNsgIds'] if attributes[:'backupNetworkNsgIds']

  raise 'You cannot provide both :backupNetworkNsgIds and :backup_network_nsg_ids' if attributes.key?(:'backupNetworkNsgIds') && attributes.key?(:'backup_network_nsg_ids')

  self.backup_network_nsg_ids = attributes[:'backup_network_nsg_ids'] if attributes[:'backup_network_nsg_ids']

  self.shape = attributes[:'shape'] if attributes[:'shape']

  self.db_system_options = attributes[:'dbSystemOptions'] if attributes[:'dbSystemOptions']

  raise 'You cannot provide both :dbSystemOptions and :db_system_options' if attributes.key?(:'dbSystemOptions') && attributes.key?(:'db_system_options')

  self.db_system_options = attributes[:'db_system_options'] if attributes[:'db_system_options']

  self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys']

  raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys')

  self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys']

  self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone']

  raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone')

  self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone']

  self.hostname = attributes[:'hostname'] if attributes[:'hostname']

  self.domain = attributes[:'domain'] if attributes[:'domain']

  self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

  raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

  self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

  self.version = attributes[:'version'] if attributes[:'version']

  self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount']

  raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count')

  self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count']

  self.cluster_name = attributes[:'clusterName'] if attributes[:'clusterName']

  raise 'You cannot provide both :clusterName and :cluster_name' if attributes.key?(:'clusterName') && attributes.key?(:'cluster_name')

  self.cluster_name = attributes[:'cluster_name'] if attributes[:'cluster_name']

  self.data_storage_percentage = attributes[:'dataStoragePercentage'] if attributes[:'dataStoragePercentage']

  raise 'You cannot provide both :dataStoragePercentage and :data_storage_percentage' if attributes.key?(:'dataStoragePercentage') && attributes.key?(:'data_storage_percentage')

  self.data_storage_percentage = attributes[:'data_storage_percentage'] if attributes[:'data_storage_percentage']

  self.database_edition = attributes[:'databaseEdition'] if attributes[:'databaseEdition']

  raise 'You cannot provide both :databaseEdition and :database_edition' if attributes.key?(:'databaseEdition') && attributes.key?(:'database_edition')

  self.database_edition = attributes[:'database_edition'] if attributes[:'database_edition']

  self.last_patch_history_entry_id = attributes[:'lastPatchHistoryEntryId'] if attributes[:'lastPatchHistoryEntryId']

  raise 'You cannot provide both :lastPatchHistoryEntryId and :last_patch_history_entry_id' if attributes.key?(:'lastPatchHistoryEntryId') && attributes.key?(:'last_patch_history_entry_id')

  self.last_patch_history_entry_id = attributes[:'last_patch_history_entry_id'] if attributes[:'last_patch_history_entry_id']

  self.listener_port = attributes[:'listenerPort'] if attributes[:'listenerPort']

  raise 'You cannot provide both :listenerPort and :listener_port' if attributes.key?(:'listenerPort') && attributes.key?(:'listener_port')

  self.listener_port = attributes[:'listener_port'] if attributes[:'listener_port']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.disk_redundancy = attributes[:'diskRedundancy'] if attributes[:'diskRedundancy']

  raise 'You cannot provide both :diskRedundancy and :disk_redundancy' if attributes.key?(:'diskRedundancy') && attributes.key?(:'disk_redundancy')

  self.disk_redundancy = attributes[:'disk_redundancy'] if attributes[:'disk_redundancy']

  self.sparse_diskgroup = attributes[:'sparseDiskgroup'] unless attributes[:'sparseDiskgroup'].nil?

  raise 'You cannot provide both :sparseDiskgroup and :sparse_diskgroup' if attributes.key?(:'sparseDiskgroup') && attributes.key?(:'sparse_diskgroup')

  self.sparse_diskgroup = attributes[:'sparse_diskgroup'] unless attributes[:'sparse_diskgroup'].nil?

  self.scan_ip_ids = attributes[:'scanIpIds'] if attributes[:'scanIpIds']

  raise 'You cannot provide both :scanIpIds and :scan_ip_ids' if attributes.key?(:'scanIpIds') && attributes.key?(:'scan_ip_ids')

  self.scan_ip_ids = attributes[:'scan_ip_ids'] if attributes[:'scan_ip_ids']

  self.vip_ids = attributes[:'vipIds'] if attributes[:'vipIds']

  raise 'You cannot provide both :vipIds and :vip_ids' if attributes.key?(:'vipIds') && attributes.key?(:'vip_ids')

  self.vip_ids = attributes[:'vip_ids'] if attributes[:'vip_ids']

  self.scan_dns_record_id = attributes[:'scanDnsRecordId'] if attributes[:'scanDnsRecordId']

  raise 'You cannot provide both :scanDnsRecordId and :scan_dns_record_id' if attributes.key?(:'scanDnsRecordId') && attributes.key?(:'scan_dns_record_id')

  self.scan_dns_record_id = attributes[:'scan_dns_record_id'] if attributes[:'scan_dns_record_id']

  self.scan_dns_name = attributes[:'scanDnsName'] if attributes[:'scanDnsName']

  raise 'You cannot provide both :scanDnsName and :scan_dns_name' if attributes.key?(:'scanDnsName') && attributes.key?(:'scan_dns_name')

  self.scan_dns_name = attributes[:'scan_dns_name'] if attributes[:'scan_dns_name']

  self.zone_id = attributes[:'zoneId'] if attributes[:'zoneId']

  raise 'You cannot provide both :zoneId and :zone_id' if attributes.key?(:'zoneId') && attributes.key?(:'zone_id')

  self.zone_id = attributes[:'zone_id'] if attributes[:'zone_id']

  self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs']

  raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs')

  self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs']

  self.reco_storage_size_in_gb = attributes[:'recoStorageSizeInGB'] if attributes[:'recoStorageSizeInGB']

  raise 'You cannot provide both :recoStorageSizeInGB and :reco_storage_size_in_gb' if attributes.key?(:'recoStorageSizeInGB') && attributes.key?(:'reco_storage_size_in_gb')

  self.reco_storage_size_in_gb = attributes[:'reco_storage_size_in_gb'] if attributes[:'reco_storage_size_in_gb']

  self.node_count = attributes[:'nodeCount'] if attributes[:'nodeCount']

  raise 'You cannot provide both :nodeCount and :node_count' if attributes.key?(:'nodeCount') && attributes.key?(:'node_count')

  self.node_count = attributes[:'node_count'] if attributes[:'node_count']

  self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel']

  raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model')

  self.license_model = attributes[:'license_model'] if attributes[:'license_model']

  self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow']

  raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window')

  self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window']

  self.last_maintenance_run_id = attributes[:'lastMaintenanceRunId'] if attributes[:'lastMaintenanceRunId']

  raise 'You cannot provide both :lastMaintenanceRunId and :last_maintenance_run_id' if attributes.key?(:'lastMaintenanceRunId') && attributes.key?(:'last_maintenance_run_id')

  self.last_maintenance_run_id = attributes[:'last_maintenance_run_id'] if attributes[:'last_maintenance_run_id']

  self.next_maintenance_run_id = attributes[:'nextMaintenanceRunId'] if attributes[:'nextMaintenanceRunId']

  raise 'You cannot provide both :nextMaintenanceRunId and :next_maintenance_run_id' if attributes.key?(:'nextMaintenanceRunId') && attributes.key?(:'next_maintenance_run_id')

  self.next_maintenance_run_id = attributes[:'next_maintenance_run_id'] if attributes[:'next_maintenance_run_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.source_db_system_id = attributes[:'sourceDbSystemId'] if attributes[:'sourceDbSystemId']

  raise 'You cannot provide both :sourceDbSystemId and :source_db_system_id' if attributes.key?(:'sourceDbSystemId') && attributes.key?(:'source_db_system_id')

  self.source_db_system_id = attributes[:'source_db_system_id'] if attributes[:'source_db_system_id']

  self.point_in_time_data_disk_clone_timestamp = attributes[:'pointInTimeDataDiskCloneTimestamp'] if attributes[:'pointInTimeDataDiskCloneTimestamp']

  raise 'You cannot provide both :pointInTimeDataDiskCloneTimestamp and :point_in_time_data_disk_clone_timestamp' if attributes.key?(:'pointInTimeDataDiskCloneTimestamp') && attributes.key?(:'point_in_time_data_disk_clone_timestamp')

  self.point_in_time_data_disk_clone_timestamp = attributes[:'point_in_time_data_disk_clone_timestamp'] if attributes[:'point_in_time_data_disk_clone_timestamp']
end

Instance Attribute Details

#availability_domainString

[Required] The name of the availability domain that the DB system is located in.

Returns:

  • (String)


80
81
82
# File 'lib/oci/database/models/db_system_summary.rb', line 80

def availability_domain
  @availability_domain
end

#backup_network_nsg_idsArray<String>

A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). Applicable only to Exadata systems.

Returns:

  • (Array<String>)


116
117
118
# File 'lib/oci/database/models/db_system_summary.rb', line 116

def backup_network_nsg_ids
  @backup_network_nsg_ids
end

#backup_subnet_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup network subnet the DB system is associated with. Applicable only to Exadata DB systems.

**Subnet Restriction:** See the subnet restrictions information for subnetId.

Returns:

  • (String)


104
105
106
# File 'lib/oci/database/models/db_system_summary.rb', line 104

def backup_subnet_id
  @backup_subnet_id
end

#cluster_nameString

The cluster name for Exadata and 2-node RAC virtual machine DB systems. The cluster name must begin with an alphabetic character, and may contain hyphens (-). Underscores (_) are not permitted. The cluster name can be no longer than 11 characters and is not case sensitive.

Returns:

  • (String)


159
160
161
# File 'lib/oci/database/models/db_system_summary.rb', line 159

def cluster_name
  @cluster_name
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


72
73
74
# File 'lib/oci/database/models/db_system_summary.rb', line 72

def compartment_id
  @compartment_id
end

#cpu_core_countInteger

[Required] The number of CPU cores enabled on the DB system.

Returns:

  • (Integer)


154
155
156
# File 'lib/oci/database/models/db_system_summary.rb', line 154

def cpu_core_count
  @cpu_core_count
end

#data_storage_percentageInteger

The percentage assigned to DATA storage (user data and database files). The remaining percentage is assigned to RECO storage (database redo logs, archive logs, and recovery manager backups). Accepted values are 40 and 80. The default is 80 percent assigned to DATA storage. Not applicable for virtual machine DB systems.

Returns:

  • (Integer)


165
166
167
# File 'lib/oci/database/models/db_system_summary.rb', line 165

def data_storage_percentage
  @data_storage_percentage
end

#data_storage_size_in_gbsInteger

The data storage size, in gigabytes, that is currently available to the DB system. Applies only for virtual machine DB systems.

Returns:

  • (Integer)


240
241
242
# File 'lib/oci/database/models/db_system_summary.rb', line 240

def data_storage_size_in_gbs
  @data_storage_size_in_gbs
end

#database_editionString

[Required] The Oracle Database edition that applies to all the databases on the DB system.

Returns:

  • (String)


170
171
172
# File 'lib/oci/database/models/db_system_summary.rb', line 170

def database_edition
  @database_edition
end

#db_system_optionsOCI::Database::Models::DbSystemOptions



126
127
128
# File 'lib/oci/database/models/db_system_summary.rb', line 126

def db_system_options
  @db_system_options
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Returns:

  • (Hash<String, Hash<String, Object>>)


280
281
282
# File 'lib/oci/database/models/db_system_summary.rb', line 280

def defined_tags
  @defined_tags
end

#disk_redundancyString

The type of redundancy configured for the DB system. NORMAL is 2-way redundancy. HIGH is 3-way redundancy.

Returns:

  • (String)


197
198
199
# File 'lib/oci/database/models/db_system_summary.rb', line 197

def disk_redundancy
  @disk_redundancy
end

#display_nameString

[Required] The user-friendly name for the DB system. The name does not have to be unique.

Returns:

  • (String)


76
77
78
# File 'lib/oci/database/models/db_system_summary.rb', line 76

def display_name
  @display_name
end

#domainString

[Required] The domain name for the DB system.

Returns:

  • (String)


142
143
144
# File 'lib/oci/database/models/db_system_summary.rb', line 142

def domain
  @domain
end

#fault_domainsArray<String>

List of the Fault Domains in which this DB system is provisioned.

Returns:

  • (Array<String>)


84
85
86
# File 'lib/oci/database/models/db_system_summary.rb', line 84

def fault_domains
  @fault_domains
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


274
275
276
# File 'lib/oci/database/models/db_system_summary.rb', line 274

def freeform_tags
  @freeform_tags
end

#hostnameString

[Required] The hostname for the DB system.

Returns:

  • (String)


138
139
140
# File 'lib/oci/database/models/db_system_summary.rb', line 138

def hostname
  @hostname
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DB system.

Returns:

  • (String)


68
69
70
# File 'lib/oci/database/models/db_system_summary.rb', line 68

def id
  @id
end

#kms_key_idString

The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.

Returns:

  • (String)


146
147
148
# File 'lib/oci/database/models/db_system_summary.rb', line 146

def kms_key_id
  @kms_key_id
end

#last_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.

Returns:

  • (String)


262
263
264
# File 'lib/oci/database/models/db_system_summary.rb', line 262

def last_maintenance_run_id
  @last_maintenance_run_id
end

#last_patch_history_entry_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last patch history. This value is updated as soon as a patch operation starts.

Returns:

  • (String)


174
175
176
# File 'lib/oci/database/models/db_system_summary.rb', line 174

def last_patch_history_entry_id
  @last_patch_history_entry_id
end

#license_modelString

The Oracle license model that applies to all the databases on the DB system. The default is LICENSE_INCLUDED.

Returns:

  • (String)


255
256
257
# File 'lib/oci/database/models/db_system_summary.rb', line 255

def license_model
  @license_model
end

#lifecycle_detailsString

Additional information about the current lifecycle state.

Returns:

  • (String)


190
191
192
# File 'lib/oci/database/models/db_system_summary.rb', line 190

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the DB system.

Returns:

  • (String)


182
183
184
# File 'lib/oci/database/models/db_system_summary.rb', line 182

def lifecycle_state
  @lifecycle_state
end

#listener_portInteger

The port number configured for the listener on the DB system.

Returns:

  • (Integer)


178
179
180
# File 'lib/oci/database/models/db_system_summary.rb', line 178

def listener_port
  @listener_port
end

#maintenance_windowOCI::Database::Models::MaintenanceWindow



258
259
260
# File 'lib/oci/database/models/db_system_summary.rb', line 258

def maintenance_window
  @maintenance_window
end

#next_maintenance_run_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.

Returns:

  • (String)


266
267
268
# File 'lib/oci/database/models/db_system_summary.rb', line 266

def next_maintenance_run_id
  @next_maintenance_run_id
end

#node_countInteger

The number of nodes in the DB system. For RAC DB systems, the value is greater than 1.

Returns:

  • (Integer)


250
251
252
# File 'lib/oci/database/models/db_system_summary.rb', line 250

def node_count
  @node_count
end

#nsg_idsArray<String>

A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**

  • Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

Returns:

  • (Array<String>)


111
112
113
# File 'lib/oci/database/models/db_system_summary.rb', line 111

def nsg_ids
  @nsg_ids
end

#point_in_time_data_disk_clone_timestampDateTime

The point in time for a cloned database system when the data disks were cloned from the source database system, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).

Returns:

  • (DateTime)


288
289
290
# File 'lib/oci/database/models/db_system_summary.rb', line 288

def point_in_time_data_disk_clone_timestamp
  @point_in_time_data_disk_clone_timestamp
end

#reco_storage_size_in_gbInteger

The RECO/REDO storage size, in gigabytes, that is currently allocated to the DB system. Applies only for virtual machine DB systems.

Returns:

  • (Integer)


245
246
247
# File 'lib/oci/database/models/db_system_summary.rb', line 245

def reco_storage_size_in_gb
  @reco_storage_size_in_gb
end

#scan_dns_nameString

The FQDN of the DNS record for the SCAN IP addresses that are associated with the DB system.

Returns:

  • (String)


230
231
232
# File 'lib/oci/database/models/db_system_summary.rb', line 230

def scan_dns_name
  @scan_dns_name
end

#scan_dns_record_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the DNS record for the SCAN IP addresses that are associated with the DB system.

Returns:

  • (String)


225
226
227
# File 'lib/oci/database/models/db_system_summary.rb', line 225

def scan_dns_record_id
  @scan_dns_record_id
end

#scan_ip_idsArray<String>

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Single Client Access Name (SCAN) IP addresses associated with the DB system. SCAN IP addresses are typically used for load balancing and are not assigned to any interface. Oracle Clusterware directs the requests to the appropriate nodes in the cluster.

Note: For a single-node DB system, this list is empty.

Returns:

  • (Array<String>)


211
212
213
# File 'lib/oci/database/models/db_system_summary.rb', line 211

def scan_ip_ids
  @scan_ip_ids
end

#shapeString

[Required] The shape of the DB system. The shape determines resources to allocate to the DB system.

  • For virtual machine shapes, the number of CPU cores and memory

  • For bare metal and Exadata shapes, the number of CPU cores, storage, and memory

Returns:

  • (String)


123
124
125
# File 'lib/oci/database/models/db_system_summary.rb', line 123

def shape
  @shape
end

#source_db_system_idString

Returns:

  • (String)


284
285
286
# File 'lib/oci/database/models/db_system_summary.rb', line 284

def source_db_system_id
  @source_db_system_id
end

#sparse_diskgroupBOOLEAN

True, if Sparse Diskgroup is configured for Exadata dbsystem, False, if Sparse diskgroup was not configured.

Returns:

  • (BOOLEAN)


202
203
204
# File 'lib/oci/database/models/db_system_summary.rb', line 202

def sparse_diskgroup
  @sparse_diskgroup
end

#ssh_public_keysArray<String>

[Required] The public key portion of one or more key pairs used for SSH access to the DB system.

Returns:

  • (Array<String>)


130
131
132
# File 'lib/oci/database/models/db_system_summary.rb', line 130

def ssh_public_keys
  @ssh_public_keys
end

#subnet_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet the DB system is associated with.

**Subnet Restrictions:**

  • For bare metal DB systems and for single node virtual machine DB systems, do not use a subnet that overlaps with 192.168.16.16/28.

  • For Exadata and virtual machine 2-node RAC DB systems, do not use a subnet that overlaps with 192.168.128.0/20.

These subnets are used by the Oracle Clusterware private interconnect on the database instance. Specifying an overlapping subnet will cause the private interconnect to malfunction. This restriction applies to both the client subnet and backup subnet.

Returns:

  • (String)


97
98
99
# File 'lib/oci/database/models/db_system_summary.rb', line 97

def subnet_id
  @subnet_id
end

#time_createdDateTime

The date and time the DB system was created.

Returns:

  • (DateTime)


186
187
188
# File 'lib/oci/database/models/db_system_summary.rb', line 186

def time_created
  @time_created
end

#time_zoneString

The time zone of the DB system. For details, see [DB System Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).

Returns:

  • (String)


134
135
136
# File 'lib/oci/database/models/db_system_summary.rb', line 134

def time_zone
  @time_zone
end

#versionString

The Oracle Database version of the DB system.

Returns:

  • (String)


150
151
152
# File 'lib/oci/database/models/db_system_summary.rb', line 150

def version
  @version
end

#vip_idsArray<String>

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the virtual IP (VIP) addresses associated with the DB system. The Cluster Ready Services (CRS) creates and maintains one VIP address for each node in the DB system to enable failover. If one node fails, the VIP is reassigned to another active node in the cluster.

Note: For a single-node DB system, this list is empty.

Returns:

  • (Array<String>)


220
221
222
# File 'lib/oci/database/models/db_system_summary.rb', line 220

def vip_ids
  @vip_ids
end

#zone_idString

The OCID of the zone the DB system is associated with.

Returns:

  • (String)


235
236
237
# File 'lib/oci/database/models/db_system_summary.rb', line 235

def zone_id
  @zone_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/oci/database/models/db_system_summary.rb', line 291

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'availability_domain': :'availabilityDomain',
    'fault_domains': :'faultDomains',
    'subnet_id': :'subnetId',
    'backup_subnet_id': :'backupSubnetId',
    'nsg_ids': :'nsgIds',
    'backup_network_nsg_ids': :'backupNetworkNsgIds',
    'shape': :'shape',
    'db_system_options': :'dbSystemOptions',
    'ssh_public_keys': :'sshPublicKeys',
    'time_zone': :'timeZone',
    'hostname': :'hostname',
    'domain': :'domain',
    'kms_key_id': :'kmsKeyId',
    'version': :'version',
    'cpu_core_count': :'cpuCoreCount',
    'cluster_name': :'clusterName',
    'data_storage_percentage': :'dataStoragePercentage',
    'database_edition': :'databaseEdition',
    'last_patch_history_entry_id': :'lastPatchHistoryEntryId',
    'listener_port': :'listenerPort',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'lifecycle_details': :'lifecycleDetails',
    'disk_redundancy': :'diskRedundancy',
    'sparse_diskgroup': :'sparseDiskgroup',
    'scan_ip_ids': :'scanIpIds',
    'vip_ids': :'vipIds',
    'scan_dns_record_id': :'scanDnsRecordId',
    'scan_dns_name': :'scanDnsName',
    'zone_id': :'zoneId',
    'data_storage_size_in_gbs': :'dataStorageSizeInGBs',
    'reco_storage_size_in_gb': :'recoStorageSizeInGB',
    'node_count': :'nodeCount',
    'license_model': :'licenseModel',
    'maintenance_window': :'maintenanceWindow',
    'last_maintenance_run_id': :'lastMaintenanceRunId',
    'next_maintenance_run_id': :'nextMaintenanceRunId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'source_db_system_id': :'sourceDbSystemId',
    'point_in_time_data_disk_clone_timestamp': :'pointInTimeDataDiskCloneTimestamp'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/oci/database/models/db_system_summary.rb', line 343

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'availability_domain': :'String',
    'fault_domains': :'Array<String>',
    'subnet_id': :'String',
    'backup_subnet_id': :'String',
    'nsg_ids': :'Array<String>',
    'backup_network_nsg_ids': :'Array<String>',
    'shape': :'String',
    'db_system_options': :'OCI::Database::Models::DbSystemOptions',
    'ssh_public_keys': :'Array<String>',
    'time_zone': :'String',
    'hostname': :'String',
    'domain': :'String',
    'kms_key_id': :'String',
    'version': :'String',
    'cpu_core_count': :'Integer',
    'cluster_name': :'String',
    'data_storage_percentage': :'Integer',
    'database_edition': :'String',
    'last_patch_history_entry_id': :'String',
    'listener_port': :'Integer',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'lifecycle_details': :'String',
    'disk_redundancy': :'String',
    'sparse_diskgroup': :'BOOLEAN',
    'scan_ip_ids': :'Array<String>',
    'vip_ids': :'Array<String>',
    'scan_dns_record_id': :'String',
    'scan_dns_name': :'String',
    'zone_id': :'String',
    'data_storage_size_in_gbs': :'Integer',
    'reco_storage_size_in_gb': :'Integer',
    'node_count': :'Integer',
    'license_model': :'String',
    'maintenance_window': :'OCI::Database::Models::MaintenanceWindow',
    'last_maintenance_run_id': :'String',
    'next_maintenance_run_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'source_db_system_id': :'String',
    'point_in_time_data_disk_clone_timestamp': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
# File 'lib/oci/database/models/db_system_summary.rb', line 754

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    availability_domain == other.availability_domain &&
    fault_domains == other.fault_domains &&
    subnet_id == other.subnet_id &&
    backup_subnet_id == other.backup_subnet_id &&
    nsg_ids == other.nsg_ids &&
    backup_network_nsg_ids == other.backup_network_nsg_ids &&
    shape == other.shape &&
    db_system_options == other.db_system_options &&
    ssh_public_keys == other.ssh_public_keys &&
    time_zone == other.time_zone &&
    hostname == other.hostname &&
    domain == other.domain &&
    kms_key_id == other.kms_key_id &&
    version == other.version &&
    cpu_core_count == other.cpu_core_count &&
    cluster_name == other.cluster_name &&
    data_storage_percentage == other.data_storage_percentage &&
    database_edition == other.database_edition &&
    last_patch_history_entry_id == other.last_patch_history_entry_id &&
    listener_port == other.listener_port &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    lifecycle_details == other.lifecycle_details &&
    disk_redundancy == other.disk_redundancy &&
    sparse_diskgroup == other.sparse_diskgroup &&
    scan_ip_ids == other.scan_ip_ids &&
    vip_ids == other.vip_ids &&
    scan_dns_record_id == other.scan_dns_record_id &&
    scan_dns_name == other.scan_dns_name &&
    zone_id == other.zone_id &&
    data_storage_size_in_gbs == other.data_storage_size_in_gbs &&
    reco_storage_size_in_gb == other.reco_storage_size_in_gb &&
    node_count == other.node_count &&
    license_model == other.license_model &&
    maintenance_window == other.maintenance_window &&
    last_maintenance_run_id == other.last_maintenance_run_id &&
    next_maintenance_run_id == other.next_maintenance_run_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    source_db_system_id == other.source_db_system_id &&
    point_in_time_data_disk_clone_timestamp == other.point_in_time_data_disk_clone_timestamp
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
# File 'lib/oci/database/models/db_system_summary.rb', line 827

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


807
808
809
# File 'lib/oci/database/models/db_system_summary.rb', line 807

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



816
817
818
# File 'lib/oci/database/models/db_system_summary.rb', line 816

def hash
  [id, compartment_id, display_name, availability_domain, fault_domains, subnet_id, backup_subnet_id, nsg_ids, backup_network_nsg_ids, shape, db_system_options, ssh_public_keys, time_zone, hostname, domain, kms_key_id, version, cpu_core_count, cluster_name, data_storage_percentage, database_edition, last_patch_history_entry_id, listener_port, lifecycle_state, time_created, lifecycle_details, disk_redundancy, sparse_diskgroup, scan_ip_ids, vip_ids, scan_dns_record_id, scan_dns_name, zone_id, data_storage_size_in_gbs, reco_storage_size_in_gb, node_count, license_model, maintenance_window, last_maintenance_run_id, next_maintenance_run_id, freeform_tags, defined_tags, source_db_system_id, point_in_time_data_disk_clone_timestamp].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



860
861
862
863
864
865
866
867
868
869
# File 'lib/oci/database/models/db_system_summary.rb', line 860

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



854
855
856
# File 'lib/oci/database/models/db_system_summary.rb', line 854

def to_s
  to_hash.to_s
end