Class: OCI::Database::Models::DbSystemUpgradeHistoryEntry
- Inherits:
-
Object
- Object
- OCI::Database::Models::DbSystemUpgradeHistoryEntry
- Defined in:
- lib/oci/database/models/db_system_upgrade_history_entry.rb
Overview
The record of an OS upgrade action on a DB system.
*Warning:* Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- ACTION_ENUM =
[ ACTION_PRECHECK = 'PRECHECK'.freeze, ACTION_ROLLBACK = 'ROLLBACK'.freeze, ACTION_UPDATE_SNAPSHOT_RETENTION_DAYS = 'UPDATE_SNAPSHOT_RETENTION_DAYS'.freeze, ACTION_UPGRADE = 'UPGRADE'.freeze, ACTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action ⇒ String
**[Required]** The operating system upgrade action.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the upgrade history entry.
-
#lifecycle_details ⇒ String
A descriptive text associated with the lifecycleState.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the action.
-
#new_gi_version ⇒ String
**[Required]** A valid Oracle Grid Infrastructure (GI) software version.
-
#old_gi_version ⇒ String
**[Required]** A valid Oracle Grid Infrastructure (GI) software version.
-
#snapshot_retention_period_in_days ⇒ Integer
**[Required]** The retention period, in days, for the snapshot that allows you to perform a rollback of the upgrade operation.
-
#time_ended ⇒ DateTime
The date and time when the upgrade action completed.
-
#time_started ⇒ DateTime
**[Required]** The date and time when the upgrade action started.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbSystemUpgradeHistoryEntry
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbSystemUpgradeHistoryEntry
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 117 def initialize(attributes = {}) return unless attributes.is_a?(Hash) self.id = attributes[:'id'] if attributes[:'id'] self.action = attributes[:'action'] if attributes[:'action'] self.new_gi_version = attributes[:'newGiVersion'] if attributes[:'newGiVersion'] raise 'You cannot provide both :newGiVersion and :new_gi_version' if attributes.key?(:'newGiVersion') && attributes.key?(:'new_gi_version') self.new_gi_version = attributes[:'new_gi_version'] if attributes[:'new_gi_version'] self.old_gi_version = attributes[:'oldGiVersion'] if attributes[:'oldGiVersion'] raise 'You cannot provide both :oldGiVersion and :old_gi_version' if attributes.key?(:'oldGiVersion') && attributes.key?(:'old_gi_version') self.old_gi_version = attributes[:'old_gi_version'] if attributes[:'old_gi_version'] self.snapshot_retention_period_in_days = attributes[:'snapshotRetentionPeriodInDays'] if attributes[:'snapshotRetentionPeriodInDays'] raise 'You cannot provide both :snapshotRetentionPeriodInDays and :snapshot_retention_period_in_days' if attributes.key?(:'snapshotRetentionPeriodInDays') && attributes.key?(:'snapshot_retention_period_in_days') self.snapshot_retention_period_in_days = attributes[:'snapshot_retention_period_in_days'] if attributes[:'snapshot_retention_period_in_days'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded'] raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended') self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended'] end |
Instance Attribute Details
#action ⇒ String
**[Required]** The operating system upgrade action.
36 37 38 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 36 def action @action end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the upgrade history entry.
32 33 34 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 32 def id @id end |
#lifecycle_details ⇒ String
A descriptive text associated with the lifecycleState. Typically contains additional displayable text.
58 59 60 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 58 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the action.
52 53 54 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 52 def lifecycle_state @lifecycle_state end |
#new_gi_version ⇒ String
**[Required]** A valid Oracle Grid Infrastructure (GI) software version.
40 41 42 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 40 def new_gi_version @new_gi_version end |
#old_gi_version ⇒ String
**[Required]** A valid Oracle Grid Infrastructure (GI) software version.
44 45 46 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 44 def old_gi_version @old_gi_version end |
#snapshot_retention_period_in_days ⇒ Integer
**[Required]** The retention period, in days, for the snapshot that allows you to perform a rollback of the upgrade operation. After this number of days passes, you cannot roll back the upgrade.
48 49 50 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 48 def snapshot_retention_period_in_days @snapshot_retention_period_in_days end |
#time_ended ⇒ DateTime
The date and time when the upgrade action completed
66 67 68 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 66 def time_ended @time_ended end |
#time_started ⇒ DateTime
**[Required]** The date and time when the upgrade action started.
62 63 64 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 62 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'action': :'action', 'new_gi_version': :'newGiVersion', 'old_gi_version': :'oldGiVersion', 'snapshot_retention_period_in_days': :'snapshotRetentionPeriodInDays', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_started': :'timeStarted', 'time_ended': :'timeEnded' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 86 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'action': :'String', 'new_gi_version': :'String', 'old_gi_version': :'String', 'snapshot_retention_period_in_days': :'Integer', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_started': :'DateTime', 'time_ended': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 200 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && action == other.action && new_gi_version == other.new_gi_version && old_gi_version == other.old_gi_version && snapshot_retention_period_in_days == other.snapshot_retention_period_in_days && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_started == other.time_started && time_ended == other.time_ended end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 238 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
218 219 220 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 218 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 227 def hash [id, action, new_gi_version, old_gi_version, snapshot_retention_period_in_days, lifecycle_state, lifecycle_details, time_started, time_ended].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
265 266 267 |
# File 'lib/oci/database/models/db_system_upgrade_history_entry.rb', line 265 def to_s to_hash.to_s end |