Class: OCI::Database::Models::ExadataInfrastructureSummary
- Inherits:
-
Object
- Object
- OCI::Database::Models::ExadataInfrastructureSummary
- Defined in:
- lib/oci/database/models/exadata_infrastructure_summary.rb
Overview
Details of the Exadata Cloud@Customer infrastructure. Applies to Exadata Cloud@Customer instances only. See cloud_exadata_infrastructure_summary for details of the cloud Exadata infrastructure resource used by Exadata Cloud Service instances.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_REQUIRES_ACTIVATION = 'REQUIRES_ACTIVATION'.freeze, LIFECYCLE_STATE_ACTIVATING = 'ACTIVATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_ACTIVATION_FAILED = 'ACTIVATION_FAILED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DISCONNECTED = 'DISCONNECTED'.freeze, LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- MAINTENANCE_SLO_STATUS_ENUM =
[ MAINTENANCE_SLO_STATUS_OK = 'OK'.freeze, MAINTENANCE_SLO_STATUS_DEGRADED = 'DEGRADED'.freeze, MAINTENANCE_SLO_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#activated_storage_count ⇒ Integer
The requested number of additional storage servers activated for the Exadata infrastructure.
-
#additional_storage_count ⇒ Integer
The requested number of additional storage servers for the Exadata infrastructure.
-
#admin_network_cidr ⇒ String
The CIDR block for the Exadata administration network.
-
#cloud_control_plane_server1 ⇒ String
The IP address for the first control plane server.
-
#cloud_control_plane_server2 ⇒ String
The IP address for the second control plane server.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#compute_count ⇒ Integer
The number of compute servers for the Exadata infrastructure.
-
#contacts ⇒ Array<OCI::Database::Models::ExadataInfrastructureContact>
The list of contacts for the Exadata infrastructure.
-
#corporate_proxy ⇒ String
The corporate network proxy for access to the control plane network.
-
#cpus_enabled ⇒ Integer
The number of enabled CPU cores.
-
#csi_number ⇒ String
The CSI Number of the Exadata infrastructure.
-
#data_storage_size_in_tbs ⇒ Float
Size, in terabytes, of the DATA disk group.
-
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage allocated in GBs.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] The user-friendly name for the Exadata Cloud@Customer infrastructure.
-
#dns_server ⇒ Array<String>
The list of DNS server IP addresses.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#gateway ⇒ String
The gateway for the control plane network.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.
-
#infini_band_network_cidr ⇒ String
The CIDR block for the Exadata InfiniBand interconnect.
-
#last_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
-
#lifecycle_state ⇒ String
[Required] The current lifecycle state of the Exadata infrastructure.
-
#maintenance_slo_status ⇒ String
A field to capture u2018Maintenance SLO Statusu2019 for the Exadata infrastructure with values u2018OKu2019, u2018DEGRADEDu2019.
- #maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
-
#max_cpu_count ⇒ Integer
The total number of CPU cores available.
-
#max_data_storage_in_t_bs ⇒ Float
The total available DATA disk group size.
-
#max_db_node_storage_in_g_bs ⇒ Integer
The total local node storage available in GBs.
-
#max_memory_in_gbs ⇒ Integer
The total memory available in GBs.
-
#memory_size_in_gbs ⇒ Integer
The memory allocated in GBs.
-
#netmask ⇒ String
The netmask for the control plane network.
-
#next_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.
-
#ntp_server ⇒ Array<String>
The list of NTP server IP addresses.
-
#shape ⇒ String
[Required] The shape of the Exadata infrastructure.
-
#storage_count ⇒ Integer
The number of Exadata storage servers for the Exadata infrastructure.
-
#time_created ⇒ DateTime
The date and time the Exadata infrastructure was created.
-
#time_zone ⇒ String
The time zone of the Exadata infrastructure.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExadataInfrastructureSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ExadataInfrastructureSummary
Initializes the object
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 322 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone'] raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone'] self.cpus_enabled = attributes[:'cpusEnabled'] if attributes[:'cpusEnabled'] raise 'You cannot provide both :cpusEnabled and :cpus_enabled' if attributes.key?(:'cpusEnabled') && attributes.key?(:'cpus_enabled') self.cpus_enabled = attributes[:'cpus_enabled'] if attributes[:'cpus_enabled'] self.max_cpu_count = attributes[:'maxCpuCount'] if attributes[:'maxCpuCount'] raise 'You cannot provide both :maxCpuCount and :max_cpu_count' if attributes.key?(:'maxCpuCount') && attributes.key?(:'max_cpu_count') self.max_cpu_count = attributes[:'max_cpu_count'] if attributes[:'max_cpu_count'] self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs'] raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs') self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs'] self.max_memory_in_gbs = attributes[:'maxMemoryInGBs'] if attributes[:'maxMemoryInGBs'] raise 'You cannot provide both :maxMemoryInGBs and :max_memory_in_gbs' if attributes.key?(:'maxMemoryInGBs') && attributes.key?(:'max_memory_in_gbs') self.max_memory_in_gbs = attributes[:'max_memory_in_gbs'] if attributes[:'max_memory_in_gbs'] self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs'] raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs') self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs'] self.max_db_node_storage_in_g_bs = attributes[:'maxDbNodeStorageInGBs'] if attributes[:'maxDbNodeStorageInGBs'] raise 'You cannot provide both :maxDbNodeStorageInGBs and :max_db_node_storage_in_g_bs' if attributes.key?(:'maxDbNodeStorageInGBs') && attributes.key?(:'max_db_node_storage_in_g_bs') self.max_db_node_storage_in_g_bs = attributes[:'max_db_node_storage_in_g_bs'] if attributes[:'max_db_node_storage_in_g_bs'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.max_data_storage_in_t_bs = attributes[:'maxDataStorageInTBs'] if attributes[:'maxDataStorageInTBs'] raise 'You cannot provide both :maxDataStorageInTBs and :max_data_storage_in_t_bs' if attributes.key?(:'maxDataStorageInTBs') && attributes.key?(:'max_data_storage_in_t_bs') self.max_data_storage_in_t_bs = attributes[:'max_data_storage_in_t_bs'] if attributes[:'max_data_storage_in_t_bs'] self.storage_count = attributes[:'storageCount'] if attributes[:'storageCount'] raise 'You cannot provide both :storageCount and :storage_count' if attributes.key?(:'storageCount') && attributes.key?(:'storage_count') self.storage_count = attributes[:'storage_count'] if attributes[:'storage_count'] self.additional_storage_count = attributes[:'additionalStorageCount'] if attributes[:'additionalStorageCount'] raise 'You cannot provide both :additionalStorageCount and :additional_storage_count' if attributes.key?(:'additionalStorageCount') && attributes.key?(:'additional_storage_count') self.additional_storage_count = attributes[:'additional_storage_count'] if attributes[:'additional_storage_count'] self.activated_storage_count = attributes[:'activatedStorageCount'] if attributes[:'activatedStorageCount'] raise 'You cannot provide both :activatedStorageCount and :activated_storage_count' if attributes.key?(:'activatedStorageCount') && attributes.key?(:'activated_storage_count') self.activated_storage_count = attributes[:'activated_storage_count'] if attributes[:'activated_storage_count'] self.compute_count = attributes[:'computeCount'] if attributes[:'computeCount'] raise 'You cannot provide both :computeCount and :compute_count' if attributes.key?(:'computeCount') && attributes.key?(:'compute_count') self.compute_count = attributes[:'compute_count'] if attributes[:'compute_count'] self.cloud_control_plane_server1 = attributes[:'cloudControlPlaneServer1'] if attributes[:'cloudControlPlaneServer1'] raise 'You cannot provide both :cloudControlPlaneServer1 and :cloud_control_plane_server1' if attributes.key?(:'cloudControlPlaneServer1') && attributes.key?(:'cloud_control_plane_server1') self.cloud_control_plane_server1 = attributes[:'cloud_control_plane_server1'] if attributes[:'cloud_control_plane_server1'] self.cloud_control_plane_server2 = attributes[:'cloudControlPlaneServer2'] if attributes[:'cloudControlPlaneServer2'] raise 'You cannot provide both :cloudControlPlaneServer2 and :cloud_control_plane_server2' if attributes.key?(:'cloudControlPlaneServer2') && attributes.key?(:'cloud_control_plane_server2') self.cloud_control_plane_server2 = attributes[:'cloud_control_plane_server2'] if attributes[:'cloud_control_plane_server2'] self.netmask = attributes[:'netmask'] if attributes[:'netmask'] self.gateway = attributes[:'gateway'] if attributes[:'gateway'] self.admin_network_cidr = attributes[:'adminNetworkCIDR'] if attributes[:'adminNetworkCIDR'] raise 'You cannot provide both :adminNetworkCIDR and :admin_network_cidr' if attributes.key?(:'adminNetworkCIDR') && attributes.key?(:'admin_network_cidr') self.admin_network_cidr = attributes[:'admin_network_cidr'] if attributes[:'admin_network_cidr'] self.infini_band_network_cidr = attributes[:'infiniBandNetworkCIDR'] if attributes[:'infiniBandNetworkCIDR'] raise 'You cannot provide both :infiniBandNetworkCIDR and :infini_band_network_cidr' if attributes.key?(:'infiniBandNetworkCIDR') && attributes.key?(:'infini_band_network_cidr') self.infini_band_network_cidr = attributes[:'infini_band_network_cidr'] if attributes[:'infini_band_network_cidr'] self.corporate_proxy = attributes[:'corporateProxy'] if attributes[:'corporateProxy'] raise 'You cannot provide both :corporateProxy and :corporate_proxy' if attributes.key?(:'corporateProxy') && attributes.key?(:'corporate_proxy') self.corporate_proxy = attributes[:'corporate_proxy'] if attributes[:'corporate_proxy'] self.dns_server = attributes[:'dnsServer'] if attributes[:'dnsServer'] raise 'You cannot provide both :dnsServer and :dns_server' if attributes.key?(:'dnsServer') && attributes.key?(:'dns_server') self.dns_server = attributes[:'dns_server'] if attributes[:'dns_server'] self.ntp_server = attributes[:'ntpServer'] if attributes[:'ntpServer'] raise 'You cannot provide both :ntpServer and :ntp_server' if attributes.key?(:'ntpServer') && attributes.key?(:'ntp_server') self.ntp_server = attributes[:'ntp_server'] if attributes[:'ntp_server'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.csi_number = attributes[:'csiNumber'] if attributes[:'csiNumber'] raise 'You cannot provide both :csiNumber and :csi_number' if attributes.key?(:'csiNumber') && attributes.key?(:'csi_number') self.csi_number = attributes[:'csi_number'] if attributes[:'csi_number'] self.contacts = attributes[:'contacts'] if attributes[:'contacts'] self.maintenance_slo_status = attributes[:'maintenanceSLOStatus'] if attributes[:'maintenanceSLOStatus'] raise 'You cannot provide both :maintenanceSLOStatus and :maintenance_slo_status' if attributes.key?(:'maintenanceSLOStatus') && attributes.key?(:'maintenance_slo_status') self.maintenance_slo_status = attributes[:'maintenance_slo_status'] if attributes[:'maintenance_slo_status'] self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow'] raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window') self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window'] self.last_maintenance_run_id = attributes[:'lastMaintenanceRunId'] if attributes[:'lastMaintenanceRunId'] raise 'You cannot provide both :lastMaintenanceRunId and :last_maintenance_run_id' if attributes.key?(:'lastMaintenanceRunId') && attributes.key?(:'last_maintenance_run_id') self.last_maintenance_run_id = attributes[:'last_maintenance_run_id'] if attributes[:'last_maintenance_run_id'] self.next_maintenance_run_id = attributes[:'nextMaintenanceRunId'] if attributes[:'nextMaintenanceRunId'] raise 'You cannot provide both :nextMaintenanceRunId and :next_maintenance_run_id' if attributes.key?(:'nextMaintenanceRunId') && attributes.key?(:'next_maintenance_run_id') self.next_maintenance_run_id = attributes[:'next_maintenance_run_id'] if attributes[:'next_maintenance_run_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#activated_storage_count ⇒ Integer
The requested number of additional storage servers activated for the Exadata infrastructure.
102 103 104 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 102 def activated_storage_count @activated_storage_count end |
#additional_storage_count ⇒ Integer
The requested number of additional storage servers for the Exadata infrastructure.
98 99 100 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 98 def additional_storage_count @additional_storage_count end |
#admin_network_cidr ⇒ String
The CIDR block for the Exadata administration network.
126 127 128 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 126 def admin_network_cidr @admin_network_cidr end |
#cloud_control_plane_server1 ⇒ String
The IP address for the first control plane server.
110 111 112 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 110 def cloud_control_plane_server1 @cloud_control_plane_server1 end |
#cloud_control_plane_server2 ⇒ String
The IP address for the second control plane server.
114 115 116 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 114 def cloud_control_plane_server2 @cloud_control_plane_server2 end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
40 41 42 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 40 def compartment_id @compartment_id end |
#compute_count ⇒ Integer
The number of compute servers for the Exadata infrastructure.
106 107 108 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 106 def compute_count @compute_count end |
#contacts ⇒ Array<OCI::Database::Models::ExadataInfrastructureContact>
The list of contacts for the Exadata infrastructure.
158 159 160 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 158 def contacts @contacts end |
#corporate_proxy ⇒ String
The corporate network proxy for access to the control plane network.
134 135 136 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 134 def corporate_proxy @corporate_proxy end |
#cpus_enabled ⇒ Integer
The number of enabled CPU cores.
61 62 63 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 61 def cpus_enabled @cpus_enabled end |
#csi_number ⇒ String
The CSI Number of the Exadata infrastructure.
154 155 156 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 154 def csi_number @csi_number end |
#data_storage_size_in_tbs ⇒ Float
Size, in terabytes, of the DATA disk group.
86 87 88 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 86 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage allocated in GBs.
77 78 79 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 77 def db_node_storage_size_in_gbs @db_node_storage_size_in_gbs end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
187 188 189 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 187 def @defined_tags end |
#display_name ⇒ String
[Required] The user-friendly name for the Exadata Cloud@Customer infrastructure. The name does not need to be unique.
48 49 50 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 48 def display_name @display_name end |
#dns_server ⇒ Array<String>
The list of DNS server IP addresses. Maximum of 3 allowed.
138 139 140 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 138 def dns_server @dns_server end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
181 182 183 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 181 def @freeform_tags end |
#gateway ⇒ String
The gateway for the control plane network.
122 123 124 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 122 def gateway @gateway end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.
36 37 38 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 36 def id @id end |
#infini_band_network_cidr ⇒ String
The CIDR block for the Exadata InfiniBand interconnect.
130 131 132 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 130 def infini_band_network_cidr @infini_band_network_cidr end |
#last_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the last maintenance run.
169 170 171 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 169 def last_maintenance_run_id @last_maintenance_run_id end |
#lifecycle_details ⇒ String
Additional information about the current lifecycle state.
150 151 152 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 150 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current lifecycle state of the Exadata infrastructure.
44 45 46 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 44 def lifecycle_state @lifecycle_state end |
#maintenance_slo_status ⇒ String
A field to capture u2018Maintenance SLO Statusu2019 for the Exadata infrastructure with values u2018OKu2019, u2018DEGRADEDu2019. Default is u2018OKu2019 when the infrastructure is provisioned.
162 163 164 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 162 def maintenance_slo_status @maintenance_slo_status end |
#maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
165 166 167 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 165 def maintenance_window @maintenance_window end |
#max_cpu_count ⇒ Integer
The total number of CPU cores available.
65 66 67 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 65 def max_cpu_count @max_cpu_count end |
#max_data_storage_in_t_bs ⇒ Float
The total available DATA disk group size.
90 91 92 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 90 def max_data_storage_in_t_bs @max_data_storage_in_t_bs end |
#max_db_node_storage_in_g_bs ⇒ Integer
The total local node storage available in GBs.
81 82 83 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 81 def max_db_node_storage_in_g_bs @max_db_node_storage_in_g_bs end |
#max_memory_in_gbs ⇒ Integer
The total memory available in GBs.
73 74 75 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 73 def max_memory_in_gbs @max_memory_in_gbs end |
#memory_size_in_gbs ⇒ Integer
The memory allocated in GBs.
69 70 71 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 69 def memory_size_in_gbs @memory_size_in_gbs end |
#netmask ⇒ String
The netmask for the control plane network.
118 119 120 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 118 def netmask @netmask end |
#next_maintenance_run_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the next maintenance run.
173 174 175 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 173 def next_maintenance_run_id @next_maintenance_run_id end |
#ntp_server ⇒ Array<String>
The list of NTP server IP addresses. Maximum of 3 allowed.
142 143 144 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 142 def ntp_server @ntp_server end |
#shape ⇒ String
[Required] The shape of the Exadata infrastructure. The shape determines the amount of CPU, storage, and memory resources allocated to the instance.
53 54 55 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 53 def shape @shape end |
#storage_count ⇒ Integer
The number of Exadata storage servers for the Exadata infrastructure.
94 95 96 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 94 def storage_count @storage_count end |
#time_created ⇒ DateTime
The date and time the Exadata infrastructure was created.
146 147 148 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 146 def time_created @time_created end |
#time_zone ⇒ String
The time zone of the Exadata infrastructure. For details, see [Exadata Infrastructure Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).
57 58 59 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 57 def time_zone @time_zone end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 190 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'display_name': :'displayName', 'shape': :'shape', 'time_zone': :'timeZone', 'cpus_enabled': :'cpusEnabled', 'max_cpu_count': :'maxCpuCount', 'memory_size_in_gbs': :'memorySizeInGBs', 'max_memory_in_gbs': :'maxMemoryInGBs', 'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs', 'max_db_node_storage_in_g_bs': :'maxDbNodeStorageInGBs', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'max_data_storage_in_t_bs': :'maxDataStorageInTBs', 'storage_count': :'storageCount', 'additional_storage_count': :'additionalStorageCount', 'activated_storage_count': :'activatedStorageCount', 'compute_count': :'computeCount', 'cloud_control_plane_server1': :'cloudControlPlaneServer1', 'cloud_control_plane_server2': :'cloudControlPlaneServer2', 'netmask': :'netmask', 'gateway': :'gateway', 'admin_network_cidr': :'adminNetworkCIDR', 'infini_band_network_cidr': :'infiniBandNetworkCIDR', 'corporate_proxy': :'corporateProxy', 'dns_server': :'dnsServer', 'ntp_server': :'ntpServer', 'time_created': :'timeCreated', 'lifecycle_details': :'lifecycleDetails', 'csi_number': :'csiNumber', 'contacts': :'contacts', 'maintenance_slo_status': :'maintenanceSLOStatus', 'maintenance_window': :'maintenanceWindow', 'last_maintenance_run_id': :'lastMaintenanceRunId', 'next_maintenance_run_id': :'nextMaintenanceRunId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 235 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'display_name': :'String', 'shape': :'String', 'time_zone': :'String', 'cpus_enabled': :'Integer', 'max_cpu_count': :'Integer', 'memory_size_in_gbs': :'Integer', 'max_memory_in_gbs': :'Integer', 'db_node_storage_size_in_gbs': :'Integer', 'max_db_node_storage_in_g_bs': :'Integer', 'data_storage_size_in_tbs': :'Float', 'max_data_storage_in_t_bs': :'Float', 'storage_count': :'Integer', 'additional_storage_count': :'Integer', 'activated_storage_count': :'Integer', 'compute_count': :'Integer', 'cloud_control_plane_server1': :'String', 'cloud_control_plane_server2': :'String', 'netmask': :'String', 'gateway': :'String', 'admin_network_cidr': :'String', 'infini_band_network_cidr': :'String', 'corporate_proxy': :'String', 'dns_server': :'Array<String>', 'ntp_server': :'Array<String>', 'time_created': :'DateTime', 'lifecycle_details': :'String', 'csi_number': :'String', 'contacts': :'Array<OCI::Database::Models::ExadataInfrastructureContact>', 'maintenance_slo_status': :'String', 'maintenance_window': :'OCI::Database::Models::MaintenanceWindow', 'last_maintenance_run_id': :'String', 'next_maintenance_run_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 564 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && display_name == other.display_name && shape == other.shape && time_zone == other.time_zone && cpus_enabled == other.cpus_enabled && max_cpu_count == other.max_cpu_count && memory_size_in_gbs == other.memory_size_in_gbs && max_memory_in_gbs == other.max_memory_in_gbs && db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs && max_db_node_storage_in_g_bs == other.max_db_node_storage_in_g_bs && data_storage_size_in_tbs == other.data_storage_size_in_tbs && max_data_storage_in_t_bs == other.max_data_storage_in_t_bs && storage_count == other.storage_count && additional_storage_count == other.additional_storage_count && activated_storage_count == other.activated_storage_count && compute_count == other.compute_count && cloud_control_plane_server1 == other.cloud_control_plane_server1 && cloud_control_plane_server2 == other.cloud_control_plane_server2 && netmask == other.netmask && gateway == other.gateway && admin_network_cidr == other.admin_network_cidr && infini_band_network_cidr == other.infini_band_network_cidr && corporate_proxy == other.corporate_proxy && dns_server == other.dns_server && ntp_server == other.ntp_server && time_created == other.time_created && lifecycle_details == other.lifecycle_details && csi_number == other.csi_number && contacts == other.contacts && maintenance_slo_status == other.maintenance_slo_status && maintenance_window == other.maintenance_window && last_maintenance_run_id == other.last_maintenance_run_id && next_maintenance_run_id == other.next_maintenance_run_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 630 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
610 611 612 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 610 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
619 620 621 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 619 def hash [id, compartment_id, lifecycle_state, display_name, shape, time_zone, cpus_enabled, max_cpu_count, memory_size_in_gbs, max_memory_in_gbs, db_node_storage_size_in_gbs, max_db_node_storage_in_g_bs, data_storage_size_in_tbs, max_data_storage_in_t_bs, storage_count, additional_storage_count, activated_storage_count, compute_count, cloud_control_plane_server1, cloud_control_plane_server2, netmask, gateway, admin_network_cidr, infini_band_network_cidr, corporate_proxy, dns_server, ntp_server, time_created, lifecycle_details, csi_number, contacts, maintenance_slo_status, maintenance_window, last_maintenance_run_id, next_maintenance_run_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
663 664 665 666 667 668 669 670 671 672 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 663 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
657 658 659 |
# File 'lib/oci/database/models/exadata_infrastructure_summary.rb', line 657 def to_s to_hash.to_s end |