Class: OCI::Database::Models::RemoteClonePluggableDatabaseDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::RemoteClonePluggableDatabaseDetails
- Defined in:
- lib/oci/database/models/remote_clone_pluggable_database_details.rb
Overview
Parameters for cloning a pluggable database (PDB) in a remote database (CDB). A remote CDB is one that does not contain the source PDB.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Instance Attribute Summary collapse
-
#cloned_pdb_name ⇒ String
[Required] The name for the pluggable database (PDB).
-
#pdb_admin_password ⇒ String
[Required] A strong password for PDB Admin of the newly cloned PDB.
-
#source_container_db_admin_password ⇒ String
[Required] The DB system administrator password of the source CDB.
-
#target_container_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the target CDB.
-
#target_tde_wallet_password ⇒ String
[Required] The existing TDE wallet password of the target CDB.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RemoteClonePluggableDatabaseDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RemoteClonePluggableDatabaseDetails
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 70 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.target_container_database_id = attributes[:'targetContainerDatabaseId'] if attributes[:'targetContainerDatabaseId'] raise 'You cannot provide both :targetContainerDatabaseId and :target_container_database_id' if attributes.key?(:'targetContainerDatabaseId') && attributes.key?(:'target_container_database_id') self.target_container_database_id = attributes[:'target_container_database_id'] if attributes[:'target_container_database_id'] self.source_container_db_admin_password = attributes[:'sourceContainerDbAdminPassword'] if attributes[:'sourceContainerDbAdminPassword'] raise 'You cannot provide both :sourceContainerDbAdminPassword and :source_container_db_admin_password' if attributes.key?(:'sourceContainerDbAdminPassword') && attributes.key?(:'source_container_db_admin_password') self.source_container_db_admin_password = attributes[:'source_container_db_admin_password'] if attributes[:'source_container_db_admin_password'] self.cloned_pdb_name = attributes[:'clonedPdbName'] if attributes[:'clonedPdbName'] raise 'You cannot provide both :clonedPdbName and :cloned_pdb_name' if attributes.key?(:'clonedPdbName') && attributes.key?(:'cloned_pdb_name') self.cloned_pdb_name = attributes[:'cloned_pdb_name'] if attributes[:'cloned_pdb_name'] self.pdb_admin_password = attributes[:'pdbAdminPassword'] if attributes[:'pdbAdminPassword'] raise 'You cannot provide both :pdbAdminPassword and :pdb_admin_password' if attributes.key?(:'pdbAdminPassword') && attributes.key?(:'pdb_admin_password') self.pdb_admin_password = attributes[:'pdb_admin_password'] if attributes[:'pdb_admin_password'] self.target_tde_wallet_password = attributes[:'targetTdeWalletPassword'] if attributes[:'targetTdeWalletPassword'] raise 'You cannot provide both :targetTdeWalletPassword and :target_tde_wallet_password' if attributes.key?(:'targetTdeWalletPassword') && attributes.key?(:'target_tde_wallet_password') self.target_tde_wallet_password = attributes[:'target_tde_wallet_password'] if attributes[:'target_tde_wallet_password'] end |
Instance Attribute Details
#cloned_pdb_name ⇒ String
[Required] The name for the pluggable database (PDB). The name is unique in the context of a Database. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.
23 24 25 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 23 def cloned_pdb_name @cloned_pdb_name end |
#pdb_admin_password ⇒ String
[Required] A strong password for PDB Admin of the newly cloned PDB. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \#, or -.
27 28 29 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 27 def pdb_admin_password @pdb_admin_password end |
#source_container_db_admin_password ⇒ String
[Required] The DB system administrator password of the source CDB.
19 20 21 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 19 def source_container_db_admin_password @source_container_db_admin_password end |
#target_container_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the target CDB
15 16 17 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 15 def target_container_database_id @target_container_database_id end |
#target_tde_wallet_password ⇒ String
[Required] The existing TDE wallet password of the target CDB.
31 32 33 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 31 def target_tde_wallet_password @target_tde_wallet_password end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'target_container_database_id': :'targetContainerDatabaseId', 'source_container_db_admin_password': :'sourceContainerDbAdminPassword', 'cloned_pdb_name': :'clonedPdbName', 'pdb_admin_password': :'pdbAdminPassword', 'target_tde_wallet_password': :'targetTdeWalletPassword' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 47 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'target_container_database_id': :'String', 'source_container_db_admin_password': :'String', 'cloned_pdb_name': :'String', 'pdb_admin_password': :'String', 'target_tde_wallet_password': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 114 def ==(other) return true if equal?(other) self.class == other.class && target_container_database_id == other.target_container_database_id && source_container_db_admin_password == other.source_container_db_admin_password && cloned_pdb_name == other.cloned_pdb_name && pdb_admin_password == other.pdb_admin_password && target_tde_wallet_password == other.target_tde_wallet_password end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 148 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
128 129 130 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 128 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
137 138 139 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 137 def hash [target_container_database_id, source_container_db_admin_password, cloned_pdb_name, pdb_admin_password, target_tde_wallet_password].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 181 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
175 176 177 |
# File 'lib/oci/database/models/remote_clone_pluggable_database_details.rb', line 175 def to_s to_hash.to_s end |