Class: OCI::Database::Models::SelfMountDetails

Inherits:
MountTypeDetails show all
Defined in:
lib/oci/database/models/self_mount_details.rb

Overview

Used for creating NFS Self mount backup destinations for non-autonomous ExaCC.

Constant Summary

Constants inherited from MountTypeDetails

MountTypeDetails::MOUNT_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from MountTypeDetails

#mount_type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from MountTypeDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ SelfMountDetails

Initializes the object

Options Hash (attributes):



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/oci/database/models/self_mount_details.rb', line 43

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['mountType'] = 'SELF_MOUNT'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.local_mount_point_path = attributes[:'localMountPointPath'] if attributes[:'localMountPointPath']

  raise 'You cannot provide both :localMountPointPath and :local_mount_point_path' if attributes.key?(:'localMountPointPath') && attributes.key?(:'local_mount_point_path')

  self.local_mount_point_path = attributes[:'local_mount_point_path'] if attributes[:'local_mount_point_path']
end

Instance Attribute Details

#local_mount_point_pathString

[Required] The local directory path on each VM cluster node where the NFS server location is mounted. The local directory path and the NFS server location must each be the same across all of the VM cluster nodes. Ensure that the NFS mount is maintained continuously on all of the VM cluster nodes.



14
15
16
# File 'lib/oci/database/models/self_mount_details.rb', line 14

def local_mount_point_path
  @local_mount_point_path
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



17
18
19
20
21
22
23
24
# File 'lib/oci/database/models/self_mount_details.rb', line 17

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'mount_type': :'mountType',
    'local_mount_point_path': :'localMountPointPath'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



27
28
29
30
31
32
33
34
# File 'lib/oci/database/models/self_mount_details.rb', line 27

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'mount_type': :'String',
    'local_mount_point_path': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



67
68
69
70
71
72
73
# File 'lib/oci/database/models/self_mount_details.rb', line 67

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    mount_type == other.mount_type &&
    local_mount_point_path == other.local_mount_point_path
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/database/models/self_mount_details.rb', line 98

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


78
79
80
# File 'lib/oci/database/models/self_mount_details.rb', line 78

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



87
88
89
# File 'lib/oci/database/models/self_mount_details.rb', line 87

def hash
  [mount_type, local_mount_point_path].hash
end

#to_hashHash

Returns the object in the form of hash



131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/database/models/self_mount_details.rb', line 131

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



125
126
127
# File 'lib/oci/database/models/self_mount_details.rb', line 125

def to_s
  to_hash.to_s
end