Class: OCI::Database::Models::UpdateAutonomousDatabaseDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::UpdateAutonomousDatabaseDetails
- Defined in:
- lib/oci/database/models/update_autonomous_database_details.rb
Overview
Details to update an Oracle Autonomous Database.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#admin_password ⇒ String
The password must be between 12 and 30 characters long, and must contain at least 1 uppercase, 1 lowercase, and 1 numeric character.
-
#cpu_core_count ⇒ Integer
The number of CPU cores to be made available to the database.
-
#data_storage_size_in_tbs ⇒ Integer
The size, in terabytes, of the data volume that will be attached to the database.
-
#db_name ⇒ String
New name for this Autonomous Database.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The user-friendly name for the Autonomous Database.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#is_auto_scaling_enabled ⇒ BOOLEAN
Indicates if auto scaling is enabled for the Autonomous Database CPU core count.
-
#license_model ⇒ String
The new Oracle license model that applies to the Oracle Autonomous Transaction Processing database.
-
#whitelisted_ips ⇒ Array<String>
The client IP access control list (ACL).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAutonomousDatabaseDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAutonomousDatabaseDetails
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 123 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.admin_password = attributes[:'adminPassword'] if attributes[:'adminPassword'] raise 'You cannot provide both :adminPassword and :admin_password' if attributes.key?(:'adminPassword') && attributes.key?(:'admin_password') self.admin_password = attributes[:'admin_password'] if attributes[:'admin_password'] self.db_name = attributes[:'dbName'] if attributes[:'dbName'] raise 'You cannot provide both :dbName and :db_name' if attributes.key?(:'dbName') && attributes.key?(:'db_name') self.db_name = attributes[:'db_name'] if attributes[:'db_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.whitelisted_ips = attributes[:'whitelistedIps'] if attributes[:'whitelistedIps'] raise 'You cannot provide both :whitelistedIps and :whitelisted_ips' if attributes.key?(:'whitelistedIps') && attributes.key?(:'whitelisted_ips') self.whitelisted_ips = attributes[:'whitelisted_ips'] if attributes[:'whitelisted_ips'] self.is_auto_scaling_enabled = attributes[:'isAutoScalingEnabled'] unless attributes[:'isAutoScalingEnabled'].nil? raise 'You cannot provide both :isAutoScalingEnabled and :is_auto_scaling_enabled' if attributes.key?(:'isAutoScalingEnabled') && attributes.key?(:'is_auto_scaling_enabled') self.is_auto_scaling_enabled = attributes[:'is_auto_scaling_enabled'] unless attributes[:'is_auto_scaling_enabled'].nil? end |
Instance Attribute Details
#admin_password ⇒ String
The password must be between 12 and 30 characters long, and must contain at least 1 uppercase, 1 lowercase, and 1 numeric character. It cannot contain the double quote symbol (") or the username "admin", regardless of casing. It must be different from the last four passwords and it must not be a password used within the last 24 hours.
32 33 34 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 32 def admin_password @admin_password end |
#cpu_core_count ⇒ Integer
The number of CPU cores to be made available to the database.
19 20 21 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 19 def cpu_core_count @cpu_core_count end |
#data_storage_size_in_tbs ⇒ Integer
The size, in terabytes, of the data volume that will be attached to the database.
24 25 26 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 24 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_name ⇒ String
New name for this Autonomous Database. It must begin with an alphabetic character and can contain a maximum of eight alphanumeric characters. Special characters are not permitted. This is valid only for dedicated databases.
39 40 41 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 39 def db_name @db_name end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
55 56 57 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 55 def end |
#display_name ⇒ String
The user-friendly name for the Autonomous Database. The name does not have to be unique.
28 29 30 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 28 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
47 48 49 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 47 def end |
#is_auto_scaling_enabled ⇒ BOOLEAN
Indicates if auto scaling is enabled for the Autonomous Database CPU core count. The default value is false.
69 70 71 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 69 def is_auto_scaling_enabled @is_auto_scaling_enabled end |
#license_model ⇒ String
The new Oracle license model that applies to the Oracle Autonomous Transaction Processing database.
60 61 62 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 60 def license_model @license_model end |
#whitelisted_ips ⇒ Array<String>
The client IP access control list (ACL). Only clients connecting from an IP address included in the ACL may access the Autonomous Database instance. This is an array of CIDR (Classless Inter-Domain Routing) notations for a subnet. To delete all the existing white listed IPu2019s, use an array with a single empty string entry.
64 65 66 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 64 def whitelisted_ips @whitelisted_ips end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 72 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cpu_core_count': :'cpuCoreCount', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'display_name': :'displayName', 'admin_password': :'adminPassword', 'db_name': :'dbName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'license_model': :'licenseModel', 'whitelisted_ips': :'whitelistedIps', 'is_auto_scaling_enabled': :'isAutoScalingEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 90 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cpu_core_count': :'Integer', 'data_storage_size_in_tbs': :'Integer', 'display_name': :'String', 'admin_password': :'String', 'db_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'license_model': :'String', 'whitelisted_ips': :'Array<String>', 'is_auto_scaling_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 205 def ==(other) return true if equal?(other) self.class == other.class && cpu_core_count == other.cpu_core_count && data_storage_size_in_tbs == other.data_storage_size_in_tbs && display_name == other.display_name && admin_password == other.admin_password && db_name == other.db_name && == other. && == other. && license_model == other.license_model && whitelisted_ips == other.whitelisted_ips && is_auto_scaling_enabled == other.is_auto_scaling_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 244 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
224 225 226 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 224 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 233 def hash [cpu_core_count, data_storage_size_in_tbs, display_name, admin_password, db_name, , , license_model, whitelisted_ips, is_auto_scaling_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
277 278 279 280 281 282 283 284 285 286 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 277 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
271 272 273 |
# File 'lib/oci/database/models/update_autonomous_database_details.rb', line 271 def to_s to_hash.to_s end |