Class: OCI::Database::Models::UpdateCloudExadataInfrastructureDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::UpdateCloudExadataInfrastructureDetails
- Defined in:
- lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb
Overview
Updates the cloud Exadata infrastructure. Applies to Exadata Cloud Service instances only.
Instance Attribute Summary collapse
-
#compute_count ⇒ Integer
The number of compute servers for the cloud Exadata infrastructure.
-
#customer_contacts ⇒ Array<OCI::Database::Models::CustomerContact>
Customer contacts.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The user-friendly name for the cloud Exadata infrastructure.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
- #maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
-
#storage_count ⇒ Integer
The number of storage servers for the cloud Exadata infrastructure.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCloudExadataInfrastructureDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCloudExadataInfrastructureDetails
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow'] raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window') self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window'] self.compute_count = attributes[:'computeCount'] if attributes[:'computeCount'] raise 'You cannot provide both :computeCount and :compute_count' if attributes.key?(:'computeCount') && attributes.key?(:'compute_count') self.compute_count = attributes[:'compute_count'] if attributes[:'compute_count'] self.storage_count = attributes[:'storageCount'] if attributes[:'storageCount'] raise 'You cannot provide both :storageCount and :storage_count' if attributes.key?(:'storageCount') && attributes.key?(:'storage_count') self.storage_count = attributes[:'storage_count'] if attributes[:'storage_count'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.customer_contacts = attributes[:'customerContacts'] if attributes[:'customerContacts'] raise 'You cannot provide both :customerContacts and :customer_contacts' if attributes.key?(:'customerContacts') && attributes.key?(:'customer_contacts') self.customer_contacts = attributes[:'customer_contacts'] if attributes[:'customer_contacts'] end |
Instance Attribute Details
#compute_count ⇒ Integer
The number of compute servers for the cloud Exadata infrastructure.
21 22 23 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 21 def compute_count @compute_count end |
#customer_contacts ⇒ Array<OCI::Database::Models::CustomerContact>
Customer contacts. Setting this to an empty list removes all customer contact information (email addresses) for the specified OCI Database service resource.
43 44 45 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 43 def customer_contacts @customer_contacts end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
39 40 41 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 39 def @defined_tags end |
#display_name ⇒ String
The user-friendly name for the cloud Exadata infrastructure. The name does not need to be unique.
14 15 16 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 14 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
33 34 35 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 33 def @freeform_tags end |
#maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
17 18 19 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 17 def maintenance_window @maintenance_window end |
#storage_count ⇒ Integer
The number of storage servers for the cloud Exadata infrastructure.
25 26 27 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 25 def storage_count @storage_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 46 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'maintenance_window': :'maintenanceWindow', 'compute_count': :'computeCount', 'storage_count': :'storageCount', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'customer_contacts': :'customerContacts' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'maintenance_window': :'OCI::Database::Models::MaintenanceWindow', 'compute_count': :'Integer', 'storage_count': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'customer_contacts': :'Array<OCI::Database::Models::CustomerContact>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 144 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && maintenance_window == other.maintenance_window && compute_count == other.compute_count && storage_count == other.storage_count && == other. && == other. && customer_contacts == other.customer_contacts end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 180 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
160 161 162 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 160 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
169 170 171 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 169 def hash [display_name, maintenance_window, compute_count, storage_count, , , customer_contacts].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
207 208 209 |
# File 'lib/oci/database/models/update_cloud_exadata_infrastructure_details.rb', line 207 def to_s to_hash.to_s end |