Class: OCI::Database::Models::UpdateCloudVmClusterDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::UpdateCloudVmClusterDetails
- Defined in:
- lib/oci/database/models/update_cloud_vm_cluster_details.rb
Overview
Details for updating the cloud VM cluster. Applies to Exadata Cloud Service instances only.
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#backup_network_nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that the backup network of this DB system belongs to.
-
#compute_nodes ⇒ Array<String>
The list of compute servers to be added to the cloud VM cluster.
-
#cpu_core_count ⇒ Integer
The number of CPU cores to enable for the cloud VM cluster.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The user-friendly name for the cloud VM cluster.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#license_model ⇒ String
The Oracle license model that applies to the cloud VM cluster.
-
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to.
-
#ocpu_count ⇒ Float
The number of OCPU cores to enable for a cloud VM cluster.
-
#ssh_public_keys ⇒ Array<String>
The public key portion of one or more key pairs used for SSH access to the cloud VM cluster.
-
#storage_size_in_gbs ⇒ Integer
The disk group size to be allocated in GBs.
- #update_details ⇒ OCI::Database::Models::UpdateDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCloudVmClusterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCloudVmClusterDetails
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 133 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.ocpu_count = attributes[:'ocpuCount'] if attributes[:'ocpuCount'] raise 'You cannot provide both :ocpuCount and :ocpu_count' if attributes.key?(:'ocpuCount') && attributes.key?(:'ocpu_count') self.ocpu_count = attributes[:'ocpu_count'] if attributes[:'ocpu_count'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys'] raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys') self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys'] self.update_details = attributes[:'updateDetails'] if attributes[:'updateDetails'] raise 'You cannot provide both :updateDetails and :update_details' if attributes.key?(:'updateDetails') && attributes.key?(:'update_details') self.update_details = attributes[:'update_details'] if attributes[:'update_details'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.backup_network_nsg_ids = attributes[:'backupNetworkNsgIds'] if attributes[:'backupNetworkNsgIds'] raise 'You cannot provide both :backupNetworkNsgIds and :backup_network_nsg_ids' if attributes.key?(:'backupNetworkNsgIds') && attributes.key?(:'backup_network_nsg_ids') self.backup_network_nsg_ids = attributes[:'backup_network_nsg_ids'] if attributes[:'backup_network_nsg_ids'] self.compute_nodes = attributes[:'computeNodes'] if attributes[:'computeNodes'] raise 'You cannot provide both :computeNodes and :compute_nodes' if attributes.key?(:'computeNodes') && attributes.key?(:'compute_nodes') self.compute_nodes = attributes[:'compute_nodes'] if attributes[:'compute_nodes'] self.storage_size_in_gbs = attributes[:'storageSizeInGBs'] if attributes[:'storageSizeInGBs'] raise 'You cannot provide both :storageSizeInGBs and :storage_size_in_gbs' if attributes.key?(:'storageSizeInGBs') && attributes.key?(:'storage_size_in_gbs') self.storage_size_in_gbs = attributes[:'storage_size_in_gbs'] if attributes[:'storage_size_in_gbs'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#backup_network_nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). Applicable only to Exadata systems.
51 52 53 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 51 def backup_network_nsg_ids @backup_network_nsg_ids end |
#compute_nodes ⇒ Array<String>
The list of compute servers to be added to the cloud VM cluster.
55 56 57 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 55 def compute_nodes @compute_nodes end |
#cpu_core_count ⇒ Integer
The number of CPU cores to enable for the cloud VM cluster.
23 24 25 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 23 def cpu_core_count @cpu_core_count end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
73 74 75 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 73 def @defined_tags end |
#display_name ⇒ String
The user-friendly name for the cloud VM cluster. The name does not need to be unique.
19 20 21 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 19 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
67 68 69 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 67 def @freeform_tags end |
#license_model ⇒ String
The Oracle license model that applies to the cloud VM cluster. The default is BRING_YOUR_OWN_LICENSE. Applies to Exadata Cloud Service instances only.
32 33 34 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 32 def license_model @license_model end |
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**
-
Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.
46 47 48 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 46 def nsg_ids @nsg_ids end |
#ocpu_count ⇒ Float
The number of OCPU cores to enable for a cloud VM cluster. Only 1 decimal place is allowed for the fractional part.
27 28 29 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 27 def ocpu_count @ocpu_count end |
#ssh_public_keys ⇒ Array<String>
The public key portion of one or more key pairs used for SSH access to the cloud VM cluster.
36 37 38 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 36 def ssh_public_keys @ssh_public_keys end |
#storage_size_in_gbs ⇒ Integer
The disk group size to be allocated in GBs.
59 60 61 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 59 def storage_size_in_gbs @storage_size_in_gbs end |
#update_details ⇒ OCI::Database::Models::UpdateDetails
39 40 41 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 39 def update_details @update_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'cpu_core_count': :'cpuCoreCount', 'ocpu_count': :'ocpuCount', 'license_model': :'licenseModel', 'ssh_public_keys': :'sshPublicKeys', 'update_details': :'updateDetails', 'nsg_ids': :'nsgIds', 'backup_network_nsg_ids': :'backupNetworkNsgIds', 'compute_nodes': :'computeNodes', 'storage_size_in_gbs': :'storageSizeInGBs', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 96 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'cpu_core_count': :'Integer', 'ocpu_count': :'Float', 'license_model': :'String', 'ssh_public_keys': :'Array<String>', 'update_details': :'OCI::Database::Models::UpdateDetails', 'nsg_ids': :'Array<String>', 'backup_network_nsg_ids': :'Array<String>', 'compute_nodes': :'Array<String>', 'storage_size_in_gbs': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 227 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && cpu_core_count == other.cpu_core_count && ocpu_count == other.ocpu_count && license_model == other.license_model && ssh_public_keys == other.ssh_public_keys && update_details == other.update_details && nsg_ids == other.nsg_ids && backup_network_nsg_ids == other.backup_network_nsg_ids && compute_nodes == other.compute_nodes && storage_size_in_gbs == other.storage_size_in_gbs && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 268 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
248 249 250 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 248 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 257 def hash [display_name, cpu_core_count, ocpu_count, license_model, ssh_public_keys, update_details, nsg_ids, backup_network_nsg_ids, compute_nodes, storage_size_in_gbs, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
301 302 303 304 305 306 307 308 309 310 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 301 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
295 296 297 |
# File 'lib/oci/database/models/update_cloud_vm_cluster_details.rb', line 295 def to_s to_hash.to_s end |