Class: OCI::Database::Models::UpdateDataGuardAssociationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/update_data_guard_association_details.rb

Overview

The configuration details for updating a Data Guard association for a database.

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

PROTECTION_MODE_ENUM =
[
  PROTECTION_MODE_MAXIMUM_AVAILABILITY = 'MAXIMUM_AVAILABILITY'.freeze,
  PROTECTION_MODE_MAXIMUM_PERFORMANCE = 'MAXIMUM_PERFORMANCE'.freeze,
  PROTECTION_MODE_MAXIMUM_PROTECTION = 'MAXIMUM_PROTECTION'.freeze
].freeze
TRANSPORT_TYPE_ENUM =
[
  TRANSPORT_TYPE_SYNC = 'SYNC'.freeze,
  TRANSPORT_TYPE_ASYNC = 'ASYNC'.freeze,
  TRANSPORT_TYPE_FASTSYNC = 'FASTSYNC'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateDataGuardAssociationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 92

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.database_admin_password = attributes[:'databaseAdminPassword'] if attributes[:'databaseAdminPassword']

  raise 'You cannot provide both :databaseAdminPassword and :database_admin_password' if attributes.key?(:'databaseAdminPassword') && attributes.key?(:'database_admin_password')

  self.database_admin_password = attributes[:'database_admin_password'] if attributes[:'database_admin_password']

  self.protection_mode = attributes[:'protectionMode'] if attributes[:'protectionMode']

  raise 'You cannot provide both :protectionMode and :protection_mode' if attributes.key?(:'protectionMode') && attributes.key?(:'protection_mode')

  self.protection_mode = attributes[:'protection_mode'] if attributes[:'protection_mode']

  self.transport_type = attributes[:'transportType'] if attributes[:'transportType']

  raise 'You cannot provide both :transportType and :transport_type' if attributes.key?(:'transportType') && attributes.key?(:'transport_type')

  self.transport_type = attributes[:'transport_type'] if attributes[:'transport_type']
end

Instance Attribute Details

#database_admin_passwordString

A strong password for the ‘SYS’, ‘SYSTEM’, and ‘PDB Admin’ users to apply during standby creation.

The password must contain no fewer than nine characters and include:

  • At least two uppercase characters.

  • At least two lowercase characters.

  • At least two numeric characters.

  • At least two special characters. Valid special characters include "_", "#", and "-" only.

**The password MUST be the same as the primary admin password.**

Returns:

  • (String)


40
41
42
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 40

def database_admin_password
  @database_admin_password
end

#protection_modeString

The protection mode for the Data Guard association’s primary and standby database. For more information, see [Oracle Data Guard Protection Modes](docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000) in the Oracle Data Guard documentation.

Returns:

  • (String)


47
48
49
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 47

def protection_mode
  @protection_mode
end

#transport_typeString

The redo transport type to use for this Data Guard association. Valid values depend on the specified ‘protectionMode’:

  • MAXIMUM_AVAILABILITY - Use SYNC or FASTSYNC

  • MAXIMUM_PERFORMANCE - Use ASYNC

  • MAXIMUM_PROTECTION - Use SYNC

For more information, see [Redo Transport Services](docs.oracle.com/database/122/SBYDB/oracle-data-guard-redo-transport-services.htm#SBYDB00400) in the Oracle Data Guard documentation.

Returns:

  • (String)


59
60
61
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 59

def transport_type
  @transport_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 62

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'database_admin_password': :'databaseAdminPassword',
    'protection_mode': :'protectionMode',
    'transport_type': :'transportType'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 73

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'database_admin_password': :'String',
    'protection_mode': :'String',
    'transport_type': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



140
141
142
143
144
145
146
147
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 140

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    database_admin_password == other.database_admin_password &&
    protection_mode == other.protection_mode &&
    transport_type == other.transport_type
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 172

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 152

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



161
162
163
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 161

def hash
  [database_admin_password, protection_mode, transport_type].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



199
200
201
# File 'lib/oci/database/models/update_data_guard_association_details.rb', line 199

def to_s
  to_hash.to_s
end