Class: OCI::Database::Models::UpdateDbSystemDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::UpdateDbSystemDetails
- Defined in:
- lib/oci/database/models/update_db_system_details.rb
Overview
Describes the parameters for updating the DB system.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#backup_network_nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that the backup network of this DB system belongs to.
-
#cpu_core_count ⇒ Integer
The new number of CPU cores to set for the DB system.
-
#data_storage_size_in_gbs ⇒ Integer
The size, in gigabytes, to scale the attached storage up to for this virtual machine DB system.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#license_model ⇒ String
The Oracle Database license model that applies to all databases on the DB system.
- #maintenance_window_details ⇒ OCI::Database::Models::MaintenanceWindow
-
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to.
-
#reco_storage_size_in_gbs ⇒ Integer
The size, in gigabytes, to scale the attached RECO storage up to for this virtual machine DB system.
-
#shape ⇒ String
The shape of the DB system.
-
#ssh_public_keys ⇒ Array<String>
The public key portion of the key pair to use for SSH access to the DB system.
- #version ⇒ OCI::Database::Models::PatchDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateDbSystemDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateDbSystemDetails
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 139 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.version = attributes[:'version'] if attributes[:'version'] self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys'] raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys') self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.reco_storage_size_in_gbs = attributes[:'recoStorageSizeInGBs'] if attributes[:'recoStorageSizeInGBs'] raise 'You cannot provide both :recoStorageSizeInGBs and :reco_storage_size_in_gbs' if attributes.key?(:'recoStorageSizeInGBs') && attributes.key?(:'reco_storage_size_in_gbs') self.reco_storage_size_in_gbs = attributes[:'reco_storage_size_in_gbs'] if attributes[:'reco_storage_size_in_gbs'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.backup_network_nsg_ids = attributes[:'backupNetworkNsgIds'] if attributes[:'backupNetworkNsgIds'] raise 'You cannot provide both :backupNetworkNsgIds and :backup_network_nsg_ids' if attributes.key?(:'backupNetworkNsgIds') && attributes.key?(:'backup_network_nsg_ids') self.backup_network_nsg_ids = attributes[:'backup_network_nsg_ids'] if attributes[:'backup_network_nsg_ids'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.maintenance_window_details = attributes[:'maintenanceWindowDetails'] if attributes[:'maintenanceWindowDetails'] raise 'You cannot provide both :maintenanceWindowDetails and :maintenance_window_details' if attributes.key?(:'maintenanceWindowDetails') && attributes.key?(:'maintenance_window_details') self.maintenance_window_details = attributes[:'maintenance_window_details'] if attributes[:'maintenance_window_details'] end |
Instance Attribute Details
#backup_network_nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). Applicable only to Exadata systems.
71 72 73 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 71 def backup_network_nsg_ids @backup_network_nsg_ids end |
#cpu_core_count ⇒ Integer
The new number of CPU cores to set for the DB system. Not applicable for virtual machine DB systems.
20 21 22 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 20 def cpu_core_count @cpu_core_count end |
#data_storage_size_in_gbs ⇒ Integer
The size, in gigabytes, to scale the attached storage up to for this virtual machine DB system. This value must be greater than current storage size. Note that the resulting total storage size attached will be greater than the amount requested to allow for REDO/RECO space and software volume. Applies only to virtual machine DB systems.
32 33 34 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 32 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
51 52 53 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 51 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
45 46 47 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 45 def @freeform_tags end |
#license_model ⇒ String
The Oracle Database license model that applies to all databases on the DB system. The default is LICENSE_INCLUDED.
76 77 78 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 76 def license_model @license_model end |
#maintenance_window_details ⇒ OCI::Database::Models::MaintenanceWindow
79 80 81 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 79 def maintenance_window_details @maintenance_window_details end |
#nsg_ids ⇒ Array<String>
A list of the [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see [Security Rules](docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm). **NsgIds restrictions:**
-
Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.
66 67 68 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 66 def nsg_ids @nsg_ids end |
#reco_storage_size_in_gbs ⇒ Integer
The size, in gigabytes, to scale the attached RECO storage up to for this virtual machine DB system. This value must be greater than current storage size. Note that the resulting total storage size attached will be greater than the amount requested to allow for the software volume. Applies only to virtual machine DB systems.
37 38 39 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 37 def reco_storage_size_in_gbs @reco_storage_size_in_gbs end |
#shape ⇒ String
The shape of the DB system. The shape determines resources allocated to the DB system.
-
For virtual machine shapes, the number of CPU cores and memory
To get a list of shapes, use the list_db_system_shapes operation.
59 60 61 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 59 def shape @shape end |
#ssh_public_keys ⇒ Array<String>
The public key portion of the key pair to use for SSH access to the DB system. Multiple public keys can be provided. The length of the combined keys cannot exceed 40,000 characters.
27 28 29 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 27 def ssh_public_keys @ssh_public_keys end |
#version ⇒ OCI::Database::Models::PatchDetails
23 24 25 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 23 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 82 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cpu_core_count': :'cpuCoreCount', 'version': :'version', 'ssh_public_keys': :'sshPublicKeys', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'reco_storage_size_in_gbs': :'recoStorageSizeInGBs', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'shape': :'shape', 'nsg_ids': :'nsgIds', 'backup_network_nsg_ids': :'backupNetworkNsgIds', 'license_model': :'licenseModel', 'maintenance_window_details': :'maintenanceWindowDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 102 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cpu_core_count': :'Integer', 'version': :'OCI::Database::Models::PatchDetails', 'ssh_public_keys': :'Array<String>', 'data_storage_size_in_gbs': :'Integer', 'reco_storage_size_in_gbs': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'shape': :'String', 'nsg_ids': :'Array<String>', 'backup_network_nsg_ids': :'Array<String>', 'license_model': :'String', 'maintenance_window_details': :'OCI::Database::Models::MaintenanceWindow' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 225 def ==(other) return true if equal?(other) self.class == other.class && cpu_core_count == other.cpu_core_count && version == other.version && ssh_public_keys == other.ssh_public_keys && data_storage_size_in_gbs == other.data_storage_size_in_gbs && reco_storage_size_in_gbs == other.reco_storage_size_in_gbs && == other. && == other. && shape == other.shape && nsg_ids == other.nsg_ids && backup_network_nsg_ids == other.backup_network_nsg_ids && license_model == other.license_model && maintenance_window_details == other.maintenance_window_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 266 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
246 247 248 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 246 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 255 def hash [cpu_core_count, version, ssh_public_keys, data_storage_size_in_gbs, reco_storage_size_in_gbs, , , shape, nsg_ids, backup_network_nsg_ids, license_model, maintenance_window_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
293 294 295 |
# File 'lib/oci/database/models/update_db_system_details.rb', line 293 def to_s to_hash.to_s end |