Class: OCI::Database::Models::UpdateExadataInfrastructureDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::UpdateExadataInfrastructureDetails
- Defined in:
- lib/oci/database/models/update_exadata_infrastructure_details.rb
Overview
Updates the Exadata infrastructure. Applies to Exadata Cloud@Customer instances only. See update_cloud_exadata_infrastructure_details for information on updating Exadata Cloud Service cloud Exadata infrastructure resources.
Instance Attribute Summary collapse
-
#additional_storage_count ⇒ Integer
The requested number of additional storage servers for the Exadata infrastructure.
-
#admin_network_cidr ⇒ String
The CIDR block for the Exadata administration network.
-
#cloud_control_plane_server1 ⇒ String
The IP address for the first control plane server.
-
#cloud_control_plane_server2 ⇒ String
The IP address for the second control plane server.
-
#contacts ⇒ Array<OCI::Database::Models::ExadataInfrastructureContact>
The list of contacts for the Exadata infrastructure.
-
#corporate_proxy ⇒ String
The corporate network proxy for access to the control plane network.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#dns_server ⇒ Array<String>
The list of DNS server IP addresses.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#gateway ⇒ String
The gateway for the control plane network.
-
#infini_band_network_cidr ⇒ String
The CIDR block for the Exadata InfiniBand interconnect.
-
#is_cps_offline_report_enabled ⇒ BOOLEAN
Indicates whether cps offline diagnostic report is enabled for this Exadata infrastructure.
- #maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
-
#netmask ⇒ String
The netmask for the control plane network.
-
#ntp_server ⇒ Array<String>
The list of NTP server IP addresses.
-
#time_zone ⇒ String
The time zone of the Exadata infrastructure.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateExadataInfrastructureDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateExadataInfrastructureDetails
Initializes the object
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 155 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cloud_control_plane_server1 = attributes[:'cloudControlPlaneServer1'] if attributes[:'cloudControlPlaneServer1'] raise 'You cannot provide both :cloudControlPlaneServer1 and :cloud_control_plane_server1' if attributes.key?(:'cloudControlPlaneServer1') && attributes.key?(:'cloud_control_plane_server1') self.cloud_control_plane_server1 = attributes[:'cloud_control_plane_server1'] if attributes[:'cloud_control_plane_server1'] self.cloud_control_plane_server2 = attributes[:'cloudControlPlaneServer2'] if attributes[:'cloudControlPlaneServer2'] raise 'You cannot provide both :cloudControlPlaneServer2 and :cloud_control_plane_server2' if attributes.key?(:'cloudControlPlaneServer2') && attributes.key?(:'cloud_control_plane_server2') self.cloud_control_plane_server2 = attributes[:'cloud_control_plane_server2'] if attributes[:'cloud_control_plane_server2'] self.netmask = attributes[:'netmask'] if attributes[:'netmask'] self.gateway = attributes[:'gateway'] if attributes[:'gateway'] self.admin_network_cidr = attributes[:'adminNetworkCIDR'] if attributes[:'adminNetworkCIDR'] raise 'You cannot provide both :adminNetworkCIDR and :admin_network_cidr' if attributes.key?(:'adminNetworkCIDR') && attributes.key?(:'admin_network_cidr') self.admin_network_cidr = attributes[:'admin_network_cidr'] if attributes[:'admin_network_cidr'] self.infini_band_network_cidr = attributes[:'infiniBandNetworkCIDR'] if attributes[:'infiniBandNetworkCIDR'] raise 'You cannot provide both :infiniBandNetworkCIDR and :infini_band_network_cidr' if attributes.key?(:'infiniBandNetworkCIDR') && attributes.key?(:'infini_band_network_cidr') self.infini_band_network_cidr = attributes[:'infini_band_network_cidr'] if attributes[:'infini_band_network_cidr'] self.corporate_proxy = attributes[:'corporateProxy'] if attributes[:'corporateProxy'] raise 'You cannot provide both :corporateProxy and :corporate_proxy' if attributes.key?(:'corporateProxy') && attributes.key?(:'corporate_proxy') self.corporate_proxy = attributes[:'corporate_proxy'] if attributes[:'corporate_proxy'] self.contacts = attributes[:'contacts'] if attributes[:'contacts'] self.maintenance_window = attributes[:'maintenanceWindow'] if attributes[:'maintenanceWindow'] raise 'You cannot provide both :maintenanceWindow and :maintenance_window' if attributes.key?(:'maintenanceWindow') && attributes.key?(:'maintenance_window') self.maintenance_window = attributes[:'maintenance_window'] if attributes[:'maintenance_window'] self.additional_storage_count = attributes[:'additionalStorageCount'] if attributes[:'additionalStorageCount'] raise 'You cannot provide both :additionalStorageCount and :additional_storage_count' if attributes.key?(:'additionalStorageCount') && attributes.key?(:'additional_storage_count') self.additional_storage_count = attributes[:'additional_storage_count'] if attributes[:'additional_storage_count'] self.dns_server = attributes[:'dnsServer'] if attributes[:'dnsServer'] raise 'You cannot provide both :dnsServer and :dns_server' if attributes.key?(:'dnsServer') && attributes.key?(:'dns_server') self.dns_server = attributes[:'dns_server'] if attributes[:'dns_server'] self.ntp_server = attributes[:'ntpServer'] if attributes[:'ntpServer'] raise 'You cannot provide both :ntpServer and :ntp_server' if attributes.key?(:'ntpServer') && attributes.key?(:'ntp_server') self.ntp_server = attributes[:'ntp_server'] if attributes[:'ntp_server'] self.time_zone = attributes[:'timeZone'] if attributes[:'timeZone'] raise 'You cannot provide both :timeZone and :time_zone' if attributes.key?(:'timeZone') && attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] if attributes[:'time_zone'] self.is_cps_offline_report_enabled = attributes[:'isCpsOfflineReportEnabled'] unless attributes[:'isCpsOfflineReportEnabled'].nil? raise 'You cannot provide both :isCpsOfflineReportEnabled and :is_cps_offline_report_enabled' if attributes.key?(:'isCpsOfflineReportEnabled') && attributes.key?(:'is_cps_offline_report_enabled') self.is_cps_offline_report_enabled = attributes[:'is_cps_offline_report_enabled'] unless attributes[:'is_cps_offline_report_enabled'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#additional_storage_count ⇒ Integer
The requested number of additional storage servers for the Exadata infrastructure.
49 50 51 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 49 def additional_storage_count @additional_storage_count end |
#admin_network_cidr ⇒ String
The CIDR block for the Exadata administration network.
30 31 32 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 30 def admin_network_cidr @admin_network_cidr end |
#cloud_control_plane_server1 ⇒ String
The IP address for the first control plane server.
14 15 16 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 14 def cloud_control_plane_server1 @cloud_control_plane_server1 end |
#cloud_control_plane_server2 ⇒ String
The IP address for the second control plane server.
18 19 20 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 18 def cloud_control_plane_server2 @cloud_control_plane_server2 end |
#contacts ⇒ Array<OCI::Database::Models::ExadataInfrastructureContact>
The list of contacts for the Exadata infrastructure.
42 43 44 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 42 def contacts @contacts end |
#corporate_proxy ⇒ String
The corporate network proxy for access to the control plane network.
38 39 40 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 38 def corporate_proxy @corporate_proxy end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
83 84 85 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 83 def @defined_tags end |
#dns_server ⇒ Array<String>
The list of DNS server IP addresses. Maximum of 3 allowed.
53 54 55 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 53 def dns_server @dns_server end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
77 78 79 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 77 def @freeform_tags end |
#gateway ⇒ String
The gateway for the control plane network.
26 27 28 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 26 def gateway @gateway end |
#infini_band_network_cidr ⇒ String
The CIDR block for the Exadata InfiniBand interconnect.
34 35 36 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 34 def infini_band_network_cidr @infini_band_network_cidr end |
#is_cps_offline_report_enabled ⇒ BOOLEAN
Indicates whether cps offline diagnostic report is enabled for this Exadata infrastructure. This will allow a customer to quickly check status themselves and fix problems on their end, saving time and frustration for both Oracle and the customer when they find the CPS in a disconnected state.You can enable offline diagnostic report during Exadata infrastructure provisioning. You can also disable or enable it at any time using the UpdateExadatainfrastructure API.
69 70 71 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 69 def is_cps_offline_report_enabled @is_cps_offline_report_enabled end |
#maintenance_window ⇒ OCI::Database::Models::MaintenanceWindow
45 46 47 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 45 def maintenance_window @maintenance_window end |
#netmask ⇒ String
The netmask for the control plane network.
22 23 24 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 22 def netmask @netmask end |
#ntp_server ⇒ Array<String>
The list of NTP server IP addresses. Maximum of 3 allowed.
57 58 59 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 57 def ntp_server @ntp_server end |
#time_zone ⇒ String
The time zone of the Exadata infrastructure. For details, see [Exadata Infrastructure Time Zones](docs.cloud.oracle.com/Content/Database/References/timezones.htm).
62 63 64 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 62 def time_zone @time_zone end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 86 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cloud_control_plane_server1': :'cloudControlPlaneServer1', 'cloud_control_plane_server2': :'cloudControlPlaneServer2', 'netmask': :'netmask', 'gateway': :'gateway', 'admin_network_cidr': :'adminNetworkCIDR', 'infini_band_network_cidr': :'infiniBandNetworkCIDR', 'corporate_proxy': :'corporateProxy', 'contacts': :'contacts', 'maintenance_window': :'maintenanceWindow', 'additional_storage_count': :'additionalStorageCount', 'dns_server': :'dnsServer', 'ntp_server': :'ntpServer', 'time_zone': :'timeZone', 'is_cps_offline_report_enabled': :'isCpsOfflineReportEnabled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 110 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cloud_control_plane_server1': :'String', 'cloud_control_plane_server2': :'String', 'netmask': :'String', 'gateway': :'String', 'admin_network_cidr': :'String', 'infini_band_network_cidr': :'String', 'corporate_proxy': :'String', 'contacts': :'Array<OCI::Database::Models::ExadataInfrastructureContact>', 'maintenance_window': :'OCI::Database::Models::MaintenanceWindow', 'additional_storage_count': :'Integer', 'dns_server': :'Array<String>', 'ntp_server': :'Array<String>', 'time_zone': :'String', 'is_cps_offline_report_enabled': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 253 def ==(other) return true if equal?(other) self.class == other.class && cloud_control_plane_server1 == other.cloud_control_plane_server1 && cloud_control_plane_server2 == other.cloud_control_plane_server2 && netmask == other.netmask && gateway == other.gateway && admin_network_cidr == other.admin_network_cidr && infini_band_network_cidr == other.infini_band_network_cidr && corporate_proxy == other.corporate_proxy && contacts == other.contacts && maintenance_window == other.maintenance_window && additional_storage_count == other.additional_storage_count && dns_server == other.dns_server && ntp_server == other.ntp_server && time_zone == other.time_zone && is_cps_offline_report_enabled == other.is_cps_offline_report_enabled && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 298 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
278 279 280 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 278 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
287 288 289 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 287 def hash [cloud_control_plane_server1, cloud_control_plane_server2, netmask, gateway, admin_network_cidr, infini_band_network_cidr, corporate_proxy, contacts, maintenance_window, additional_storage_count, dns_server, ntp_server, time_zone, is_cps_offline_report_enabled, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
325 326 327 |
# File 'lib/oci/database/models/update_exadata_infrastructure_details.rb', line 325 def to_s to_hash.to_s end |