Class: OCI::Database::Models::UpdateMaintenanceRunDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::UpdateMaintenanceRunDetails
- Defined in:
- lib/oci/database/models/update_maintenance_run_details.rb
Overview
Describes the modification parameters for the maintenance run.
Constant Summary collapse
- PATCHING_MODE_ENUM =
[ PATCHING_MODE_ROLLING = 'ROLLING'.freeze, PATCHING_MODE_NONROLLING = 'NONROLLING'.freeze ].freeze
Instance Attribute Summary collapse
-
#current_custom_action_timeout_in_mins ⇒ Integer
The current custom action timeout between the current database servers during waiting state in addition to custom action timeout, from 0 (zero) to 30 minutes.
-
#custom_action_timeout_in_mins ⇒ Integer
Determines the amount of time the system will wait before the start of each database server patching operation.
-
#is_custom_action_timeout_enabled ⇒ BOOLEAN
If true, enables the configuration of a custom action timeout (waiting period) between database servers patching operations.
-
#is_enabled ⇒ BOOLEAN
If `FALSE`, skips the maintenance run.
-
#is_patch_now_enabled ⇒ BOOLEAN
If set to `TRUE`, starts patching immediately.
-
#is_resume_patching ⇒ BOOLEAN
If true, then the patching is resumed and the next component will be patched immediately.
-
#patch_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the patch to be applied in the maintenance run.
-
#patching_mode ⇒ String
Cloud Exadata infrastructure node patching method, either "ROLLING" or "NONROLLING".
-
#time_scheduled ⇒ DateTime
The scheduled date and time of the maintenance run to update.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateMaintenanceRunDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateMaintenanceRunDetails
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 106 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.time_scheduled = attributes[:'timeScheduled'] if attributes[:'timeScheduled'] raise 'You cannot provide both :timeScheduled and :time_scheduled' if attributes.key?(:'timeScheduled') && attributes.key?(:'time_scheduled') self.time_scheduled = attributes[:'time_scheduled'] if attributes[:'time_scheduled'] self.is_patch_now_enabled = attributes[:'isPatchNowEnabled'] unless attributes[:'isPatchNowEnabled'].nil? raise 'You cannot provide both :isPatchNowEnabled and :is_patch_now_enabled' if attributes.key?(:'isPatchNowEnabled') && attributes.key?(:'is_patch_now_enabled') self.is_patch_now_enabled = attributes[:'is_patch_now_enabled'] unless attributes[:'is_patch_now_enabled'].nil? self.patch_id = attributes[:'patchId'] if attributes[:'patchId'] raise 'You cannot provide both :patchId and :patch_id' if attributes.key?(:'patchId') && attributes.key?(:'patch_id') self.patch_id = attributes[:'patch_id'] if attributes[:'patch_id'] self.patching_mode = attributes[:'patchingMode'] if attributes[:'patchingMode'] raise 'You cannot provide both :patchingMode and :patching_mode' if attributes.key?(:'patchingMode') && attributes.key?(:'patching_mode') self.patching_mode = attributes[:'patching_mode'] if attributes[:'patching_mode'] self.is_custom_action_timeout_enabled = attributes[:'isCustomActionTimeoutEnabled'] unless attributes[:'isCustomActionTimeoutEnabled'].nil? raise 'You cannot provide both :isCustomActionTimeoutEnabled and :is_custom_action_timeout_enabled' if attributes.key?(:'isCustomActionTimeoutEnabled') && attributes.key?(:'is_custom_action_timeout_enabled') self.is_custom_action_timeout_enabled = attributes[:'is_custom_action_timeout_enabled'] unless attributes[:'is_custom_action_timeout_enabled'].nil? self.custom_action_timeout_in_mins = attributes[:'customActionTimeoutInMins'] if attributes[:'customActionTimeoutInMins'] raise 'You cannot provide both :customActionTimeoutInMins and :custom_action_timeout_in_mins' if attributes.key?(:'customActionTimeoutInMins') && attributes.key?(:'custom_action_timeout_in_mins') self.custom_action_timeout_in_mins = attributes[:'custom_action_timeout_in_mins'] if attributes[:'custom_action_timeout_in_mins'] self.current_custom_action_timeout_in_mins = attributes[:'currentCustomActionTimeoutInMins'] if attributes[:'currentCustomActionTimeoutInMins'] raise 'You cannot provide both :currentCustomActionTimeoutInMins and :current_custom_action_timeout_in_mins' if attributes.key?(:'currentCustomActionTimeoutInMins') && attributes.key?(:'current_custom_action_timeout_in_mins') self.current_custom_action_timeout_in_mins = attributes[:'current_custom_action_timeout_in_mins'] if attributes[:'current_custom_action_timeout_in_mins'] self.is_resume_patching = attributes[:'isResumePatching'] unless attributes[:'isResumePatching'].nil? raise 'You cannot provide both :isResumePatching and :is_resume_patching' if attributes.key?(:'isResumePatching') && attributes.key?(:'is_resume_patching') self.is_resume_patching = attributes[:'is_resume_patching'] unless attributes[:'is_resume_patching'].nil? end |
Instance Attribute Details
#current_custom_action_timeout_in_mins ⇒ Integer
The current custom action timeout between the current database servers during waiting state in addition to custom action timeout, from 0 (zero) to 30 minutes.
51 52 53 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 51 def current_custom_action_timeout_in_mins @current_custom_action_timeout_in_mins end |
#custom_action_timeout_in_mins ⇒ Integer
Determines the amount of time the system will wait before the start of each database server patching operation. Specify a number of minutes from 15 to 120.
47 48 49 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 47 def custom_action_timeout_in_mins @custom_action_timeout_in_mins end |
#is_custom_action_timeout_enabled ⇒ BOOLEAN
If true, enables the configuration of a custom action timeout (waiting period) between database servers patching operations.
41 42 43 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 41 def is_custom_action_timeout_enabled @is_custom_action_timeout_enabled end |
#is_enabled ⇒ BOOLEAN
If `FALSE`, skips the maintenance run.
18 19 20 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 18 def is_enabled @is_enabled end |
#is_patch_now_enabled ⇒ BOOLEAN
If set to `TRUE`, starts patching immediately.
26 27 28 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 26 def is_patch_now_enabled @is_patch_now_enabled end |
#is_resume_patching ⇒ BOOLEAN
If true, then the patching is resumed and the next component will be patched immediately.
55 56 57 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 55 def is_resume_patching @is_resume_patching end |
#patch_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the patch to be applied in the maintenance run.
30 31 32 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 30 def patch_id @patch_id end |
#patching_mode ⇒ String
Cloud Exadata infrastructure node patching method, either "ROLLING" or "NONROLLING". Default value is ROLLING.
IMPORTANT: Non-rolling infrastructure patching involves system down time. See [Oracle-Managed Infrastructure Maintenance Updates](docs.cloud.oracle.com/iaas/Content/Database/Concepts/examaintenance.htm#Oracle) for more information.
37 38 39 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 37 def patching_mode @patching_mode end |
#time_scheduled ⇒ DateTime
The scheduled date and time of the maintenance run to update.
22 23 24 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 22 def time_scheduled @time_scheduled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 58 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'is_enabled': :'isEnabled', 'time_scheduled': :'timeScheduled', 'is_patch_now_enabled': :'isPatchNowEnabled', 'patch_id': :'patchId', 'patching_mode': :'patchingMode', 'is_custom_action_timeout_enabled': :'isCustomActionTimeoutEnabled', 'custom_action_timeout_in_mins': :'customActionTimeoutInMins', 'current_custom_action_timeout_in_mins': :'currentCustomActionTimeoutInMins', 'is_resume_patching': :'isResumePatching' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'is_enabled': :'BOOLEAN', 'time_scheduled': :'DateTime', 'is_patch_now_enabled': :'BOOLEAN', 'patch_id': :'String', 'patching_mode': :'String', 'is_custom_action_timeout_enabled': :'BOOLEAN', 'custom_action_timeout_in_mins': :'Integer', 'current_custom_action_timeout_in_mins': :'Integer', 'is_resume_patching': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 182 def ==(other) return true if equal?(other) self.class == other.class && is_enabled == other.is_enabled && time_scheduled == other.time_scheduled && is_patch_now_enabled == other.is_patch_now_enabled && patch_id == other.patch_id && patching_mode == other.patching_mode && is_custom_action_timeout_enabled == other.is_custom_action_timeout_enabled && custom_action_timeout_in_mins == other.custom_action_timeout_in_mins && current_custom_action_timeout_in_mins == other.current_custom_action_timeout_in_mins && is_resume_patching == other.is_resume_patching end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 220 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
200 201 202 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 200 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
209 210 211 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 209 def hash [is_enabled, time_scheduled, is_patch_now_enabled, patch_id, patching_mode, is_custom_action_timeout_enabled, custom_action_timeout_in_mins, current_custom_action_timeout_in_mins, is_resume_patching].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
253 254 255 256 257 258 259 260 261 262 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 253 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
247 248 249 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 247 def to_s to_hash.to_s end |