Class: OCI::Database::Models::UpdateMaintenanceRunDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::UpdateMaintenanceRunDetails
- Defined in:
- lib/oci/database/models/update_maintenance_run_details.rb
Overview
Describes the modification parameters for the maintenance run.
Constant Summary collapse
- PATCHING_MODE_ENUM =
[ PATCHING_MODE_ROLLING = 'ROLLING'.freeze, PATCHING_MODE_NONROLLING = 'NONROLLING'.freeze ].freeze
Instance Attribute Summary collapse
-
#is_enabled ⇒ BOOLEAN
If
FALSE, skips the maintenance run. -
#is_patch_now_enabled ⇒ BOOLEAN
If set to
TRUE, starts patching immediately. -
#patch_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the patch to be applied in the maintenance run.
-
#patching_mode ⇒ String
Cloud Exadata infrastructure node patching method, either "ROLLING" or "NONROLLING".
-
#time_scheduled ⇒ DateTime
The scheduled date and time of the maintenance run to update.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateMaintenanceRunDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateMaintenanceRunDetails
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 76 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.time_scheduled = attributes[:'timeScheduled'] if attributes[:'timeScheduled'] raise 'You cannot provide both :timeScheduled and :time_scheduled' if attributes.key?(:'timeScheduled') && attributes.key?(:'time_scheduled') self.time_scheduled = attributes[:'time_scheduled'] if attributes[:'time_scheduled'] self.is_patch_now_enabled = attributes[:'isPatchNowEnabled'] unless attributes[:'isPatchNowEnabled'].nil? raise 'You cannot provide both :isPatchNowEnabled and :is_patch_now_enabled' if attributes.key?(:'isPatchNowEnabled') && attributes.key?(:'is_patch_now_enabled') self.is_patch_now_enabled = attributes[:'is_patch_now_enabled'] unless attributes[:'is_patch_now_enabled'].nil? self.patch_id = attributes[:'patchId'] if attributes[:'patchId'] raise 'You cannot provide both :patchId and :patch_id' if attributes.key?(:'patchId') && attributes.key?(:'patch_id') self.patch_id = attributes[:'patch_id'] if attributes[:'patch_id'] self.patching_mode = attributes[:'patchingMode'] if attributes[:'patchingMode'] raise 'You cannot provide both :patchingMode and :patching_mode' if attributes.key?(:'patchingMode') && attributes.key?(:'patching_mode') self.patching_mode = attributes[:'patching_mode'] if attributes[:'patching_mode'] end |
Instance Attribute Details
#is_enabled ⇒ BOOLEAN
If FALSE, skips the maintenance run.
18 19 20 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 18 def is_enabled @is_enabled end |
#is_patch_now_enabled ⇒ BOOLEAN
If set to TRUE, starts patching immediately.
26 27 28 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 26 def is_patch_now_enabled @is_patch_now_enabled end |
#patch_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the patch to be applied in the maintenance run.
30 31 32 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 30 def patch_id @patch_id end |
#patching_mode ⇒ String
Cloud Exadata infrastructure node patching method, either "ROLLING" or "NONROLLING". Default value is ROLLING.
IMPORTANT: Non-rolling infrastructure patching involves system down time. See [Oracle-Managed Infrastructure Maintenance Updates](docs.cloud.oracle.com/iaas/Content/Database/Concepts/examaintenance.htm#Oracle) for more information.
37 38 39 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 37 def patching_mode @patching_mode end |
#time_scheduled ⇒ DateTime
The scheduled date and time of the maintenance run to update.
22 23 24 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 22 def time_scheduled @time_scheduled end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'is_enabled': :'isEnabled', 'time_scheduled': :'timeScheduled', 'is_patch_now_enabled': :'isPatchNowEnabled', 'patch_id': :'patchId', 'patching_mode': :'patchingMode' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'is_enabled': :'BOOLEAN', 'time_scheduled': :'DateTime', 'is_patch_now_enabled': :'BOOLEAN', 'patch_id': :'String', 'patching_mode': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 128 def ==(other) return true if equal?(other) self.class == other.class && is_enabled == other.is_enabled && time_scheduled == other.time_scheduled && is_patch_now_enabled == other.is_patch_now_enabled && patch_id == other.patch_id && patching_mode == other.patching_mode end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 162 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
142 143 144 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 142 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 151 def hash [is_enabled, time_scheduled, is_patch_now_enabled, patch_id, patching_mode].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
189 190 191 |
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 189 def to_s to_hash.to_s end |