Class: OCI::Database::Models::UpdateMaintenanceRunDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database/models/update_maintenance_run_details.rb

Overview

Describes the modification parameters for the maintenance run.

Constant Summary collapse

PATCHING_MODE_ENUM =
[
  PATCHING_MODE_ROLLING = 'ROLLING'.freeze,
  PATCHING_MODE_NONROLLING = 'NONROLLING'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateMaintenanceRunDetails

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :is_enabled (BOOLEAN)

    The value to assign to the #is_enabled property

  • :time_scheduled (DateTime)

    The value to assign to the #time_scheduled property

  • :is_patch_now_enabled (BOOLEAN)

    The value to assign to the #is_patch_now_enabled property

  • :patch_id (String)

    The value to assign to the #patch_id property

  • :patching_mode (String)

    The value to assign to the #patching_mode property



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 73

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil?

  raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled')

  self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil?

  self.time_scheduled = attributes[:'timeScheduled'] if attributes[:'timeScheduled']

  raise 'You cannot provide both :timeScheduled and :time_scheduled' if attributes.key?(:'timeScheduled') && attributes.key?(:'time_scheduled')

  self.time_scheduled = attributes[:'time_scheduled'] if attributes[:'time_scheduled']

  self.is_patch_now_enabled = attributes[:'isPatchNowEnabled'] unless attributes[:'isPatchNowEnabled'].nil?

  raise 'You cannot provide both :isPatchNowEnabled and :is_patch_now_enabled' if attributes.key?(:'isPatchNowEnabled') && attributes.key?(:'is_patch_now_enabled')

  self.is_patch_now_enabled = attributes[:'is_patch_now_enabled'] unless attributes[:'is_patch_now_enabled'].nil?

  self.patch_id = attributes[:'patchId'] if attributes[:'patchId']

  raise 'You cannot provide both :patchId and :patch_id' if attributes.key?(:'patchId') && attributes.key?(:'patch_id')

  self.patch_id = attributes[:'patch_id'] if attributes[:'patch_id']

  self.patching_mode = attributes[:'patchingMode'] if attributes[:'patchingMode']

  raise 'You cannot provide both :patchingMode and :patching_mode' if attributes.key?(:'patchingMode') && attributes.key?(:'patching_mode')

  self.patching_mode = attributes[:'patching_mode'] if attributes[:'patching_mode']
end

Instance Attribute Details

#is_enabledBOOLEAN

If FALSE, skips the maintenance run.

Returns:



18
19
20
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 18

def is_enabled
  @is_enabled
end

#is_patch_now_enabledBOOLEAN

If set to TRUE, starts patching immediately.

Returns:



26
27
28
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 26

def is_patch_now_enabled
  @is_patch_now_enabled
end

#patch_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the patch to be applied in the maintenance run.

Returns:



30
31
32
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 30

def patch_id
  @patch_id
end

#patching_modeString

Maintenance method, it will be either "ROLLING" or "NONROLLING". Default value is ROLLING.

Returns:



34
35
36
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 34

def patching_mode
  @patching_mode
end

#time_scheduledDateTime

The scheduled date and time of the maintenance run to update.

Returns:



22
23
24
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 22

def time_scheduled
  @time_scheduled
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 37

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'is_enabled': :'isEnabled',
    'time_scheduled': :'timeScheduled',
    'is_patch_now_enabled': :'isPatchNowEnabled',
    'patch_id': :'patchId',
    'patching_mode': :'patchingMode'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 50

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'is_enabled': :'BOOLEAN',
    'time_scheduled': :'DateTime',
    'is_patch_now_enabled': :'BOOLEAN',
    'patch_id': :'String',
    'patching_mode': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



125
126
127
128
129
130
131
132
133
134
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 125

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    is_enabled == other.is_enabled &&
    time_scheduled == other.time_scheduled &&
    is_patch_now_enabled == other.is_patch_now_enabled &&
    patch_id == other.patch_id &&
    patching_mode == other.patching_mode
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 159

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


139
140
141
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 139

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



148
149
150
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 148

def hash
  [is_enabled, time_scheduled, is_patch_now_enabled, patch_id, patching_mode].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 192

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



186
187
188
# File 'lib/oci/database/models/update_maintenance_run_details.rb', line 186

def to_s
  to_hash.to_s
end