Class: OCI::Database::Models::UpdateVmClusterDetails
- Inherits:
-
Object
- Object
- OCI::Database::Models::UpdateVmClusterDetails
- Defined in:
- lib/oci/database/models/update_vm_cluster_details.rb
Overview
Details for updating the VM cluster. Applies to Exadata Cloud@Customer instances only. For details on updating a cloud VM cluster in an Exadata Cloud Service instance, see update_cloud_vm_cluster_details
Constant Summary collapse
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cpu_core_count ⇒ Integer
The number of CPU cores to enable for the VM cluster.
-
#data_storage_size_in_gbs ⇒ Float
The data disk group size to be allocated in GBs.
-
#data_storage_size_in_tbs ⇒ Float
The data disk group size to be allocated in TBs.
-
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage to be allocated in GBs.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#license_model ⇒ String
The Oracle license model that applies to the VM cluster.
-
#memory_size_in_gbs ⇒ Integer
The memory to be allocated in GBs.
-
#ocpu_count ⇒ Float
The number of OCPU cores to enable for the VM cluster.
-
#ssh_public_keys ⇒ Array<String>
The public key portion of one or more key pairs used for SSH access to the VM cluster.
- #update_details ⇒ OCI::Database::Models::VmClusterUpdateDetails
- #version ⇒ OCI::Database::Models::PatchDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateVmClusterDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateVmClusterDetails
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 128 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.ocpu_count = attributes[:'ocpuCount'] if attributes[:'ocpuCount'] raise 'You cannot provide both :ocpuCount and :ocpu_count' if attributes.key?(:'ocpuCount') && attributes.key?(:'ocpu_count') self.ocpu_count = attributes[:'ocpu_count'] if attributes[:'ocpu_count'] self.memory_size_in_gbs = attributes[:'memorySizeInGBs'] if attributes[:'memorySizeInGBs'] raise 'You cannot provide both :memorySizeInGBs and :memory_size_in_gbs' if attributes.key?(:'memorySizeInGBs') && attributes.key?(:'memory_size_in_gbs') self.memory_size_in_gbs = attributes[:'memory_size_in_gbs'] if attributes[:'memory_size_in_gbs'] self.db_node_storage_size_in_gbs = attributes[:'dbNodeStorageSizeInGBs'] if attributes[:'dbNodeStorageSizeInGBs'] raise 'You cannot provide both :dbNodeStorageSizeInGBs and :db_node_storage_size_in_gbs' if attributes.key?(:'dbNodeStorageSizeInGBs') && attributes.key?(:'db_node_storage_size_in_gbs') self.db_node_storage_size_in_gbs = attributes[:'db_node_storage_size_in_gbs'] if attributes[:'db_node_storage_size_in_gbs'] self.data_storage_size_in_tbs = attributes[:'dataStorageSizeInTBs'] if attributes[:'dataStorageSizeInTBs'] raise 'You cannot provide both :dataStorageSizeInTBs and :data_storage_size_in_tbs' if attributes.key?(:'dataStorageSizeInTBs') && attributes.key?(:'data_storage_size_in_tbs') self.data_storage_size_in_tbs = attributes[:'data_storage_size_in_tbs'] if attributes[:'data_storage_size_in_tbs'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.ssh_public_keys = attributes[:'sshPublicKeys'] if attributes[:'sshPublicKeys'] raise 'You cannot provide both :sshPublicKeys and :ssh_public_keys' if attributes.key?(:'sshPublicKeys') && attributes.key?(:'ssh_public_keys') self.ssh_public_keys = attributes[:'ssh_public_keys'] if attributes[:'ssh_public_keys'] self.version = attributes[:'version'] if attributes[:'version'] self.update_details = attributes[:'updateDetails'] if attributes[:'updateDetails'] raise 'You cannot provide both :updateDetails and :update_details' if attributes.key?(:'updateDetails') && attributes.key?(:'update_details') self.update_details = attributes[:'update_details'] if attributes[:'update_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#cpu_core_count ⇒ Integer
The number of CPU cores to enable for the VM cluster.
19 20 21 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 19 def cpu_core_count @cpu_core_count end |
#data_storage_size_in_gbs ⇒ Float
The data disk group size to be allocated in GBs.
39 40 41 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 39 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#data_storage_size_in_tbs ⇒ Float
The data disk group size to be allocated in TBs.
35 36 37 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 35 def data_storage_size_in_tbs @data_storage_size_in_tbs end |
#db_node_storage_size_in_gbs ⇒ Integer
The local node storage to be allocated in GBs.
31 32 33 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 31 def db_node_storage_size_in_gbs @db_node_storage_size_in_gbs end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
68 69 70 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 68 def @defined_tags end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
62 63 64 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 62 def @freeform_tags end |
#license_model ⇒ String
The Oracle license model that applies to the VM cluster. The default is BRING_YOUR_OWN_LICENSE.
44 45 46 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 44 def license_model @license_model end |
#memory_size_in_gbs ⇒ Integer
The memory to be allocated in GBs.
27 28 29 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 27 def memory_size_in_gbs @memory_size_in_gbs end |
#ocpu_count ⇒ Float
The number of OCPU cores to enable for the VM cluster. Only 1 decimal place is allowed for the fractional part.
23 24 25 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 23 def ocpu_count @ocpu_count end |
#ssh_public_keys ⇒ Array<String>
The public key portion of one or more key pairs used for SSH access to the VM cluster.
48 49 50 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 48 def ssh_public_keys @ssh_public_keys end |
#update_details ⇒ OCI::Database::Models::VmClusterUpdateDetails
54 55 56 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 54 def update_details @update_details end |
#version ⇒ OCI::Database::Models::PatchDetails
51 52 53 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 51 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 71 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cpu_core_count': :'cpuCoreCount', 'ocpu_count': :'ocpuCount', 'memory_size_in_gbs': :'memorySizeInGBs', 'db_node_storage_size_in_gbs': :'dbNodeStorageSizeInGBs', 'data_storage_size_in_tbs': :'dataStorageSizeInTBs', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'license_model': :'licenseModel', 'ssh_public_keys': :'sshPublicKeys', 'version': :'version', 'update_details': :'updateDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 91 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cpu_core_count': :'Integer', 'ocpu_count': :'Float', 'memory_size_in_gbs': :'Integer', 'db_node_storage_size_in_gbs': :'Integer', 'data_storage_size_in_tbs': :'Float', 'data_storage_size_in_gbs': :'Float', 'license_model': :'String', 'ssh_public_keys': :'Array<String>', 'version': :'OCI::Database::Models::PatchDetails', 'update_details': :'OCI::Database::Models::VmClusterUpdateDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 218 def ==(other) return true if equal?(other) self.class == other.class && cpu_core_count == other.cpu_core_count && ocpu_count == other.ocpu_count && memory_size_in_gbs == other.memory_size_in_gbs && db_node_storage_size_in_gbs == other.db_node_storage_size_in_gbs && data_storage_size_in_tbs == other.data_storage_size_in_tbs && data_storage_size_in_gbs == other.data_storage_size_in_gbs && license_model == other.license_model && ssh_public_keys == other.ssh_public_keys && version == other.version && update_details == other.update_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 259 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
239 240 241 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 239 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 248 def hash [cpu_core_count, ocpu_count, memory_size_in_gbs, db_node_storage_size_in_gbs, data_storage_size_in_tbs, data_storage_size_in_gbs, license_model, ssh_public_keys, version, update_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
286 287 288 |
# File 'lib/oci/database/models/update_vm_cluster_details.rb', line 286 def to_s to_hash.to_s end |