Class: OCI::DatabaseManagement::Models::ChildDatabase
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::ChildDatabase
- Defined in:
- lib/oci/database_management/models/child_database.rb
Overview
The child Managed Database of a Managed Database Group.
Constant Summary collapse
- DATABASE_TYPE_ENUM =
[ DATABASE_TYPE_EXTERNAL_SIDB = 'EXTERNAL_SIDB'.freeze, DATABASE_TYPE_EXTERNAL_RAC = 'EXTERNAL_RAC'.freeze, DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DATABASE_SUB_TYPE_ENUM =
[ DATABASE_SUB_TYPE_CDB = 'CDB'.freeze, DATABASE_SUB_TYPE_PDB = 'PDB'.freeze, DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze, DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the Managed Database resides.
-
#database_sub_type ⇒ String
The subtype of the Oracle Database.
-
#database_type ⇒ String
The type of Oracle Database installation.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database.
-
#name ⇒ String
[Required] The name of the Managed Database.
-
#time_added ⇒ DateTime
[Required] The date and time the Managed Database was added to the group.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChildDatabase
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ChildDatabase
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/database_management/models/child_database.rb', line 88 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType'] raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type') self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type'] self.time_added = attributes[:'timeAdded'] if attributes[:'timeAdded'] raise 'You cannot provide both :timeAdded and :time_added' if attributes.key?(:'timeAdded') && attributes.key?(:'time_added') self.time_added = attributes[:'time_added'] if attributes[:'time_added'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the Managed Database resides.
34 35 36 |
# File 'lib/oci/database_management/models/child_database.rb', line 34 def compartment_id @compartment_id end |
#database_sub_type ⇒ String
The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.
42 43 44 |
# File 'lib/oci/database_management/models/child_database.rb', line 42 def database_sub_type @database_sub_type end |
#database_type ⇒ String
The type of Oracle Database installation.
38 39 40 |
# File 'lib/oci/database_management/models/child_database.rb', line 38 def database_type @database_type end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database.
26 27 28 |
# File 'lib/oci/database_management/models/child_database.rb', line 26 def id @id end |
#name ⇒ String
[Required] The name of the Managed Database.
30 31 32 |
# File 'lib/oci/database_management/models/child_database.rb', line 30 def name @name end |
#time_added ⇒ DateTime
[Required] The date and time the Managed Database was added to the group.
46 47 48 |
# File 'lib/oci/database_management/models/child_database.rb', line 46 def time_added @time_added end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/database_management/models/child_database.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'compartment_id': :'compartmentId', 'database_type': :'databaseType', 'database_sub_type': :'databaseSubType', 'time_added': :'timeAdded' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/oci/database_management/models/child_database.rb', line 63 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'compartment_id': :'String', 'database_type': :'String', 'database_sub_type': :'String', 'time_added': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/database_management/models/child_database.rb', line 156 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && compartment_id == other.compartment_id && database_type == other.database_type && database_sub_type == other.database_sub_type && time_added == other.time_added end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/database_management/models/child_database.rb', line 191 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
171 172 173 |
# File 'lib/oci/database_management/models/child_database.rb', line 171 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/oci/database_management/models/child_database.rb', line 180 def hash [id, name, compartment_id, database_type, database_sub_type, time_added].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/database_management/models/child_database.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/oci/database_management/models/child_database.rb', line 218 def to_s to_hash.to_s end |