Class: OCI::DatabaseManagement::Models::CreateJobDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::CreateJobDetails
- Defined in:
- lib/oci/database_management/models/create_job_details.rb
Overview
The details required to create a job. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- DATABASE_SUB_TYPE_ENUM =
[ DATABASE_SUB_TYPE_CDB = 'CDB'.freeze, DATABASE_SUB_TYPE_PDB = 'PDB'.freeze, DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze, DATABASE_SUB_TYPE_ACD = 'ACD'.freeze, DATABASE_SUB_TYPE_ADB = 'ADB'.freeze ].freeze
- JOB_TYPE_ENUM =
[ JOB_TYPE_SQL = 'SQL'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the job resides.
-
#database_sub_type ⇒ String
The subtype of the Oracle Database where the job has to be executed.
-
#description ⇒ String
The description of the job.
-
#job_type ⇒ String
[Required] The type of job.
-
#managed_database_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the job has to be executed.
-
#managed_database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database where the job has to be executed.
-
#name ⇒ String
[Required] The name of the job.
- #result_location ⇒ OCI::DatabaseManagement::Models::JobExecutionResultLocation
- #schedule_details ⇒ OCI::DatabaseManagement::Models::JobScheduleDetails
-
#schedule_type ⇒ String
[Required] The schedule type of the job.
-
#timeout ⇒ String
The job timeout duration, which is expressed like "1h 10m 15s".
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateJobDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateJobDetails
Initializes the object
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 138 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.managed_database_group_id = attributes[:'managedDatabaseGroupId'] if attributes[:'managedDatabaseGroupId'] raise 'You cannot provide both :managedDatabaseGroupId and :managed_database_group_id' if attributes.key?(:'managedDatabaseGroupId') && attributes.key?(:'managed_database_group_id') self.managed_database_group_id = attributes[:'managed_database_group_id'] if attributes[:'managed_database_group_id'] self.managed_database_id = attributes[:'managedDatabaseId'] if attributes[:'managedDatabaseId'] raise 'You cannot provide both :managedDatabaseId and :managed_database_id' if attributes.key?(:'managedDatabaseId') && attributes.key?(:'managed_database_id') self.managed_database_id = attributes[:'managed_database_id'] if attributes[:'managed_database_id'] self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType'] raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type') self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type'] self.schedule_type = attributes[:'scheduleType'] if attributes[:'scheduleType'] raise 'You cannot provide both :scheduleType and :schedule_type' if attributes.key?(:'scheduleType') && attributes.key?(:'schedule_type') self.schedule_type = attributes[:'schedule_type'] if attributes[:'schedule_type'] self.job_type = attributes[:'jobType'] if attributes[:'jobType'] raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type') self.job_type = attributes[:'job_type'] if attributes[:'job_type'] self.timeout = attributes[:'timeout'] if attributes[:'timeout'] self.result_location = attributes[:'resultLocation'] if attributes[:'resultLocation'] raise 'You cannot provide both :resultLocation and :result_location' if attributes.key?(:'resultLocation') && attributes.key?(:'result_location') self.result_location = attributes[:'result_location'] if attributes[:'result_location'] self.schedule_details = attributes[:'scheduleDetails'] if attributes[:'scheduleDetails'] raise 'You cannot provide both :scheduleDetails and :schedule_details' if attributes.key?(:'scheduleDetails') && attributes.key?(:'schedule_details') self.schedule_details = attributes[:'schedule_details'] if attributes[:'schedule_details'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the job resides.
36 37 38 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 36 def compartment_id @compartment_id end |
#database_sub_type ⇒ String
The subtype of the Oracle Database where the job has to be executed. Only applicable when managedDatabaseGroupId is provided.
48 49 50 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 48 def database_sub_type @database_sub_type end |
#description ⇒ String
The description of the job.
32 33 34 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 32 def description @description end |
#job_type ⇒ String
[Required] The type of job.
56 57 58 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 56 def job_type @job_type end |
#managed_database_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the job has to be executed.
40 41 42 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 40 def managed_database_group_id @managed_database_group_id end |
#managed_database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database where the job has to be executed.
44 45 46 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 44 def managed_database_id @managed_database_id end |
#name ⇒ String
[Required] The name of the job. Valid characters are uppercase or lowercase letters, numbers, and "_". The name of the job cannot be modified. It must be unique in the compartment and must begin with an alphabetic character.
28 29 30 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 28 def name @name end |
#result_location ⇒ OCI::DatabaseManagement::Models::JobExecutionResultLocation
63 64 65 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 63 def result_location @result_location end |
#schedule_details ⇒ OCI::DatabaseManagement::Models::JobScheduleDetails
66 67 68 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 66 def schedule_details @schedule_details end |
#schedule_type ⇒ String
[Required] The schedule type of the job.
52 53 54 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 52 def schedule_type @schedule_type end |
#timeout ⇒ String
The job timeout duration, which is expressed like "1h 10m 15s".
60 61 62 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 60 def timeout @timeout end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'compartment_id': :'compartmentId', 'managed_database_group_id': :'managedDatabaseGroupId', 'managed_database_id': :'managedDatabaseId', 'database_sub_type': :'databaseSubType', 'schedule_type': :'scheduleType', 'job_type': :'jobType', 'timeout': :'timeout', 'result_location': :'resultLocation', 'schedule_details': :'scheduleDetails' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
111 112 113 114 115 116 117 118 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 111 def self.get_subtype(object_hash) type = object_hash[:'jobType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DatabaseManagement::Models::CreateSqlJobDetails' if type == 'SQL' # TODO: Log a warning when the subtype is not found. 'OCI::DatabaseManagement::Models::CreateJobDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 88 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'compartment_id': :'String', 'managed_database_group_id': :'String', 'managed_database_id': :'String', 'database_sub_type': :'String', 'schedule_type': :'String', 'job_type': :'String', 'timeout': :'String', 'result_location': :'OCI::DatabaseManagement::Models::JobExecutionResultLocation', 'schedule_details': :'OCI::DatabaseManagement::Models::JobScheduleDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 222 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && compartment_id == other.compartment_id && managed_database_group_id == other.managed_database_group_id && managed_database_id == other.managed_database_id && database_sub_type == other.database_sub_type && schedule_type == other.schedule_type && job_type == other.job_type && timeout == other.timeout && result_location == other.result_location && schedule_details == other.schedule_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 262 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
242 243 244 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 242 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
251 252 253 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 251 def hash [name, description, compartment_id, managed_database_group_id, managed_database_id, database_sub_type, schedule_type, job_type, timeout, result_location, schedule_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 304 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
289 290 291 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 289 def to_s to_hash.to_s end |