Class: OCI::DatabaseManagement::Models::CreateJobDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::CreateJobDetails
- Defined in:
- lib/oci/database_management/models/create_job_details.rb
Overview
The details required to create a job. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- DATABASE_SUB_TYPE_ENUM =
[ DATABASE_SUB_TYPE_CDB = 'CDB'.freeze, DATABASE_SUB_TYPE_PDB = 'PDB'.freeze, DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze ].freeze
- JOB_TYPE_ENUM =
[ JOB_TYPE_SQL = 'SQL'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the job resides.
-
#database_sub_type ⇒ String
The subtype of the Oracle Database where the job has to be executed.
-
#description ⇒ String
The description of the job.
-
#job_type ⇒ String
[Required] The type of job.
-
#managed_database_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the job has to be executed.
-
#managed_database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database where the job has to be executed.
-
#name ⇒ String
[Required] The name of the job.
- #result_location ⇒ OCI::DatabaseManagement::Models::JobExecutionResultLocation
-
#schedule_type ⇒ String
[Required] The schedule type of the job.
-
#timeout ⇒ String
The job timeout duration, which is expressed like "1h 10m 15s".
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateJobDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateJobDetails
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 130 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.managed_database_group_id = attributes[:'managedDatabaseGroupId'] if attributes[:'managedDatabaseGroupId'] raise 'You cannot provide both :managedDatabaseGroupId and :managed_database_group_id' if attributes.key?(:'managedDatabaseGroupId') && attributes.key?(:'managed_database_group_id') self.managed_database_group_id = attributes[:'managed_database_group_id'] if attributes[:'managed_database_group_id'] self.managed_database_id = attributes[:'managedDatabaseId'] if attributes[:'managedDatabaseId'] raise 'You cannot provide both :managedDatabaseId and :managed_database_id' if attributes.key?(:'managedDatabaseId') && attributes.key?(:'managed_database_id') self.managed_database_id = attributes[:'managed_database_id'] if attributes[:'managed_database_id'] self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType'] raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type') self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type'] self.schedule_type = attributes[:'scheduleType'] if attributes[:'scheduleType'] raise 'You cannot provide both :scheduleType and :schedule_type' if attributes.key?(:'scheduleType') && attributes.key?(:'schedule_type') self.schedule_type = attributes[:'schedule_type'] if attributes[:'schedule_type'] self.job_type = attributes[:'jobType'] if attributes[:'jobType'] raise 'You cannot provide both :jobType and :job_type' if attributes.key?(:'jobType') && attributes.key?(:'job_type') self.job_type = attributes[:'job_type'] if attributes[:'job_type'] self.timeout = attributes[:'timeout'] if attributes[:'timeout'] self.result_location = attributes[:'resultLocation'] if attributes[:'resultLocation'] raise 'You cannot provide both :resultLocation and :result_location' if attributes.key?(:'resultLocation') && attributes.key?(:'result_location') self.result_location = attributes[:'result_location'] if attributes[:'result_location'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the job resides.
34 35 36 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 34 def compartment_id @compartment_id end |
#database_sub_type ⇒ String
The subtype of the Oracle Database where the job has to be executed. Only applicable when managedDatabaseGroupId is provided.
46 47 48 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 46 def database_sub_type @database_sub_type end |
#description ⇒ String
The description of the job.
30 31 32 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 30 def description @description end |
#job_type ⇒ String
[Required] The type of job.
54 55 56 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 54 def job_type @job_type end |
#managed_database_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the job has to be executed.
38 39 40 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 38 def managed_database_group_id @managed_database_group_id end |
#managed_database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database where the job has to be executed.
42 43 44 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 42 def managed_database_id @managed_database_id end |
#name ⇒ String
[Required] The name of the job. Valid characters are uppercase or lowercase letters, numbers, and "_". The name of the job cannot be modified. It must be unique in the compartment and must begin with an alphabetic character.
26 27 28 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 26 def name @name end |
#result_location ⇒ OCI::DatabaseManagement::Models::JobExecutionResultLocation
61 62 63 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 61 def result_location @result_location end |
#schedule_type ⇒ String
[Required] The schedule type of the job.
50 51 52 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 50 def schedule_type @schedule_type end |
#timeout ⇒ String
The job timeout duration, which is expressed like "1h 10m 15s".
58 59 60 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 58 def timeout @timeout end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 64 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'compartment_id': :'compartmentId', 'managed_database_group_id': :'managedDatabaseGroupId', 'managed_database_id': :'managedDatabaseId', 'database_sub_type': :'databaseSubType', 'schedule_type': :'scheduleType', 'job_type': :'jobType', 'timeout': :'timeout', 'result_location': :'resultLocation' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
104 105 106 107 108 109 110 111 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 104 def self.get_subtype(object_hash) type = object_hash[:'jobType'] # rubocop:disable Style/SymbolLiteral return 'OCI::DatabaseManagement::Models::CreateSqlJobDetails' if type == 'SQL' # TODO: Log a warning when the subtype is not found. 'OCI::DatabaseManagement::Models::CreateJobDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 82 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'compartment_id': :'String', 'managed_database_group_id': :'String', 'managed_database_id': :'String', 'database_sub_type': :'String', 'schedule_type': :'String', 'job_type': :'String', 'timeout': :'String', 'result_location': :'OCI::DatabaseManagement::Models::JobExecutionResultLocation' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 208 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && compartment_id == other.compartment_id && managed_database_group_id == other.managed_database_group_id && managed_database_id == other.managed_database_id && database_sub_type == other.database_sub_type && schedule_type == other.schedule_type && job_type == other.job_type && timeout == other.timeout && result_location == other.result_location end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 247 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
227 228 229 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 227 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 236 def hash [name, description, compartment_id, managed_database_group_id, managed_database_id, database_sub_type, schedule_type, job_type, timeout, result_location].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
274 275 276 |
# File 'lib/oci/database_management/models/create_job_details.rb', line 274 def to_s to_hash.to_s end |