Class: OCI::DatabaseManagement::Models::CreateSqlJobDetails

Inherits:
CreateJobDetails show all
Defined in:
lib/oci/database_management/models/create_sql_job_details.rb

Overview

The details specific to the SQL job request.

Constant Summary

Constants inherited from CreateJobDetails

OCI::DatabaseManagement::Models::CreateJobDetails::DATABASE_SUB_TYPE_ENUM, OCI::DatabaseManagement::Models::CreateJobDetails::JOB_TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from CreateJobDetails

#compartment_id, #database_sub_type, #description, #job_type, #managed_database_group_id, #managed_database_id, #name, #result_location, #schedule_type, #timeout

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from CreateJobDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ CreateSqlJobDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 106

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['jobType'] = 'SQL'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.sql_text = attributes[:'sqlText'] if attributes[:'sqlText']

  raise 'You cannot provide both :sqlText and :sql_text' if attributes.key?(:'sqlText') && attributes.key?(:'sql_text')

  self.sql_text = attributes[:'sql_text'] if attributes[:'sql_text']

  self.sql_type = attributes[:'sqlType'] if attributes[:'sqlType']

  raise 'You cannot provide both :sqlType and :sql_type' if attributes.key?(:'sqlType') && attributes.key?(:'sql_type')

  self.sql_type = attributes[:'sql_type'] if attributes[:'sql_type']

  self.operation_type = attributes[:'operationType'] if attributes[:'operationType']

  raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type')

  self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type']

  self.user_name = attributes[:'userName'] if attributes[:'userName']

  raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name')

  self.user_name = attributes[:'user_name'] if attributes[:'user_name']

  self.password = attributes[:'password'] if attributes[:'password']

  self.role = attributes[:'role'] if attributes[:'role']
end

Instance Attribute Details

#operation_typeString

[Required] The SQL operation type.

Returns:

  • (String)


20
21
22
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 20

def operation_type
  @operation_type
end

#passwordString

The password for the database user name used to execute the SQL job.

Returns:

  • (String)


31
32
33
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 31

def password
  @password
end

#roleString

The role of the database user. Indicates whether the database user is a normal user or sysdba.

Returns:

  • (String)


35
36
37
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 35

def role
  @role
end

#sql_textString

The SQL text to be executed as part of the job.

Returns:

  • (String)


13
14
15
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 13

def sql_text
  @sql_text
end

#sql_typeString

Returns:

  • (String)


16
17
18
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 16

def sql_type
  @sql_type
end

#user_nameString

The database user name used to execute the SQL job. If the job is being executed on a Managed Database Group, then the user name should exist on all the databases in the group with the same password.

Returns:

  • (String)


27
28
29
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 27

def user_name
  @user_name
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 38

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'managed_database_group_id': :'managedDatabaseGroupId',
    'managed_database_id': :'managedDatabaseId',
    'database_sub_type': :'databaseSubType',
    'schedule_type': :'scheduleType',
    'job_type': :'jobType',
    'timeout': :'timeout',
    'result_location': :'resultLocation',
    'sql_text': :'sqlText',
    'sql_type': :'sqlType',
    'operation_type': :'operationType',
    'user_name': :'userName',
    'password': :'password',
    'role': :'role'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 62

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'managed_database_group_id': :'String',
    'managed_database_id': :'String',
    'database_sub_type': :'String',
    'schedule_type': :'String',
    'job_type': :'String',
    'timeout': :'String',
    'result_location': :'OCI::DatabaseManagement::Models::JobExecutionResultLocation',
    'sql_text': :'String',
    'sql_type': :'String',
    'operation_type': :'String',
    'user_name': :'String',
    'password': :'String',
    'role': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 152

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    managed_database_group_id == other.managed_database_group_id &&
    managed_database_id == other.managed_database_id &&
    database_sub_type == other.database_sub_type &&
    schedule_type == other.schedule_type &&
    job_type == other.job_type &&
    timeout == other.timeout &&
    result_location == other.result_location &&
    sql_text == other.sql_text &&
    sql_type == other.sql_type &&
    operation_type == other.operation_type &&
    user_name == other.user_name &&
    password == other.password &&
    role == other.role
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 197

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 177

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



186
187
188
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 186

def hash
  [name, description, compartment_id, managed_database_group_id, managed_database_id, database_sub_type, schedule_type, job_type, timeout, result_location, sql_text, sql_type, operation_type, user_name, password, role].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



224
225
226
# File 'lib/oci/database_management/models/create_sql_job_details.rb', line 224

def to_s
  to_hash.to_s
end