Class: OCI::DatabaseManagement::Models::DatabaseCredentials
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::DatabaseCredentials
- Defined in:
- lib/oci/database_management/models/database_credentials.rb
Overview
The database credentials used to perform management activity.
Constant Summary collapse
- ROLE_ENUM =
[ ROLE_NORMAL = 'NORMAL'.freeze, ROLE_SYSDBA = 'SYSDBA'.freeze ].freeze
Instance Attribute Summary collapse
-
#password ⇒ String
The password for the database user name.
-
#role ⇒ String
The role of the database user.
-
#user_name ⇒ String
The database user name used to perform management activity.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseCredentials
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseCredentials
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.user_name = attributes[:'userName'] if attributes[:'userName'] raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] if attributes[:'user_name'] self.password = attributes[:'password'] if attributes[:'password'] self.role = attributes[:'role'] if attributes[:'role'] end |
Instance Attribute Details
#password ⇒ String
The password for the database user name.
23 24 25 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 23 def password @password end |
#role ⇒ String
The role of the database user. Indicates whether the database user is a normal user or sysdba.
27 28 29 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 27 def role @role end |
#user_name ⇒ String
The database user name used to perform management activity.
18 19 20 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 18 def user_name @user_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'user_name': :'userName', 'password': :'password', 'role': :'role' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 41 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'user_name': :'String', 'password': :'String', 'role': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
92 93 94 95 96 97 98 99 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 92 def ==(other) return true if equal?(other) self.class == other.class && user_name == other.user_name && password == other.password && role == other.role end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 124 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
104 105 106 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 104 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
113 114 115 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 113 def hash [user_name, password, role].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 157 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
151 152 153 |
# File 'lib/oci/database_management/models/database_credentials.rb', line 151 def to_s to_hash.to_s end |