Class: OCI::DatabaseManagement::Models::DatabaseFleetHealthMetrics
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::DatabaseFleetHealthMetrics
- Defined in:
- lib/oci/database_management/models/database_fleet_health_metrics.rb
Overview
The details of the fleet health metrics.
Constant Summary collapse
- COMPARE_TYPE_ENUM =
[ COMPARE_TYPE_HOUR = 'HOUR'.freeze, COMPARE_TYPE_DAY = 'DAY'.freeze, COMPARE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compare_baseline_time ⇒ String
[Required] The baseline date and time in UTC in ISO-8601 format, which is "yyyy-MM-dd’T’hh:mm:ss.sss’Z’".
-
#compare_target_time ⇒ String
[Required] The target date and time in UTC in ISO-8601 format, which is "yyyy-MM-dd’T’hh:mm:ss.sss’Z’".
-
#compare_type ⇒ String
The time window used for metrics comparison.
-
#fleet_databases ⇒ Array<OCI::DatabaseManagement::Models::DatabaseUsageMetrics>
[Required] A list of the databases present in the fleet and their usage metrics.
- #fleet_summary ⇒ OCI::DatabaseManagement::Models::FleetSummary
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseFleetHealthMetrics
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseFleetHealthMetrics
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compare_baseline_time = attributes[:'compareBaselineTime'] if attributes[:'compareBaselineTime'] raise 'You cannot provide both :compareBaselineTime and :compare_baseline_time' if attributes.key?(:'compareBaselineTime') && attributes.key?(:'compare_baseline_time') self.compare_baseline_time = attributes[:'compare_baseline_time'] if attributes[:'compare_baseline_time'] self.compare_target_time = attributes[:'compareTargetTime'] if attributes[:'compareTargetTime'] raise 'You cannot provide both :compareTargetTime and :compare_target_time' if attributes.key?(:'compareTargetTime') && attributes.key?(:'compare_target_time') self.compare_target_time = attributes[:'compare_target_time'] if attributes[:'compare_target_time'] self.compare_type = attributes[:'compareType'] if attributes[:'compareType'] raise 'You cannot provide both :compareType and :compare_type' if attributes.key?(:'compareType') && attributes.key?(:'compare_type') self.compare_type = attributes[:'compare_type'] if attributes[:'compare_type'] self.fleet_summary = attributes[:'fleetSummary'] if attributes[:'fleetSummary'] raise 'You cannot provide both :fleetSummary and :fleet_summary' if attributes.key?(:'fleetSummary') && attributes.key?(:'fleet_summary') self.fleet_summary = attributes[:'fleet_summary'] if attributes[:'fleet_summary'] self.fleet_databases = attributes[:'fleetDatabases'] if attributes[:'fleetDatabases'] raise 'You cannot provide both :fleetDatabases and :fleet_databases' if attributes.key?(:'fleetDatabases') && attributes.key?(:'fleet_databases') self.fleet_databases = attributes[:'fleet_databases'] if attributes[:'fleet_databases'] end |
Instance Attribute Details
#compare_baseline_time ⇒ String
[Required] The baseline date and time in UTC in ISO-8601 format, which is "yyyy-MM-dd’T’hh:mm:ss.sss’Z’". This is the date and time against which percentage change is calculated.
21 22 23 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 21 def compare_baseline_time @compare_baseline_time end |
#compare_target_time ⇒ String
[Required] The target date and time in UTC in ISO-8601 format, which is "yyyy-MM-dd’T’hh:mm:ss.sss’Z’". All the metrics are returned for the target date and time and the percentage change is calculated against the baseline date and time.
28 29 30 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 28 def compare_target_time @compare_target_time end |
#compare_type ⇒ String
The time window used for metrics comparison.
32 33 34 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 32 def compare_type @compare_type end |
#fleet_databases ⇒ Array<OCI::DatabaseManagement::Models::DatabaseUsageMetrics>
[Required] A list of the databases present in the fleet and their usage metrics.
39 40 41 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 39 def fleet_databases @fleet_databases end |
#fleet_summary ⇒ OCI::DatabaseManagement::Models::FleetSummary
35 36 37 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 35 def fleet_summary @fleet_summary end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compare_baseline_time': :'compareBaselineTime', 'compare_target_time': :'compareTargetTime', 'compare_type': :'compareType', 'fleet_summary': :'fleetSummary', 'fleet_databases': :'fleetDatabases' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compare_baseline_time': :'String', 'compare_target_time': :'String', 'compare_type': :'String', 'fleet_summary': :'OCI::DatabaseManagement::Models::FleetSummary', 'fleet_databases': :'Array<OCI::DatabaseManagement::Models::DatabaseUsageMetrics>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 135 def ==(other) return true if equal?(other) self.class == other.class && compare_baseline_time == other.compare_baseline_time && compare_target_time == other.compare_target_time && compare_type == other.compare_type && fleet_summary == other.fleet_summary && fleet_databases == other.fleet_databases end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 169 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
149 150 151 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 149 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 158 def hash [compare_baseline_time, compare_target_time, compare_type, fleet_summary, fleet_databases].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
196 197 198 |
# File 'lib/oci/database_management/models/database_fleet_health_metrics.rb', line 196 def to_s to_hash.to_s end |