Class: OCI::DatabaseManagement::Models::DatabaseParametersCollection
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::DatabaseParametersCollection
- Defined in:
- lib/oci/database_management/models/database_parameters_collection.rb
Overview
A collection of database parameters.
Constant Summary collapse
- DATABASE_TYPE_ENUM =
[ DATABASE_TYPE_EXTERNAL_SIDB = 'EXTERNAL_SIDB'.freeze, DATABASE_TYPE_EXTERNAL_RAC = 'EXTERNAL_RAC'.freeze, DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DATABASE_SUB_TYPE_ENUM =
[ DATABASE_SUB_TYPE_CDB = 'CDB'.freeze, DATABASE_SUB_TYPE_PDB = 'PDB'.freeze, DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze, DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#database_name ⇒ String
[Required] The name of the Managed Database.
-
#database_sub_type ⇒ String
[Required] The subtype of the Oracle Database.
-
#database_type ⇒ String
[Required] The type of Oracle Database installation.
-
#database_version ⇒ String
[Required] The Oracle Database version.
-
#items ⇒ Array<OCI::DatabaseManagement::Models::DatabaseParameterSummary>
[Required] An array of DatabaseParameterSummary objects.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseParametersCollection
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseParametersCollection
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.database_name = attributes[:'databaseName'] if attributes[:'databaseName'] raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name') self.database_name = attributes[:'database_name'] if attributes[:'database_name'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType'] raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type') self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type'] self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion'] raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version') self.database_version = attributes[:'database_version'] if attributes[:'database_version'] self.items = attributes[:'items'] if attributes[:'items'] end |
Instance Attribute Details
#database_name ⇒ String
[Required] The name of the Managed Database.
26 27 28 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 26 def database_name @database_name end |
#database_sub_type ⇒ String
[Required] The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.
36 37 38 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 36 def database_sub_type @database_sub_type end |
#database_type ⇒ String
[Required] The type of Oracle Database installation.
30 31 32 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 30 def database_type @database_type end |
#database_version ⇒ String
[Required] The Oracle Database version.
40 41 42 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 40 def database_version @database_version end |
#items ⇒ Array<OCI::DatabaseManagement::Models::DatabaseParameterSummary>
[Required] An array of DatabaseParameterSummary objects.
44 45 46 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 44 def items @items end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'database_name': :'databaseName', 'database_type': :'databaseType', 'database_sub_type': :'databaseSubType', 'database_version': :'databaseVersion', 'items': :'items' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 60 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'database_name': :'String', 'database_type': :'String', 'database_sub_type': :'String', 'database_version': :'String', 'items': :'Array<OCI::DatabaseManagement::Models::DatabaseParameterSummary>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 149 def ==(other) return true if equal?(other) self.class == other.class && database_name == other.database_name && database_type == other.database_type && database_sub_type == other.database_sub_type && database_version == other.database_version && items == other.items end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 172 def hash [database_name, database_type, database_sub_type, database_version, items].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/database_management/models/database_parameters_collection.rb', line 210 def to_s to_hash.to_s end |