Class: OCI::DatabaseManagement::Models::DbManagementPrivateEndpoint
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::DbManagementPrivateEndpoint
- Defined in:
- lib/oci/database_management/models/db_management_private_endpoint.rb
Overview
A Database Management private endpoint allows Database Management to connect to databases in a Virtual Cloud Network (VCN).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#description ⇒ String
The description of the Database Management private endpoint.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Database Management private endpoint.
-
#is_cluster ⇒ BOOLEAN
Specifies whether the Database Management private endpoint can be used for Oracle Databases in a cluster.
-
#lifecycle_state ⇒ String
The current lifecycle state of the Database Management private endpoint.
-
#name ⇒ String
[Required] The display name of the Database Management private endpoint.
-
#nsg_ids ⇒ Array<String>
The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.
-
#private_ip ⇒ String
The IP addresses assigned to the Database Management private endpoint.
-
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet.
-
#time_created ⇒ DateTime
The date and time the Database Managament private endpoint was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VCN.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbManagementPrivateEndpoint
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbManagementPrivateEndpoint
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 122 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_cluster = attributes[:'isCluster'] unless attributes[:'isCluster'].nil? raise 'You cannot provide both :isCluster and :is_cluster' if attributes.key?(:'isCluster') && attributes.key?(:'is_cluster') self.is_cluster = attributes[:'is_cluster'] unless attributes[:'is_cluster'].nil? self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.private_ip = attributes[:'privateIp'] if attributes[:'privateIp'] raise 'You cannot provide both :privateIp and :private_ip' if attributes.key?(:'privateIp') && attributes.key?(:'private_ip') self.private_ip = attributes[:'private_ip'] if attributes[:'private_ip'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
31 32 33 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 31 def compartment_id @compartment_id end |
#description ⇒ String
The description of the Database Management private endpoint.
52 53 54 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 52 def description @description end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Database Management private endpoint.
23 24 25 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 23 def id @id end |
#is_cluster ⇒ BOOLEAN
Specifies whether the Database Management private endpoint can be used for Oracle Databases in a cluster.
35 36 37 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 35 def is_cluster @is_cluster end |
#lifecycle_state ⇒ String
The current lifecycle state of the Database Management private endpoint.
60 61 62 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 60 def lifecycle_state @lifecycle_state end |
#name ⇒ String
[Required] The display name of the Database Management private endpoint.
27 28 29 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 27 def name @name end |
#nsg_ids ⇒ Array<String>
The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.
65 66 67 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 65 def nsg_ids @nsg_ids end |
#private_ip ⇒ String
The IP addresses assigned to the Database Management private endpoint.
48 49 50 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 48 def private_ip @private_ip end |
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet.
43 44 45 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 43 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
The date and time the Database Managament private endpoint was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
56 57 58 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 56 def time_created @time_created end |
#vcn_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VCN.
39 40 41 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 39 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 68 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'compartment_id': :'compartmentId', 'is_cluster': :'isCluster', 'vcn_id': :'vcnId', 'subnet_id': :'subnetId', 'private_ip': :'privateIp', 'description': :'description', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'nsg_ids': :'nsgIds' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 87 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'compartment_id': :'String', 'is_cluster': :'BOOLEAN', 'vcn_id': :'String', 'subnet_id': :'String', 'private_ip': :'String', 'description': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'nsg_ids': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 203 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && compartment_id == other.compartment_id && is_cluster == other.is_cluster && vcn_id == other.vcn_id && subnet_id == other.subnet_id && private_ip == other.private_ip && description == other.description && time_created == other.time_created && lifecycle_state == other.lifecycle_state && nsg_ids == other.nsg_ids end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 243 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
223 224 225 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 223 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 232 def hash [id, name, compartment_id, is_cluster, vcn_id, subnet_id, private_ip, description, time_created, lifecycle_state, nsg_ids].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 276 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
270 271 272 |
# File 'lib/oci/database_management/models/db_management_private_endpoint.rb', line 270 def to_s to_hash.to_s end |