Class: OCI::DatabaseManagement::Models::JobExecution

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/job_execution.rb

Overview

The details of a job execution.

Constant Summary collapse

STATUS_ENUM =
[
  STATUS_SUCCEEDED = 'SUCCEEDED'.freeze,
  STATUS_FAILED = 'FAILED'.freeze,
  STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JobExecution

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/database_management/models/job_execution.rb', line 139

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.managed_database_group_id = attributes[:'managedDatabaseGroupId'] if attributes[:'managedDatabaseGroupId']

  raise 'You cannot provide both :managedDatabaseGroupId and :managed_database_group_id' if attributes.key?(:'managedDatabaseGroupId') && attributes.key?(:'managed_database_group_id')

  self.managed_database_group_id = attributes[:'managed_database_group_id'] if attributes[:'managed_database_group_id']

  self.managed_database_id = attributes[:'managedDatabaseId'] if attributes[:'managedDatabaseId']

  raise 'You cannot provide both :managedDatabaseId and :managed_database_id' if attributes.key?(:'managedDatabaseId') && attributes.key?(:'managed_database_id')

  self.managed_database_id = attributes[:'managed_database_id'] if attributes[:'managed_database_id']

  self.managed_database_name = attributes[:'managedDatabaseName'] if attributes[:'managedDatabaseName']

  raise 'You cannot provide both :managedDatabaseName and :managed_database_name' if attributes.key?(:'managedDatabaseName') && attributes.key?(:'managed_database_name')

  self.managed_database_name = attributes[:'managed_database_name'] if attributes[:'managed_database_name']

  self.job_id = attributes[:'jobId'] if attributes[:'jobId']

  raise 'You cannot provide both :jobId and :job_id' if attributes.key?(:'jobId') && attributes.key?(:'job_id')

  self.job_id = attributes[:'job_id'] if attributes[:'job_id']

  self.job_name = attributes[:'jobName'] if attributes[:'jobName']

  raise 'You cannot provide both :jobName and :job_name' if attributes.key?(:'jobName') && attributes.key?(:'job_name')

  self.job_name = attributes[:'job_name'] if attributes[:'job_name']

  self.job_run_id = attributes[:'jobRunId'] if attributes[:'jobRunId']

  raise 'You cannot provide both :jobRunId and :job_run_id' if attributes.key?(:'jobRunId') && attributes.key?(:'job_run_id')

  self.job_run_id = attributes[:'job_run_id'] if attributes[:'job_run_id']

  self.status = attributes[:'status'] if attributes[:'status']

  self.error_message = attributes[:'errorMessage'] if attributes[:'errorMessage']

  raise 'You cannot provide both :errorMessage and :error_message' if attributes.key?(:'errorMessage') && attributes.key?(:'error_message')

  self.error_message = attributes[:'error_message'] if attributes[:'error_message']

  self.result_details = attributes[:'resultDetails'] if attributes[:'resultDetails']

  raise 'You cannot provide both :resultDetails and :result_details' if attributes.key?(:'resultDetails') && attributes.key?(:'result_details')

  self.result_details = attributes[:'result_details'] if attributes[:'result_details']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_completed = attributes[:'timeCompleted'] if attributes[:'timeCompleted']

  raise 'You cannot provide both :timeCompleted and :time_completed' if attributes.key?(:'timeCompleted') && attributes.key?(:'time_completed')

  self.time_completed = attributes[:'time_completed'] if attributes[:'time_completed']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the parent job resides.

Returns:

  • (String)


28
29
30
# File 'lib/oci/database_management/models/job_execution.rb', line 28

def compartment_id
  @compartment_id
end

#error_messageString

The error message that is returned if the job execution fails. Null is returned if the job is still running or if the job execution is successful.

Returns:

  • (String)


62
63
64
# File 'lib/oci/database_management/models/job_execution.rb', line 62

def error_message
  @error_message
end

#idString

[Required] The identifier of the job execution.

Returns:

  • (String)


20
21
22
# File 'lib/oci/database_management/models/job_execution.rb', line 20

def id
  @id
end

#job_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent job.

Returns:

  • (String)


44
45
46
# File 'lib/oci/database_management/models/job_execution.rb', line 44

def job_id
  @job_id
end

#job_nameString

[Required] The name of the parent job.

Returns:

  • (String)


48
49
50
# File 'lib/oci/database_management/models/job_execution.rb', line 48

def job_name
  @job_name
end

#job_run_idString

[Required] The identifier of the associated job run.

Returns:

  • (String)


52
53
54
# File 'lib/oci/database_management/models/job_execution.rb', line 52

def job_run_id
  @job_run_id
end

#managed_database_group_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the parent job has to be executed.

Returns:

  • (String)


32
33
34
# File 'lib/oci/database_management/models/job_execution.rb', line 32

def managed_database_group_id
  @managed_database_group_id
end

#managed_database_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database associated with the job execution.

Returns:

  • (String)


36
37
38
# File 'lib/oci/database_management/models/job_execution.rb', line 36

def managed_database_id
  @managed_database_id
end

#managed_database_nameString

[Required] The name of the Managed Database associated with the job execution.

Returns:

  • (String)


40
41
42
# File 'lib/oci/database_management/models/job_execution.rb', line 40

def managed_database_name
  @managed_database_name
end

#nameString

[Required] The name of the job execution.

Returns:

  • (String)


24
25
26
# File 'lib/oci/database_management/models/job_execution.rb', line 24

def name
  @name
end

#result_detailsOCI::DatabaseManagement::Models::JobExecutionResultDetails



65
66
67
# File 'lib/oci/database_management/models/job_execution.rb', line 65

def result_details
  @result_details
end

#statusString

[Required] The status of the job execution.

Returns:

  • (String)


56
57
58
# File 'lib/oci/database_management/models/job_execution.rb', line 56

def status
  @status
end

#time_completedDateTime

The date and time when the job execution completed.

Returns:

  • (DateTime)


73
74
75
# File 'lib/oci/database_management/models/job_execution.rb', line 73

def time_completed
  @time_completed
end

#time_createdDateTime

[Required] The date and time when the job execution was created.

Returns:

  • (DateTime)


69
70
71
# File 'lib/oci/database_management/models/job_execution.rb', line 69

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/oci/database_management/models/job_execution.rb', line 76

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'managed_database_group_id': :'managedDatabaseGroupId',
    'managed_database_id': :'managedDatabaseId',
    'managed_database_name': :'managedDatabaseName',
    'job_id': :'jobId',
    'job_name': :'jobName',
    'job_run_id': :'jobRunId',
    'status': :'status',
    'error_message': :'errorMessage',
    'result_details': :'resultDetails',
    'time_created': :'timeCreated',
    'time_completed': :'timeCompleted'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/oci/database_management/models/job_execution.rb', line 98

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'managed_database_group_id': :'String',
    'managed_database_id': :'String',
    'managed_database_name': :'String',
    'job_id': :'String',
    'job_name': :'String',
    'job_run_id': :'String',
    'status': :'String',
    'error_message': :'String',
    'result_details': :'OCI::DatabaseManagement::Models::JobExecutionResultDetails',
    'time_created': :'DateTime',
    'time_completed': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/oci/database_management/models/job_execution.rb', line 238

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    managed_database_group_id == other.managed_database_group_id &&
    managed_database_id == other.managed_database_id &&
    managed_database_name == other.managed_database_name &&
    job_id == other.job_id &&
    job_name == other.job_name &&
    job_run_id == other.job_run_id &&
    status == other.status &&
    error_message == other.error_message &&
    result_details == other.result_details &&
    time_created == other.time_created &&
    time_completed == other.time_completed
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/oci/database_management/models/job_execution.rb', line 281

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/oci/database_management/models/job_execution.rb', line 261

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



270
271
272
# File 'lib/oci/database_management/models/job_execution.rb', line 270

def hash
  [id, name, compartment_id, managed_database_group_id, managed_database_id, managed_database_name, job_id, job_name, job_run_id, status, error_message, result_details, time_created, time_completed].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



314
315
316
317
318
319
320
321
322
323
# File 'lib/oci/database_management/models/job_execution.rb', line 314

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



308
309
310
# File 'lib/oci/database_management/models/job_execution.rb', line 308

def to_s
  to_hash.to_s
end