Class: OCI::DatabaseManagement::Models::JobExecutionSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::JobExecutionSummary
- Defined in:
- lib/oci/database_management/models/job_execution_summary.rb
Overview
A summary of a job execution on a Managed Database.
Constant Summary collapse
- DATABASE_TYPE_ENUM =
[ DATABASE_TYPE_EXTERNAL_SIDB = 'EXTERNAL_SIDB'.freeze, DATABASE_TYPE_EXTERNAL_RAC = 'EXTERNAL_RAC'.freeze, DATABASE_TYPE_CLOUD_SIDB = 'CLOUD_SIDB'.freeze, DATABASE_TYPE_CLOUD_RAC = 'CLOUD_RAC'.freeze, DATABASE_TYPE_SHARED = 'SHARED'.freeze, DATABASE_TYPE_DEDICATED = 'DEDICATED'.freeze, DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DATABASE_SUB_TYPE_ENUM =
[ DATABASE_SUB_TYPE_CDB = 'CDB'.freeze, DATABASE_SUB_TYPE_PDB = 'PDB'.freeze, DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze, DATABASE_SUB_TYPE_ACD = 'ACD'.freeze, DATABASE_SUB_TYPE_ADB = 'ADB'.freeze, DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DEPLOYMENT_TYPE_ENUM =
[ DEPLOYMENT_TYPE_ONPREMISE = 'ONPREMISE'.freeze, DEPLOYMENT_TYPE_BM = 'BM'.freeze, DEPLOYMENT_TYPE_VM = 'VM'.freeze, DEPLOYMENT_TYPE_EXADATA = 'EXADATA'.freeze, DEPLOYMENT_TYPE_EXADATA_CC = 'EXADATA_CC'.freeze, DEPLOYMENT_TYPE_AUTONOMOUS = 'AUTONOMOUS'.freeze, DEPLOYMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- WORKLOAD_TYPE_ENUM =
[ WORKLOAD_TYPE_OLTP = 'OLTP'.freeze, WORKLOAD_TYPE_DW = 'DW'.freeze, WORKLOAD_TYPE_AJD = 'AJD'.freeze, WORKLOAD_TYPE_APEX = 'APEX'.freeze, WORKLOAD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the parent job resides.
-
#database_sub_type ⇒ String
The subtype of the Oracle Database.
-
#database_type ⇒ String
The type of Oracle Database installation.
-
#deployment_type ⇒ String
A list of the supported infrastructure that can be used to deploy the database.
-
#id ⇒ String
[Required] The identifier of the job execution.
-
#is_cluster ⇒ BOOLEAN
Indicates whether the Oracle Database is part of a cluster.
-
#job_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent job.
-
#job_name ⇒ String
[Required] The name of the parent job.
-
#managed_database_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the parent job has to be executed.
-
#managed_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of Managed Database associated with the job execution.
-
#managed_database_name ⇒ String
[Required] The name of the Managed Database associated with the job execution.
-
#name ⇒ String
[Required] The name of the job execution.
-
#status ⇒ String
[Required] The status of the job execution.
-
#time_completed ⇒ DateTime
The date and time when the job execution was completed.
-
#time_created ⇒ DateTime
[Required] The date and time when the job execution was created.
-
#workload_type ⇒ String
The workload type of the Autonomous Database.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JobExecutionSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ JobExecutionSummary
Initializes the object
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 182 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.managed_database_group_id = attributes[:'managedDatabaseGroupId'] if attributes[:'managedDatabaseGroupId'] raise 'You cannot provide both :managedDatabaseGroupId and :managed_database_group_id' if attributes.key?(:'managedDatabaseGroupId') && attributes.key?(:'managed_database_group_id') self.managed_database_group_id = attributes[:'managed_database_group_id'] if attributes[:'managed_database_group_id'] self.managed_database_id = attributes[:'managedDatabaseId'] if attributes[:'managedDatabaseId'] raise 'You cannot provide both :managedDatabaseId and :managed_database_id' if attributes.key?(:'managedDatabaseId') && attributes.key?(:'managed_database_id') self.managed_database_id = attributes[:'managed_database_id'] if attributes[:'managed_database_id'] self.managed_database_name = attributes[:'managedDatabaseName'] if attributes[:'managedDatabaseName'] raise 'You cannot provide both :managedDatabaseName and :managed_database_name' if attributes.key?(:'managedDatabaseName') && attributes.key?(:'managed_database_name') self.managed_database_name = attributes[:'managed_database_name'] if attributes[:'managed_database_name'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType'] raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type') self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type'] self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType'] raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type') self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type'] self.is_cluster = attributes[:'isCluster'] unless attributes[:'isCluster'].nil? raise 'You cannot provide both :isCluster and :is_cluster' if attributes.key?(:'isCluster') && attributes.key?(:'is_cluster') self.is_cluster = attributes[:'is_cluster'] unless attributes[:'is_cluster'].nil? self.workload_type = attributes[:'workloadType'] if attributes[:'workloadType'] raise 'You cannot provide both :workloadType and :workload_type' if attributes.key?(:'workloadType') && attributes.key?(:'workload_type') self.workload_type = attributes[:'workload_type'] if attributes[:'workload_type'] self.job_id = attributes[:'jobId'] if attributes[:'jobId'] raise 'You cannot provide both :jobId and :job_id' if attributes.key?(:'jobId') && attributes.key?(:'job_id') self.job_id = attributes[:'job_id'] if attributes[:'job_id'] self.job_name = attributes[:'jobName'] if attributes[:'jobName'] raise 'You cannot provide both :jobName and :job_name' if attributes.key?(:'jobName') && attributes.key?(:'job_name') self.job_name = attributes[:'job_name'] if attributes[:'job_name'] self.status = attributes[:'status'] if attributes[:'status'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_completed = attributes[:'timeCompleted'] if attributes[:'timeCompleted'] raise 'You cannot provide both :timeCompleted and :time_completed' if attributes.key?(:'timeCompleted') && attributes.key?(:'time_completed') self.time_completed = attributes[:'time_completed'] if attributes[:'time_completed'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the parent job resides.
58 59 60 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 58 def compartment_id @compartment_id end |
#database_sub_type ⇒ String
The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.
78 79 80 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 78 def database_sub_type @database_sub_type end |
#database_type ⇒ String
The type of Oracle Database installation.
74 75 76 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 74 def database_type @database_type end |
#deployment_type ⇒ String
A list of the supported infrastructure that can be used to deploy the database.
82 83 84 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 82 def deployment_type @deployment_type end |
#id ⇒ String
[Required] The identifier of the job execution.
50 51 52 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 50 def id @id end |
#is_cluster ⇒ BOOLEAN
Indicates whether the Oracle Database is part of a cluster.
86 87 88 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 86 def is_cluster @is_cluster end |
#job_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent job.
94 95 96 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 94 def job_id @job_id end |
#job_name ⇒ String
[Required] The name of the parent job.
98 99 100 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 98 def job_name @job_name end |
#managed_database_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the parent job has to be executed.
62 63 64 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 62 def managed_database_group_id @managed_database_group_id end |
#managed_database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of Managed Database associated with the job execution.
66 67 68 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 66 def managed_database_id @managed_database_id end |
#managed_database_name ⇒ String
[Required] The name of the Managed Database associated with the job execution.
70 71 72 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 70 def managed_database_name @managed_database_name end |
#name ⇒ String
[Required] The name of the job execution.
54 55 56 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 54 def name @name end |
#status ⇒ String
[Required] The status of the job execution.
102 103 104 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 102 def status @status end |
#time_completed ⇒ DateTime
The date and time when the job execution was completed.
110 111 112 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 110 def time_completed @time_completed end |
#time_created ⇒ DateTime
[Required] The date and time when the job execution was created.
106 107 108 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 106 def time_created @time_created end |
#workload_type ⇒ String
The workload type of the Autonomous Database.
90 91 92 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 90 def workload_type @workload_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 113 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'compartment_id': :'compartmentId', 'managed_database_group_id': :'managedDatabaseGroupId', 'managed_database_id': :'managedDatabaseId', 'managed_database_name': :'managedDatabaseName', 'database_type': :'databaseType', 'database_sub_type': :'databaseSubType', 'deployment_type': :'deploymentType', 'is_cluster': :'isCluster', 'workload_type': :'workloadType', 'job_id': :'jobId', 'job_name': :'jobName', 'status': :'status', 'time_created': :'timeCreated', 'time_completed': :'timeCompleted' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 137 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'compartment_id': :'String', 'managed_database_group_id': :'String', 'managed_database_id': :'String', 'managed_database_name': :'String', 'database_type': :'String', 'database_sub_type': :'String', 'deployment_type': :'String', 'is_cluster': :'BOOLEAN', 'workload_type': :'String', 'job_id': :'String', 'job_name': :'String', 'status': :'String', 'time_created': :'DateTime', 'time_completed': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 332 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && compartment_id == other.compartment_id && managed_database_group_id == other.managed_database_group_id && managed_database_id == other.managed_database_id && managed_database_name == other.managed_database_name && database_type == other.database_type && database_sub_type == other.database_sub_type && deployment_type == other.deployment_type && is_cluster == other.is_cluster && workload_type == other.workload_type && job_id == other.job_id && job_name == other.job_name && status == other.status && time_created == other.time_created && time_completed == other.time_completed end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 377 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
357 358 359 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 357 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
366 367 368 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 366 def hash [id, name, compartment_id, managed_database_group_id, managed_database_id, managed_database_name, database_type, database_sub_type, deployment_type, is_cluster, workload_type, job_id, job_name, status, time_created, time_completed].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
410 411 412 413 414 415 416 417 418 419 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 410 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
404 405 406 |
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 404 def to_s to_hash.to_s end |