Class: OCI::DatabaseManagement::Models::JobExecutionSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/job_execution_summary.rb

Overview

A summary of a job execution on a Managed Database.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ JobExecutionSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :name (String)

    The value to assign to the #name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :managed_database_group_id (String)

    The value to assign to the #managed_database_group_id property

  • :managed_database_id (String)

    The value to assign to the #managed_database_id property

  • :managed_database_name (String)

    The value to assign to the #managed_database_name property

  • :job_id (String)

    The value to assign to the #job_id property

  • :job_name (String)

    The value to assign to the #job_name property

  • :status (String)

    The value to assign to the #status property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_completed (DateTime)

    The value to assign to the #time_completed property



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 110

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.managed_database_group_id = attributes[:'managedDatabaseGroupId'] if attributes[:'managedDatabaseGroupId']

  raise 'You cannot provide both :managedDatabaseGroupId and :managed_database_group_id' if attributes.key?(:'managedDatabaseGroupId') && attributes.key?(:'managed_database_group_id')

  self.managed_database_group_id = attributes[:'managed_database_group_id'] if attributes[:'managed_database_group_id']

  self.managed_database_id = attributes[:'managedDatabaseId'] if attributes[:'managedDatabaseId']

  raise 'You cannot provide both :managedDatabaseId and :managed_database_id' if attributes.key?(:'managedDatabaseId') && attributes.key?(:'managed_database_id')

  self.managed_database_id = attributes[:'managed_database_id'] if attributes[:'managed_database_id']

  self.managed_database_name = attributes[:'managedDatabaseName'] if attributes[:'managedDatabaseName']

  raise 'You cannot provide both :managedDatabaseName and :managed_database_name' if attributes.key?(:'managedDatabaseName') && attributes.key?(:'managed_database_name')

  self.managed_database_name = attributes[:'managed_database_name'] if attributes[:'managed_database_name']

  self.job_id = attributes[:'jobId'] if attributes[:'jobId']

  raise 'You cannot provide both :jobId and :job_id' if attributes.key?(:'jobId') && attributes.key?(:'job_id')

  self.job_id = attributes[:'job_id'] if attributes[:'job_id']

  self.job_name = attributes[:'jobName'] if attributes[:'jobName']

  raise 'You cannot provide both :jobName and :job_name' if attributes.key?(:'jobName') && attributes.key?(:'job_name')

  self.job_name = attributes[:'job_name'] if attributes[:'job_name']

  self.status = attributes[:'status'] if attributes[:'status']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_completed = attributes[:'timeCompleted'] if attributes[:'timeCompleted']

  raise 'You cannot provide both :timeCompleted and :time_completed' if attributes.key?(:'timeCompleted') && attributes.key?(:'time_completed')

  self.time_completed = attributes[:'time_completed'] if attributes[:'time_completed']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the parent job resides.

Returns:

  • (String)


21
22
23
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 21

def compartment_id
  @compartment_id
end

#idString

[Required] The identifier of the job execution.

Returns:

  • (String)


13
14
15
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 13

def id
  @id
end

#job_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent job.

Returns:

  • (String)


37
38
39
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 37

def job_id
  @job_id
end

#job_nameString

[Required] The name of the parent job.

Returns:

  • (String)


41
42
43
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 41

def job_name
  @job_name
end

#managed_database_group_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the parent job has to be executed.

Returns:

  • (String)


25
26
27
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 25

def managed_database_group_id
  @managed_database_group_id
end

#managed_database_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of Managed Database associated with the job execution.

Returns:

  • (String)


29
30
31
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 29

def managed_database_id
  @managed_database_id
end

#managed_database_nameString

[Required] The name of the Managed Database associated with the job execution.

Returns:

  • (String)


33
34
35
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 33

def managed_database_name
  @managed_database_name
end

#nameString

[Required] The name of the job execution.

Returns:

  • (String)


17
18
19
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 17

def name
  @name
end

#statusString

[Required] The status of the job execution.

Returns:

  • (String)


45
46
47
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 45

def status
  @status
end

#time_completedDateTime

The date and time when the job execution was completed.

Returns:

  • (DateTime)


53
54
55
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 53

def time_completed
  @time_completed
end

#time_createdDateTime

[Required] The date and time when the job execution was created.

Returns:

  • (DateTime)


49
50
51
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 49

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 56

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'managed_database_group_id': :'managedDatabaseGroupId',
    'managed_database_id': :'managedDatabaseId',
    'managed_database_name': :'managedDatabaseName',
    'job_id': :'jobId',
    'job_name': :'jobName',
    'status': :'status',
    'time_created': :'timeCreated',
    'time_completed': :'timeCompleted'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 75

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'managed_database_group_id': :'String',
    'managed_database_id': :'String',
    'managed_database_name': :'String',
    'job_id': :'String',
    'job_name': :'String',
    'status': :'String',
    'time_created': :'DateTime',
    'time_completed': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 178

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    managed_database_group_id == other.managed_database_group_id &&
    managed_database_id == other.managed_database_id &&
    managed_database_name == other.managed_database_name &&
    job_id == other.job_id &&
    job_name == other.job_name &&
    status == other.status &&
    time_created == other.time_created &&
    time_completed == other.time_completed
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 218

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 198

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



207
208
209
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 207

def hash
  [id, name, compartment_id, managed_database_group_id, managed_database_id, managed_database_name, job_id, job_name, status, time_created, time_completed].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



245
246
247
# File 'lib/oci/database_management/models/job_execution_summary.rb', line 245

def to_s
  to_hash.to_s
end