Class: OCI::DatabaseManagement::Models::JobRunSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::JobRunSummary
- Defined in:
- lib/oci/database_management/models/job_run_summary.rb
Overview
A summary of a specific job run.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the parent job resides.
-
#id ⇒ String
[Required] The identifier of the job run.
-
#job_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent job.
-
#job_name ⇒ String
[Required] The name of the parent job.
-
#managed_database_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the parent job has to be executed.
-
#managed_database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database where the parent job has to be executed.
-
#name ⇒ String
[Required] The name of the job run.
-
#run_status ⇒ String
[Required] The status of the job run.
-
#time_submitted ⇒ DateTime
[Required] The date and time when the job run was submitted.
-
#time_updated ⇒ DateTime
[Required] The date and time when the job run was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JobRunSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ JobRunSummary
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 103 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.job_id = attributes[:'jobId'] if attributes[:'jobId'] raise 'You cannot provide both :jobId and :job_id' if attributes.key?(:'jobId') && attributes.key?(:'job_id') self.job_id = attributes[:'job_id'] if attributes[:'job_id'] self.job_name = attributes[:'jobName'] if attributes[:'jobName'] raise 'You cannot provide both :jobName and :job_name' if attributes.key?(:'jobName') && attributes.key?(:'job_name') self.job_name = attributes[:'job_name'] if attributes[:'job_name'] self.managed_database_group_id = attributes[:'managedDatabaseGroupId'] if attributes[:'managedDatabaseGroupId'] raise 'You cannot provide both :managedDatabaseGroupId and :managed_database_group_id' if attributes.key?(:'managedDatabaseGroupId') && attributes.key?(:'managed_database_group_id') self.managed_database_group_id = attributes[:'managed_database_group_id'] if attributes[:'managed_database_group_id'] self.managed_database_id = attributes[:'managedDatabaseId'] if attributes[:'managedDatabaseId'] raise 'You cannot provide both :managedDatabaseId and :managed_database_id' if attributes.key?(:'managedDatabaseId') && attributes.key?(:'managed_database_id') self.managed_database_id = attributes[:'managed_database_id'] if attributes[:'managed_database_id'] self.run_status = attributes[:'runStatus'] if attributes[:'runStatus'] raise 'You cannot provide both :runStatus and :run_status' if attributes.key?(:'runStatus') && attributes.key?(:'run_status') self.run_status = attributes[:'run_status'] if attributes[:'run_status'] self.time_submitted = attributes[:'timeSubmitted'] if attributes[:'timeSubmitted'] raise 'You cannot provide both :timeSubmitted and :time_submitted' if attributes.key?(:'timeSubmitted') && attributes.key?(:'time_submitted') self.time_submitted = attributes[:'time_submitted'] if attributes[:'time_submitted'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the parent job resides.
21 22 23 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 21 def compartment_id @compartment_id end |
#id ⇒ String
[Required] The identifier of the job run.
13 14 15 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 13 def id @id end |
#job_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent job.
25 26 27 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 25 def job_id @job_id end |
#job_name ⇒ String
[Required] The name of the parent job.
29 30 31 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 29 def job_name @job_name end |
#managed_database_group_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the parent job has to be executed.
33 34 35 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 33 def managed_database_group_id @managed_database_group_id end |
#managed_database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database where the parent job has to be executed.
37 38 39 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 37 def managed_database_id @managed_database_id end |
#name ⇒ String
[Required] The name of the job run.
17 18 19 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 17 def name @name end |
#run_status ⇒ String
[Required] The status of the job run.
41 42 43 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 41 def run_status @run_status end |
#time_submitted ⇒ DateTime
[Required] The date and time when the job run was submitted.
45 46 47 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 45 def time_submitted @time_submitted end |
#time_updated ⇒ DateTime
[Required] The date and time when the job run was last updated.
49 50 51 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 49 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 52 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'compartment_id': :'compartmentId', 'job_id': :'jobId', 'job_name': :'jobName', 'managed_database_group_id': :'managedDatabaseGroupId', 'managed_database_id': :'managedDatabaseId', 'run_status': :'runStatus', 'time_submitted': :'timeSubmitted', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 70 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'compartment_id': :'String', 'job_id': :'String', 'job_name': :'String', 'managed_database_group_id': :'String', 'managed_database_id': :'String', 'run_status': :'String', 'time_submitted': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 169 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && compartment_id == other.compartment_id && job_id == other.job_id && job_name == other.job_name && managed_database_group_id == other.managed_database_group_id && managed_database_id == other.managed_database_id && run_status == other.run_status && time_submitted == other.time_submitted && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 208 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
188 189 190 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 188 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
197 198 199 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 197 def hash [id, name, compartment_id, job_id, job_name, managed_database_group_id, managed_database_id, run_status, time_submitted, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 250 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
235 236 237 |
# File 'lib/oci/database_management/models/job_run_summary.rb', line 235 def to_s to_hash.to_s end |