Class: OCI::DatabaseManagement::Models::ManagedDatabase

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/managed_database.rb

Overview

The details of a Managed Database.

Constant Summary collapse

DATABASE_TYPE_ENUM =
[
  DATABASE_TYPE_EXTERNAL_SIDB = 'EXTERNAL_SIDB'.freeze,
  DATABASE_TYPE_EXTERNAL_RAC = 'EXTERNAL_RAC'.freeze,
  DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DATABASE_SUB_TYPE_ENUM =
[
  DATABASE_SUB_TYPE_CDB = 'CDB'.freeze,
  DATABASE_SUB_TYPE_PDB = 'PDB'.freeze,
  DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze,
  DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DATABASE_STATUS_ENUM =
[
  DATABASE_STATUS_UP = 'UP'.freeze,
  DATABASE_STATUS_DOWN = 'DOWN'.freeze,
  DATABASE_STATUS_UNKNOWN = 'UNKNOWN'.freeze,
  DATABASE_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ManagedDatabase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/oci/database_management/models/managed_database.rb', line 181

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.database_type = attributes[:'databaseType'] if attributes[:'databaseType']

  raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type')

  self.database_type = attributes[:'database_type'] if attributes[:'database_type']

  self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType']

  raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type')

  self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type']

  self.is_cluster = attributes[:'isCluster'] unless attributes[:'isCluster'].nil?

  raise 'You cannot provide both :isCluster and :is_cluster' if attributes.key?(:'isCluster') && attributes.key?(:'is_cluster')

  self.is_cluster = attributes[:'is_cluster'] unless attributes[:'is_cluster'].nil?

  self.parent_container_id = attributes[:'parentContainerId'] if attributes[:'parentContainerId']

  raise 'You cannot provide both :parentContainerId and :parent_container_id' if attributes.key?(:'parentContainerId') && attributes.key?(:'parent_container_id')

  self.parent_container_id = attributes[:'parent_container_id'] if attributes[:'parent_container_id']

  self.managed_database_groups = attributes[:'managedDatabaseGroups'] if attributes[:'managedDatabaseGroups']

  raise 'You cannot provide both :managedDatabaseGroups and :managed_database_groups' if attributes.key?(:'managedDatabaseGroups') && attributes.key?(:'managed_database_groups')

  self.managed_database_groups = attributes[:'managed_database_groups'] if attributes[:'managed_database_groups']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.database_status = attributes[:'databaseStatus'] if attributes[:'databaseStatus']

  raise 'You cannot provide both :databaseStatus and :database_status' if attributes.key?(:'databaseStatus') && attributes.key?(:'database_status')

  self.database_status = attributes[:'database_status'] if attributes[:'database_status']

  self.parent_container_name = attributes[:'parentContainerName'] if attributes[:'parentContainerName']

  raise 'You cannot provide both :parentContainerName and :parent_container_name' if attributes.key?(:'parentContainerName') && attributes.key?(:'parent_container_name')

  self.parent_container_name = attributes[:'parent_container_name'] if attributes[:'parent_container_name']

  self.parent_container_compartment_id = attributes[:'parentContainerCompartmentId'] if attributes[:'parentContainerCompartmentId']

  raise 'You cannot provide both :parentContainerCompartmentId and :parent_container_compartment_id' if attributes.key?(:'parentContainerCompartmentId') && attributes.key?(:'parent_container_compartment_id')

  self.parent_container_compartment_id = attributes[:'parent_container_compartment_id'] if attributes[:'parent_container_compartment_id']

  self.instance_count = attributes[:'instanceCount'] if attributes[:'instanceCount']

  raise 'You cannot provide both :instanceCount and :instance_count' if attributes.key?(:'instanceCount') && attributes.key?(:'instance_count')

  self.instance_count = attributes[:'instance_count'] if attributes[:'instance_count']

  self.instance_details = attributes[:'instanceDetails'] if attributes[:'instanceDetails']

  raise 'You cannot provide both :instanceDetails and :instance_details' if attributes.key?(:'instanceDetails') && attributes.key?(:'instance_details')

  self.instance_details = attributes[:'instance_details'] if attributes[:'instance_details']

  self.pdb_count = attributes[:'pdbCount'] if attributes[:'pdbCount']

  raise 'You cannot provide both :pdbCount and :pdb_count' if attributes.key?(:'pdbCount') && attributes.key?(:'pdb_count')

  self.pdb_count = attributes[:'pdb_count'] if attributes[:'pdb_count']

  self.pdb_status = attributes[:'pdbStatus'] if attributes[:'pdbStatus']

  raise 'You cannot provide both :pdbStatus and :pdb_status' if attributes.key?(:'pdbStatus') && attributes.key?(:'pdb_status')

  self.pdb_status = attributes[:'pdb_status'] if attributes[:'pdb_status']

  self.additional_details = attributes[:'additionalDetails'] if attributes[:'additionalDetails']

  raise 'You cannot provide both :additionalDetails and :additional_details' if attributes.key?(:'additionalDetails') && attributes.key?(:'additional_details')

  self.additional_details = attributes[:'additional_details'] if attributes[:'additional_details']
end

Instance Attribute Details

#additional_detailsHash<String, String>

The additional details specific to a type of database defined in ‘"value"` format. Example: `"value"`

Returns:

  • (Hash<String, String>)


106
107
108
# File 'lib/oci/database_management/models/managed_database.rb', line 106

def additional_details
  @additional_details
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


37
38
39
# File 'lib/oci/database_management/models/managed_database.rb', line 37

def compartment_id
  @compartment_id
end

#database_statusString

The status of the Oracle Database. Indicates whether the status of the database is UP, DOWN, or UNKNOWN at the current time.

Returns:

  • (String)


73
74
75
# File 'lib/oci/database_management/models/managed_database.rb', line 73

def database_status
  @database_status
end

#database_sub_typeString

[Required] The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.

Returns:

  • (String)


49
50
51
# File 'lib/oci/database_management/models/managed_database.rb', line 49

def database_sub_type
  @database_sub_type
end

#database_typeString

[Required] The type of Oracle Database installation.

Returns:

  • (String)


45
46
47
# File 'lib/oci/database_management/models/managed_database.rb', line 45

def database_type
  @database_type
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database.

Returns:

  • (String)


33
34
35
# File 'lib/oci/database_management/models/managed_database.rb', line 33

def id
  @id
end

#instance_countInteger

The number of Oracle Real Application Clusters (Oracle RAC) database instances.

Returns:

  • (Integer)


88
89
90
# File 'lib/oci/database_management/models/managed_database.rb', line 88

def instance_count
  @instance_count
end

#instance_detailsArray<OCI::DatabaseManagement::Models::InstanceDetails>

The details of the Oracle Real Application Clusters (Oracle RAC) database instances.



92
93
94
# File 'lib/oci/database_management/models/managed_database.rb', line 92

def instance_details
  @instance_details
end

#is_clusterBOOLEAN

[Required] Indicates whether the Oracle Database is part of a cluster.

Returns:

  • (BOOLEAN)


53
54
55
# File 'lib/oci/database_management/models/managed_database.rb', line 53

def is_cluster
  @is_cluster
end

#managed_database_groupsArray<OCI::DatabaseManagement::Models::ParentGroup>

A list of Managed Database Groups that the Managed Database belongs to.



63
64
65
# File 'lib/oci/database_management/models/managed_database.rb', line 63

def managed_database_groups
  @managed_database_groups
end

#nameString

[Required] The name of the Managed Database.

Returns:

  • (String)


41
42
43
# File 'lib/oci/database_management/models/managed_database.rb', line 41

def name
  @name
end

#parent_container_compartment_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the parent Container Database resides, if the Managed Database is a Pluggable Database (PDB).

Returns:

  • (String)


84
85
86
# File 'lib/oci/database_management/models/managed_database.rb', line 84

def parent_container_compartment_id
  @parent_container_compartment_id
end

#parent_container_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent Container Database if Managed Database is a Pluggable Database.

Returns:

  • (String)


59
60
61
# File 'lib/oci/database_management/models/managed_database.rb', line 59

def parent_container_id
  @parent_container_id
end

#parent_container_nameString

The name of the parent Container Database.

Returns:

  • (String)


77
78
79
# File 'lib/oci/database_management/models/managed_database.rb', line 77

def parent_container_name
  @parent_container_name
end

#pdb_countInteger

The number of PDBs in the Container Database.

Returns:

  • (Integer)


96
97
98
# File 'lib/oci/database_management/models/managed_database.rb', line 96

def pdb_count
  @pdb_count
end

#pdb_statusArray<OCI::DatabaseManagement::Models::PdbStatusDetails>

The status of the PDB in the Container Database.



100
101
102
# File 'lib/oci/database_management/models/managed_database.rb', line 100

def pdb_status
  @pdb_status
end

#time_createdDateTime

[Required] The date and time the Managed Database was created.

Returns:

  • (DateTime)


67
68
69
# File 'lib/oci/database_management/models/managed_database.rb', line 67

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/oci/database_management/models/managed_database.rb', line 109

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'name': :'name',
    'database_type': :'databaseType',
    'database_sub_type': :'databaseSubType',
    'is_cluster': :'isCluster',
    'parent_container_id': :'parentContainerId',
    'managed_database_groups': :'managedDatabaseGroups',
    'time_created': :'timeCreated',
    'database_status': :'databaseStatus',
    'parent_container_name': :'parentContainerName',
    'parent_container_compartment_id': :'parentContainerCompartmentId',
    'instance_count': :'instanceCount',
    'instance_details': :'instanceDetails',
    'pdb_count': :'pdbCount',
    'pdb_status': :'pdbStatus',
    'additional_details': :'additionalDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/database_management/models/managed_database.rb', line 134

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'name': :'String',
    'database_type': :'String',
    'database_sub_type': :'String',
    'is_cluster': :'BOOLEAN',
    'parent_container_id': :'String',
    'managed_database_groups': :'Array<OCI::DatabaseManagement::Models::ParentGroup>',
    'time_created': :'DateTime',
    'database_status': :'String',
    'parent_container_name': :'String',
    'parent_container_compartment_id': :'String',
    'instance_count': :'Integer',
    'instance_details': :'Array<OCI::DatabaseManagement::Models::InstanceDetails>',
    'pdb_count': :'Integer',
    'pdb_status': :'Array<OCI::DatabaseManagement::Models::PdbStatusDetails>',
    'additional_details': :'Hash<String, String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/oci/database_management/models/managed_database.rb', line 328

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    name == other.name &&
    database_type == other.database_type &&
    database_sub_type == other.database_sub_type &&
    is_cluster == other.is_cluster &&
    parent_container_id == other.parent_container_id &&
    managed_database_groups == other.managed_database_groups &&
    time_created == other.time_created &&
    database_status == other.database_status &&
    parent_container_name == other.parent_container_name &&
    parent_container_compartment_id == other.parent_container_compartment_id &&
    instance_count == other.instance_count &&
    instance_details == other.instance_details &&
    pdb_count == other.pdb_count &&
    pdb_status == other.pdb_status &&
    additional_details == other.additional_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/oci/database_management/models/managed_database.rb', line 374

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


354
355
356
# File 'lib/oci/database_management/models/managed_database.rb', line 354

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



363
364
365
# File 'lib/oci/database_management/models/managed_database.rb', line 363

def hash
  [id, compartment_id, name, database_type, database_sub_type, is_cluster, parent_container_id, managed_database_groups, time_created, database_status, parent_container_name, parent_container_compartment_id, instance_count, instance_details, pdb_count, pdb_status, additional_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



407
408
409
410
411
412
413
414
415
416
# File 'lib/oci/database_management/models/managed_database.rb', line 407

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



401
402
403
# File 'lib/oci/database_management/models/managed_database.rb', line 401

def to_s
  to_hash.to_s
end