Class: OCI::DatabaseManagement::Models::ManagedDatabaseSummary
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::ManagedDatabaseSummary
- Defined in:
- lib/oci/database_management/models/managed_database_summary.rb
Overview
A summary of the Managed Database.
Constant Summary collapse
- DATABASE_TYPE_ENUM =
[ DATABASE_TYPE_EXTERNAL_SIDB = 'EXTERNAL_SIDB'.freeze, DATABASE_TYPE_EXTERNAL_RAC = 'EXTERNAL_RAC'.freeze, DATABASE_TYPE_CLOUD_SIDB = 'CLOUD_SIDB'.freeze, DATABASE_TYPE_CLOUD_RAC = 'CLOUD_RAC'.freeze, DATABASE_TYPE_SHARED = 'SHARED'.freeze, DATABASE_TYPE_DEDICATED = 'DEDICATED'.freeze, DATABASE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DATABASE_SUB_TYPE_ENUM =
[ DATABASE_SUB_TYPE_CDB = 'CDB'.freeze, DATABASE_SUB_TYPE_PDB = 'PDB'.freeze, DATABASE_SUB_TYPE_NON_CDB = 'NON_CDB'.freeze, DATABASE_SUB_TYPE_ACD = 'ACD'.freeze, DATABASE_SUB_TYPE_ADB = 'ADB'.freeze, DATABASE_SUB_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DEPLOYMENT_TYPE_ENUM =
[ DEPLOYMENT_TYPE_ONPREMISE = 'ONPREMISE'.freeze, DEPLOYMENT_TYPE_BM = 'BM'.freeze, DEPLOYMENT_TYPE_VM = 'VM'.freeze, DEPLOYMENT_TYPE_EXADATA = 'EXADATA'.freeze, DEPLOYMENT_TYPE_EXADATA_CC = 'EXADATA_CC'.freeze, DEPLOYMENT_TYPE_AUTONOMOUS = 'AUTONOMOUS'.freeze, DEPLOYMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- MANAGEMENT_OPTION_ENUM =
[ MANAGEMENT_OPTION_BASIC = 'BASIC'.freeze, MANAGEMENT_OPTION_ADVANCED = 'ADVANCED'.freeze, MANAGEMENT_OPTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- WORKLOAD_TYPE_ENUM =
[ WORKLOAD_TYPE_OLTP = 'OLTP'.freeze, WORKLOAD_TYPE_DW = 'DW'.freeze, WORKLOAD_TYPE_AJD = 'AJD'.freeze, WORKLOAD_TYPE_APEX = 'APEX'.freeze, WORKLOAD_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#database_sub_type ⇒ String
[Required] The subtype of the Oracle Database.
-
#database_type ⇒ String
[Required] The type of Oracle Database installation.
-
#deployment_type ⇒ String
The infrastructure used to deploy the Oracle Database.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database.
-
#is_cluster ⇒ BOOLEAN
[Required] Indicates whether the Oracle Database is part of a cluster.
-
#management_option ⇒ String
The management option used when enabling Database Management.
-
#name ⇒ String
[Required] The name of the Managed Database.
-
#parent_container_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent Container Database if the Managed Database is a Pluggable Database.
-
#time_created ⇒ DateTime
[Required] The date and time the Managed Database was created.
-
#workload_type ⇒ String
The workload type of the Autonomous Database.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagedDatabaseSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ManagedDatabaseSummary
Initializes the object
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 157 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.database_sub_type = attributes[:'databaseSubType'] if attributes[:'databaseSubType'] raise 'You cannot provide both :databaseSubType and :database_sub_type' if attributes.key?(:'databaseSubType') && attributes.key?(:'database_sub_type') self.database_sub_type = attributes[:'database_sub_type'] if attributes[:'database_sub_type'] self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType'] raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type') self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type'] self.management_option = attributes[:'managementOption'] if attributes[:'managementOption'] raise 'You cannot provide both :managementOption and :management_option' if attributes.key?(:'managementOption') && attributes.key?(:'management_option') self.management_option = attributes[:'management_option'] if attributes[:'management_option'] self.workload_type = attributes[:'workloadType'] if attributes[:'workloadType'] raise 'You cannot provide both :workloadType and :workload_type' if attributes.key?(:'workloadType') && attributes.key?(:'workload_type') self.workload_type = attributes[:'workload_type'] if attributes[:'workload_type'] self.is_cluster = attributes[:'isCluster'] unless attributes[:'isCluster'].nil? raise 'You cannot provide both :isCluster and :is_cluster' if attributes.key?(:'isCluster') && attributes.key?(:'is_cluster') self.is_cluster = attributes[:'is_cluster'] unless attributes[:'is_cluster'].nil? self.parent_container_id = attributes[:'parentContainerId'] if attributes[:'parentContainerId'] raise 'You cannot provide both :parentContainerId and :parent_container_id' if attributes.key?(:'parentContainerId') && attributes.key?(:'parent_container_id') self.parent_container_id = attributes[:'parent_container_id'] if attributes[:'parent_container_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
60 61 62 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 60 def compartment_id @compartment_id end |
#database_sub_type ⇒ String
[Required] The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, Non-container Database, Autonomous Database, or Autonomous Container Database.
74 75 76 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 74 def database_sub_type @database_sub_type end |
#database_type ⇒ String
[Required] The type of Oracle Database installation.
68 69 70 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 68 def database_type @database_type end |
#deployment_type ⇒ String
The infrastructure used to deploy the Oracle Database.
78 79 80 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 78 def deployment_type @deployment_type end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database.
56 57 58 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 56 def id @id end |
#is_cluster ⇒ BOOLEAN
[Required] Indicates whether the Oracle Database is part of a cluster.
90 91 92 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 90 def is_cluster @is_cluster end |
#management_option ⇒ String
The management option used when enabling Database Management.
82 83 84 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 82 def management_option @management_option end |
#name ⇒ String
[Required] The name of the Managed Database.
64 65 66 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 64 def name @name end |
#parent_container_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent Container Database if the Managed Database is a Pluggable Database.
96 97 98 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 96 def parent_container_id @parent_container_id end |
#time_created ⇒ DateTime
[Required] The date and time the Managed Database was created.
100 101 102 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 100 def time_created @time_created end |
#workload_type ⇒ String
The workload type of the Autonomous Database.
86 87 88 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 86 def workload_type @workload_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 103 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'database_type': :'databaseType', 'database_sub_type': :'databaseSubType', 'deployment_type': :'deploymentType', 'management_option': :'managementOption', 'workload_type': :'workloadType', 'is_cluster': :'isCluster', 'parent_container_id': :'parentContainerId', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 122 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'database_type': :'String', 'database_sub_type': :'String', 'deployment_type': :'String', 'management_option': :'String', 'workload_type': :'String', 'is_cluster': :'BOOLEAN', 'parent_container_id': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 294 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && name == other.name && database_type == other.database_type && database_sub_type == other.database_sub_type && deployment_type == other.deployment_type && management_option == other.management_option && workload_type == other.workload_type && is_cluster == other.is_cluster && parent_container_id == other.parent_container_id && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 334 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
314 315 316 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 314 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
323 324 325 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 323 def hash [id, compartment_id, name, database_type, database_sub_type, deployment_type, management_option, workload_type, is_cluster, parent_container_id, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
367 368 369 370 371 372 373 374 375 376 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 367 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
361 362 363 |
# File 'lib/oci/database_management/models/managed_database_summary.rb', line 361 def to_s to_hash.to_s end |