Class: OCI::DatabaseManagement::Models::ObjectStorageJobExecutionResultDetails

Inherits:
JobExecutionResultDetails show all
Defined in:
lib/oci/database_management/models/object_storage_job_execution_result_details.rb

Overview

The details of the job execution result stored in Object Storage. The job execution result could be accessed using the Object Storage API.

Constant Summary

Constants inherited from JobExecutionResultDetails

JobExecutionResultDetails::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from JobExecutionResultDetails

#type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from JobExecutionResultDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ ObjectStorageJobExecutionResultDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :namespace_name (String)

    The value to assign to the #namespace_name property

  • :bucket_name (String)

    The value to assign to the #bucket_name property

  • :object_name (String)

    The value to assign to the #object_name property

  • :row_count (Integer)

    The value to assign to the #row_count property



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 65

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'OBJECT_STORAGE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.namespace_name = attributes[:'namespaceName'] if attributes[:'namespaceName']

  raise 'You cannot provide both :namespaceName and :namespace_name' if attributes.key?(:'namespaceName') && attributes.key?(:'namespace_name')

  self.namespace_name = attributes[:'namespace_name'] if attributes[:'namespace_name']

  self.bucket_name = attributes[:'bucketName'] if attributes[:'bucketName']

  raise 'You cannot provide both :bucketName and :bucket_name' if attributes.key?(:'bucketName') && attributes.key?(:'bucket_name')

  self.bucket_name = attributes[:'bucket_name'] if attributes[:'bucket_name']

  self.object_name = attributes[:'objectName'] if attributes[:'objectName']

  raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name')

  self.object_name = attributes[:'object_name'] if attributes[:'object_name']

  self.row_count = attributes[:'rowCount'] if attributes[:'rowCount']

  raise 'You cannot provide both :rowCount and :row_count' if attributes.key?(:'rowCount') && attributes.key?(:'row_count')

  self.row_count = attributes[:'row_count'] if attributes[:'row_count']
end

Instance Attribute Details

#bucket_nameString

The name of the bucket used for job execution result storage.

Returns:

  • (String)


19
20
21
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 19

def bucket_name
  @bucket_name
end

#namespace_nameString

The Object Storage namespace used for job execution result storage.

Returns:

  • (String)


15
16
17
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 15

def namespace_name
  @namespace_name
end

#object_nameString

The name of the object containing the job execution result.

Returns:

  • (String)


23
24
25
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 23

def object_name
  @object_name
end

#row_countInteger

The number of rows returned in the result. Only applicable for QUERY SqlType.

Returns:

  • (Integer)


27
28
29
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 27

def row_count
  @row_count
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
39
40
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 30

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'namespace_name': :'namespaceName',
    'bucket_name': :'bucketName',
    'object_name': :'objectName',
    'row_count': :'rowCount'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
50
51
52
53
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 43

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'namespace_name': :'String',
    'bucket_name': :'String',
    'object_name': :'String',
    'row_count': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



107
108
109
110
111
112
113
114
115
116
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 107

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    namespace_name == other.namespace_name &&
    bucket_name == other.bucket_name &&
    object_name == other.object_name &&
    row_count == other.row_count
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 141

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


121
122
123
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 121

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



130
131
132
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 130

def hash
  [type, namespace_name, bucket_name, object_name, row_count].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



174
175
176
177
178
179
180
181
182
183
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 174

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



168
169
170
# File 'lib/oci/database_management/models/object_storage_job_execution_result_details.rb', line 168

def to_s
  to_hash.to_s
end