Class: DatabaseManagement::Models::SqlJob
- Inherits:
-
Job
- Object
- Job
- DatabaseManagement::Models::SqlJob
- Defined in:
- lib/oci/database_management/models/sql_job.rb
Overview
The details of the SQL job.
Constant Summary collapse
- SQL_TYPE_ENUM =
[ SQL_TYPE_QUERY = 'QUERY'.freeze, SQL_TYPE_DML = 'DML'.freeze, SQL_TYPE_DDL = 'DDL'.freeze, SQL_TYPE_PLSQL = 'PLSQL'.freeze, SQL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- OPERATION_TYPE_ENUM =
[ OPERATION_TYPE_EXECUTE_SQL = 'EXECUTE_SQL'.freeze, OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ROLE_ENUM =
[ ROLE_NORMAL = 'NORMAL'.freeze, ROLE_SYSDBA = 'SYSDBA'.freeze, ROLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#operation_type ⇒ String
**[Required]** The SQL operation type.
-
#role ⇒ String
The role of the database user.
-
#sql_text ⇒ String
The SQL text to be executed in the job.
-
#sql_type ⇒ String
The type of SQL.
-
#user_name ⇒ String
The database user name used to execute the SQL job.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlJob
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlJob
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/database_management/models/sql_job.rb', line 140 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['jobType'] = 'SQL' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.sql_type = attributes[:'sqlType'] if attributes[:'sqlType'] raise 'You cannot provide both :sqlType and :sql_type' if attributes.key?(:'sqlType') && attributes.key?(:'sql_type') self.sql_type = attributes[:'sql_type'] if attributes[:'sql_type'] self.sql_text = attributes[:'sqlText'] if attributes[:'sqlText'] raise 'You cannot provide both :sqlText and :sql_text' if attributes.key?(:'sqlText') && attributes.key?(:'sql_text') self.sql_text = attributes[:'sql_text'] if attributes[:'sql_text'] self.operation_type = attributes[:'operationType'] if attributes[:'operationType'] raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type'] self.user_name = attributes[:'userName'] if attributes[:'userName'] raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] if attributes[:'user_name'] self.role = attributes[:'role'] if attributes[:'role'] end |
Instance Attribute Details
#operation_type ⇒ String
**[Required]** The SQL operation type.
41 42 43 |
# File 'lib/oci/database_management/models/sql_job.rb', line 41 def operation_type @operation_type end |
#role ⇒ String
The role of the database user. Indicates whether the database user is a normal user or sysdba.
51 52 53 |
# File 'lib/oci/database_management/models/sql_job.rb', line 51 def role @role end |
#sql_text ⇒ String
The SQL text to be executed in the job. This is a mandatory field for the EXECUTE_SQL operationType.
37 38 39 |
# File 'lib/oci/database_management/models/sql_job.rb', line 37 def sql_text @sql_text end |
#sql_type ⇒ String
The type of SQL. This is a mandatory field for the EXECUTE_SQL operationType.
33 34 35 |
# File 'lib/oci/database_management/models/sql_job.rb', line 33 def sql_type @sql_type end |
#user_name ⇒ String
The database user name used to execute the SQL job. If the job is being executed on a Managed Database Group, then the user name should exist on all the databases in the group with the same password.
47 48 49 |
# File 'lib/oci/database_management/models/sql_job.rb', line 47 def user_name @user_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/oci/database_management/models/sql_job.rb', line 54 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'managed_database_group_id': :'managedDatabaseGroupId', 'managed_database_id': :'managedDatabaseId', 'managed_databases_details': :'managedDatabasesDetails', 'database_sub_type': :'databaseSubType', 'schedule_type': :'scheduleType', 'job_type': :'jobType', 'lifecycle_state': :'lifecycleState', 'timeout': :'timeout', 'result_location': :'resultLocation', 'schedule_details': :'scheduleDetails', 'submission_error_message': :'submissionErrorMessage', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'sql_type': :'sqlType', 'sql_text': :'sqlText', 'operation_type': :'operationType', 'user_name': :'userName', 'role': :'role' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/database_management/models/sql_job.rb', line 84 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'managed_database_group_id': :'String', 'managed_database_id': :'String', 'managed_databases_details': :'Array<OCI::DatabaseManagement::Models::JobDatabase>', 'database_sub_type': :'String', 'schedule_type': :'String', 'job_type': :'String', 'lifecycle_state': :'String', 'timeout': :'String', 'result_location': :'OCI::DatabaseManagement::Models::JobExecutionResultLocation', 'schedule_details': :'OCI::DatabaseManagement::Models::JobScheduleDetails', 'submission_error_message': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'sql_type': :'String', 'sql_text': :'String', 'operation_type': :'String', 'user_name': :'String', 'role': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/database_management/models/sql_job.rb', line 223 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && name == other.name && description == other.description && managed_database_group_id == other.managed_database_group_id && managed_database_id == other.managed_database_id && managed_databases_details == other.managed_databases_details && database_sub_type == other.database_sub_type && schedule_type == other.schedule_type && job_type == other.job_type && lifecycle_state == other.lifecycle_state && timeout == other.timeout && result_location == other.result_location && schedule_details == other.schedule_details && == other. && time_created == other.time_created && time_updated == other.time_updated && sql_type == other.sql_type && sql_text == other.sql_text && operation_type == other.operation_type && user_name == other.user_name && role == other.role end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/oci/database_management/models/sql_job.rb', line 274 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
254 255 256 |
# File 'lib/oci/database_management/models/sql_job.rb', line 254 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/oci/database_management/models/sql_job.rb', line 263 def hash [id, compartment_id, name, description, managed_database_group_id, managed_database_id, managed_databases_details, database_sub_type, schedule_type, job_type, lifecycle_state, timeout, result_location, schedule_details, , time_created, time_updated, sql_type, sql_text, operation_type, user_name, role].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
307 308 309 310 311 312 313 314 315 316 |
# File 'lib/oci/database_management/models/sql_job.rb', line 307 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
301 302 303 |
# File 'lib/oci/database_management/models/sql_job.rb', line 301 def to_s to_hash.to_s end |