Class: OCI::DatabaseManagement::Models::SqlTuningAdvisorTaskSummaryReportTaskInfo
- Inherits:
-
Object
- Object
- OCI::DatabaseManagement::Models::SqlTuningAdvisorTaskSummaryReportTaskInfo
- Defined in:
- lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb
Overview
SQL Tuning advisor task general info.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_COMPLETED = 'COMPLETED'.freeze, STATUS_INITIAL = 'INITIAL'.freeze, STATUS_EXECUTING = 'EXECUTING'.freeze, STATUS_INTERRUPTED = 'INTERRUPTED'.freeze, STATUS_ERROR = 'ERROR'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
The SQL Tuning Advisor task description.
-
#id ⇒ Integer
[Required] The SQL Tuning Advisor task id.
-
#name ⇒ String
[Required] The SQL Tuning Advisor task name.
-
#owner ⇒ String
[Required] The SQL Tuning Advisor task user owner.
-
#running_time ⇒ Integer
The total running time in seconds.
-
#status ⇒ String
The SQL Tuning Advisor task status.
-
#time_ended ⇒ DateTime
[Required] End timestamp of task execution.
-
#time_started ⇒ DateTime
[Required] Start timestamp of task execution.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlTuningAdvisorTaskSummaryReportTaskInfo
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlTuningAdvisorTaskSummaryReportTaskInfo
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 98 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.owner = attributes[:'owner'] if attributes[:'owner'] self.status = attributes[:'status'] if attributes[:'status'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded'] raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended') self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended'] self.running_time = attributes[:'runningTime'] if attributes[:'runningTime'] raise 'You cannot provide both :runningTime and :running_time' if attributes.key?(:'runningTime') && attributes.key?(:'running_time') self.running_time = attributes[:'running_time'] if attributes[:'running_time'] end |
Instance Attribute Details
#description ⇒ String
The SQL Tuning Advisor task description. Not defined on Auto SQL Tuning tasks.
30 31 32 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 30 def description @description end |
#id ⇒ Integer
[Required] The SQL Tuning Advisor task id. It is not the [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
22 23 24 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 22 def id @id end |
#name ⇒ String
[Required] The SQL Tuning Advisor task name.
26 27 28 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 26 def name @name end |
#owner ⇒ String
[Required] The SQL Tuning Advisor task user owner.
34 35 36 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 34 def owner @owner end |
#running_time ⇒ Integer
The total running time in seconds. Not defined on Auto SQL Tuning tasks.
50 51 52 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 50 def running_time @running_time end |
#status ⇒ String
The SQL Tuning Advisor task status. Not defined on Auto SQL Tuning tasks.
38 39 40 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 38 def status @status end |
#time_ended ⇒ DateTime
[Required] End timestamp of task execution.
46 47 48 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 46 def time_ended @time_ended end |
#time_started ⇒ DateTime
[Required] Start timestamp of task execution.
42 43 44 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 42 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 53 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'description': :'description', 'owner': :'owner', 'status': :'status', 'time_started': :'timeStarted', 'time_ended': :'timeEnded', 'running_time': :'runningTime' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'Integer', 'name': :'String', 'description': :'String', 'owner': :'String', 'status': :'String', 'time_started': :'DateTime', 'time_ended': :'DateTime', 'running_time': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 153 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && owner == other.owner && status == other.status && time_started == other.time_started && time_ended == other.time_ended && running_time == other.running_time end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 190 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
170 171 172 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 170 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 179 def hash [id, name, description, owner, status, time_started, time_ended, running_time].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
217 218 219 |
# File 'lib/oci/database_management/models/sql_tuning_advisor_task_summary_report_task_info.rb', line 217 def to_s to_hash.to_s end |