Class: OCI::DatabaseManagement::Models::TablespaceSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/database_management/models/tablespace_summary.rb

Overview

The summary of a tablespace.

Constant Summary collapse

TYPE_ENUM =
[
  TYPE_UNDO = 'UNDO'.freeze,
  TYPE_LOST_WRITE_PROTECTION = 'LOST_WRITE_PROTECTION'.freeze,
  TYPE_PERMANENT = 'PERMANENT'.freeze,
  TYPE_TEMPORARY = 'TEMPORARY'.freeze,
  TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_ONLINE = 'ONLINE'.freeze,
  STATUS_OFFLINE = 'OFFLINE'.freeze,
  STATUS_READ_ONLY = 'READ_ONLY'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LOGGING_ENUM =
[
  LOGGING_LOGGING = 'LOGGING'.freeze,
  LOGGING_NOLOGGING = 'NOLOGGING'.freeze,
  LOGGING_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
EXTENT_MANAGEMENT_ENUM =
[
  EXTENT_MANAGEMENT_LOCAL = 'LOCAL'.freeze,
  EXTENT_MANAGEMENT_DICTIONARY = 'DICTIONARY'.freeze,
  EXTENT_MANAGEMENT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
ALLOCATION_TYPE_ENUM =
[
  ALLOCATION_TYPE_SYSTEM = 'SYSTEM'.freeze,
  ALLOCATION_TYPE_UNIFORM = 'UNIFORM'.freeze,
  ALLOCATION_TYPE_USER = 'USER'.freeze,
  ALLOCATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
SEGMENT_SPACE_MANAGEMENT_ENUM =
[
  SEGMENT_SPACE_MANAGEMENT_MANUAL = 'MANUAL'.freeze,
  SEGMENT_SPACE_MANAGEMENT_AUTO = 'AUTO'.freeze,
  SEGMENT_SPACE_MANAGEMENT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEFAULT_TABLE_COMPRESSION_ENUM =
[
  DEFAULT_TABLE_COMPRESSION_ENABLED = 'ENABLED'.freeze,
  DEFAULT_TABLE_COMPRESSION_DISABLED = 'DISABLED'.freeze,
  DEFAULT_TABLE_COMPRESSION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
RETENTION_ENUM =
[
  RETENTION_GUARANTEE = 'GUARANTEE'.freeze,
  RETENTION_NOGUARANTEE = 'NOGUARANTEE'.freeze,
  RETENTION_NOT_APPLY = 'NOT_APPLY'.freeze,
  RETENTION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PREDICATE_EVALUATION_ENUM =
[
  PREDICATE_EVALUATION_HOST = 'HOST'.freeze,
  PREDICATE_EVALUATION_STORAGE = 'STORAGE'.freeze,
  PREDICATE_EVALUATION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
COMPRESS_FOR_ENUM =
[
  COMPRESS_FOR_BASIC = 'BASIC'.freeze,
  COMPRESS_FOR_ADVANCED = 'ADVANCED'.freeze,
  COMPRESS_FOR_QUERY_LOW = 'QUERY_LOW'.freeze,
  COMPRESS_FOR_QUERY_HIGH = 'QUERY_HIGH'.freeze,
  COMPRESS_FOR_ARCHIVE_LOW = 'ARCHIVE_LOW'.freeze,
  COMPRESS_FOR_ARCHIVE_HIGH = 'ARCHIVE_HIGH'.freeze,
  COMPRESS_FOR_DIRECT_LOAD_ONLY = 'DIRECT_LOAD_ONLY'.freeze,
  COMPRESS_FOR_FOR_ALL_OPERATIONS = 'FOR_ALL_OPERATIONS'.freeze,
  COMPRESS_FOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEFAULT_IN_MEMORY_ENUM =
[
  DEFAULT_IN_MEMORY_ENABLED = 'ENABLED'.freeze,
  DEFAULT_IN_MEMORY_DISABLED = 'DISABLED'.freeze,
  DEFAULT_IN_MEMORY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEFAULT_IN_MEMORY_PRIORITY_ENUM =
[
  DEFAULT_IN_MEMORY_PRIORITY_LOW = 'LOW'.freeze,
  DEFAULT_IN_MEMORY_PRIORITY_MEDIUM = 'MEDIUM'.freeze,
  DEFAULT_IN_MEMORY_PRIORITY_HIGH = 'HIGH'.freeze,
  DEFAULT_IN_MEMORY_PRIORITY_CRITICAL = 'CRITICAL'.freeze,
  DEFAULT_IN_MEMORY_PRIORITY_NONE = 'NONE'.freeze,
  DEFAULT_IN_MEMORY_PRIORITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEFAULT_IN_MEMORY_DISTRIBUTE_ENUM =
[
  DEFAULT_IN_MEMORY_DISTRIBUTE_AUTO = 'AUTO'.freeze,
  DEFAULT_IN_MEMORY_DISTRIBUTE_BY_ROWID_RANGE = 'BY_ROWID_RANGE'.freeze,
  DEFAULT_IN_MEMORY_DISTRIBUTE_BY_PARTITION = 'BY_PARTITION'.freeze,
  DEFAULT_IN_MEMORY_DISTRIBUTE_BY_SUBPARTITION = 'BY_SUBPARTITION'.freeze,
  DEFAULT_IN_MEMORY_DISTRIBUTE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEFAULT_IN_MEMORY_COMPRESSION_ENUM =
[
  DEFAULT_IN_MEMORY_COMPRESSION_NO_MEMCOMPRESS = 'NO_MEMCOMPRESS'.freeze,
  DEFAULT_IN_MEMORY_COMPRESSION_FOR_DML = 'FOR_DML'.freeze,
  DEFAULT_IN_MEMORY_COMPRESSION_FOR_QUERY_LOW = 'FOR_QUERY_LOW'.freeze,
  DEFAULT_IN_MEMORY_COMPRESSION_FOR_QUERY_HIGH = 'FOR_QUERY_HIGH'.freeze,
  DEFAULT_IN_MEMORY_COMPRESSION_FOR_CAPACITY_LOW = 'FOR_CAPACITY_LOW'.freeze,
  DEFAULT_IN_MEMORY_COMPRESSION_FOR_CAPACITY_HIGH = 'FOR_CAPACITY_HIGH'.freeze,
  DEFAULT_IN_MEMORY_COMPRESSION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEFAULT_IN_MEMORY_DUPLICATE_ENUM =
[
  DEFAULT_IN_MEMORY_DUPLICATE_NO_DUPLICATE = 'NO_DUPLICATE'.freeze,
  DEFAULT_IN_MEMORY_DUPLICATE_DUPLICATE = 'DUPLICATE'.freeze,
  DEFAULT_IN_MEMORY_DUPLICATE_DUPLICATE_ALL = 'DUPLICATE_ALL'.freeze,
  DEFAULT_IN_MEMORY_DUPLICATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
SHARED_ENUM =
[
  SHARED_SHARED = 'SHARED'.freeze,
  SHARED_LOCAL_ON_LEAF = 'LOCAL_ON_LEAF'.freeze,
  SHARED_LOCAL_ON_ALL = 'LOCAL_ON_ALL'.freeze,
  SHARED_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEFAULT_INDEX_COMPRESSION_ENUM =
[
  DEFAULT_INDEX_COMPRESSION_ENABLED = 'ENABLED'.freeze,
  DEFAULT_INDEX_COMPRESSION_DISABLED = 'DISABLED'.freeze,
  DEFAULT_INDEX_COMPRESSION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
INDEX_COMPRESS_FOR_ENUM =
[
  INDEX_COMPRESS_FOR_ADVANCED_LOW = 'ADVANCED_LOW'.freeze,
  INDEX_COMPRESS_FOR_ADVANCED_HIGH = 'ADVANCED_HIGH'.freeze,
  INDEX_COMPRESS_FOR_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
DEFAULT_IN_MEMORY_SERVICE_ENUM =
[
  DEFAULT_IN_MEMORY_SERVICE_DEFAULT = 'DEFAULT'.freeze,
  DEFAULT_IN_MEMORY_SERVICE_NONE = 'NONE'.freeze,
  DEFAULT_IN_MEMORY_SERVICE_ALL = 'ALL'.freeze,
  DEFAULT_IN_MEMORY_SERVICE_USER_DEFINED = 'USER_DEFINED'.freeze,
  DEFAULT_IN_MEMORY_SERVICE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LOST_WRITE_PROTECT_ENUM =
[
  LOST_WRITE_PROTECT_ENABLED = 'ENABLED'.freeze,
  LOST_WRITE_PROTECT_PROTECT_OFF = 'PROTECT_OFF'.freeze,
  LOST_WRITE_PROTECT_SUSPEND = 'SUSPEND'.freeze,
  LOST_WRITE_PROTECT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TablespaceSummary

Initializes the object

Options Hash (attributes):



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 444

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.type = attributes[:'type'] if attributes[:'type']

  self.status = attributes[:'status'] if attributes[:'status']

  self.block_size_bytes = attributes[:'blockSizeBytes'] if attributes[:'blockSizeBytes']

  raise 'You cannot provide both :blockSizeBytes and :block_size_bytes' if attributes.key?(:'blockSizeBytes') && attributes.key?(:'block_size_bytes')

  self.block_size_bytes = attributes[:'block_size_bytes'] if attributes[:'block_size_bytes']

  self.logging = attributes[:'logging'] if attributes[:'logging']

  self.is_force_logging = attributes[:'isForceLogging'] unless attributes[:'isForceLogging'].nil?

  raise 'You cannot provide both :isForceLogging and :is_force_logging' if attributes.key?(:'isForceLogging') && attributes.key?(:'is_force_logging')

  self.is_force_logging = attributes[:'is_force_logging'] unless attributes[:'is_force_logging'].nil?

  self.extent_management = attributes[:'extentManagement'] if attributes[:'extentManagement']

  raise 'You cannot provide both :extentManagement and :extent_management' if attributes.key?(:'extentManagement') && attributes.key?(:'extent_management')

  self.extent_management = attributes[:'extent_management'] if attributes[:'extent_management']

  self.allocation_type = attributes[:'allocationType'] if attributes[:'allocationType']

  raise 'You cannot provide both :allocationType and :allocation_type' if attributes.key?(:'allocationType') && attributes.key?(:'allocation_type')

  self.allocation_type = attributes[:'allocation_type'] if attributes[:'allocation_type']

  self.is_plugged_in = attributes[:'isPluggedIn'] unless attributes[:'isPluggedIn'].nil?

  raise 'You cannot provide both :isPluggedIn and :is_plugged_in' if attributes.key?(:'isPluggedIn') && attributes.key?(:'is_plugged_in')

  self.is_plugged_in = attributes[:'is_plugged_in'] unless attributes[:'is_plugged_in'].nil?

  self.segment_space_management = attributes[:'segmentSpaceManagement'] if attributes[:'segmentSpaceManagement']

  raise 'You cannot provide both :segmentSpaceManagement and :segment_space_management' if attributes.key?(:'segmentSpaceManagement') && attributes.key?(:'segment_space_management')

  self.segment_space_management = attributes[:'segment_space_management'] if attributes[:'segment_space_management']

  self.default_table_compression = attributes[:'defaultTableCompression'] if attributes[:'defaultTableCompression']

  raise 'You cannot provide both :defaultTableCompression and :default_table_compression' if attributes.key?(:'defaultTableCompression') && attributes.key?(:'default_table_compression')

  self.default_table_compression = attributes[:'default_table_compression'] if attributes[:'default_table_compression']

  self.retention = attributes[:'retention'] if attributes[:'retention']

  self.is_bigfile = attributes[:'isBigfile'] unless attributes[:'isBigfile'].nil?

  raise 'You cannot provide both :isBigfile and :is_bigfile' if attributes.key?(:'isBigfile') && attributes.key?(:'is_bigfile')

  self.is_bigfile = attributes[:'is_bigfile'] unless attributes[:'is_bigfile'].nil?

  self.predicate_evaluation = attributes[:'predicateEvaluation'] if attributes[:'predicateEvaluation']

  raise 'You cannot provide both :predicateEvaluation and :predicate_evaluation' if attributes.key?(:'predicateEvaluation') && attributes.key?(:'predicate_evaluation')

  self.predicate_evaluation = attributes[:'predicate_evaluation'] if attributes[:'predicate_evaluation']

  self.is_encrypted = attributes[:'isEncrypted'] unless attributes[:'isEncrypted'].nil?

  raise 'You cannot provide both :isEncrypted and :is_encrypted' if attributes.key?(:'isEncrypted') && attributes.key?(:'is_encrypted')

  self.is_encrypted = attributes[:'is_encrypted'] unless attributes[:'is_encrypted'].nil?

  self.compress_for = attributes[:'compressFor'] if attributes[:'compressFor']

  raise 'You cannot provide both :compressFor and :compress_for' if attributes.key?(:'compressFor') && attributes.key?(:'compress_for')

  self.compress_for = attributes[:'compress_for'] if attributes[:'compress_for']

  self.default_in_memory = attributes[:'defaultInMemory'] if attributes[:'defaultInMemory']

  raise 'You cannot provide both :defaultInMemory and :default_in_memory' if attributes.key?(:'defaultInMemory') && attributes.key?(:'default_in_memory')

  self.default_in_memory = attributes[:'default_in_memory'] if attributes[:'default_in_memory']

  self.default_in_memory_priority = attributes[:'defaultInMemoryPriority'] if attributes[:'defaultInMemoryPriority']

  raise 'You cannot provide both :defaultInMemoryPriority and :default_in_memory_priority' if attributes.key?(:'defaultInMemoryPriority') && attributes.key?(:'default_in_memory_priority')

  self.default_in_memory_priority = attributes[:'default_in_memory_priority'] if attributes[:'default_in_memory_priority']

  self.default_in_memory_distribute = attributes[:'defaultInMemoryDistribute'] if attributes[:'defaultInMemoryDistribute']

  raise 'You cannot provide both :defaultInMemoryDistribute and :default_in_memory_distribute' if attributes.key?(:'defaultInMemoryDistribute') && attributes.key?(:'default_in_memory_distribute')

  self.default_in_memory_distribute = attributes[:'default_in_memory_distribute'] if attributes[:'default_in_memory_distribute']

  self.default_in_memory_compression = attributes[:'defaultInMemoryCompression'] if attributes[:'defaultInMemoryCompression']

  raise 'You cannot provide both :defaultInMemoryCompression and :default_in_memory_compression' if attributes.key?(:'defaultInMemoryCompression') && attributes.key?(:'default_in_memory_compression')

  self.default_in_memory_compression = attributes[:'default_in_memory_compression'] if attributes[:'default_in_memory_compression']

  self.default_in_memory_duplicate = attributes[:'defaultInMemoryDuplicate'] if attributes[:'defaultInMemoryDuplicate']

  raise 'You cannot provide both :defaultInMemoryDuplicate and :default_in_memory_duplicate' if attributes.key?(:'defaultInMemoryDuplicate') && attributes.key?(:'default_in_memory_duplicate')

  self.default_in_memory_duplicate = attributes[:'default_in_memory_duplicate'] if attributes[:'default_in_memory_duplicate']

  self.shared = attributes[:'shared'] if attributes[:'shared']

  self.default_index_compression = attributes[:'defaultIndexCompression'] if attributes[:'defaultIndexCompression']

  raise 'You cannot provide both :defaultIndexCompression and :default_index_compression' if attributes.key?(:'defaultIndexCompression') && attributes.key?(:'default_index_compression')

  self.default_index_compression = attributes[:'default_index_compression'] if attributes[:'default_index_compression']

  self.index_compress_for = attributes[:'indexCompressFor'] if attributes[:'indexCompressFor']

  raise 'You cannot provide both :indexCompressFor and :index_compress_for' if attributes.key?(:'indexCompressFor') && attributes.key?(:'index_compress_for')

  self.index_compress_for = attributes[:'index_compress_for'] if attributes[:'index_compress_for']

  self.default_cell_memory = attributes[:'defaultCellMemory'] if attributes[:'defaultCellMemory']

  raise 'You cannot provide both :defaultCellMemory and :default_cell_memory' if attributes.key?(:'defaultCellMemory') && attributes.key?(:'default_cell_memory')

  self.default_cell_memory = attributes[:'default_cell_memory'] if attributes[:'default_cell_memory']

  self.default_in_memory_service = attributes[:'defaultInMemoryService'] if attributes[:'defaultInMemoryService']

  raise 'You cannot provide both :defaultInMemoryService and :default_in_memory_service' if attributes.key?(:'defaultInMemoryService') && attributes.key?(:'default_in_memory_service')

  self.default_in_memory_service = attributes[:'default_in_memory_service'] if attributes[:'default_in_memory_service']

  self.default_in_memory_service_name = attributes[:'defaultInMemoryServiceName'] if attributes[:'defaultInMemoryServiceName']

  raise 'You cannot provide both :defaultInMemoryServiceName and :default_in_memory_service_name' if attributes.key?(:'defaultInMemoryServiceName') && attributes.key?(:'default_in_memory_service_name')

  self.default_in_memory_service_name = attributes[:'default_in_memory_service_name'] if attributes[:'default_in_memory_service_name']

  self.lost_write_protect = attributes[:'lostWriteProtect'] if attributes[:'lostWriteProtect']

  raise 'You cannot provide both :lostWriteProtect and :lost_write_protect' if attributes.key?(:'lostWriteProtect') && attributes.key?(:'lost_write_protect')

  self.lost_write_protect = attributes[:'lost_write_protect'] if attributes[:'lost_write_protect']

  self.is_chunk_tablespace = attributes[:'isChunkTablespace'] unless attributes[:'isChunkTablespace'].nil?

  raise 'You cannot provide both :isChunkTablespace and :is_chunk_tablespace' if attributes.key?(:'isChunkTablespace') && attributes.key?(:'is_chunk_tablespace')

  self.is_chunk_tablespace = attributes[:'is_chunk_tablespace'] unless attributes[:'is_chunk_tablespace'].nil?

  self.temp_group = attributes[:'tempGroup'] if attributes[:'tempGroup']

  raise 'You cannot provide both :tempGroup and :temp_group' if attributes.key?(:'tempGroup') && attributes.key?(:'temp_group')

  self.temp_group = attributes[:'temp_group'] if attributes[:'temp_group']

  self.max_size_kb = attributes[:'maxSizeKB'] if attributes[:'maxSizeKB']

  raise 'You cannot provide both :maxSizeKB and :max_size_kb' if attributes.key?(:'maxSizeKB') && attributes.key?(:'max_size_kb')

  self.max_size_kb = attributes[:'max_size_kb'] if attributes[:'max_size_kb']

  self.allocated_size_kb = attributes[:'allocatedSizeKB'] if attributes[:'allocatedSizeKB']

  raise 'You cannot provide both :allocatedSizeKB and :allocated_size_kb' if attributes.key?(:'allocatedSizeKB') && attributes.key?(:'allocated_size_kb')

  self.allocated_size_kb = attributes[:'allocated_size_kb'] if attributes[:'allocated_size_kb']

  self.user_size_kb = attributes[:'userSizeKB'] if attributes[:'userSizeKB']

  raise 'You cannot provide both :userSizeKB and :user_size_kb' if attributes.key?(:'userSizeKB') && attributes.key?(:'user_size_kb')

  self.user_size_kb = attributes[:'user_size_kb'] if attributes[:'user_size_kb']

  self.free_space_kb = attributes[:'freeSpaceKB'] if attributes[:'freeSpaceKB']

  raise 'You cannot provide both :freeSpaceKB and :free_space_kb' if attributes.key?(:'freeSpaceKB') && attributes.key?(:'free_space_kb')

  self.free_space_kb = attributes[:'free_space_kb'] if attributes[:'free_space_kb']

  self.used_space_kb = attributes[:'usedSpaceKB'] if attributes[:'usedSpaceKB']

  raise 'You cannot provide both :usedSpaceKB and :used_space_kb' if attributes.key?(:'usedSpaceKB') && attributes.key?(:'used_space_kb')

  self.used_space_kb = attributes[:'used_space_kb'] if attributes[:'used_space_kb']

  self.used_percent_available = attributes[:'usedPercentAvailable'] if attributes[:'usedPercentAvailable']

  raise 'You cannot provide both :usedPercentAvailable and :used_percent_available' if attributes.key?(:'usedPercentAvailable') && attributes.key?(:'used_percent_available')

  self.used_percent_available = attributes[:'used_percent_available'] if attributes[:'used_percent_available']

  self.used_percent_allocated = attributes[:'usedPercentAllocated'] if attributes[:'usedPercentAllocated']

  raise 'You cannot provide both :usedPercentAllocated and :used_percent_allocated' if attributes.key?(:'usedPercentAllocated') && attributes.key?(:'used_percent_allocated')

  self.used_percent_allocated = attributes[:'used_percent_allocated'] if attributes[:'used_percent_allocated']

  self.datafiles = attributes[:'datafiles'] if attributes[:'datafiles']
end

Instance Attribute Details

#allocated_size_kbFloat

The allocated tablespace size in KB.



282
283
284
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 282

def allocated_size_kb
  @allocated_size_kb
end

#allocation_typeString

The type of extent allocation in effect for the tablespace.



186
187
188
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 186

def allocation_type
  @allocation_type
end

#block_size_bytesFloat

The tablespace block size in bytes.



170
171
172
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 170

def block_size_bytes
  @block_size_bytes
end

#compress_forString

The operation type for which default compression is enabled.



218
219
220
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 218

def compress_for
  @compress_for
end

#datafilesArray<OCI::DatabaseManagement::Models::Datafile>

A list of the datafiles associated with the tablespace.



306
307
308
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 306

def datafiles
  @datafiles
end

#default_cell_memoryString

This specifies the default value for the CELLMEMORY attribute that tables created in the tablespace will inherit unless the behavior is overridden explicitly. This column is intended for use with Oracle Exadata.



254
255
256
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 254

def default_cell_memory
  @default_cell_memory
end

#default_in_memoryString

Indicates whether the In-Memory Column Store (IM column store) is by default enabled or disabled for tables in this tablespace.



222
223
224
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 222

def default_in_memory
  @default_in_memory
end

#default_in_memory_compressionString

Indicates the default compression level for the IM column store for this tablespace.



234
235
236
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 234

def default_in_memory_compression
  @default_in_memory_compression
end

#default_in_memory_distributeString

Indicates how the IM column store is distributed by default for this tablespace in an Oracle Real Application Clusters (Oracle RAC) environment.



230
231
232
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 230

def default_in_memory_distribute
  @default_in_memory_distribute
end

#default_in_memory_duplicateString

Indicates the duplicate setting for the IM column store in an Oracle RAC environment.



238
239
240
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 238

def default_in_memory_duplicate
  @default_in_memory_duplicate
end

#default_in_memory_priorityString

Indicates the default priority for In-Memory Column Store (IM column store) population for this tablespace.



226
227
228
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 226

def default_in_memory_priority
  @default_in_memory_priority
end

#default_in_memory_serviceString

Indicates how the IM column store is populated on various instances by default for this tablespace.



258
259
260
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 258

def default_in_memory_service
  @default_in_memory_service
end

#default_in_memory_service_nameString

Indicates the service name for the service on which the IM column store should be populated by default for this tablespace. This column has a value only when the corresponding DEF_INMEMORY_SERVICE is USER_DEFINED. In all other cases, this column is null.



262
263
264
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 262

def default_in_memory_service_name
  @default_in_memory_service_name
end

#default_index_compressionString

Indicates whether default index compression is enabled or disabled.



246
247
248
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 246

def default_index_compression
  @default_index_compression
end

#default_table_compressionString

Indicates whether default table compression is enabled or disabled.



198
199
200
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 198

def default_table_compression
  @default_table_compression
end

#extent_managementString

Indicates whether the extents in the tablespace are Locally managed or Dictionary managed.



182
183
184
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 182

def extent_management
  @extent_management
end

#free_space_kbFloat

The free space available in this tablespace in KB.



290
291
292
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 290

def free_space_kb
  @free_space_kb
end

#index_compress_forString

The operation type for which default index compression is enabled.



250
251
252
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 250

def index_compress_for
  @index_compress_for
end

#is_bigfileBOOLEAN

Indicates whether the tablespace is a Bigfile tablespace or a Smallfile tablespace.



206
207
208
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 206

def is_bigfile
  @is_bigfile
end

#is_chunk_tablespaceBOOLEAN

Indicates whether this is a chunk tablespace.



270
271
272
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 270

def is_chunk_tablespace
  @is_chunk_tablespace
end

#is_encryptedBOOLEAN

Indicates whether the tablespace is encrypted.



214
215
216
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 214

def is_encrypted
  @is_encrypted
end

#is_force_loggingBOOLEAN

Indicates whether the tablespace is under Force Logging mode.



178
179
180
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 178

def is_force_logging
  @is_force_logging
end

#is_plugged_inBOOLEAN

Indicates whether the tablespace is plugged in.



190
191
192
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 190

def is_plugged_in
  @is_plugged_in
end

#loggingString

The default logging attribute.



174
175
176
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 174

def logging
  @logging
end

#lost_write_protectString

The lost write protection setting for the tablespace.



266
267
268
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 266

def lost_write_protect
  @lost_write_protect
end

#max_size_kbFloat

The maximum tablespace size in KB. If the tablespace contains any datafiles with Autoextend enabled, then this column displays the amount of underlying free storage space for the tablespace. For example, if the current tablespace size is 1 GB, the combined maximum size of all its datafiles is 32 GB, and its underlying storage (for example, ASM or file system storage) has 20 GB of free space, then this column will have a value of approximately 20 GB. If the tablespace contains only datafiles with autoextend disabled, then this column displays the allocated space for the entire tablespace, that is, the combined size of all datafiles in the tablespace.



278
279
280
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 278

def max_size_kb
  @max_size_kb
end

#nameString

[Required] The name of the tablespace.



158
159
160
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 158

def name
  @name
end

#predicate_evaluationString

Indicates whether predicates are evaluated by Host or by Storage.



210
211
212
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 210

def predicate_evaluation
  @predicate_evaluation
end

#retentionString

Indicates whether undo retention guarantee is enabled for the tablespace.



202
203
204
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 202

def retention
  @retention
end

#segment_space_managementString

Indicates whether the free and used segment space in the tablespace is managed using free lists (MANUAL) or bitmaps (AUTO).



194
195
196
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 194

def segment_space_management
  @segment_space_management
end

#sharedString

Indicates whether the tablespace is for shared tablespace, or for local temporary tablespace for leaf (read-only) instances, or for local temporary tablespace for all instance types.



242
243
244
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 242

def shared
  @shared
end

#statusString

The status of the tablespace.



166
167
168
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 166

def status
  @status
end

#temp_groupString

The temporary tablespace group.



274
275
276
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 274

def temp_group
  @temp_group
end

#typeString

[Required] The type of the tablespace.



162
163
164
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 162

def type
  @type
end

#used_percent_allocatedFloat

The percentage of used space out of the total allocated space in the tablespace.



302
303
304
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 302

def used_percent_allocated
  @used_percent_allocated
end

#used_percent_availableFloat

The percentage of used space out of the maximum available space in the tablespace.



298
299
300
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 298

def used_percent_available
  @used_percent_available
end

#used_space_kbFloat

The total space used by the tablespace in KB.



294
295
296
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 294

def used_space_kb
  @used_space_kb
end

#user_size_kbFloat

The size of the tablespace available for user data in KB. The difference between tablespace size and user data size is used for storing metadata.



286
287
288
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 286

def user_size_kb
  @user_size_kb
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 309

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'type': :'type',
    'status': :'status',
    'block_size_bytes': :'blockSizeBytes',
    'logging': :'logging',
    'is_force_logging': :'isForceLogging',
    'extent_management': :'extentManagement',
    'allocation_type': :'allocationType',
    'is_plugged_in': :'isPluggedIn',
    'segment_space_management': :'segmentSpaceManagement',
    'default_table_compression': :'defaultTableCompression',
    'retention': :'retention',
    'is_bigfile': :'isBigfile',
    'predicate_evaluation': :'predicateEvaluation',
    'is_encrypted': :'isEncrypted',
    'compress_for': :'compressFor',
    'default_in_memory': :'defaultInMemory',
    'default_in_memory_priority': :'defaultInMemoryPriority',
    'default_in_memory_distribute': :'defaultInMemoryDistribute',
    'default_in_memory_compression': :'defaultInMemoryCompression',
    'default_in_memory_duplicate': :'defaultInMemoryDuplicate',
    'shared': :'shared',
    'default_index_compression': :'defaultIndexCompression',
    'index_compress_for': :'indexCompressFor',
    'default_cell_memory': :'defaultCellMemory',
    'default_in_memory_service': :'defaultInMemoryService',
    'default_in_memory_service_name': :'defaultInMemoryServiceName',
    'lost_write_protect': :'lostWriteProtect',
    'is_chunk_tablespace': :'isChunkTablespace',
    'temp_group': :'tempGroup',
    'max_size_kb': :'maxSizeKB',
    'allocated_size_kb': :'allocatedSizeKB',
    'user_size_kb': :'userSizeKB',
    'free_space_kb': :'freeSpaceKB',
    'used_space_kb': :'usedSpaceKB',
    'used_percent_available': :'usedPercentAvailable',
    'used_percent_allocated': :'usedPercentAllocated',
    'datafiles': :'datafiles'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 355

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'type': :'String',
    'status': :'String',
    'block_size_bytes': :'Float',
    'logging': :'String',
    'is_force_logging': :'BOOLEAN',
    'extent_management': :'String',
    'allocation_type': :'String',
    'is_plugged_in': :'BOOLEAN',
    'segment_space_management': :'String',
    'default_table_compression': :'String',
    'retention': :'String',
    'is_bigfile': :'BOOLEAN',
    'predicate_evaluation': :'String',
    'is_encrypted': :'BOOLEAN',
    'compress_for': :'String',
    'default_in_memory': :'String',
    'default_in_memory_priority': :'String',
    'default_in_memory_distribute': :'String',
    'default_in_memory_compression': :'String',
    'default_in_memory_duplicate': :'String',
    'shared': :'String',
    'default_index_compression': :'String',
    'index_compress_for': :'String',
    'default_cell_memory': :'String',
    'default_in_memory_service': :'String',
    'default_in_memory_service_name': :'String',
    'lost_write_protect': :'String',
    'is_chunk_tablespace': :'BOOLEAN',
    'temp_group': :'String',
    'max_size_kb': :'Float',
    'allocated_size_kb': :'Float',
    'user_size_kb': :'Float',
    'free_space_kb': :'Float',
    'used_space_kb': :'Float',
    'used_percent_available': :'Float',
    'used_percent_allocated': :'Float',
    'datafiles': :'Array<OCI::DatabaseManagement::Models::Datafile>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 918

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    type == other.type &&
    status == other.status &&
    block_size_bytes == other.block_size_bytes &&
    logging == other.logging &&
    is_force_logging == other.is_force_logging &&
    extent_management == other.extent_management &&
    allocation_type == other.allocation_type &&
    is_plugged_in == other.is_plugged_in &&
    segment_space_management == other.segment_space_management &&
    default_table_compression == other.default_table_compression &&
    retention == other.retention &&
    is_bigfile == other.is_bigfile &&
    predicate_evaluation == other.predicate_evaluation &&
    is_encrypted == other.is_encrypted &&
    compress_for == other.compress_for &&
    default_in_memory == other.default_in_memory &&
    default_in_memory_priority == other.default_in_memory_priority &&
    default_in_memory_distribute == other.default_in_memory_distribute &&
    default_in_memory_compression == other.default_in_memory_compression &&
    default_in_memory_duplicate == other.default_in_memory_duplicate &&
    shared == other.shared &&
    default_index_compression == other.default_index_compression &&
    index_compress_for == other.index_compress_for &&
    default_cell_memory == other.default_cell_memory &&
    default_in_memory_service == other.default_in_memory_service &&
    default_in_memory_service_name == other.default_in_memory_service_name &&
    lost_write_protect == other.lost_write_protect &&
    is_chunk_tablespace == other.is_chunk_tablespace &&
    temp_group == other.temp_group &&
    max_size_kb == other.max_size_kb &&
    allocated_size_kb == other.allocated_size_kb &&
    user_size_kb == other.user_size_kb &&
    free_space_kb == other.free_space_kb &&
    used_space_kb == other.used_space_kb &&
    used_percent_available == other.used_percent_available &&
    used_percent_allocated == other.used_percent_allocated &&
    datafiles == other.datafiles
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 985

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


965
966
967
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 965

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



974
975
976
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 974

def hash
  [name, type, status, block_size_bytes, logging, is_force_logging, extent_management, allocation_type, is_plugged_in, segment_space_management, default_table_compression, retention, is_bigfile, predicate_evaluation, is_encrypted, compress_for, default_in_memory, default_in_memory_priority, default_in_memory_distribute, default_in_memory_compression, default_in_memory_duplicate, shared, default_index_compression, index_compress_for, default_cell_memory, default_in_memory_service, default_in_memory_service_name, lost_write_protect, is_chunk_tablespace, temp_group, max_size_kb, allocated_size_kb, user_size_kb, free_space_kb, used_space_kb, used_percent_available, used_percent_allocated, datafiles].hash
end

#to_hashHash

Returns the object in the form of hash



1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 1018

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



1012
1013
1014
# File 'lib/oci/database_management/models/tablespace_summary.rb', line 1012

def to_s
  to_hash.to_s
end