Class: OCI::DatabaseManagement::Models::UpdateSqlJobDetails
- Inherits:
-
UpdateJobDetails
- Object
- UpdateJobDetails
- OCI::DatabaseManagement::Models::UpdateSqlJobDetails
- Defined in:
- lib/oci/database_management/models/update_sql_job_details.rb
Overview
The details specific to the SQL job request.
Constant Summary
Constants inherited from UpdateJobDetails
OCI::DatabaseManagement::Models::UpdateJobDetails::JOB_TYPE_ENUM
Instance Attribute Summary collapse
-
#password ⇒ String
The password for the database user name used to execute the SQL job.
-
#role ⇒ String
The role of the database user.
-
#secret_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the secret containing the user password.
-
#sql_text ⇒ String
The SQL text to be executed as part of the job.
- #sql_type ⇒ String
-
#user_name ⇒ String
The database user name used to execute the SQL job.
Attributes inherited from UpdateJobDetails
#description, #job_type, #result_location, #schedule_details, #timeout
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateSqlJobDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateJobDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateSqlJobDetails
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['jobType'] = 'SQL' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.sql_text = attributes[:'sqlText'] if attributes[:'sqlText'] raise 'You cannot provide both :sqlText and :sql_text' if attributes.key?(:'sqlText') && attributes.key?(:'sql_text') self.sql_text = attributes[:'sql_text'] if attributes[:'sql_text'] self.sql_type = attributes[:'sqlType'] if attributes[:'sqlType'] raise 'You cannot provide both :sqlType and :sql_type' if attributes.key?(:'sqlType') && attributes.key?(:'sql_type') self.sql_type = attributes[:'sql_type'] if attributes[:'sql_type'] self.user_name = attributes[:'userName'] if attributes[:'userName'] raise 'You cannot provide both :userName and :user_name' if attributes.key?(:'userName') && attributes.key?(:'user_name') self.user_name = attributes[:'user_name'] if attributes[:'user_name'] self.password = attributes[:'password'] if attributes[:'password'] self.secret_id = attributes[:'secretId'] if attributes[:'secretId'] raise 'You cannot provide both :secretId and :secret_id' if attributes.key?(:'secretId') && attributes.key?(:'secret_id') self.secret_id = attributes[:'secret_id'] if attributes[:'secret_id'] self.role = attributes[:'role'] if attributes[:'role'] end |
Instance Attribute Details
#password ⇒ String
The password for the database user name used to execute the SQL job.
27 28 29 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 27 def password @password end |
#role ⇒ String
The role of the database user. Indicates whether the database user is a normal user or sysdba.
35 36 37 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 35 def role @role end |
#secret_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the secret containing the user password.
31 32 33 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 31 def secret_id @secret_id end |
#sql_text ⇒ String
The SQL text to be executed as part of the job.
13 14 15 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 13 def sql_text @sql_text end |
#sql_type ⇒ String
16 17 18 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 16 def sql_type @sql_type end |
#user_name ⇒ String
The database user name used to execute the SQL job. If the job is being executed on a Managed Database Group, then the user name should exist on all the databases in the group with the same password.
23 24 25 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 23 def user_name @user_name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'job_type': :'jobType', 'timeout': :'timeout', 'result_location': :'resultLocation', 'schedule_details': :'scheduleDetails', 'sql_text': :'sqlText', 'sql_type': :'sqlType', 'user_name': :'userName', 'password': :'password', 'secret_id': :'secretId', 'role': :'role' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'job_type': :'String', 'timeout': :'String', 'result_location': :'OCI::DatabaseManagement::Models::JobExecutionResultLocation', 'schedule_details': :'OCI::DatabaseManagement::Models::JobScheduleDetails', 'sql_text': :'String', 'sql_type': :'String', 'user_name': :'String', 'password': :'String', 'secret_id': :'String', 'role': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 137 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && job_type == other.job_type && timeout == other.timeout && result_location == other.result_location && schedule_details == other.schedule_details && sql_text == other.sql_text && sql_type == other.sql_type && user_name == other.user_name && password == other.password && secret_id == other.secret_id && role == other.role end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 177 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
157 158 159 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 157 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 166 def hash [description, job_type, timeout, result_location, schedule_details, sql_text, sql_type, user_name, password, secret_id, role].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
204 205 206 |
# File 'lib/oci/database_management/models/update_sql_job_details.rb', line 204 def to_s to_hash.to_s end |