Class: OCI::DatabaseMigration::Models::CloneMigrationDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseMigration::Models::CloneMigrationDetails
- Defined in:
- lib/oci/database_migration/models/clone_migration_details.rb
Overview
Details that will override an existing Migration configuration that will be cloned.
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The OCID of the registered on-premises ODMS Agent.
-
#compartment_id ⇒ String
OCID of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Migration Display Name.
-
#exclude_objects ⇒ Array<OCI::DatabaseMigration::Models::DatabaseObject>
Database objects to exclude from migration.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#source_container_database_connection_id ⇒ String
The OCID of the Source Container Database Connection.
-
#source_database_connection_id ⇒ String
[Required] The OCID of the Source Database Connection.
-
#target_database_connection_id ⇒ String
[Required] The OCID of the Target Database Connection.
- #vault_details ⇒ OCI::DatabaseMigration::Models::CreateVaultDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CloneMigrationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CloneMigrationDetails
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.agent_id = attributes[:'agentId'] if attributes[:'agentId'] raise 'You cannot provide both :agentId and :agent_id' if attributes.key?(:'agentId') && attributes.key?(:'agent_id') self.agent_id = attributes[:'agent_id'] if attributes[:'agent_id'] self.source_database_connection_id = attributes[:'sourceDatabaseConnectionId'] if attributes[:'sourceDatabaseConnectionId'] raise 'You cannot provide both :sourceDatabaseConnectionId and :source_database_connection_id' if attributes.key?(:'sourceDatabaseConnectionId') && attributes.key?(:'source_database_connection_id') self.source_database_connection_id = attributes[:'source_database_connection_id'] if attributes[:'source_database_connection_id'] self.source_container_database_connection_id = attributes[:'sourceContainerDatabaseConnectionId'] if attributes[:'sourceContainerDatabaseConnectionId'] raise 'You cannot provide both :sourceContainerDatabaseConnectionId and :source_container_database_connection_id' if attributes.key?(:'sourceContainerDatabaseConnectionId') && attributes.key?(:'source_container_database_connection_id') self.source_container_database_connection_id = attributes[:'source_container_database_connection_id'] if attributes[:'source_container_database_connection_id'] self.target_database_connection_id = attributes[:'targetDatabaseConnectionId'] if attributes[:'targetDatabaseConnectionId'] raise 'You cannot provide both :targetDatabaseConnectionId and :target_database_connection_id' if attributes.key?(:'targetDatabaseConnectionId') && attributes.key?(:'target_database_connection_id') self.target_database_connection_id = attributes[:'target_database_connection_id'] if attributes[:'target_database_connection_id'] self.exclude_objects = attributes[:'excludeObjects'] if attributes[:'excludeObjects'] raise 'You cannot provide both :excludeObjects and :exclude_objects' if attributes.key?(:'excludeObjects') && attributes.key?(:'exclude_objects') self.exclude_objects = attributes[:'exclude_objects'] if attributes[:'exclude_objects'] self.vault_details = attributes[:'vaultDetails'] if attributes[:'vaultDetails'] raise 'You cannot provide both :vaultDetails and :vault_details' if attributes.key?(:'vaultDetails') && attributes.key?(:'vault_details') self.vault_details = attributes[:'vault_details'] if attributes[:'vault_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#agent_id ⇒ String
The OCID of the registered on-premises ODMS Agent. Only valid for Offline Logical Migrations.
24 25 26 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 24 def agent_id @agent_id end |
#compartment_id ⇒ String
OCID of the compartment
19 20 21 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 19 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
60 61 62 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 60 def end |
#display_name ⇒ String
Migration Display Name
14 15 16 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 14 def display_name @display_name end |
#exclude_objects ⇒ Array<OCI::DatabaseMigration::Models::DatabaseObject>
Database objects to exclude from migration.
45 46 47 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 45 def exclude_objects @exclude_objects end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
54 55 56 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 54 def end |
#source_container_database_connection_id ⇒ String
The OCID of the Source Container Database Connection. Only used for Online migrations. Only Connections of type Non-Autonomous can be used as source container databases.
35 36 37 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 35 def source_container_database_connection_id @source_container_database_connection_id end |
#source_database_connection_id ⇒ String
[Required] The OCID of the Source Database Connection.
29 30 31 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 29 def source_database_connection_id @source_database_connection_id end |
#target_database_connection_id ⇒ String
[Required] The OCID of the Target Database Connection.
40 41 42 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 40 def target_database_connection_id @target_database_connection_id end |
#vault_details ⇒ OCI::DatabaseMigration::Models::CreateVaultDetails
48 49 50 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 48 def vault_details @vault_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'agent_id': :'agentId', 'source_database_connection_id': :'sourceDatabaseConnectionId', 'source_container_database_connection_id': :'sourceContainerDatabaseConnectionId', 'target_database_connection_id': :'targetDatabaseConnectionId', 'exclude_objects': :'excludeObjects', 'vault_details': :'vaultDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'agent_id': :'String', 'source_database_connection_id': :'String', 'source_container_database_connection_id': :'String', 'target_database_connection_id': :'String', 'exclude_objects': :'Array<OCI::DatabaseMigration::Models::DatabaseObject>', 'vault_details': :'OCI::DatabaseMigration::Models::CreateVaultDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 188 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && agent_id == other.agent_id && source_database_connection_id == other.source_database_connection_id && source_container_database_connection_id == other.source_container_database_connection_id && target_database_connection_id == other.target_database_connection_id && exclude_objects == other.exclude_objects && vault_details == other.vault_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 227 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
207 208 209 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 207 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 216 def hash [display_name, compartment_id, agent_id, source_database_connection_id, source_container_database_connection_id, target_database_connection_id, exclude_objects, vault_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
254 255 256 |
# File 'lib/oci/database_migration/models/clone_migration_details.rb', line 254 def to_s to_hash.to_s end |