Class: OCI::DatabaseMigration::Models::CreateConnectionDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseMigration::Models::CreateConnectionDetails
- Defined in:
- lib/oci/database_migration/models/create_connection_details.rb
Overview
Details to create a Database Connection resource.
Constant Summary collapse
- DATABASE_TYPE_ENUM =
[ DATABASE_TYPE_MANUAL = 'MANUAL'.freeze, DATABASE_TYPE_AUTONOMOUS = 'AUTONOMOUS'.freeze, DATABASE_TYPE_USER_MANAGED_OCI = 'USER_MANAGED_OCI'.freeze ].freeze
- MANUAL_DATABASE_SUB_TYPE_ENUM =
[ MANUAL_DATABASE_SUB_TYPE_ORACLE = 'ORACLE'.freeze, MANUAL_DATABASE_SUB_TYPE_RDS_ORACLE = 'RDS_ORACLE'.freeze ].freeze
Instance Attribute Summary collapse
-
#admin_credentials ⇒ OCI::DatabaseMigration::Models::CreateAdminCredentials
This attribute is required.
-
#certificate_tdn ⇒ String
This name is the distinguished name used while creating the certificate on target database.
-
#compartment_id ⇒ String
**[Required]** OCID of the compartment.
- #connect_descriptor ⇒ OCI::DatabaseMigration::Models::CreateConnectDescriptor
-
#database_id ⇒ String
The OCID of the cloud database.
-
#database_type ⇒ String
**[Required]** Database connection type.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Database Connection display name identifier.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#manual_database_sub_type ⇒ String
Database manual connection subtype.
- #private_endpoint ⇒ OCI::DatabaseMigration::Models::CreatePrivateEndpoint
- #ssh_details ⇒ OCI::DatabaseMigration::Models::CreateSshDetails
-
#tls_keystore ⇒ String
keystore.jks file contents; base64 encoded String.
-
#tls_wallet ⇒ String
cwallet.sso containing containing the TCPS/SSL certificate; base64 encoded String.
-
#vault_details ⇒ OCI::DatabaseMigration::Models::CreateVaultDetails
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateConnectionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateConnectionDetails
Initializes the object
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 159 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.manual_database_sub_type = attributes[:'manualDatabaseSubType'] if attributes[:'manualDatabaseSubType'] self.manual_database_sub_type = "ORACLE" if manual_database_sub_type.nil? && !attributes.key?(:'manualDatabaseSubType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :manualDatabaseSubType and :manual_database_sub_type' if attributes.key?(:'manualDatabaseSubType') && attributes.key?(:'manual_database_sub_type') self.manual_database_sub_type = attributes[:'manual_database_sub_type'] if attributes[:'manual_database_sub_type'] self.manual_database_sub_type = "ORACLE" if manual_database_sub_type.nil? && !attributes.key?(:'manualDatabaseSubType') && !attributes.key?(:'manual_database_sub_type') # rubocop:disable Style/StringLiterals self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.connect_descriptor = attributes[:'connectDescriptor'] if attributes[:'connectDescriptor'] raise 'You cannot provide both :connectDescriptor and :connect_descriptor' if attributes.key?(:'connectDescriptor') && attributes.key?(:'connect_descriptor') self.connect_descriptor = attributes[:'connect_descriptor'] if attributes[:'connect_descriptor'] self.certificate_tdn = attributes[:'certificateTdn'] if attributes[:'certificateTdn'] raise 'You cannot provide both :certificateTdn and :certificate_tdn' if attributes.key?(:'certificateTdn') && attributes.key?(:'certificate_tdn') self.certificate_tdn = attributes[:'certificate_tdn'] if attributes[:'certificate_tdn'] self.tls_wallet = attributes[:'tlsWallet'] if attributes[:'tlsWallet'] raise 'You cannot provide both :tlsWallet and :tls_wallet' if attributes.key?(:'tlsWallet') && attributes.key?(:'tls_wallet') self.tls_wallet = attributes[:'tls_wallet'] if attributes[:'tls_wallet'] self.tls_keystore = attributes[:'tlsKeystore'] if attributes[:'tlsKeystore'] raise 'You cannot provide both :tlsKeystore and :tls_keystore' if attributes.key?(:'tlsKeystore') && attributes.key?(:'tls_keystore') self.tls_keystore = attributes[:'tls_keystore'] if attributes[:'tls_keystore'] self.ssh_details = attributes[:'sshDetails'] if attributes[:'sshDetails'] raise 'You cannot provide both :sshDetails and :ssh_details' if attributes.key?(:'sshDetails') && attributes.key?(:'ssh_details') self.ssh_details = attributes[:'ssh_details'] if attributes[:'ssh_details'] self.admin_credentials = attributes[:'adminCredentials'] if attributes[:'adminCredentials'] raise 'You cannot provide both :adminCredentials and :admin_credentials' if attributes.key?(:'adminCredentials') && attributes.key?(:'admin_credentials') self.admin_credentials = attributes[:'admin_credentials'] if attributes[:'admin_credentials'] self.private_endpoint = attributes[:'privateEndpoint'] if attributes[:'privateEndpoint'] raise 'You cannot provide both :privateEndpoint and :private_endpoint' if attributes.key?(:'privateEndpoint') && attributes.key?(:'private_endpoint') self.private_endpoint = attributes[:'private_endpoint'] if attributes[:'private_endpoint'] self.vault_details = attributes[:'vaultDetails'] if attributes[:'vaultDetails'] raise 'You cannot provide both :vaultDetails and :vault_details' if attributes.key?(:'vaultDetails') && attributes.key?(:'vault_details') self.vault_details = attributes[:'vault_details'] if attributes[:'vault_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#admin_credentials ⇒ OCI::DatabaseMigration::Models::CreateAdminCredentials
This attribute is required.
71 72 73 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 71 def admin_credentials @admin_credentials end |
#certificate_tdn ⇒ String
This name is the distinguished name used while creating the certificate on target database. Requires a TLS wallet to be specified. Not required for source container database connections.
54 55 56 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 54 def certificate_tdn @certificate_tdn end |
#compartment_id ⇒ String
**[Required]** OCID of the compartment
25 26 27 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 25 def compartment_id @compartment_id end |
#connect_descriptor ⇒ OCI::DatabaseMigration::Models::CreateConnectDescriptor
48 49 50 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 48 def connect_descriptor @connect_descriptor end |
#database_id ⇒ String
The OCID of the cloud database. Required if the database connection type is Autonomous.
45 46 47 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 45 def database_id @database_id end |
#database_type ⇒ String
**[Required]** Database connection type.
35 36 37 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 35 def database_type @database_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
90 91 92 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 90 def @defined_tags end |
#display_name ⇒ String
Database Connection display name identifier.
30 31 32 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 30 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
84 85 86 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 84 def @freeform_tags end |
#manual_database_sub_type ⇒ String
Database manual connection subtype. This value can only be specified for manual connections.
40 41 42 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 40 def manual_database_sub_type @manual_database_sub_type end |
#private_endpoint ⇒ OCI::DatabaseMigration::Models::CreatePrivateEndpoint
74 75 76 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 74 def private_endpoint @private_endpoint end |
#ssh_details ⇒ OCI::DatabaseMigration::Models::CreateSshDetails
67 68 69 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 67 def ssh_details @ssh_details end |
#tls_keystore ⇒ String
keystore.jks file contents; base64 encoded String. Requires a TLS wallet to be specified. Not required for source container database connections.
64 65 66 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 64 def tls_keystore @tls_keystore end |
#tls_wallet ⇒ String
cwallet.sso containing containing the TCPS/SSL certificate; base64 encoded String. Not required for source container database connections.
59 60 61 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 59 def tls_wallet @tls_wallet end |
#vault_details ⇒ OCI::DatabaseMigration::Models::CreateVaultDetails
This attribute is required.
78 79 80 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 78 def vault_details @vault_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 93 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'database_type': :'databaseType', 'manual_database_sub_type': :'manualDatabaseSubType', 'database_id': :'databaseId', 'connect_descriptor': :'connectDescriptor', 'certificate_tdn': :'certificateTdn', 'tls_wallet': :'tlsWallet', 'tls_keystore': :'tlsKeystore', 'ssh_details': :'sshDetails', 'admin_credentials': :'adminCredentials', 'private_endpoint': :'privateEndpoint', 'vault_details': :'vaultDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 116 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'database_type': :'String', 'manual_database_sub_type': :'String', 'database_id': :'String', 'connect_descriptor': :'OCI::DatabaseMigration::Models::CreateConnectDescriptor', 'certificate_tdn': :'String', 'tls_wallet': :'String', 'tls_keystore': :'String', 'ssh_details': :'OCI::DatabaseMigration::Models::CreateSshDetails', 'admin_credentials': :'OCI::DatabaseMigration::Models::CreateAdminCredentials', 'private_endpoint': :'OCI::DatabaseMigration::Models::CreatePrivateEndpoint', 'vault_details': :'OCI::DatabaseMigration::Models::CreateVaultDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 281 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && database_type == other.database_type && manual_database_sub_type == other.manual_database_sub_type && database_id == other.database_id && connect_descriptor == other.connect_descriptor && certificate_tdn == other.certificate_tdn && tls_wallet == other.tls_wallet && tls_keystore == other.tls_keystore && ssh_details == other.ssh_details && admin_credentials == other.admin_credentials && private_endpoint == other.private_endpoint && vault_details == other.vault_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 325 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
305 306 307 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 305 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
314 315 316 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 314 def hash [compartment_id, display_name, database_type, manual_database_sub_type, database_id, connect_descriptor, certificate_tdn, tls_wallet, tls_keystore, ssh_details, admin_credentials, private_endpoint, vault_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
358 359 360 361 362 363 364 365 366 367 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 358 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
352 353 354 |
# File 'lib/oci/database_migration/models/create_connection_details.rb', line 352 def to_s to_hash.to_s end |