Class: OCI::DatabaseMigration::Models::CreateDataTransferMediumDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseMigration::Models::CreateDataTransferMediumDetails
- Defined in:
- lib/oci/database_migration/models/create_data_transfer_medium_details.rb
Overview
Data Transfer Medium details for the Migration. If not specified, it will default to Database Link. Only one type of data transfer medium can be specified.
Instance Attribute Summary collapse
- #database_link_details ⇒ OCI::DatabaseMigration::Models::CreateDatabaseLinkDetails
- #object_storage_details ⇒ OCI::DatabaseMigration::Models::CreateObjectStoreBucket
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDataTransferMediumDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDataTransferMediumDetails
Initializes the object
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 46 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.database_link_details = attributes[:'databaseLinkDetails'] if attributes[:'databaseLinkDetails'] raise 'You cannot provide both :databaseLinkDetails and :database_link_details' if attributes.key?(:'databaseLinkDetails') && attributes.key?(:'database_link_details') self.database_link_details = attributes[:'database_link_details'] if attributes[:'database_link_details'] self.object_storage_details = attributes[:'objectStorageDetails'] if attributes[:'objectStorageDetails'] raise 'You cannot provide both :objectStorageDetails and :object_storage_details' if attributes.key?(:'objectStorageDetails') && attributes.key?(:'object_storage_details') self.object_storage_details = attributes[:'object_storage_details'] if attributes[:'object_storage_details'] end |
Instance Attribute Details
#database_link_details ⇒ OCI::DatabaseMigration::Models::CreateDatabaseLinkDetails
13 14 15 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 13 def database_link_details @database_link_details end |
#object_storage_details ⇒ OCI::DatabaseMigration::Models::CreateObjectStoreBucket
16 17 18 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 16 def object_storage_details @object_storage_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
19 20 21 22 23 24 25 26 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 19 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'database_link_details': :'databaseLinkDetails', 'object_storage_details': :'objectStorageDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
29 30 31 32 33 34 35 36 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 29 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'database_link_details': :'OCI::DatabaseMigration::Models::CreateDatabaseLinkDetails', 'object_storage_details': :'OCI::DatabaseMigration::Models::CreateObjectStoreBucket' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
72 73 74 75 76 77 78 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 72 def ==(other) return true if equal?(other) self.class == other.class && database_link_details == other.database_link_details && object_storage_details == other.object_storage_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 103 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
83 84 85 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 83 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
92 93 94 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 92 def hash [database_link_details, object_storage_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 136 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
130 131 132 |
# File 'lib/oci/database_migration/models/create_data_transfer_medium_details.rb', line 130 def to_s to_hash.to_s end |