Class: OCI::DatabaseMigration::Models::CreateMigrationDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseMigration::Models::CreateMigrationDetails
- Defined in:
- lib/oci/database_migration/models/create_migration_details.rb
Overview
Create Migration resource parameters.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_ONLINE = 'ONLINE'.freeze, TYPE_OFFLINE = 'OFFLINE'.freeze ].freeze
Instance Attribute Summary collapse
- #advisor_settings ⇒ OCI::DatabaseMigration::Models::CreateAdvisorSettings
-
#agent_id ⇒ String
The OCID of the registered ODMS Agent.
-
#compartment_id ⇒ String
[Required] OCID of the compartment.
- #data_transfer_medium_details ⇒ OCI::DatabaseMigration::Models::CreateDataTransferMediumDetails
- #datapump_settings ⇒ OCI::DatabaseMigration::Models::CreateDataPumpSettings
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Migration Display Name.
- #dump_transfer_details ⇒ OCI::DatabaseMigration::Models::CreateDumpTransferDetails
-
#exclude_objects ⇒ Array<OCI::DatabaseMigration::Models::DatabaseObject>
Database objects to exclude from migration, cannot be specified alongside ‘includeObjects’.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #golden_gate_details ⇒ OCI::DatabaseMigration::Models::CreateGoldenGateDetails
-
#include_objects ⇒ Array<OCI::DatabaseMigration::Models::DatabaseObject>
Database objects to include from migration, cannot be specified alongside ‘excludeObjects’.
-
#source_container_database_connection_id ⇒ String
The OCID of the Source Container Database Connection.
-
#source_database_connection_id ⇒ String
[Required] The OCID of the Source Database Connection.
-
#target_database_connection_id ⇒ String
[Required] The OCID of the Target Database Connection.
-
#type ⇒ String
[Required] Migration type.
- #vault_details ⇒ OCI::DatabaseMigration::Models::CreateVaultDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateMigrationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateMigrationDetails
Initializes the object
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 165 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.agent_id = attributes[:'agentId'] if attributes[:'agentId'] raise 'You cannot provide both :agentId and :agent_id' if attributes.key?(:'agentId') && attributes.key?(:'agent_id') self.agent_id = attributes[:'agent_id'] if attributes[:'agent_id'] self.source_database_connection_id = attributes[:'sourceDatabaseConnectionId'] if attributes[:'sourceDatabaseConnectionId'] raise 'You cannot provide both :sourceDatabaseConnectionId and :source_database_connection_id' if attributes.key?(:'sourceDatabaseConnectionId') && attributes.key?(:'source_database_connection_id') self.source_database_connection_id = attributes[:'source_database_connection_id'] if attributes[:'source_database_connection_id'] self.source_container_database_connection_id = attributes[:'sourceContainerDatabaseConnectionId'] if attributes[:'sourceContainerDatabaseConnectionId'] raise 'You cannot provide both :sourceContainerDatabaseConnectionId and :source_container_database_connection_id' if attributes.key?(:'sourceContainerDatabaseConnectionId') && attributes.key?(:'source_container_database_connection_id') self.source_container_database_connection_id = attributes[:'source_container_database_connection_id'] if attributes[:'source_container_database_connection_id'] self.target_database_connection_id = attributes[:'targetDatabaseConnectionId'] if attributes[:'targetDatabaseConnectionId'] raise 'You cannot provide both :targetDatabaseConnectionId and :target_database_connection_id' if attributes.key?(:'targetDatabaseConnectionId') && attributes.key?(:'target_database_connection_id') self.target_database_connection_id = attributes[:'target_database_connection_id'] if attributes[:'target_database_connection_id'] self.data_transfer_medium_details = attributes[:'dataTransferMediumDetails'] if attributes[:'dataTransferMediumDetails'] raise 'You cannot provide both :dataTransferMediumDetails and :data_transfer_medium_details' if attributes.key?(:'dataTransferMediumDetails') && attributes.key?(:'data_transfer_medium_details') self.data_transfer_medium_details = attributes[:'data_transfer_medium_details'] if attributes[:'data_transfer_medium_details'] self.dump_transfer_details = attributes[:'dumpTransferDetails'] if attributes[:'dumpTransferDetails'] raise 'You cannot provide both :dumpTransferDetails and :dump_transfer_details' if attributes.key?(:'dumpTransferDetails') && attributes.key?(:'dump_transfer_details') self.dump_transfer_details = attributes[:'dump_transfer_details'] if attributes[:'dump_transfer_details'] self.datapump_settings = attributes[:'datapumpSettings'] if attributes[:'datapumpSettings'] raise 'You cannot provide both :datapumpSettings and :datapump_settings' if attributes.key?(:'datapumpSettings') && attributes.key?(:'datapump_settings') self.datapump_settings = attributes[:'datapump_settings'] if attributes[:'datapump_settings'] self.advisor_settings = attributes[:'advisorSettings'] if attributes[:'advisorSettings'] raise 'You cannot provide both :advisorSettings and :advisor_settings' if attributes.key?(:'advisorSettings') && attributes.key?(:'advisor_settings') self.advisor_settings = attributes[:'advisor_settings'] if attributes[:'advisor_settings'] self.exclude_objects = attributes[:'excludeObjects'] if attributes[:'excludeObjects'] raise 'You cannot provide both :excludeObjects and :exclude_objects' if attributes.key?(:'excludeObjects') && attributes.key?(:'exclude_objects') self.exclude_objects = attributes[:'exclude_objects'] if attributes[:'exclude_objects'] self.include_objects = attributes[:'includeObjects'] if attributes[:'includeObjects'] raise 'You cannot provide both :includeObjects and :include_objects' if attributes.key?(:'includeObjects') && attributes.key?(:'include_objects') self.include_objects = attributes[:'include_objects'] if attributes[:'include_objects'] self.golden_gate_details = attributes[:'goldenGateDetails'] if attributes[:'goldenGateDetails'] raise 'You cannot provide both :goldenGateDetails and :golden_gate_details' if attributes.key?(:'goldenGateDetails') && attributes.key?(:'golden_gate_details') self.golden_gate_details = attributes[:'golden_gate_details'] if attributes[:'golden_gate_details'] self.vault_details = attributes[:'vaultDetails'] if attributes[:'vaultDetails'] raise 'You cannot provide both :vaultDetails and :vault_details' if attributes.key?(:'vaultDetails') && attributes.key?(:'vault_details') self.vault_details = attributes[:'vault_details'] if attributes[:'vault_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#advisor_settings ⇒ OCI::DatabaseMigration::Models::CreateAdvisorSettings
62 63 64 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 62 def advisor_settings @advisor_settings end |
#agent_id ⇒ String
The OCID of the registered ODMS Agent. Only valid for Offline Logical Migrations.
34 35 36 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 34 def agent_id @agent_id end |
#compartment_id ⇒ String
[Required] OCID of the compartment
29 30 31 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 29 def compartment_id @compartment_id end |
#data_transfer_medium_details ⇒ OCI::DatabaseMigration::Models::CreateDataTransferMediumDetails
53 54 55 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 53 def data_transfer_medium_details @data_transfer_medium_details end |
#datapump_settings ⇒ OCI::DatabaseMigration::Models::CreateDataPumpSettings
59 60 61 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 59 def datapump_settings @datapump_settings end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
90 91 92 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 90 def end |
#display_name ⇒ String
Migration Display Name
24 25 26 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 24 def display_name @display_name end |
#dump_transfer_details ⇒ OCI::DatabaseMigration::Models::CreateDumpTransferDetails
56 57 58 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 56 def dump_transfer_details @dump_transfer_details end |
#exclude_objects ⇒ Array<OCI::DatabaseMigration::Models::DatabaseObject>
Database objects to exclude from migration, cannot be specified alongside ‘includeObjects’
67 68 69 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 67 def exclude_objects @exclude_objects end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
84 85 86 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 84 def end |
#golden_gate_details ⇒ OCI::DatabaseMigration::Models::CreateGoldenGateDetails
75 76 77 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 75 def golden_gate_details @golden_gate_details end |
#include_objects ⇒ Array<OCI::DatabaseMigration::Models::DatabaseObject>
Database objects to include from migration, cannot be specified alongside ‘excludeObjects’
72 73 74 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 72 def include_objects @include_objects end |
#source_container_database_connection_id ⇒ String
The OCID of the Source Container Database Connection. Only used for Online migrations. Only Connections of type Non-Autonomous can be used as source container databases.
45 46 47 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 45 def source_container_database_connection_id @source_container_database_connection_id end |
#source_database_connection_id ⇒ String
[Required] The OCID of the Source Database Connection.
39 40 41 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 39 def source_database_connection_id @source_database_connection_id end |
#target_database_connection_id ⇒ String
[Required] The OCID of the Target Database Connection.
50 51 52 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 50 def target_database_connection_id @target_database_connection_id end |
#type ⇒ String
[Required] Migration type.
19 20 21 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 19 def type @type end |
#vault_details ⇒ OCI::DatabaseMigration::Models::CreateVaultDetails
78 79 80 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 78 def vault_details @vault_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 93 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'agent_id': :'agentId', 'source_database_connection_id': :'sourceDatabaseConnectionId', 'source_container_database_connection_id': :'sourceContainerDatabaseConnectionId', 'target_database_connection_id': :'targetDatabaseConnectionId', 'data_transfer_medium_details': :'dataTransferMediumDetails', 'dump_transfer_details': :'dumpTransferDetails', 'datapump_settings': :'datapumpSettings', 'advisor_settings': :'advisorSettings', 'exclude_objects': :'excludeObjects', 'include_objects': :'includeObjects', 'golden_gate_details': :'goldenGateDetails', 'vault_details': :'vaultDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 118 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'display_name': :'String', 'compartment_id': :'String', 'agent_id': :'String', 'source_database_connection_id': :'String', 'source_container_database_connection_id': :'String', 'target_database_connection_id': :'String', 'data_transfer_medium_details': :'OCI::DatabaseMigration::Models::CreateDataTransferMediumDetails', 'dump_transfer_details': :'OCI::DatabaseMigration::Models::CreateDumpTransferDetails', 'datapump_settings': :'OCI::DatabaseMigration::Models::CreateDataPumpSettings', 'advisor_settings': :'OCI::DatabaseMigration::Models::CreateAdvisorSettings', 'exclude_objects': :'Array<OCI::DatabaseMigration::Models::DatabaseObject>', 'include_objects': :'Array<OCI::DatabaseMigration::Models::DatabaseObject>', 'golden_gate_details': :'OCI::DatabaseMigration::Models::CreateGoldenGateDetails', 'vault_details': :'OCI::DatabaseMigration::Models::CreateVaultDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 285 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && display_name == other.display_name && compartment_id == other.compartment_id && agent_id == other.agent_id && source_database_connection_id == other.source_database_connection_id && source_container_database_connection_id == other.source_container_database_connection_id && target_database_connection_id == other.target_database_connection_id && data_transfer_medium_details == other.data_transfer_medium_details && dump_transfer_details == other.dump_transfer_details && datapump_settings == other.datapump_settings && advisor_settings == other.advisor_settings && exclude_objects == other.exclude_objects && include_objects == other.include_objects && golden_gate_details == other.golden_gate_details && vault_details == other.vault_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 331 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
311 312 313 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 311 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
320 321 322 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 320 def hash [type, display_name, compartment_id, agent_id, source_database_connection_id, source_container_database_connection_id, target_database_connection_id, data_transfer_medium_details, dump_transfer_details, datapump_settings, advisor_settings, exclude_objects, include_objects, golden_gate_details, vault_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
364 365 366 367 368 369 370 371 372 373 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 364 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
358 359 360 |
# File 'lib/oci/database_migration/models/create_migration_details.rb', line 358 def to_s to_hash.to_s end |