Class: OCI::DatabaseMigration::Models::DataPumpSettings
- Inherits:
-
Object
- Object
- OCI::DatabaseMigration::Models::DataPumpSettings
- Defined in:
- lib/oci/database_migration/models/data_pump_settings.rb
Overview
Optional settings for Data Pump Export and Import jobs
Constant Summary collapse
- JOB_MODE_ENUM =
[ JOB_MODE_FULL = 'FULL'.freeze, JOB_MODE_SCHEMA = 'SCHEMA'.freeze, JOB_MODE_TABLE = 'TABLE'.freeze, JOB_MODE_TABLESPACE = 'TABLESPACE'.freeze, JOB_MODE_TRANSPORTABLE = 'TRANSPORTABLE'.freeze, JOB_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #data_pump_parameters ⇒ OCI::DatabaseMigration::Models::DataPumpParameters
- #export_directory_object ⇒ OCI::DatabaseMigration::Models::DirectoryObject
- #import_directory_object ⇒ OCI::DatabaseMigration::Models::DirectoryObject
-
#job_mode ⇒ String
Data Pump job mode.
-
#metadata_remaps ⇒ Array<OCI::DatabaseMigration::Models::MetadataRemap>
Defines remapping to be applied to objects as they are processed.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataPumpSettings
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DataPumpSettings
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 79 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.job_mode = attributes[:'jobMode'] if attributes[:'jobMode'] raise 'You cannot provide both :jobMode and :job_mode' if attributes.key?(:'jobMode') && attributes.key?(:'job_mode') self.job_mode = attributes[:'job_mode'] if attributes[:'job_mode'] self.data_pump_parameters = attributes[:'dataPumpParameters'] if attributes[:'dataPumpParameters'] raise 'You cannot provide both :dataPumpParameters and :data_pump_parameters' if attributes.key?(:'dataPumpParameters') && attributes.key?(:'data_pump_parameters') self.data_pump_parameters = attributes[:'data_pump_parameters'] if attributes[:'data_pump_parameters'] self. = attributes[:'metadataRemaps'] if attributes[:'metadataRemaps'] raise 'You cannot provide both :metadataRemaps and :metadata_remaps' if attributes.key?(:'metadataRemaps') && attributes.key?(:'metadata_remaps') self. = attributes[:'metadata_remaps'] if attributes[:'metadata_remaps'] self.export_directory_object = attributes[:'exportDirectoryObject'] if attributes[:'exportDirectoryObject'] raise 'You cannot provide both :exportDirectoryObject and :export_directory_object' if attributes.key?(:'exportDirectoryObject') && attributes.key?(:'export_directory_object') self.export_directory_object = attributes[:'export_directory_object'] if attributes[:'export_directory_object'] self.import_directory_object = attributes[:'importDirectoryObject'] if attributes[:'importDirectoryObject'] raise 'You cannot provide both :importDirectoryObject and :import_directory_object' if attributes.key?(:'importDirectoryObject') && attributes.key?(:'import_directory_object') self.import_directory_object = attributes[:'import_directory_object'] if attributes[:'import_directory_object'] end |
Instance Attribute Details
#data_pump_parameters ⇒ OCI::DatabaseMigration::Models::DataPumpParameters
28 29 30 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 28 def data_pump_parameters @data_pump_parameters end |
#export_directory_object ⇒ OCI::DatabaseMigration::Models::DirectoryObject
37 38 39 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 37 def export_directory_object @export_directory_object end |
#import_directory_object ⇒ OCI::DatabaseMigration::Models::DirectoryObject
40 41 42 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 40 def import_directory_object @import_directory_object end |
#job_mode ⇒ String
Data Pump job mode. Refer to [Data Pump Export Modes ](docs.oracle.com/en/database/oracle/oracle-database/19/sutil/oracle-data-pump-export-utility.html#GUID-8E497131-6B9B-4CC8-AA50-35F480CAC2C4)
25 26 27 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 25 def job_mode @job_mode end |
#metadata_remaps ⇒ Array<OCI::DatabaseMigration::Models::MetadataRemap>
Defines remapping to be applied to objects as they are processed. Refer to [METADATA_REMAP Procedure ](docs.oracle.com/en/database/oracle/oracle-database/19/arpls/DBMS_DATAPUMP.html#GUID-0FC32790-91E6-4781-87A3-229DE024CB3D)
34 35 36 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 34 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 43 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'job_mode': :'jobMode', 'data_pump_parameters': :'dataPumpParameters', 'metadata_remaps': :'metadataRemaps', 'export_directory_object': :'exportDirectoryObject', 'import_directory_object': :'importDirectoryObject' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 56 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'job_mode': :'String', 'data_pump_parameters': :'OCI::DatabaseMigration::Models::DataPumpParameters', 'metadata_remaps': :'Array<OCI::DatabaseMigration::Models::MetadataRemap>', 'export_directory_object': :'OCI::DatabaseMigration::Models::DirectoryObject', 'import_directory_object': :'OCI::DatabaseMigration::Models::DirectoryObject' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 136 def ==(other) return true if equal?(other) self.class == other.class && job_mode == other.job_mode && data_pump_parameters == other.data_pump_parameters && == other. && export_directory_object == other.export_directory_object && import_directory_object == other.import_directory_object end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 170 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
150 151 152 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 150 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 159 def hash [job_mode, data_pump_parameters, , export_directory_object, import_directory_object].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
197 198 199 |
# File 'lib/oci/database_migration/models/data_pump_settings.rb', line 197 def to_s to_hash.to_s end |