Class: OCI::DatabaseMigration::Models::PhaseStatus
- Inherits:
-
Object
- Object
- OCI::DatabaseMigration::Models::PhaseStatus
- Defined in:
- lib/oci/database_migration/models/phase_status.rb
Overview
Job phase status details.
Constant Summary collapse
- NAME_ENUM =
[ NAME_ODMS_VALIDATE_TGT = 'ODMS_VALIDATE_TGT'.freeze, NAME_ODMS_VALIDATE_SRC = 'ODMS_VALIDATE_SRC'.freeze, NAME_ODMS_VALIDATE_PREMIGRATION_ADVISOR = 'ODMS_VALIDATE_PREMIGRATION_ADVISOR'.freeze, NAME_ODMS_VALIDATE_GG_HUB = 'ODMS_VALIDATE_GG_HUB'.freeze, NAME_ODMS_VALIDATE_DATAPUMP_SETTINGS = 'ODMS_VALIDATE_DATAPUMP_SETTINGS'.freeze, NAME_ODMS_VALIDATE_DATAPUMP_SETTINGS_SRC = 'ODMS_VALIDATE_DATAPUMP_SETTINGS_SRC'.freeze, NAME_ODMS_VALIDATE_DATAPUMP_SETTINGS_TGT = 'ODMS_VALIDATE_DATAPUMP_SETTINGS_TGT'.freeze, NAME_ODMS_VALIDATE_DATAPUMP_SRC = 'ODMS_VALIDATE_DATAPUMP_SRC'.freeze, NAME_ODMS_VALIDATE_DATAPUMP_ESTIMATE_SRC = 'ODMS_VALIDATE_DATAPUMP_ESTIMATE_SRC'.freeze, NAME_ODMS_VALIDATE = 'ODMS_VALIDATE'.freeze, NAME_ODMS_PREPARE = 'ODMS_PREPARE'.freeze, NAME_ODMS_INITIAL_LOAD_EXPORT = 'ODMS_INITIAL_LOAD_EXPORT'.freeze, NAME_ODMS_DATA_UPLOAD = 'ODMS_DATA_UPLOAD'.freeze, NAME_ODMS_INITIAL_LOAD_IMPORT = 'ODMS_INITIAL_LOAD_IMPORT'.freeze, NAME_ODMS_POST_INITIAL_LOAD = 'ODMS_POST_INITIAL_LOAD'.freeze, NAME_ODMS_PREPARE_REPLICATION_TARGET = 'ODMS_PREPARE_REPLICATION_TARGET'.freeze, NAME_ODMS_MONITOR_REPLICATION_LAG = 'ODMS_MONITOR_REPLICATION_LAG'.freeze, NAME_ODMS_SWITCHOVER = 'ODMS_SWITCHOVER'.freeze, NAME_ODMS_CLEANUP = 'ODMS_CLEANUP'.freeze, NAME_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_PENDING = 'PENDING'.freeze, STATUS_STARTED = 'STARTED'.freeze, STATUS_COMPLETED = 'COMPLETED'.freeze, STATUS_FAILED = 'FAILED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#duration_in_ms ⇒ Integer
[Required] Duration of the phase in milliseconds.
-
#extract ⇒ Array<OCI::DatabaseMigration::Models::PhaseExtractEntry>
Summary of phase status results.
-
#is_advisor_report_available ⇒ BOOLEAN
True if a Pre-Migration Advisor report is available for this phase.
- #log_location ⇒ OCI::DatabaseMigration::Models::LogLocationBucketDetails
-
#name ⇒ String
[Required] Phase name.
-
#progress ⇒ Integer
Percent progress of job phase.
-
#status ⇒ String
[Required] Phase status.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PhaseStatus
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PhaseStatus
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 119 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.status = attributes[:'status'] if attributes[:'status'] self.duration_in_ms = attributes[:'durationInMs'] if attributes[:'durationInMs'] raise 'You cannot provide both :durationInMs and :duration_in_ms' if attributes.key?(:'durationInMs') && attributes.key?(:'duration_in_ms') self.duration_in_ms = attributes[:'duration_in_ms'] if attributes[:'duration_in_ms'] self.is_advisor_report_available = attributes[:'isAdvisorReportAvailable'] unless attributes[:'isAdvisorReportAvailable'].nil? raise 'You cannot provide both :isAdvisorReportAvailable and :is_advisor_report_available' if attributes.key?(:'isAdvisorReportAvailable') && attributes.key?(:'is_advisor_report_available') self.is_advisor_report_available = attributes[:'is_advisor_report_available'] unless attributes[:'is_advisor_report_available'].nil? self.extract = attributes[:'extract'] if attributes[:'extract'] self.log_location = attributes[:'logLocation'] if attributes[:'logLocation'] raise 'You cannot provide both :logLocation and :log_location' if attributes.key?(:'logLocation') && attributes.key?(:'log_location') self.log_location = attributes[:'log_location'] if attributes[:'log_location'] self.progress = attributes[:'progress'] if attributes[:'progress'] end |
Instance Attribute Details
#duration_in_ms ⇒ Integer
[Required] Duration of the phase in milliseconds
56 57 58 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 56 def duration_in_ms @duration_in_ms end |
#extract ⇒ Array<OCI::DatabaseMigration::Models::PhaseExtractEntry>
Summary of phase status results.
66 67 68 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 66 def extract @extract end |
#is_advisor_report_available ⇒ BOOLEAN
True if a Pre-Migration Advisor report is available for this phase. False or null if no report is available.
61 62 63 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 61 def is_advisor_report_available @is_advisor_report_available end |
#log_location ⇒ OCI::DatabaseMigration::Models::LogLocationBucketDetails
69 70 71 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 69 def log_location @log_location end |
#name ⇒ String
[Required] Phase name
46 47 48 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 46 def name @name end |
#progress ⇒ Integer
Percent progress of job phase.
74 75 76 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 74 def progress @progress end |
#status ⇒ String
[Required] Phase status
51 52 53 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 51 def status @status end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 77 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'status': :'status', 'duration_in_ms': :'durationInMs', 'is_advisor_report_available': :'isAdvisorReportAvailable', 'extract': :'extract', 'log_location': :'logLocation', 'progress': :'progress' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 92 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'status': :'String', 'duration_in_ms': :'Integer', 'is_advisor_report_available': :'BOOLEAN', 'extract': :'Array<OCI::DatabaseMigration::Models::PhaseExtractEntry>', 'log_location': :'OCI::DatabaseMigration::Models::LogLocationBucketDetails', 'progress': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 185 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && status == other.status && duration_in_ms == other.duration_in_ms && is_advisor_report_available == other.is_advisor_report_available && extract == other.extract && log_location == other.log_location && progress == other.progress end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 221 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
201 202 203 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 201 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
210 211 212 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 210 def hash [name, status, duration_in_ms, is_advisor_report_available, extract, log_location, progress].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 254 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
248 249 250 |
# File 'lib/oci/database_migration/models/phase_status.rb', line 248 def to_s to_hash.to_s end |