Class: OCI::DatabaseMigration::Models::UpdateConnectionDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseMigration::Models::UpdateConnectionDetails
- Defined in:
- lib/oci/database_migration/models/update_connection_details.rb
Overview
Details to update in a Database Connection resource.
Instance Attribute Summary collapse
- #admin_credentials ⇒ OCI::DatabaseMigration::Models::UpdateAdminCredentials
-
#certificate_tdn ⇒ String
This name is the distinguished name used while creating the certificate on target database.
- #connect_descriptor ⇒ OCI::DatabaseMigration::Models::UpdateConnectDescriptor
-
#database_id ⇒ String
The OCID of the cloud database.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Database Connection display name identifier.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #private_endpoint ⇒ OCI::DatabaseMigration::Models::UpdatePrivateEndpoint
- #ssh_details ⇒ OCI::DatabaseMigration::Models::UpdateSshDetails
-
#tls_keystore ⇒ String
keystore.jks file contents; base64 encoded String.
-
#tls_wallet ⇒ String
cwallet.sso containing containing the TCPS/SSL certificate; base64 encoded String.
- #vault_details ⇒ OCI::DatabaseMigration::Models::UpdateVaultDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateConnectionDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateConnectionDetails
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 120 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.connect_descriptor = attributes[:'connectDescriptor'] if attributes[:'connectDescriptor'] raise 'You cannot provide both :connectDescriptor and :connect_descriptor' if attributes.key?(:'connectDescriptor') && attributes.key?(:'connect_descriptor') self.connect_descriptor = attributes[:'connect_descriptor'] if attributes[:'connect_descriptor'] self.certificate_tdn = attributes[:'certificateTdn'] if attributes[:'certificateTdn'] raise 'You cannot provide both :certificateTdn and :certificate_tdn' if attributes.key?(:'certificateTdn') && attributes.key?(:'certificate_tdn') self.certificate_tdn = attributes[:'certificate_tdn'] if attributes[:'certificate_tdn'] self.tls_wallet = attributes[:'tlsWallet'] if attributes[:'tlsWallet'] raise 'You cannot provide both :tlsWallet and :tls_wallet' if attributes.key?(:'tlsWallet') && attributes.key?(:'tls_wallet') self.tls_wallet = attributes[:'tls_wallet'] if attributes[:'tls_wallet'] self.tls_keystore = attributes[:'tlsKeystore'] if attributes[:'tlsKeystore'] raise 'You cannot provide both :tlsKeystore and :tls_keystore' if attributes.key?(:'tlsKeystore') && attributes.key?(:'tls_keystore') self.tls_keystore = attributes[:'tls_keystore'] if attributes[:'tls_keystore'] self.ssh_details = attributes[:'sshDetails'] if attributes[:'sshDetails'] raise 'You cannot provide both :sshDetails and :ssh_details' if attributes.key?(:'sshDetails') && attributes.key?(:'ssh_details') self.ssh_details = attributes[:'ssh_details'] if attributes[:'ssh_details'] self.admin_credentials = attributes[:'adminCredentials'] if attributes[:'adminCredentials'] raise 'You cannot provide both :adminCredentials and :admin_credentials' if attributes.key?(:'adminCredentials') && attributes.key?(:'admin_credentials') self.admin_credentials = attributes[:'admin_credentials'] if attributes[:'admin_credentials'] self.private_endpoint = attributes[:'privateEndpoint'] if attributes[:'privateEndpoint'] raise 'You cannot provide both :privateEndpoint and :private_endpoint' if attributes.key?(:'privateEndpoint') && attributes.key?(:'private_endpoint') self.private_endpoint = attributes[:'private_endpoint'] if attributes[:'private_endpoint'] self.vault_details = attributes[:'vaultDetails'] if attributes[:'vaultDetails'] raise 'You cannot provide both :vaultDetails and :vault_details' if attributes.key?(:'vaultDetails') && attributes.key?(:'vault_details') self.vault_details = attributes[:'vault_details'] if attributes[:'vault_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#admin_credentials ⇒ OCI::DatabaseMigration::Models::UpdateAdminCredentials
42 43 44 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 42 def admin_credentials @admin_credentials end |
#certificate_tdn ⇒ String
This name is the distinguished name used while creating the certificate on target database. Not required for source container database connections.
26 27 28 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 26 def certificate_tdn @certificate_tdn end |
#connect_descriptor ⇒ OCI::DatabaseMigration::Models::UpdateConnectDescriptor
22 23 24 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 22 def connect_descriptor @connect_descriptor end |
#database_id ⇒ String
The OCID of the cloud database.
19 20 21 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 19 def database_id @database_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
60 61 62 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 60 def end |
#display_name ⇒ String
Database Connection display name identifier.
14 15 16 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 14 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
54 55 56 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 54 def end |
#private_endpoint ⇒ OCI::DatabaseMigration::Models::UpdatePrivateEndpoint
45 46 47 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 45 def private_endpoint @private_endpoint end |
#ssh_details ⇒ OCI::DatabaseMigration::Models::UpdateSshDetails
39 40 41 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 39 def ssh_details @ssh_details end |
#tls_keystore ⇒ String
keystore.jks file contents; base64 encoded String. Not required for source container database connections.
36 37 38 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 36 def tls_keystore @tls_keystore end |
#tls_wallet ⇒ String
cwallet.sso containing containing the TCPS/SSL certificate; base64 encoded String. Not required for source container database connections.
31 32 33 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 31 def tls_wallet @tls_wallet end |
#vault_details ⇒ OCI::DatabaseMigration::Models::UpdateVaultDetails
48 49 50 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 48 def vault_details @vault_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'database_id': :'databaseId', 'connect_descriptor': :'connectDescriptor', 'certificate_tdn': :'certificateTdn', 'tls_wallet': :'tlsWallet', 'tls_keystore': :'tlsKeystore', 'ssh_details': :'sshDetails', 'admin_credentials': :'adminCredentials', 'private_endpoint': :'privateEndpoint', 'vault_details': :'vaultDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 83 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'database_id': :'String', 'connect_descriptor': :'OCI::DatabaseMigration::Models::UpdateConnectDescriptor', 'certificate_tdn': :'String', 'tls_wallet': :'String', 'tls_keystore': :'String', 'ssh_details': :'OCI::DatabaseMigration::Models::UpdateSshDetails', 'admin_credentials': :'OCI::DatabaseMigration::Models::UpdateAdminCredentials', 'private_endpoint': :'OCI::DatabaseMigration::Models::UpdatePrivateEndpoint', 'vault_details': :'OCI::DatabaseMigration::Models::UpdateVaultDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 206 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && database_id == other.database_id && connect_descriptor == other.connect_descriptor && certificate_tdn == other.certificate_tdn && tls_wallet == other.tls_wallet && tls_keystore == other.tls_keystore && ssh_details == other.ssh_details && admin_credentials == other.admin_credentials && private_endpoint == other.private_endpoint && vault_details == other.vault_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 247 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
227 228 229 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 227 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 236 def hash [display_name, database_id, connect_descriptor, certificate_tdn, tls_wallet, tls_keystore, ssh_details, admin_credentials, private_endpoint, vault_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
274 275 276 |
# File 'lib/oci/database_migration/models/update_connection_details.rb', line 274 def to_s to_hash.to_s end |