Class: OCI::DatabaseMigration::Models::UpdateMigrationDetails
- Inherits:
-
Object
- Object
- OCI::DatabaseMigration::Models::UpdateMigrationDetails
- Defined in:
- lib/oci/database_migration/models/update_migration_details.rb
Overview
Update Migration resource parameters.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_ONLINE = 'ONLINE'.freeze, TYPE_OFFLINE = 'OFFLINE'.freeze ].freeze
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The OCID of the registered ODMS Agent.
- #data_transfer_medium_details ⇒ OCI::DatabaseMigration::Models::UpdateDataTransferMediumDetails
- #datapump_settings ⇒ OCI::DatabaseMigration::Models::UpdateDataPumpSettings
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
Migration Display Name.
-
#exclude_objects ⇒ Array<OCI::DatabaseMigration::Models::DatabaseObject>
Database objects to exclude from migration.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #golden_gate_details ⇒ OCI::DatabaseMigration::Models::UpdateGoldenGateDetails
-
#source_container_database_connection_id ⇒ String
The OCID of the Source Container Database Connection.
-
#source_database_connection_id ⇒ String
The OCID of the Source Database Connection.
-
#target_database_connection_id ⇒ String
The OCID of the Target Database Connection.
-
#type ⇒ String
Migration type.
- #vault_details ⇒ OCI::DatabaseMigration::Models::UpdateVaultDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateMigrationDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateMigrationDetails
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 139 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.agent_id = attributes[:'agentId'] if attributes[:'agentId'] raise 'You cannot provide both :agentId and :agent_id' if attributes.key?(:'agentId') && attributes.key?(:'agent_id') self.agent_id = attributes[:'agent_id'] if attributes[:'agent_id'] self.source_database_connection_id = attributes[:'sourceDatabaseConnectionId'] if attributes[:'sourceDatabaseConnectionId'] raise 'You cannot provide both :sourceDatabaseConnectionId and :source_database_connection_id' if attributes.key?(:'sourceDatabaseConnectionId') && attributes.key?(:'source_database_connection_id') self.source_database_connection_id = attributes[:'source_database_connection_id'] if attributes[:'source_database_connection_id'] self.source_container_database_connection_id = attributes[:'sourceContainerDatabaseConnectionId'] if attributes[:'sourceContainerDatabaseConnectionId'] raise 'You cannot provide both :sourceContainerDatabaseConnectionId and :source_container_database_connection_id' if attributes.key?(:'sourceContainerDatabaseConnectionId') && attributes.key?(:'source_container_database_connection_id') self.source_container_database_connection_id = attributes[:'source_container_database_connection_id'] if attributes[:'source_container_database_connection_id'] self.target_database_connection_id = attributes[:'targetDatabaseConnectionId'] if attributes[:'targetDatabaseConnectionId'] raise 'You cannot provide both :targetDatabaseConnectionId and :target_database_connection_id' if attributes.key?(:'targetDatabaseConnectionId') && attributes.key?(:'target_database_connection_id') self.target_database_connection_id = attributes[:'target_database_connection_id'] if attributes[:'target_database_connection_id'] self.data_transfer_medium_details = attributes[:'dataTransferMediumDetails'] if attributes[:'dataTransferMediumDetails'] raise 'You cannot provide both :dataTransferMediumDetails and :data_transfer_medium_details' if attributes.key?(:'dataTransferMediumDetails') && attributes.key?(:'data_transfer_medium_details') self.data_transfer_medium_details = attributes[:'data_transfer_medium_details'] if attributes[:'data_transfer_medium_details'] self.datapump_settings = attributes[:'datapumpSettings'] if attributes[:'datapumpSettings'] raise 'You cannot provide both :datapumpSettings and :datapump_settings' if attributes.key?(:'datapumpSettings') && attributes.key?(:'datapump_settings') self.datapump_settings = attributes[:'datapump_settings'] if attributes[:'datapump_settings'] self.exclude_objects = attributes[:'excludeObjects'] if attributes[:'excludeObjects'] raise 'You cannot provide both :excludeObjects and :exclude_objects' if attributes.key?(:'excludeObjects') && attributes.key?(:'exclude_objects') self.exclude_objects = attributes[:'exclude_objects'] if attributes[:'exclude_objects'] self.golden_gate_details = attributes[:'goldenGateDetails'] if attributes[:'goldenGateDetails'] raise 'You cannot provide both :goldenGateDetails and :golden_gate_details' if attributes.key?(:'goldenGateDetails') && attributes.key?(:'golden_gate_details') self.golden_gate_details = attributes[:'golden_gate_details'] if attributes[:'golden_gate_details'] self.vault_details = attributes[:'vaultDetails'] if attributes[:'vaultDetails'] raise 'You cannot provide both :vaultDetails and :vault_details' if attributes.key?(:'vaultDetails') && attributes.key?(:'vault_details') self.vault_details = attributes[:'vault_details'] if attributes[:'vault_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#agent_id ⇒ String
The OCID of the registered ODMS Agent.
29 30 31 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 29 def agent_id @agent_id end |
#data_transfer_medium_details ⇒ OCI::DatabaseMigration::Models::UpdateDataTransferMediumDetails
49 50 51 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 49 def data_transfer_medium_details @data_transfer_medium_details end |
#datapump_settings ⇒ OCI::DatabaseMigration::Models::UpdateDataPumpSettings
52 53 54 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 52 def datapump_settings @datapump_settings end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
76 77 78 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 76 def end |
#display_name ⇒ String
Migration Display Name
24 25 26 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 24 def display_name @display_name end |
#exclude_objects ⇒ Array<OCI::DatabaseMigration::Models::DatabaseObject>
Database objects to exclude from migration. If specified, the list will be replaced entirely. Empty list will remove stored excludeObjects details.
58 59 60 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 58 def exclude_objects @exclude_objects end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
70 71 72 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 70 def end |
#golden_gate_details ⇒ OCI::DatabaseMigration::Models::UpdateGoldenGateDetails
61 62 63 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 61 def golden_gate_details @golden_gate_details end |
#source_container_database_connection_id ⇒ String
The OCID of the Source Container Database Connection. Only used for Online migrations. Only Connections of type Non-Autonomous can be used as source container databases. An empty value would remove the stored Connection ID.
41 42 43 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 41 def source_container_database_connection_id @source_container_database_connection_id end |
#source_database_connection_id ⇒ String
The OCID of the Source Database Connection.
34 35 36 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 34 def source_database_connection_id @source_database_connection_id end |
#target_database_connection_id ⇒ String
The OCID of the Target Database Connection.
46 47 48 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 46 def target_database_connection_id @target_database_connection_id end |
#type ⇒ String
Migration type.
19 20 21 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 19 def type @type end |
#vault_details ⇒ OCI::DatabaseMigration::Models::UpdateVaultDetails
64 65 66 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 64 def vault_details @vault_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 79 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'display_name': :'displayName', 'agent_id': :'agentId', 'source_database_connection_id': :'sourceDatabaseConnectionId', 'source_container_database_connection_id': :'sourceContainerDatabaseConnectionId', 'target_database_connection_id': :'targetDatabaseConnectionId', 'data_transfer_medium_details': :'dataTransferMediumDetails', 'datapump_settings': :'datapumpSettings', 'exclude_objects': :'excludeObjects', 'golden_gate_details': :'goldenGateDetails', 'vault_details': :'vaultDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 100 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'display_name': :'String', 'agent_id': :'String', 'source_database_connection_id': :'String', 'source_container_database_connection_id': :'String', 'target_database_connection_id': :'String', 'data_transfer_medium_details': :'OCI::DatabaseMigration::Models::UpdateDataTransferMediumDetails', 'datapump_settings': :'OCI::DatabaseMigration::Models::UpdateDataPumpSettings', 'exclude_objects': :'Array<OCI::DatabaseMigration::Models::DatabaseObject>', 'golden_gate_details': :'OCI::DatabaseMigration::Models::UpdateGoldenGateDetails', 'vault_details': :'OCI::DatabaseMigration::Models::UpdateVaultDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 235 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && display_name == other.display_name && agent_id == other.agent_id && source_database_connection_id == other.source_database_connection_id && source_container_database_connection_id == other.source_container_database_connection_id && target_database_connection_id == other.target_database_connection_id && data_transfer_medium_details == other.data_transfer_medium_details && datapump_settings == other.datapump_settings && exclude_objects == other.exclude_objects && golden_gate_details == other.golden_gate_details && vault_details == other.vault_details && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 277 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
257 258 259 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 257 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
266 267 268 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 266 def hash [type, display_name, agent_id, source_database_connection_id, source_container_database_connection_id, target_database_connection_id, data_transfer_medium_details, datapump_settings, exclude_objects, golden_gate_details, vault_details, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
304 305 306 |
# File 'lib/oci/database_migration/models/update_migration_details.rb', line 304 def to_s to_hash.to_s end |