Class: OCI::DatabaseTools::Models::ValidateDatabaseToolsConnectionResult
- Inherits:
-
Object
- Object
- OCI::DatabaseTools::Models::ValidateDatabaseToolsConnectionResult
- Defined in:
- lib/oci/database_tools/models/validate_database_tools_connection_result.rb
Overview
Connection validation result. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_ORACLE_DATABASE = 'ORACLE_DATABASE'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#action ⇒ String
A human-readable message that suggests a remedial action to resolve the validation error.
-
#cause ⇒ String
A human-readable message that describes possible causes for the validation error.
-
#code ⇒ String
[Required] A short code that defines the result of the validation, meant for programmatic parsing.
-
#message ⇒ String
[Required] A human-readable message that describes the result of the validation.
-
#type ⇒ String
[Required] The DatabaseToolsConnection type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ValidateDatabaseToolsConnectionResult
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ValidateDatabaseToolsConnectionResult
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 89 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.type = attributes[:'type'] if attributes[:'type'] self.code = attributes[:'code'] if attributes[:'code'] self. = attributes[:'message'] if attributes[:'message'] self.cause = attributes[:'cause'] if attributes[:'cause'] self.action = attributes[:'action'] if attributes[:'action'] end |
Instance Attribute Details
#action ⇒ String
A human-readable message that suggests a remedial action to resolve the validation error.
35 36 37 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 35 def action @action end |
#cause ⇒ String
A human-readable message that describes possible causes for the validation error.
31 32 33 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 31 def cause @cause end |
#code ⇒ String
[Required] A short code that defines the result of the validation, meant for programmatic parsing.
23 24 25 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 23 def code @code end |
#message ⇒ String
[Required] A human-readable message that describes the result of the validation.
27 28 29 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 27 def end |
#type ⇒ String
[Required] The DatabaseToolsConnection type.
19 20 21 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 19 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'code': :'code', 'message': :'message', 'cause': :'cause', 'action': :'action' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
68 69 70 71 72 73 74 75 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 68 def self.get_subtype(object_hash) type = object_hash[:'type'] # rubocop:disable Style/SymbolLiteral return 'OCI::DatabaseTools::Models::ValidateDatabaseToolsConnectionOracleDatabaseResult' if type == 'ORACLE_DATABASE' # TODO: Log a warning when the subtype is not found. 'OCI::DatabaseTools::Models::ValidateDatabaseToolsConnectionResult' end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'code': :'String', 'message': :'String', 'cause': :'String', 'action': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 126 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && code == other.code && == other. && cause == other.cause && action == other.action end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 160 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
140 141 142 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 140 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 149 def hash [type, code, , cause, action].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
187 188 189 |
# File 'lib/oci/database_tools/models/validate_database_tools_connection_result.rb', line 187 def to_s to_hash.to_s end |