Class: OCI::Devops::Models::BuildSource
- Inherits:
-
Object
- Object
- OCI::Devops::Models::BuildSource
- Defined in:
- lib/oci/devops/models/build_source.rb
Overview
Build source required for the Build stage. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
DevopsCodeRepositoryBuildSource, GithubBuildSource, GitlabBuildSource
Constant Summary collapse
- CONNECTION_TYPE_ENUM =
[ CONNECTION_TYPE_GITHUB = 'GITHUB'.freeze, CONNECTION_TYPE_GITLAB = 'GITLAB'.freeze, CONNECTION_TYPE_DEVOPS_CODE_REPOSITORY = 'DEVOPS_CODE_REPOSITORY'.freeze, CONNECTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#branch ⇒ String
[Required] Branch name.
-
#connection_type ⇒ String
[Required] The type of source provider.
-
#name ⇒ String
[Required] Name of the build source.
-
#repository_url ⇒ String
[Required] URL for the repository.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BuildSource
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BuildSource
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/devops/models/build_source.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.connection_type = attributes[:'connectionType'] if attributes[:'connectionType'] raise 'You cannot provide both :connectionType and :connection_type' if attributes.key?(:'connectionType') && attributes.key?(:'connection_type') self.connection_type = attributes[:'connection_type'] if attributes[:'connection_type'] self.repository_url = attributes[:'repositoryUrl'] if attributes[:'repositoryUrl'] raise 'You cannot provide both :repositoryUrl and :repository_url' if attributes.key?(:'repositoryUrl') && attributes.key?(:'repository_url') self.repository_url = attributes[:'repository_url'] if attributes[:'repository_url'] self.branch = attributes[:'branch'] if attributes[:'branch'] end |
Instance Attribute Details
#branch ⇒ String
[Required] Branch name.
33 34 35 |
# File 'lib/oci/devops/models/build_source.rb', line 33 def branch @branch end |
#connection_type ⇒ String
[Required] The type of source provider.
25 26 27 |
# File 'lib/oci/devops/models/build_source.rb', line 25 def connection_type @connection_type end |
#name ⇒ String
[Required] Name of the build source. This must be unique within a build source collection. The name can be used by customers to locate the working directory pertinent to this repository.
21 22 23 |
# File 'lib/oci/devops/models/build_source.rb', line 21 def name @name end |
#repository_url ⇒ String
[Required] URL for the repository.
29 30 31 |
# File 'lib/oci/devops/models/build_source.rb', line 29 def repository_url @repository_url end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/devops/models/build_source.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'connection_type': :'connectionType', 'repository_url': :'repositoryUrl', 'branch': :'branch' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/devops/models/build_source.rb', line 64 def self.get_subtype(object_hash) type = object_hash[:'connectionType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Devops::Models::GithubBuildSource' if type == 'GITHUB' return 'OCI::Devops::Models::DevopsCodeRepositoryBuildSource' if type == 'DEVOPS_CODE_REPOSITORY' return 'OCI::Devops::Models::GitlabBuildSource' if type == 'GITLAB' # TODO: Log a warning when the subtype is not found. 'OCI::Devops::Models::BuildSource' end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/oci/devops/models/build_source.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'connection_type': :'String', 'repository_url': :'String', 'branch': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/devops/models/build_source.rb', line 129 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && connection_type == other.connection_type && repository_url == other.repository_url && branch == other.branch end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/devops/models/build_source.rb', line 162 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
142 143 144 |
# File 'lib/oci/devops/models/build_source.rb', line 142 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/oci/devops/models/build_source.rb', line 151 def hash [name, connection_type, repository_url, branch].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/devops/models/build_source.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
189 190 191 |
# File 'lib/oci/devops/models/build_source.rb', line 189 def to_s to_hash.to_s end |