Class: OCI::Devops::Models::CreateComputeInstanceGroupBlueGreenDeployStageDetails
- Inherits:
-
CreateDeployStageDetails
- Object
- CreateDeployStageDetails
- OCI::Devops::Models::CreateComputeInstanceGroupBlueGreenDeployStageDetails
- Defined in:
- lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb
Overview
Specifies the Instance Group Blue-Green deployment stage.
Instance Attribute Summary collapse
-
#deploy_artifact_ids ⇒ Array<String>
The list of file artifact OCIDs to deploy.
-
#deploy_environment_id_a ⇒ String
**[Required]** First compute instance group environment OCID for deployment.
-
#deploy_environment_id_b ⇒ String
**[Required]** Second compute instance group environment OCID for deployment.
-
#deployment_spec_deploy_artifact_id ⇒ String
**[Required]** The OCID of the artifact that contains the deployment specification.
- #failure_policy ⇒ OCI::Devops::Models::ComputeInstanceGroupFailurePolicy
-
#production_load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
This attribute is required.
-
#rollout_policy ⇒ OCI::Devops::Models::ComputeInstanceGroupRolloutPolicy
This attribute is required.
- #test_load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
Attributes inherited from CreateDeployStageDetails
#defined_tags, #deploy_pipeline_id, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateComputeInstanceGroupBlueGreenDeployStageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from CreateDeployStageDetails
Constructor Details
#initialize(attributes = {}) ⇒ CreateComputeInstanceGroupBlueGreenDeployStageDetails
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 107 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'COMPUTE_INSTANCE_GROUP_BLUE_GREEN_DEPLOYMENT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.deploy_environment_id_a = attributes[:'deployEnvironmentIdA'] if attributes[:'deployEnvironmentIdA'] raise 'You cannot provide both :deployEnvironmentIdA and :deploy_environment_id_a' if attributes.key?(:'deployEnvironmentIdA') && attributes.key?(:'deploy_environment_id_a') self.deploy_environment_id_a = attributes[:'deploy_environment_id_a'] if attributes[:'deploy_environment_id_a'] self.deploy_environment_id_b = attributes[:'deployEnvironmentIdB'] if attributes[:'deployEnvironmentIdB'] raise 'You cannot provide both :deployEnvironmentIdB and :deploy_environment_id_b' if attributes.key?(:'deployEnvironmentIdB') && attributes.key?(:'deploy_environment_id_b') self.deploy_environment_id_b = attributes[:'deploy_environment_id_b'] if attributes[:'deploy_environment_id_b'] self.deployment_spec_deploy_artifact_id = attributes[:'deploymentSpecDeployArtifactId'] if attributes[:'deploymentSpecDeployArtifactId'] raise 'You cannot provide both :deploymentSpecDeployArtifactId and :deployment_spec_deploy_artifact_id' if attributes.key?(:'deploymentSpecDeployArtifactId') && attributes.key?(:'deployment_spec_deploy_artifact_id') self.deployment_spec_deploy_artifact_id = attributes[:'deployment_spec_deploy_artifact_id'] if attributes[:'deployment_spec_deploy_artifact_id'] self.deploy_artifact_ids = attributes[:'deployArtifactIds'] if attributes[:'deployArtifactIds'] raise 'You cannot provide both :deployArtifactIds and :deploy_artifact_ids' if attributes.key?(:'deployArtifactIds') && attributes.key?(:'deploy_artifact_ids') self.deploy_artifact_ids = attributes[:'deploy_artifact_ids'] if attributes[:'deploy_artifact_ids'] self.rollout_policy = attributes[:'rolloutPolicy'] if attributes[:'rolloutPolicy'] raise 'You cannot provide both :rolloutPolicy and :rollout_policy' if attributes.key?(:'rolloutPolicy') && attributes.key?(:'rollout_policy') self.rollout_policy = attributes[:'rollout_policy'] if attributes[:'rollout_policy'] self.failure_policy = attributes[:'failurePolicy'] if attributes[:'failurePolicy'] raise 'You cannot provide both :failurePolicy and :failure_policy' if attributes.key?(:'failurePolicy') && attributes.key?(:'failure_policy') self.failure_policy = attributes[:'failure_policy'] if attributes[:'failure_policy'] self.test_load_balancer_config = attributes[:'testLoadBalancerConfig'] if attributes[:'testLoadBalancerConfig'] raise 'You cannot provide both :testLoadBalancerConfig and :test_load_balancer_config' if attributes.key?(:'testLoadBalancerConfig') && attributes.key?(:'test_load_balancer_config') self.test_load_balancer_config = attributes[:'test_load_balancer_config'] if attributes[:'test_load_balancer_config'] self.production_load_balancer_config = attributes[:'productionLoadBalancerConfig'] if attributes[:'productionLoadBalancerConfig'] raise 'You cannot provide both :productionLoadBalancerConfig and :production_load_balancer_config' if attributes.key?(:'productionLoadBalancerConfig') && attributes.key?(:'production_load_balancer_config') self.production_load_balancer_config = attributes[:'production_load_balancer_config'] if attributes[:'production_load_balancer_config'] end |
Instance Attribute Details
#deploy_artifact_ids ⇒ Array<String>
The list of file artifact OCIDs to deploy.
25 26 27 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 25 def deploy_artifact_ids @deploy_artifact_ids end |
#deploy_environment_id_a ⇒ String
**[Required]** First compute instance group environment OCID for deployment.
13 14 15 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 13 def deploy_environment_id_a @deploy_environment_id_a end |
#deploy_environment_id_b ⇒ String
**[Required]** Second compute instance group environment OCID for deployment.
17 18 19 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 17 def deploy_environment_id_b @deploy_environment_id_b end |
#deployment_spec_deploy_artifact_id ⇒ String
**[Required]** The OCID of the artifact that contains the deployment specification.
21 22 23 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 21 def deployment_spec_deploy_artifact_id @deployment_spec_deploy_artifact_id end |
#failure_policy ⇒ OCI::Devops::Models::ComputeInstanceGroupFailurePolicy
32 33 34 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 32 def failure_policy @failure_policy end |
#production_load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
This attribute is required.
39 40 41 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 39 def production_load_balancer_config @production_load_balancer_config end |
#rollout_policy ⇒ OCI::Devops::Models::ComputeInstanceGroupRolloutPolicy
This attribute is required.
29 30 31 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 29 def rollout_policy @rollout_policy end |
#test_load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
35 36 37 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 35 def test_load_balancer_config @test_load_balancer_config end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'deploy_stage_type': :'deployStageType', 'deploy_pipeline_id': :'deployPipelineId', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'deploy_environment_id_a': :'deployEnvironmentIdA', 'deploy_environment_id_b': :'deployEnvironmentIdB', 'deployment_spec_deploy_artifact_id': :'deploymentSpecDeployArtifactId', 'deploy_artifact_ids': :'deployArtifactIds', 'rollout_policy': :'rolloutPolicy', 'failure_policy': :'failurePolicy', 'test_load_balancer_config': :'testLoadBalancerConfig', 'production_load_balancer_config': :'productionLoadBalancerConfig' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'deploy_stage_type': :'String', 'deploy_pipeline_id': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'deploy_environment_id_a': :'String', 'deploy_environment_id_b': :'String', 'deployment_spec_deploy_artifact_id': :'String', 'deploy_artifact_ids': :'Array<String>', 'rollout_policy': :'OCI::Devops::Models::ComputeInstanceGroupRolloutPolicy', 'failure_policy': :'OCI::Devops::Models::ComputeInstanceGroupFailurePolicy', 'test_load_balancer_config': :'OCI::Devops::Models::LoadBalancerConfig', 'production_load_balancer_config': :'OCI::Devops::Models::LoadBalancerConfig' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 173 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && deploy_stage_type == other.deploy_stage_type && deploy_pipeline_id == other.deploy_pipeline_id && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. && deploy_environment_id_a == other.deploy_environment_id_a && deploy_environment_id_b == other.deploy_environment_id_b && deployment_spec_deploy_artifact_id == other.deployment_spec_deploy_artifact_id && deploy_artifact_ids == other.deploy_artifact_ids && rollout_policy == other.rollout_policy && failure_policy == other.failure_policy && test_load_balancer_config == other.test_load_balancer_config && production_load_balancer_config == other.production_load_balancer_config end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 217 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
197 198 199 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 197 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 206 def hash [description, display_name, deploy_stage_type, deploy_pipeline_id, deploy_stage_predecessor_collection, , , deploy_environment_id_a, deploy_environment_id_b, deployment_spec_deploy_artifact_id, deploy_artifact_ids, rollout_policy, failure_policy, test_load_balancer_config, production_load_balancer_config].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
244 245 246 |
# File 'lib/oci/devops/models/create_compute_instance_group_blue_green_deploy_stage_details.rb', line 244 def to_s to_hash.to_s end |