Class: OCI::Devops::Models::CreateDeployStageDetails
- Inherits:
-
Object
- Object
- OCI::Devops::Models::CreateDeployStageDetails
- Defined in:
- lib/oci/devops/models/create_deploy_stage_details.rb
Overview
The information about new deployment stage. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
CreateComputeInstanceGroupDeployStageDetails, CreateFunctionDeployStageDetails, CreateInvokeFunctionDeployStageDetails, CreateLoadBalancerTrafficShiftDeployStageDetails, CreateManualApprovalDeployStageDetails, CreateOkeDeployStageDetails, CreateWaitDeployStageDetails
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#deploy_pipeline_id ⇒ String
[Required] The OCID of a pipeline.
-
#deploy_stage_predecessor_collection ⇒ OCI::Devops::Models::DeployStagePredecessorCollection
This attribute is required.
-
#deploy_stage_type ⇒ String
[Required] Deployment stage type.
-
#description ⇒ String
Optional description about the deployment stage.
-
#display_name ⇒ String
Deployment stage display name, which can be renamed and is not necessarily unique.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDeployStageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDeployStageDetails
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 103 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.deploy_stage_type = attributes[:'deployStageType'] if attributes[:'deployStageType'] raise 'You cannot provide both :deployStageType and :deploy_stage_type' if attributes.key?(:'deployStageType') && attributes.key?(:'deploy_stage_type') self.deploy_stage_type = attributes[:'deploy_stage_type'] if attributes[:'deploy_stage_type'] self.deploy_pipeline_id = attributes[:'deployPipelineId'] if attributes[:'deployPipelineId'] raise 'You cannot provide both :deployPipelineId and :deploy_pipeline_id' if attributes.key?(:'deployPipelineId') && attributes.key?(:'deploy_pipeline_id') self.deploy_pipeline_id = attributes[:'deploy_pipeline_id'] if attributes[:'deploy_pipeline_id'] self.deploy_stage_predecessor_collection = attributes[:'deployStagePredecessorCollection'] if attributes[:'deployStagePredecessorCollection'] raise 'You cannot provide both :deployStagePredecessorCollection and :deploy_stage_predecessor_collection' if attributes.key?(:'deployStagePredecessorCollection') && attributes.key?(:'deploy_stage_predecessor_collection') self.deploy_stage_predecessor_collection = attributes[:'deploy_stage_predecessor_collection'] if attributes[:'deploy_stage_predecessor_collection'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
37 38 39 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 37 def end |
#deploy_pipeline_id ⇒ String
[Required] The OCID of a pipeline.
25 26 27 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 25 def deploy_pipeline_id @deploy_pipeline_id end |
#deploy_stage_predecessor_collection ⇒ OCI::Devops::Models::DeployStagePredecessorCollection
This attribute is required.
29 30 31 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 29 def deploy_stage_predecessor_collection @deploy_stage_predecessor_collection end |
#deploy_stage_type ⇒ String
[Required] Deployment stage type.
21 22 23 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 21 def deploy_stage_type @deploy_stage_type end |
#description ⇒ String
Optional description about the deployment stage.
13 14 15 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 13 def description @description end |
#display_name ⇒ String
Deployment stage display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
17 18 19 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 17 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
33 34 35 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 33 def end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'deploy_stage_type': :'deployStageType', 'deploy_pipeline_id': :'deployPipelineId', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 74 def self.get_subtype(object_hash) type = object_hash[:'deployStageType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Devops::Models::CreateManualApprovalDeployStageDetails' if type == 'MANUAL_APPROVAL' return 'OCI::Devops::Models::CreateWaitDeployStageDetails' if type == 'WAIT' return 'OCI::Devops::Models::CreateOkeDeployStageDetails' if type == 'OKE_DEPLOYMENT' return 'OCI::Devops::Models::CreateLoadBalancerTrafficShiftDeployStageDetails' if type == 'LOAD_BALANCER_TRAFFIC_SHIFT' return 'OCI::Devops::Models::CreateComputeInstanceGroupDeployStageDetails' if type == 'COMPUTE_INSTANCE_GROUP_ROLLING_DEPLOYMENT' return 'OCI::Devops::Models::CreateInvokeFunctionDeployStageDetails' if type == 'INVOKE_FUNCTION' return 'OCI::Devops::Models::CreateFunctionDeployStageDetails' if type == 'DEPLOY_FUNCTION' # TODO: Log a warning when the subtype is not found. 'OCI::Devops::Models::CreateDeployStageDetails' end |
.swagger_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 55 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'deploy_stage_type': :'String', 'deploy_pipeline_id': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 155 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && deploy_stage_type == other.deploy_stage_type && deploy_pipeline_id == other.deploy_pipeline_id && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 191 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
171 172 173 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 171 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 180 def hash [description, display_name, deploy_stage_type, deploy_pipeline_id, deploy_stage_predecessor_collection, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
218 219 220 |
# File 'lib/oci/devops/models/create_deploy_stage_details.rb', line 218 def to_s to_hash.to_s end |