Class: OCI::Devops::Models::DeployPipelineDeployment

Inherits:
Deployment
  • Object
show all
Defined in:
lib/oci/devops/models/deploy_pipeline_deployment.rb

Overview

Deployment of all the stages in the pipeline.

Constant Summary

Constants inherited from Deployment

OCI::Devops::Models::Deployment::DEPLOYMENT_TYPE_ENUM, OCI::Devops::Models::Deployment::LIFECYCLE_STATE_ENUM

Instance Attribute Summary

Attributes inherited from Deployment

#compartment_id, #defined_tags, #deploy_artifact_override_arguments, #deploy_pipeline_artifacts, #deploy_pipeline_environments, #deploy_pipeline_id, #deployment_arguments, #deployment_execution_progress, #deployment_type, #display_name, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #project_id, #system_tags, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Deployment

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ DeployPipelineDeployment

Initializes the object

Options Hash (attributes):



86
87
88
89
90
91
92
# File 'lib/oci/devops/models/deploy_pipeline_deployment.rb', line 86

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['deploymentType'] = 'PIPELINE_DEPLOYMENT'

  super(attributes)
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
# File 'lib/oci/devops/models/deploy_pipeline_deployment.rb', line 12

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'deploy_pipeline_artifacts': :'deployPipelineArtifacts',
    'deploy_pipeline_environments': :'deployPipelineEnvironments',
    'deployment_type': :'deploymentType',
    'id': :'id',
    'display_name': :'displayName',
    'project_id': :'projectId',
    'deploy_pipeline_id': :'deployPipelineId',
    'compartment_id': :'compartmentId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'deployment_arguments': :'deploymentArguments',
    'deploy_artifact_override_arguments': :'deployArtifactOverrideArguments',
    'deployment_execution_progress': :'deploymentExecutionProgress',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/oci/devops/models/deploy_pipeline_deployment.rb', line 38

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'deploy_pipeline_artifacts': :'OCI::Devops::Models::DeployPipelineArtifactCollection',
    'deploy_pipeline_environments': :'OCI::Devops::Models::DeployPipelineEnvironmentCollection',
    'deployment_type': :'String',
    'id': :'String',
    'display_name': :'String',
    'project_id': :'String',
    'deploy_pipeline_id': :'String',
    'compartment_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'deployment_arguments': :'OCI::Devops::Models::DeploymentArgumentCollection',
    'deploy_artifact_override_arguments': :'OCI::Devops::Models::DeployArtifactOverrideArgumentCollection',
    'deployment_execution_progress': :'OCI::Devops::Models::DeploymentExecutionProgress',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/oci/devops/models/deploy_pipeline_deployment.rb', line 101

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    deploy_pipeline_artifacts == other.deploy_pipeline_artifacts &&
    deploy_pipeline_environments == other.deploy_pipeline_environments &&
    deployment_type == other.deployment_type &&
    id == other.id &&
    display_name == other.display_name &&
    project_id == other.project_id &&
    deploy_pipeline_id == other.deploy_pipeline_id &&
    compartment_id == other.compartment_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    deployment_arguments == other.deployment_arguments &&
    deploy_artifact_override_arguments == other.deploy_artifact_override_arguments &&
    deployment_execution_progress == other.deployment_execution_progress &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/oci/devops/models/deploy_pipeline_deployment.rb', line 148

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


128
129
130
# File 'lib/oci/devops/models/deploy_pipeline_deployment.rb', line 128

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



137
138
139
# File 'lib/oci/devops/models/deploy_pipeline_deployment.rb', line 137

def hash
  [deploy_pipeline_artifacts, deploy_pipeline_environments, deployment_type, id, display_name, project_id, deploy_pipeline_id, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, deployment_arguments, deploy_artifact_override_arguments, deployment_execution_progress, freeform_tags, defined_tags, system_tags].hash
end

#to_hashHash

Returns the object in the form of hash



181
182
183
184
185
186
187
188
189
190
# File 'lib/oci/devops/models/deploy_pipeline_deployment.rb', line 181

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



175
176
177
# File 'lib/oci/devops/models/deploy_pipeline_deployment.rb', line 175

def to_s
  to_hash.to_s
end