Class: OCI::Devops::Models::DeployStageSummary
- Inherits:
-
Object
- Object
- OCI::Devops::Models::DeployStageSummary
- Defined in:
- lib/oci/devops/models/deploy_stage_summary.rb
Overview
Summary of the deployment stage. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
ComputeInstanceGroupBlueGreenDeployStageSummary, ComputeInstanceGroupBlueGreenTrafficShiftDeployStageSummary, ComputeInstanceGroupCanaryApprovalDeployStageSummary, ComputeInstanceGroupCanaryDeployStageSummary, ComputeInstanceGroupCanaryTrafficShiftDeployStageSummary, ComputeInstanceGroupDeployStageSummary, FunctionDeployStageSummary, InvokeFunctionDeployStageSummary, LoadBalancerTrafficShiftDeployStageSummary, ManualApprovalDeployStageSummary, OkeBlueGreenDeployStageSummary, OkeBlueGreenTrafficShiftDeployStageSummary, OkeCanaryApprovalDeployStageSummary, OkeCanaryDeployStageSummary, OkeCanaryTrafficShiftDeployStageSummary, OkeDeployStageSummary, OkeHelmChartDeployStageSummary, WaitDeployStageSummary
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of a compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#deploy_pipeline_id ⇒ String
**[Required]** The OCID of a pipeline.
- #deploy_stage_predecessor_collection ⇒ OCI::Devops::Models::DeployStagePredecessorCollection
-
#deploy_stage_type ⇒ String
**[Required]** Deployment stage type.
-
#description ⇒ String
Optional description about the deployment stage.
-
#display_name ⇒ String
Deployment stage display name, which can be renamed and is not necessarily unique.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the deployment stage.
-
#project_id ⇒ String
**[Required]** The OCID of a project.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
Time the deployment stage was created.
-
#time_updated ⇒ DateTime
Time the deployment stage was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeployStageSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DeployStageSummary
Initializes the object
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 169 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.description = attributes[:'description'] if attributes[:'description'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.project_id = attributes[:'projectId'] if attributes[:'projectId'] raise 'You cannot provide both :projectId and :project_id' if attributes.key?(:'projectId') && attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] if attributes[:'project_id'] self.deploy_pipeline_id = attributes[:'deployPipelineId'] if attributes[:'deployPipelineId'] raise 'You cannot provide both :deployPipelineId and :deploy_pipeline_id' if attributes.key?(:'deployPipelineId') && attributes.key?(:'deploy_pipeline_id') self.deploy_pipeline_id = attributes[:'deploy_pipeline_id'] if attributes[:'deploy_pipeline_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.deploy_stage_type = attributes[:'deployStageType'] if attributes[:'deployStageType'] raise 'You cannot provide both :deployStageType and :deploy_stage_type' if attributes.key?(:'deployStageType') && attributes.key?(:'deploy_stage_type') self.deploy_stage_type = attributes[:'deploy_stage_type'] if attributes[:'deploy_stage_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.deploy_stage_predecessor_collection = attributes[:'deployStagePredecessorCollection'] if attributes[:'deployStagePredecessorCollection'] raise 'You cannot provide both :deployStagePredecessorCollection and :deploy_stage_predecessor_collection' if attributes.key?(:'deployStagePredecessorCollection') && attributes.key?(:'deploy_stage_predecessor_collection') self.deploy_stage_predecessor_collection = attributes[:'deploy_stage_predecessor_collection'] if attributes[:'deploy_stage_predecessor_collection'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of a compartment.
33 34 35 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 33 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"bar-key": "value"}`
64 65 66 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 64 def @defined_tags end |
#deploy_pipeline_id ⇒ String
**[Required]** The OCID of a pipeline.
29 30 31 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 29 def deploy_pipeline_id @deploy_pipeline_id end |
#deploy_stage_predecessor_collection ⇒ OCI::Devops::Models::DeployStagePredecessorCollection
56 57 58 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 56 def deploy_stage_predecessor_collection @deploy_stage_predecessor_collection end |
#deploy_stage_type ⇒ String
**[Required]** Deployment stage type.
37 38 39 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 37 def deploy_stage_type @deploy_stage_type end |
#description ⇒ String
Optional description about the deployment stage.
17 18 19 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 17 def description @description end |
#display_name ⇒ String
Deployment stage display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
21 22 23 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 21 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"value"`
60 61 62 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 60 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
13 14 15 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 13 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
53 54 55 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 53 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the deployment stage.
49 50 51 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 49 def lifecycle_state @lifecycle_state end |
#project_id ⇒ String
**[Required]** The OCID of a project.
25 26 27 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 25 def project_id @project_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"free-tier-retained": "true"}`
68 69 70 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 68 def @system_tags end |
#time_created ⇒ DateTime
Time the deployment stage was created. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
41 42 43 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 41 def time_created @time_created end |
#time_updated ⇒ DateTime
Time the deployment stage was updated. Format defined by [RFC3339](datatracker.ietf.org/doc/html/rfc3339).
45 46 47 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 45 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 71 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'description': :'description', 'display_name': :'displayName', 'project_id': :'projectId', 'deploy_pipeline_id': :'deployPipelineId', 'compartment_id': :'compartmentId', 'deploy_stage_type': :'deployStageType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 121 def self.get_subtype(object_hash) type = object_hash[:'deployStageType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Devops::Models::ComputeInstanceGroupBlueGreenDeployStageSummary' if type == 'COMPUTE_INSTANCE_GROUP_BLUE_GREEN_DEPLOYMENT' return 'OCI::Devops::Models::ComputeInstanceGroupBlueGreenTrafficShiftDeployStageSummary' if type == 'COMPUTE_INSTANCE_GROUP_BLUE_GREEN_TRAFFIC_SHIFT' return 'OCI::Devops::Models::OkeBlueGreenDeployStageSummary' if type == 'OKE_BLUE_GREEN_DEPLOYMENT' return 'OCI::Devops::Models::WaitDeployStageSummary' if type == 'WAIT' return 'OCI::Devops::Models::OkeDeployStageSummary' if type == 'OKE_DEPLOYMENT' return 'OCI::Devops::Models::ComputeInstanceGroupCanaryApprovalDeployStageSummary' if type == 'COMPUTE_INSTANCE_GROUP_CANARY_APPROVAL' return 'OCI::Devops::Models::InvokeFunctionDeployStageSummary' if type == 'INVOKE_FUNCTION' return 'OCI::Devops::Models::OkeHelmChartDeployStageSummary' if type == 'OKE_HELM_CHART_DEPLOYMENT' return 'OCI::Devops::Models::OkeCanaryTrafficShiftDeployStageSummary' if type == 'OKE_CANARY_TRAFFIC_SHIFT' return 'OCI::Devops::Models::ComputeInstanceGroupDeployStageSummary' if type == 'COMPUTE_INSTANCE_GROUP_ROLLING_DEPLOYMENT' return 'OCI::Devops::Models::ComputeInstanceGroupCanaryDeployStageSummary' if type == 'COMPUTE_INSTANCE_GROUP_CANARY_DEPLOYMENT' return 'OCI::Devops::Models::OkeCanaryApprovalDeployStageSummary' if type == 'OKE_CANARY_APPROVAL' return 'OCI::Devops::Models::OkeCanaryDeployStageSummary' if type == 'OKE_CANARY_DEPLOYMENT' return 'OCI::Devops::Models::LoadBalancerTrafficShiftDeployStageSummary' if type == 'LOAD_BALANCER_TRAFFIC_SHIFT' return 'OCI::Devops::Models::ManualApprovalDeployStageSummary' if type == 'MANUAL_APPROVAL' return 'OCI::Devops::Models::OkeBlueGreenTrafficShiftDeployStageSummary' if type == 'OKE_BLUE_GREEN_TRAFFIC_SHIFT' return 'OCI::Devops::Models::FunctionDeployStageSummary' if type == 'DEPLOY_FUNCTION' return 'OCI::Devops::Models::ComputeInstanceGroupCanaryTrafficShiftDeployStageSummary' if type == 'COMPUTE_INSTANCE_GROUP_CANARY_TRAFFIC_SHIFT' # TODO: Log a warning when the subtype is not found. 'OCI::Devops::Models::DeployStageSummary' end |
.swagger_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 94 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'description': :'String', 'display_name': :'String', 'project_id': :'String', 'deploy_pipeline_id': :'String', 'compartment_id': :'String', 'deploy_stage_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 265 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && description == other.description && display_name == other.display_name && project_id == other.project_id && deploy_pipeline_id == other.deploy_pipeline_id && compartment_id == other.compartment_id && deploy_stage_type == other.deploy_stage_type && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 309 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
289 290 291 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 289 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
298 299 300 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 298 def hash [id, description, display_name, project_id, deploy_pipeline_id, compartment_id, deploy_stage_type, time_created, time_updated, lifecycle_state, lifecycle_details, deploy_stage_predecessor_collection, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
342 343 344 345 346 347 348 349 350 351 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 342 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
336 337 338 |
# File 'lib/oci/devops/models/deploy_stage_summary.rb', line 336 def to_s to_hash.to_s end |