Class: OCI::Devops::Models::DiffSummary
- Inherits:
-
Object
- Object
- OCI::Devops::Models::DiffSummary
- Defined in:
- lib/oci/devops/models/diff_summary.rb
Overview
Response object for showing differences for a file between two revisions.
Instance Attribute Summary collapse
-
#are_conflicts_in_file ⇒ BOOLEAN
Indicates whether the changed file contains conflicts.
-
#changes ⇒ Array<OCI::Devops::Models::DiffChunk>
[Required] List of changed section in the file.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_binary ⇒ BOOLEAN
Indicates whether the file is binary.
-
#is_large ⇒ BOOLEAN
Indicates whether the file is large.
-
#new_id ⇒ String
The ID of the changed object on the target version.
-
#new_path ⇒ String
The path on the target version to the changed object.
-
#old_id ⇒ String
The ID of the changed object on the base version.
-
#old_path ⇒ String
The path on the base version to the changed object.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DiffSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DiffSummary
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/devops/models/diff_summary.rb', line 102 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.old_path = attributes[:'oldPath'] if attributes[:'oldPath'] raise 'You cannot provide both :oldPath and :old_path' if attributes.key?(:'oldPath') && attributes.key?(:'old_path') self.old_path = attributes[:'old_path'] if attributes[:'old_path'] self.new_path = attributes[:'newPath'] if attributes[:'newPath'] raise 'You cannot provide both :newPath and :new_path' if attributes.key?(:'newPath') && attributes.key?(:'new_path') self.new_path = attributes[:'new_path'] if attributes[:'new_path'] self.old_id = attributes[:'oldId'] if attributes[:'oldId'] raise 'You cannot provide both :oldId and :old_id' if attributes.key?(:'oldId') && attributes.key?(:'old_id') self.old_id = attributes[:'old_id'] if attributes[:'old_id'] self.new_id = attributes[:'newId'] if attributes[:'newId'] raise 'You cannot provide both :newId and :new_id' if attributes.key?(:'newId') && attributes.key?(:'new_id') self.new_id = attributes[:'new_id'] if attributes[:'new_id'] self.are_conflicts_in_file = attributes[:'areConflictsInFile'] unless attributes[:'areConflictsInFile'].nil? raise 'You cannot provide both :areConflictsInFile and :are_conflicts_in_file' if attributes.key?(:'areConflictsInFile') && attributes.key?(:'are_conflicts_in_file') self.are_conflicts_in_file = attributes[:'are_conflicts_in_file'] unless attributes[:'are_conflicts_in_file'].nil? self.is_large = attributes[:'isLarge'] unless attributes[:'isLarge'].nil? raise 'You cannot provide both :isLarge and :is_large' if attributes.key?(:'isLarge') && attributes.key?(:'is_large') self.is_large = attributes[:'is_large'] unless attributes[:'is_large'].nil? self.is_binary = attributes[:'isBinary'] unless attributes[:'isBinary'].nil? raise 'You cannot provide both :isBinary and :is_binary' if attributes.key?(:'isBinary') && attributes.key?(:'is_binary') self.is_binary = attributes[:'is_binary'] unless attributes[:'is_binary'].nil? self.changes = attributes[:'changes'] if attributes[:'changes'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#are_conflicts_in_file ⇒ BOOLEAN
Indicates whether the changed file contains conflicts.
28 29 30 |
# File 'lib/oci/devops/models/diff_summary.rb', line 28 def are_conflicts_in_file @are_conflicts_in_file end |
#changes ⇒ Array<OCI::Devops::Models::DiffChunk>
[Required] List of changed section in the file.
40 41 42 |
# File 'lib/oci/devops/models/diff_summary.rb', line 40 def changes @changes end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"bar-key": "value"}`
48 49 50 |
# File 'lib/oci/devops/models/diff_summary.rb', line 48 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. See [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"value"`
44 45 46 |
# File 'lib/oci/devops/models/diff_summary.rb', line 44 def end |
#is_binary ⇒ BOOLEAN
Indicates whether the file is binary.
36 37 38 |
# File 'lib/oci/devops/models/diff_summary.rb', line 36 def is_binary @is_binary end |
#is_large ⇒ BOOLEAN
Indicates whether the file is large.
32 33 34 |
# File 'lib/oci/devops/models/diff_summary.rb', line 32 def is_large @is_large end |
#new_id ⇒ String
The ID of the changed object on the target version.
24 25 26 |
# File 'lib/oci/devops/models/diff_summary.rb', line 24 def new_id @new_id end |
#new_path ⇒ String
The path on the target version to the changed object.
16 17 18 |
# File 'lib/oci/devops/models/diff_summary.rb', line 16 def new_path @new_path end |
#old_id ⇒ String
The ID of the changed object on the base version.
20 21 22 |
# File 'lib/oci/devops/models/diff_summary.rb', line 20 def old_id @old_id end |
#old_path ⇒ String
The path on the base version to the changed object.
12 13 14 |
# File 'lib/oci/devops/models/diff_summary.rb', line 12 def old_path @old_path end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/devops/models/diff_summary.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'old_path': :'oldPath', 'new_path': :'newPath', 'old_id': :'oldId', 'new_id': :'newId', 'are_conflicts_in_file': :'areConflictsInFile', 'is_large': :'isLarge', 'is_binary': :'isBinary', 'changes': :'changes', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/devops/models/diff_summary.rb', line 69 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'old_path': :'String', 'new_path': :'String', 'old_id': :'String', 'new_id': :'String', 'are_conflicts_in_file': :'BOOLEAN', 'is_large': :'BOOLEAN', 'is_binary': :'BOOLEAN', 'changes': :'Array<OCI::Devops::Models::DiffChunk>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/devops/models/diff_summary.rb', line 172 def ==(other) return true if equal?(other) self.class == other.class && old_path == other.old_path && new_path == other.new_path && old_id == other.old_id && new_id == other.new_id && are_conflicts_in_file == other.are_conflicts_in_file && is_large == other.is_large && is_binary == other.is_binary && changes == other.changes && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/oci/devops/models/diff_summary.rb', line 211 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
191 192 193 |
# File 'lib/oci/devops/models/diff_summary.rb', line 191 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/oci/devops/models/diff_summary.rb', line 200 def hash [old_path, new_path, old_id, new_id, are_conflicts_in_file, is_large, is_binary, changes, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
244 245 246 247 248 249 250 251 252 253 |
# File 'lib/oci/devops/models/diff_summary.rb', line 244 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
238 239 240 |
# File 'lib/oci/devops/models/diff_summary.rb', line 238 def to_s to_hash.to_s end |