Class: OCI::Devops::Models::HelmRepositoryDeployArtifactSource
- Inherits:
-
DeployArtifactSource
- Object
- DeployArtifactSource
- OCI::Devops::Models::HelmRepositoryDeployArtifactSource
- Defined in:
- lib/oci/devops/models/helm_repository_deploy_artifact_source.rb
Overview
Specifies Helm chart source details.
Constant Summary
Constants inherited from DeployArtifactSource
DeployArtifactSource::DEPLOY_ARTIFACT_SOURCE_TYPE_ENUM
Instance Attribute Summary collapse
-
#chart_url ⇒ String
**[Required]** The URL of an OCIR repository.
-
#deploy_artifact_version ⇒ String
**[Required]** Users can set this as a placeholder value that refers to a pipeline parameter, for example, $appVersion.
Attributes inherited from DeployArtifactSource
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HelmRepositoryDeployArtifactSource
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DeployArtifactSource
Constructor Details
#initialize(attributes = {}) ⇒ HelmRepositoryDeployArtifactSource
Initializes the object
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 49 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployArtifactSourceType'] = 'HELM_CHART' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.chart_url = attributes[:'chartUrl'] if attributes[:'chartUrl'] raise 'You cannot provide both :chartUrl and :chart_url' if attributes.key?(:'chartUrl') && attributes.key?(:'chart_url') self.chart_url = attributes[:'chart_url'] if attributes[:'chart_url'] self.deploy_artifact_version = attributes[:'deployArtifactVersion'] if attributes[:'deployArtifactVersion'] raise 'You cannot provide both :deployArtifactVersion and :deploy_artifact_version' if attributes.key?(:'deployArtifactVersion') && attributes.key?(:'deploy_artifact_version') self.deploy_artifact_version = attributes[:'deploy_artifact_version'] if attributes[:'deploy_artifact_version'] end |
Instance Attribute Details
#chart_url ⇒ String
**[Required]** The URL of an OCIR repository.
13 14 15 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 13 def chart_url @chart_url end |
#deploy_artifact_version ⇒ String
**[Required]** Users can set this as a placeholder value that refers to a pipeline parameter, for example, $appVersion.
17 18 19 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 17 def deploy_artifact_version @deploy_artifact_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 27 28 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 20 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'deploy_artifact_source_type': :'deployArtifactSourceType', 'chart_url': :'chartUrl', 'deploy_artifact_version': :'deployArtifactVersion' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 31 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'deploy_artifact_source_type': :'String', 'chart_url': :'String', 'deploy_artifact_version': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
79 80 81 82 83 84 85 86 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 79 def ==(other) return true if equal?(other) self.class == other.class && deploy_artifact_source_type == other.deploy_artifact_source_type && chart_url == other.chart_url && deploy_artifact_version == other.deploy_artifact_version end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 111 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
91 92 93 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 91 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
100 101 102 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 100 def hash [deploy_artifact_source_type, chart_url, deploy_artifact_version].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 144 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
138 139 140 |
# File 'lib/oci/devops/models/helm_repository_deploy_artifact_source.rb', line 138 def to_s to_hash.to_s end |