Class: OCI::Devops::Models::LoadBalancerConfig
- Inherits:
-
Object
- Object
- OCI::Devops::Models::LoadBalancerConfig
- Defined in:
- lib/oci/devops/models/load_balancer_config.rb
Overview
Specifies config for load balancer traffic shift stages.
Instance Attribute Summary collapse
-
#backend_port ⇒ Integer
Listen port for the backend server.
-
#listener_name ⇒ String
[Required] Name of the load balancer listener.
-
#load_balancer_id ⇒ String
[Required] The OCID of the load balancer.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LoadBalancerConfig
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LoadBalancerConfig
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 53 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.load_balancer_id = attributes[:'loadBalancerId'] if attributes[:'loadBalancerId'] raise 'You cannot provide both :loadBalancerId and :load_balancer_id' if attributes.key?(:'loadBalancerId') && attributes.key?(:'load_balancer_id') self.load_balancer_id = attributes[:'load_balancer_id'] if attributes[:'load_balancer_id'] self.listener_name = attributes[:'listenerName'] if attributes[:'listenerName'] raise 'You cannot provide both :listenerName and :listener_name' if attributes.key?(:'listenerName') && attributes.key?(:'listener_name') self.listener_name = attributes[:'listener_name'] if attributes[:'listener_name'] self.backend_port = attributes[:'backendPort'] if attributes[:'backendPort'] self.backend_port = 80 if backend_port.nil? && !attributes.key?(:'backendPort') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :backendPort and :backend_port' if attributes.key?(:'backendPort') && attributes.key?(:'backend_port') self.backend_port = attributes[:'backend_port'] if attributes[:'backend_port'] self.backend_port = 80 if backend_port.nil? && !attributes.key?(:'backendPort') && !attributes.key?(:'backend_port') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#backend_port ⇒ Integer
Listen port for the backend server.
20 21 22 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 20 def backend_port @backend_port end |
#listener_name ⇒ String
[Required] Name of the load balancer listener.
16 17 18 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 16 def listener_name @listener_name end |
#load_balancer_id ⇒ String
[Required] The OCID of the load balancer.
12 13 14 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 12 def load_balancer_id @load_balancer_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 23 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'load_balancer_id': :'loadBalancerId', 'listener_name': :'listenerName', 'backend_port': :'backendPort' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 41 42 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 34 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'load_balancer_id': :'String', 'listener_name': :'String', 'backend_port': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
87 88 89 90 91 92 93 94 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 87 def ==(other) return true if equal?(other) self.class == other.class && load_balancer_id == other.load_balancer_id && listener_name == other.listener_name && backend_port == other.backend_port end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 119 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
99 100 101 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 99 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
108 109 110 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 108 def hash [load_balancer_id, listener_name, backend_port].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 152 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
146 147 148 |
# File 'lib/oci/devops/models/load_balancer_config.rb', line 146 def to_s to_hash.to_s end |