Class: OCI::Devops::Models::UpdateBuildStageDetails
- Inherits:
-
UpdateBuildPipelineStageDetails
- Object
- UpdateBuildPipelineStageDetails
- OCI::Devops::Models::UpdateBuildStageDetails
- Defined in:
- lib/oci/devops/models/update_build_stage_details.rb
Overview
Specifies the build stage.
Instance Attribute Summary collapse
- #build_source_collection ⇒ OCI::Devops::Models::BuildSourceCollection
-
#build_spec_file ⇒ String
The path to the build specification file for this environment.
-
#image ⇒ String
Image name for the build environment.
-
#primary_build_source ⇒ String
Name of the build source where the build_spec.yml file is located.
-
#stage_execution_timeout_in_seconds ⇒ Integer
Timeout for the build stage execution.
Attributes inherited from UpdateBuildPipelineStageDetails
#build_pipeline_stage_predecessor_collection, #build_pipeline_stage_type, #defined_tags, #description, #display_name, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateBuildStageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateBuildPipelineStageDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateBuildStageDetails
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['buildPipelineStageType'] = 'BUILD' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.image = attributes[:'image'] if attributes[:'image'] self.build_spec_file = attributes[:'buildSpecFile'] if attributes[:'buildSpecFile'] raise 'You cannot provide both :buildSpecFile and :build_spec_file' if attributes.key?(:'buildSpecFile') && attributes.key?(:'build_spec_file') self.build_spec_file = attributes[:'build_spec_file'] if attributes[:'build_spec_file'] self.stage_execution_timeout_in_seconds = attributes[:'stageExecutionTimeoutInSeconds'] if attributes[:'stageExecutionTimeoutInSeconds'] raise 'You cannot provide both :stageExecutionTimeoutInSeconds and :stage_execution_timeout_in_seconds' if attributes.key?(:'stageExecutionTimeoutInSeconds') && attributes.key?(:'stage_execution_timeout_in_seconds') self.stage_execution_timeout_in_seconds = attributes[:'stage_execution_timeout_in_seconds'] if attributes[:'stage_execution_timeout_in_seconds'] self.build_source_collection = attributes[:'buildSourceCollection'] if attributes[:'buildSourceCollection'] raise 'You cannot provide both :buildSourceCollection and :build_source_collection' if attributes.key?(:'buildSourceCollection') && attributes.key?(:'build_source_collection') self.build_source_collection = attributes[:'build_source_collection'] if attributes[:'build_source_collection'] self.primary_build_source = attributes[:'primaryBuildSource'] if attributes[:'primaryBuildSource'] raise 'You cannot provide both :primaryBuildSource and :primary_build_source' if attributes.key?(:'primaryBuildSource') && attributes.key?(:'primary_build_source') self.primary_build_source = attributes[:'primary_build_source'] if attributes[:'primary_build_source'] end |
Instance Attribute Details
#build_source_collection ⇒ OCI::Devops::Models::BuildSourceCollection
24 25 26 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 24 def build_source_collection @build_source_collection end |
#build_spec_file ⇒ String
The path to the build specification file for this environment. The default location of the file if not specified is build_spec.yaml.
17 18 19 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 17 def build_spec_file @build_spec_file end |
#image ⇒ String
Image name for the build environment.
13 14 15 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 13 def image @image end |
#primary_build_source ⇒ String
Name of the build source where the build_spec.yml file is located. If not specified, the first entry in the build source collection is chosen as primary build source.
28 29 30 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 28 def primary_build_source @primary_build_source end |
#stage_execution_timeout_in_seconds ⇒ Integer
Timeout for the build stage execution. Specify value in seconds.
21 22 23 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 21 def stage_execution_timeout_in_seconds @stage_execution_timeout_in_seconds end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'description': :'description', 'build_pipeline_stage_type': :'buildPipelineStageType', 'build_pipeline_stage_predecessor_collection': :'buildPipelineStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'image': :'image', 'build_spec_file': :'buildSpecFile', 'stage_execution_timeout_in_seconds': :'stageExecutionTimeoutInSeconds', 'build_source_collection': :'buildSourceCollection', 'primary_build_source': :'primaryBuildSource' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'description': :'String', 'build_pipeline_stage_type': :'String', 'build_pipeline_stage_predecessor_collection': :'OCI::Devops::Models::BuildPipelineStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'image': :'String', 'build_spec_file': :'String', 'stage_execution_timeout_in_seconds': :'Integer', 'build_source_collection': :'OCI::Devops::Models::BuildSourceCollection', 'primary_build_source': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 128 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && description == other.description && build_pipeline_stage_type == other.build_pipeline_stage_type && build_pipeline_stage_predecessor_collection == other.build_pipeline_stage_predecessor_collection && == other. && == other. && image == other.image && build_spec_file == other.build_spec_file && stage_execution_timeout_in_seconds == other.stage_execution_timeout_in_seconds && build_source_collection == other.build_source_collection && primary_build_source == other.primary_build_source end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 157 def hash [display_name, description, build_pipeline_stage_type, build_pipeline_stage_predecessor_collection, , , image, build_spec_file, stage_execution_timeout_in_seconds, build_source_collection, primary_build_source].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/devops/models/update_build_stage_details.rb', line 195 def to_s to_hash.to_s end |