Class: OCI::Devops::Models::UpdateLoadBalancerTrafficShiftDeployStageDetails
- Inherits:
-
UpdateDeployStageDetails
- Object
- UpdateDeployStageDetails
- OCI::Devops::Models::UpdateLoadBalancerTrafficShiftDeployStageDetails
- Defined in:
- lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb
Overview
Specifies load balancer traffic shift stage.
Instance Attribute Summary collapse
- #blue_backend_ips ⇒ OCI::Devops::Models::BackendSetIpCollection
- #green_backend_ips ⇒ OCI::Devops::Models::BackendSetIpCollection
- #load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
- #rollback_policy ⇒ OCI::Devops::Models::DeployStageRollbackPolicy
- #rollout_policy ⇒ OCI::Devops::Models::LoadBalancerTrafficShiftRolloutPolicy
-
#traffic_shift_target ⇒ String
Specifies the target or destination backend set.
Attributes inherited from UpdateDeployStageDetails
#defined_tags, #deploy_stage_predecessor_collection, #deploy_stage_type, #description, #display_name, #freeform_tags
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateLoadBalancerTrafficShiftDeployStageDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from UpdateDeployStageDetails
Constructor Details
#initialize(attributes = {}) ⇒ UpdateLoadBalancerTrafficShiftDeployStageDetails
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 87 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['deployStageType'] = 'LOAD_BALANCER_TRAFFIC_SHIFT' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.blue_backend_ips = attributes[:'blueBackendIps'] if attributes[:'blueBackendIps'] raise 'You cannot provide both :blueBackendIps and :blue_backend_ips' if attributes.key?(:'blueBackendIps') && attributes.key?(:'blue_backend_ips') self.blue_backend_ips = attributes[:'blue_backend_ips'] if attributes[:'blue_backend_ips'] self.green_backend_ips = attributes[:'greenBackendIps'] if attributes[:'greenBackendIps'] raise 'You cannot provide both :greenBackendIps and :green_backend_ips' if attributes.key?(:'greenBackendIps') && attributes.key?(:'green_backend_ips') self.green_backend_ips = attributes[:'green_backend_ips'] if attributes[:'green_backend_ips'] self.traffic_shift_target = attributes[:'trafficShiftTarget'] if attributes[:'trafficShiftTarget'] raise 'You cannot provide both :trafficShiftTarget and :traffic_shift_target' if attributes.key?(:'trafficShiftTarget') && attributes.key?(:'traffic_shift_target') self.traffic_shift_target = attributes[:'traffic_shift_target'] if attributes[:'traffic_shift_target'] self.rollout_policy = attributes[:'rolloutPolicy'] if attributes[:'rolloutPolicy'] raise 'You cannot provide both :rolloutPolicy and :rollout_policy' if attributes.key?(:'rolloutPolicy') && attributes.key?(:'rollout_policy') self.rollout_policy = attributes[:'rollout_policy'] if attributes[:'rollout_policy'] self.load_balancer_config = attributes[:'loadBalancerConfig'] if attributes[:'loadBalancerConfig'] raise 'You cannot provide both :loadBalancerConfig and :load_balancer_config' if attributes.key?(:'loadBalancerConfig') && attributes.key?(:'load_balancer_config') self.load_balancer_config = attributes[:'load_balancer_config'] if attributes[:'load_balancer_config'] self.rollback_policy = attributes[:'rollbackPolicy'] if attributes[:'rollbackPolicy'] raise 'You cannot provide both :rollbackPolicy and :rollback_policy' if attributes.key?(:'rollbackPolicy') && attributes.key?(:'rollback_policy') self.rollback_policy = attributes[:'rollback_policy'] if attributes[:'rollback_policy'] end |
Instance Attribute Details
#blue_backend_ips ⇒ OCI::Devops::Models::BackendSetIpCollection
12 13 14 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 12 def blue_backend_ips @blue_backend_ips end |
#green_backend_ips ⇒ OCI::Devops::Models::BackendSetIpCollection
15 16 17 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 15 def green_backend_ips @green_backend_ips end |
#load_balancer_config ⇒ OCI::Devops::Models::LoadBalancerConfig
25 26 27 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 25 def load_balancer_config @load_balancer_config end |
#rollback_policy ⇒ OCI::Devops::Models::DeployStageRollbackPolicy
28 29 30 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 28 def rollback_policy @rollback_policy end |
#rollout_policy ⇒ OCI::Devops::Models::LoadBalancerTrafficShiftRolloutPolicy
22 23 24 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 22 def rollout_policy @rollout_policy end |
#traffic_shift_target ⇒ String
Specifies the target or destination backend set.
19 20 21 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 19 def traffic_shift_target @traffic_shift_target end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'display_name': :'displayName', 'deploy_stage_type': :'deployStageType', 'deploy_stage_predecessor_collection': :'deployStagePredecessorCollection', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'blue_backend_ips': :'blueBackendIps', 'green_backend_ips': :'greenBackendIps', 'traffic_shift_target': :'trafficShiftTarget', 'rollout_policy': :'rolloutPolicy', 'load_balancer_config': :'loadBalancerConfig', 'rollback_policy': :'rollbackPolicy' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'display_name': :'String', 'deploy_stage_type': :'String', 'deploy_stage_predecessor_collection': :'OCI::Devops::Models::DeployStagePredecessorCollection', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'blue_backend_ips': :'OCI::Devops::Models::BackendSetIpCollection', 'green_backend_ips': :'OCI::Devops::Models::BackendSetIpCollection', 'traffic_shift_target': :'String', 'rollout_policy': :'OCI::Devops::Models::LoadBalancerTrafficShiftRolloutPolicy', 'load_balancer_config': :'OCI::Devops::Models::LoadBalancerConfig', 'rollback_policy': :'OCI::Devops::Models::DeployStageRollbackPolicy' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 141 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && display_name == other.display_name && deploy_stage_type == other.deploy_stage_type && deploy_stage_predecessor_collection == other.deploy_stage_predecessor_collection && == other. && == other. && blue_backend_ips == other.blue_backend_ips && green_backend_ips == other.green_backend_ips && traffic_shift_target == other.traffic_shift_target && rollout_policy == other.rollout_policy && load_balancer_config == other.load_balancer_config && rollback_policy == other.rollback_policy end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 182 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
162 163 164 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 162 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 171 def hash [description, display_name, deploy_stage_type, deploy_stage_predecessor_collection, , , blue_backend_ips, green_backend_ips, traffic_shift_target, rollout_policy, load_balancer_config, rollback_policy].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
209 210 211 |
# File 'lib/oci/devops/models/update_load_balancer_traffic_shift_deploy_stage_details.rb', line 209 def to_s to_hash.to_s end |