Class: OCI::Email::Models::EmailDomain
- Inherits:
-
Object
- Object
- OCI::Email::Models::EmailDomain
- Defined in:
- lib/oci/email/models/email_domain.rb
Overview
The properties that define a email domain. A Email Domain contains configuration used to assert responsibility for emails sent from that domain.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#active_dkim_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DKIM key that will be used to sign mail sent from this email domain.
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains this email domain.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of a email domain.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the email domain.
-
#is_spf ⇒ BOOLEAN
Value of the SPF field.
-
#lifecycle_state ⇒ String
The current state of the email domain.
-
#name ⇒ String
[Required] The name of the email domain in the Internet Domain Name System (DNS).
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
The time the email domain was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format, "YYYY-MM-ddThh:mmZ".
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmailDomain
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EmailDomain
Initializes the object
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/oci/email/models/email_domain.rb', line 145 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.active_dkim_id = attributes[:'activeDkimId'] if attributes[:'activeDkimId'] raise 'You cannot provide both :activeDkimId and :active_dkim_id' if attributes.key?(:'activeDkimId') && attributes.key?(:'active_dkim_id') self.active_dkim_id = attributes[:'active_dkim_id'] if attributes[:'active_dkim_id'] self.is_spf = attributes[:'isSpf'] unless attributes[:'isSpf'].nil? self.is_spf = false if is_spf.nil? && !attributes.key?(:'isSpf') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isSpf and :is_spf' if attributes.key?(:'isSpf') && attributes.key?(:'is_spf') self.is_spf = attributes[:'is_spf'] unless attributes[:'is_spf'].nil? self.is_spf = false if is_spf.nil? && !attributes.key?(:'isSpf') && !attributes.key?(:'is_spf') # rubocop:disable Style/StringLiterals self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#active_dkim_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DKIM key that will be used to sign mail sent from this email domain.
48 49 50 |
# File 'lib/oci/email/models/email_domain.rb', line 48 def active_dkim_id @active_dkim_id end |
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains this email domain.
38 39 40 |
# File 'lib/oci/email/models/email_domain.rb', line 38 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
82 83 84 |
# File 'lib/oci/email/models/email_domain.rb', line 82 def end |
#description ⇒ String
The description of a email domain.
58 59 60 |
# File 'lib/oci/email/models/email_domain.rb', line 58 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
74 75 76 |
# File 'lib/oci/email/models/email_domain.rb', line 74 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the email domain.
33 34 35 |
# File 'lib/oci/email/models/email_domain.rb', line 33 def id @id end |
#is_spf ⇒ BOOLEAN
Value of the SPF field. For more information about SPF, please see [SPF Authentication](docs.cloud.oracle.com/iaas/Content/Email/Concepts/overview.htm#components).
54 55 56 |
# File 'lib/oci/email/models/email_domain.rb', line 54 def is_spf @is_spf end |
#lifecycle_state ⇒ String
The current state of the email domain.
42 43 44 |
# File 'lib/oci/email/models/email_domain.rb', line 42 def lifecycle_state @lifecycle_state end |
#name ⇒ String
[Required] The name of the email domain in the Internet Domain Name System (DNS).
Example: example.net
28 29 30 |
# File 'lib/oci/email/models/email_domain.rb', line 28 def name @name end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`
88 89 90 |
# File 'lib/oci/email/models/email_domain.rb', line 88 def end |
#time_created ⇒ DateTime
The time the email domain was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format, "YYYY-MM-ddThh:mmZ".
Example: 2021-02-12T22:47:12.613Z
66 67 68 |
# File 'lib/oci/email/models/email_domain.rb', line 66 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/email/models/email_domain.rb', line 91 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'id': :'id', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'active_dkim_id': :'activeDkimId', 'is_spf': :'isSpf', 'description': :'description', 'time_created': :'timeCreated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/email/models/email_domain.rb', line 110 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'id': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'active_dkim_id': :'String', 'is_spf': :'BOOLEAN', 'description': :'String', 'time_created': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/email/models/email_domain.rb', line 228 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && id == other.id && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && active_dkim_id == other.active_dkim_id && is_spf == other.is_spf && description == other.description && time_created == other.time_created && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/oci/email/models/email_domain.rb', line 268 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
248 249 250 |
# File 'lib/oci/email/models/email_domain.rb', line 248 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/oci/email/models/email_domain.rb', line 257 def hash [name, id, compartment_id, lifecycle_state, active_dkim_id, is_spf, description, time_created, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
301 302 303 304 305 306 307 308 309 310 |
# File 'lib/oci/email/models/email_domain.rb', line 301 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
295 296 297 |
# File 'lib/oci/email/models/email_domain.rb', line 295 def to_s to_hash.to_s end |