Class: OCI::FileStorage::Models::FileSystemSummary
- Inherits:
-
Object
- Object
- OCI::FileStorage::Models::FileSystemSummary
- Defined in:
- lib/oci/file_storage/models/file_system_summary.rb
Overview
Summary information for a file system.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
The availability domain the file system is in.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the file system.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the file system.
-
#is_clone_parent ⇒ BOOLEAN
Specifies whether the file system has been cloned.
-
#is_hydrated ⇒ BOOLEAN
Specifies whether the data has finished copying from the source to the clone.
-
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the KMS key used to encrypt the encryption keys associated with this file system.
-
#lifecycle_details ⇒ String
Additional information about the current ‘lifecycleState’.
-
#lifecycle_state ⇒ String
[Required] The current state of the file system.
-
#metered_bytes ⇒ Integer
[Required] The number of bytes consumed by the file system, including any snapshots.
- #source_details ⇒ OCI::FileStorage::Models::SourceDetails
-
#time_created ⇒ DateTime
[Required] The date and time the file system was created, expressed in [RFC 3339](tools.ietf.org/rfc/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FileSystemSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ FileSystemSummary
Initializes the object
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 169 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.metered_bytes = attributes[:'meteredBytes'] if attributes[:'meteredBytes'] raise 'You cannot provide both :meteredBytes and :metered_bytes' if attributes.key?(:'meteredBytes') && attributes.key?(:'metered_bytes') self.metered_bytes = attributes[:'metered_bytes'] if attributes[:'metered_bytes'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails'] raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details') self.source_details = attributes[:'source_details'] if attributes[:'source_details'] self.is_clone_parent = attributes[:'isCloneParent'] unless attributes[:'isCloneParent'].nil? raise 'You cannot provide both :isCloneParent and :is_clone_parent' if attributes.key?(:'isCloneParent') && attributes.key?(:'is_clone_parent') self.is_clone_parent = attributes[:'is_clone_parent'] unless attributes[:'is_clone_parent'].nil? self.is_hydrated = attributes[:'isHydrated'] unless attributes[:'isHydrated'].nil? raise 'You cannot provide both :isHydrated and :is_hydrated' if attributes.key?(:'isHydrated') && attributes.key?(:'is_hydrated') self.is_hydrated = attributes[:'is_hydrated'] unless attributes[:'is_hydrated'].nil? self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] end |
Instance Attribute Details
#availability_domain ⇒ String
The availability domain the file system is in. May be unset as a blank or NULL value.
Example: Uocm:PHX-AD-1
26 27 28 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 26 def availability_domain @availability_domain end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the file system.
38 39 40 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 38 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
77 78 79 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 77 def end |
#display_name ⇒ String
[Required] A user-friendly name. It does not have to be unique, and it is changeable. Avoid entering confidential information.
Example: ‘My file system`
46 47 48 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 46 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair
with no predefined name, type, or namespace.
For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
70 71 72 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 70 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the file system.
50 51 52 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 50 def id @id end |
#is_clone_parent ⇒ BOOLEAN
Specifies whether the file system has been cloned. See [Cloning a File System](docs.cloud.oracle.com/iaas/Content/File/Tasks/cloningafilesystem.htm).
91 92 93 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 91 def is_clone_parent @is_clone_parent end |
#is_hydrated ⇒ BOOLEAN
Specifies whether the data has finished copying from the source to the clone. Hydration can take up to several hours to complete depending on the size of the source. The source and clone remain available during hydration, but there may be some performance impact. See [Cloning a File System](docs.cloud.oracle.com/iaas/Content/File/Tasks/cloningafilesystem.htm#hydration).
99 100 101 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 99 def is_hydrated @is_hydrated end |
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the KMS key used to encrypt the encryption keys associated with this file system.
82 83 84 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 82 def kms_key_id @kms_key_id end |
#lifecycle_details ⇒ String
Additional information about the current ‘lifecycleState’.
103 104 105 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 103 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the file system.
54 55 56 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 54 def lifecycle_state @lifecycle_state end |
#metered_bytes ⇒ Integer
[Required] The number of bytes consumed by the file system, including any snapshots. This number reflects the metered size of the file system and is updated asynchronously with respect to updates to the file system.
34 35 36 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 34 def metered_bytes @metered_bytes end |
#source_details ⇒ OCI::FileStorage::Models::SourceDetails
85 86 87 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 85 def source_details @source_details end |
#time_created ⇒ DateTime
[Required] The date and time the file system was created, expressed in [RFC 3339](tools.ietf.org/rfc/rfc3339) timestamp format.
Example: 2016-08-25T21:10:29.600Z
62 63 64 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 62 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 106 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'metered_bytes': :'meteredBytes', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'kms_key_id': :'kmsKeyId', 'source_details': :'sourceDetails', 'is_clone_parent': :'isCloneParent', 'is_hydrated': :'isHydrated', 'lifecycle_details': :'lifecycleDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 128 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'metered_bytes': :'Integer', 'compartment_id': :'String', 'display_name': :'String', 'id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'kms_key_id': :'String', 'source_details': :'OCI::FileStorage::Models::SourceDetails', 'is_clone_parent': :'BOOLEAN', 'is_hydrated': :'BOOLEAN', 'lifecycle_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 276 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && metered_bytes == other.metered_bytes && compartment_id == other.compartment_id && display_name == other.display_name && id == other.id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && == other. && == other. && kms_key_id == other.kms_key_id && source_details == other.source_details && is_clone_parent == other.is_clone_parent && is_hydrated == other.is_hydrated && lifecycle_details == other.lifecycle_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 319 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
299 300 301 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 299 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 308 def hash [availability_domain, metered_bytes, compartment_id, display_name, id, lifecycle_state, time_created, , , kms_key_id, source_details, is_clone_parent, is_hydrated, lifecycle_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
352 353 354 355 356 357 358 359 360 361 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 352 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
346 347 348 |
# File 'lib/oci/file_storage/models/file_system_summary.rb', line 346 def to_s to_hash.to_s end |