Class: OCI::Functions::Models::CreateFunctionDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/functions/models/create_function_details.rb

Overview

Properties to create a new function.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateFunctionDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :application_id (String)

    The value to assign to the #application_id property

  • :image (String)

    The value to assign to the #image property

  • :image_digest (String)

    The value to assign to the #image_digest property

  • :memory_in_m_bs (Integer)

    The value to assign to the #memory_in_m_bs property

  • :config (Hash<String, String>)

    The value to assign to the #config property

  • :timeout_in_seconds (Integer)

    The value to assign to the #timeout_in_seconds property

  • :trace_config (OCI::Functions::Models::FunctionTraceConfig)

    The value to assign to the #trace_config property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/functions/models/create_function_details.rb', line 122

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.application_id = attributes[:'applicationId'] if attributes[:'applicationId']

  raise 'You cannot provide both :applicationId and :application_id' if attributes.key?(:'applicationId') && attributes.key?(:'application_id')

  self.application_id = attributes[:'application_id'] if attributes[:'application_id']

  self.image = attributes[:'image'] if attributes[:'image']

  self.image_digest = attributes[:'imageDigest'] if attributes[:'imageDigest']

  raise 'You cannot provide both :imageDigest and :image_digest' if attributes.key?(:'imageDigest') && attributes.key?(:'image_digest')

  self.image_digest = attributes[:'image_digest'] if attributes[:'image_digest']

  self.memory_in_m_bs = attributes[:'memoryInMBs'] if attributes[:'memoryInMBs']

  raise 'You cannot provide both :memoryInMBs and :memory_in_m_bs' if attributes.key?(:'memoryInMBs') && attributes.key?(:'memory_in_m_bs')

  self.memory_in_m_bs = attributes[:'memory_in_m_bs'] if attributes[:'memory_in_m_bs']

  self.config = attributes[:'config'] if attributes[:'config']

  self.timeout_in_seconds = attributes[:'timeoutInSeconds'] if attributes[:'timeoutInSeconds']
  self.timeout_in_seconds = 30 if timeout_in_seconds.nil? && !attributes.key?(:'timeoutInSeconds') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :timeoutInSeconds and :timeout_in_seconds' if attributes.key?(:'timeoutInSeconds') && attributes.key?(:'timeout_in_seconds')

  self.timeout_in_seconds = attributes[:'timeout_in_seconds'] if attributes[:'timeout_in_seconds']
  self.timeout_in_seconds = 30 if timeout_in_seconds.nil? && !attributes.key?(:'timeoutInSeconds') && !attributes.key?(:'timeout_in_seconds') # rubocop:disable Style/StringLiterals

  self.trace_config = attributes[:'traceConfig'] if attributes[:'traceConfig']

  raise 'You cannot provide both :traceConfig and :trace_config' if attributes.key?(:'traceConfig') && attributes.key?(:'trace_config')

  self.trace_config = attributes[:'trace_config'] if attributes[:'trace_config']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#application_idString

[Required] The OCID of the application this function belongs to.

Returns:

  • (String)


18
19
20
# File 'lib/oci/functions/models/create_function_details.rb', line 18

def application_id
  @application_id
end

#configHash<String, String>

Function configuration. These values are passed on to the function as environment variables, this overrides application configuration values. Keys must be ASCII strings consisting solely of letters, digits, and the ‘_’ (underscore) character, and must not begin with a digit. Values should be limited to printable unicode characters.

Example: ‘"ConfVal"`

The maximum size for all configuration keys and values is limited to 4KB. This is measured as the sum of octets necessary to represent each key and value in UTF-8.

Returns:

  • (Hash<String, String>)


46
47
48
# File 'lib/oci/functions/models/create_function_details.rb', line 46

def config
  @config
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


68
69
70
# File 'lib/oci/functions/models/create_function_details.rb', line 68

def defined_tags
  @defined_tags
end

#display_nameString

[Required] The display name of the function. The display name must be unique within the application containing the function. Avoid entering confidential information.

Returns:

  • (String)


14
15
16
# File 'lib/oci/functions/models/create_function_details.rb', line 14

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


61
62
63
# File 'lib/oci/functions/models/create_function_details.rb', line 61

def freeform_tags
  @freeform_tags
end

#imageString

[Required] The qualified name of the Docker image to use in the function, including the image tag. The image should be in the OCI Registry that is in the same region as the function itself. Example: phx.ocir.io/ten/functions/function:0.0.1

Returns:

  • (String)


25
26
27
# File 'lib/oci/functions/models/create_function_details.rb', line 25

def image
  @image
end

#image_digestString

The image digest for the version of the image that will be pulled when invoking this function. If no value is specified, the digest currently associated with the image in the OCI Registry will be used. Example: sha256:ca0eeb6fb05351dfc8759c20733c91def84cb8007aa89a5bf606bc8b315b9fc7

Returns:

  • (String)


32
33
34
# File 'lib/oci/functions/models/create_function_details.rb', line 32

def image_digest
  @image_digest
end

#memory_in_m_bsInteger

[Required] Maximum usable memory for the function (MiB).

Returns:

  • (Integer)


36
37
38
# File 'lib/oci/functions/models/create_function_details.rb', line 36

def memory_in_m_bs
  @memory_in_m_bs
end

#timeout_in_secondsInteger

Timeout for executions of the function. Value in seconds.

Returns:

  • (Integer)


50
51
52
# File 'lib/oci/functions/models/create_function_details.rb', line 50

def timeout_in_seconds
  @timeout_in_seconds
end

#trace_configOCI::Functions::Models::FunctionTraceConfig



53
54
55
# File 'lib/oci/functions/models/create_function_details.rb', line 53

def trace_config
  @trace_config
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/oci/functions/models/create_function_details.rb', line 71

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'application_id': :'applicationId',
    'image': :'image',
    'image_digest': :'imageDigest',
    'memory_in_m_bs': :'memoryInMBs',
    'config': :'config',
    'timeout_in_seconds': :'timeoutInSeconds',
    'trace_config': :'traceConfig',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/oci/functions/models/create_function_details.rb', line 89

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'application_id': :'String',
    'image': :'String',
    'image_digest': :'String',
    'memory_in_m_bs': :'Integer',
    'config': :'Hash<String, String>',
    'timeout_in_seconds': :'Integer',
    'trace_config': :'OCI::Functions::Models::FunctionTraceConfig',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/oci/functions/models/create_function_details.rb', line 190

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    application_id == other.application_id &&
    image == other.image &&
    image_digest == other.image_digest &&
    memory_in_m_bs == other.memory_in_m_bs &&
    config == other.config &&
    timeout_in_seconds == other.timeout_in_seconds &&
    trace_config == other.trace_config &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/oci/functions/models/create_function_details.rb', line 229

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/oci/functions/models/create_function_details.rb', line 209

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



218
219
220
# File 'lib/oci/functions/models/create_function_details.rb', line 218

def hash
  [display_name, application_id, image, image_digest, memory_in_m_bs, config, timeout_in_seconds, trace_config, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
# File 'lib/oci/functions/models/create_function_details.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



256
257
258
# File 'lib/oci/functions/models/create_function_details.rb', line 256

def to_s
  to_hash.to_s
end