Class: OCI::GoldenGate::Models::CreateDatabaseRegistrationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/golden_gate/models/create_database_registration_details.rb

Overview

The information about a new DatabaseRegistration.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDatabaseRegistrationDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :fqdn (String)

    The value to assign to the #fqdn property

  • :ip_address (String)

    The value to assign to the #ip_address property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :database_id (String)

    The value to assign to the #database_id property

  • :username (String)

    The value to assign to the #username property

  • :password (String)

    The value to assign to the #password property

  • :connection_string (String)

    The value to assign to the #connection_string property

  • :wallet (String)

    The value to assign to the #wallet property

  • :alias_name (String)

    The value to assign to the #alias_name property

  • :vault_id (String)

    The value to assign to the #vault_id property

  • :key_id (String)

    The value to assign to the #key_id property

  • :secret_compartment_id (String)

    The value to assign to the #secret_compartment_id property



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 171

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.fqdn = attributes[:'fqdn'] if attributes[:'fqdn']

  self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress']

  raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address')

  self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.username = attributes[:'username'] if attributes[:'username']

  self.password = attributes[:'password'] if attributes[:'password']

  self.connection_string = attributes[:'connectionString'] if attributes[:'connectionString']

  raise 'You cannot provide both :connectionString and :connection_string' if attributes.key?(:'connectionString') && attributes.key?(:'connection_string')

  self.connection_string = attributes[:'connection_string'] if attributes[:'connection_string']

  self.wallet = attributes[:'wallet'] if attributes[:'wallet']

  self.alias_name = attributes[:'aliasName'] if attributes[:'aliasName']

  raise 'You cannot provide both :aliasName and :alias_name' if attributes.key?(:'aliasName') && attributes.key?(:'alias_name')

  self.alias_name = attributes[:'alias_name'] if attributes[:'alias_name']

  self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId']

  raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id')

  self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id']

  self.key_id = attributes[:'keyId'] if attributes[:'keyId']

  raise 'You cannot provide both :keyId and :key_id' if attributes.key?(:'keyId') && attributes.key?(:'key_id')

  self.key_id = attributes[:'key_id'] if attributes[:'key_id']

  self.secret_compartment_id = attributes[:'secretCompartmentId'] if attributes[:'secretCompartmentId']

  raise 'You cannot provide both :secretCompartmentId and :secret_compartment_id' if attributes.key?(:'secretCompartmentId') && attributes.key?(:'secret_compartment_id')

  self.secret_compartment_id = attributes[:'secret_compartment_id'] if attributes[:'secret_compartment_id']
end

Instance Attribute Details

#alias_nameString

[Required] Credential store alias.

Returns:

  • (String)


81
82
83
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 81

def alias_name
  @alias_name
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.

Returns:

  • (String)


24
25
26
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 24

def compartment_id
  @compartment_id
end

#connection_stringString

Connect descriptor or Easy Connect Naming method that Oracle GoldenGate uses to connect to a database.

Returns:

  • (String)


71
72
73
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 71

def connection_string
  @connection_string
end

#database_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database being referenced.

Returns:

  • (String)


56
57
58
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 56

def database_id
  @database_id
end

#defined_tagsHash<String, Hash<String, Object>>

Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


36
37
38
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 36

def defined_tags
  @defined_tags
end

#descriptionString

Metadata about this specific object.

Returns:

  • (String)


19
20
21
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 19

def description
  @description
end

#display_nameString

[Required] An object’s Display Name.

Returns:

  • (String)


14
15
16
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 14

def display_name
  @display_name
end

#fqdnString

[Required] A three-label Fully Qualified Domain Name (FQDN) for a resource.

Returns:

  • (String)


41
42
43
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 41

def fqdn
  @fqdn
end

#freeform_tagsHash<String, String>

A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


30
31
32
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 30

def freeform_tags
  @freeform_tags
end

#ip_addressString

The private IP address in the customer’s VCN of the customer’s endpoint, typically a database.

Returns:

  • (String)


46
47
48
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 46

def ip_address
  @ip_address
end

#key_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer "Master" key being referenced. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this key to manage secrets.

Returns:

  • (String)


91
92
93
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 91

def key_id
  @key_id
end

#passwordString

[Required] The password Oracle GoldenGate uses to connect the associated RDBMS. It must conform to the specific security requirements implemented by the database including length, case sensitivity, and so on.

Returns:

  • (String)


66
67
68
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 66

def password
  @password
end

#secret_compartment_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the the GGS Secret will be created. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this Compartment in which to create a Secret.

Returns:

  • (String)


96
97
98
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 96

def secret_compartment_id
  @secret_compartment_id
end

#subnet_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.

Returns:

  • (String)


51
52
53
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 51

def subnet_id
  @subnet_id
end

#usernameString

[Required] The username Oracle GoldenGate uses to connect the associated RDBMS. This username must already exist and be available for use by the database. It must conform to the security requirements implemented by the database including length, case sensitivity, and so on.

Returns:

  • (String)


61
62
63
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 61

def username
  @username
end

#vault_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer vault being referenced. If provided, this will reference a vault which the customer will be required to ensure the policies are established to permit the GoldenGate Service to manage secrets contained within this vault.

Returns:

  • (String)


86
87
88
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 86

def vault_id
  @vault_id
end

#walletString

The wallet contents Oracle GoldenGate uses to make connections to a database. This attribute is expected to be base64 encoded.

Returns:

  • (String)


76
77
78
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 76

def wallet
  @wallet
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 99

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'fqdn': :'fqdn',
    'ip_address': :'ipAddress',
    'subnet_id': :'subnetId',
    'database_id': :'databaseId',
    'username': :'username',
    'password': :'password',
    'connection_string': :'connectionString',
    'wallet': :'wallet',
    'alias_name': :'aliasName',
    'vault_id': :'vaultId',
    'key_id': :'keyId',
    'secret_compartment_id': :'secretCompartmentId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 124

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'fqdn': :'String',
    'ip_address': :'String',
    'subnet_id': :'String',
    'database_id': :'String',
    'username': :'String',
    'password': :'String',
    'connection_string': :'String',
    'wallet': :'String',
    'alias_name': :'String',
    'vault_id': :'String',
    'key_id': :'String',
    'secret_compartment_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 267

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    fqdn == other.fqdn &&
    ip_address == other.ip_address &&
    subnet_id == other.subnet_id &&
    database_id == other.database_id &&
    username == other.username &&
    password == other.password &&
    connection_string == other.connection_string &&
    wallet == other.wallet &&
    alias_name == other.alias_name &&
    vault_id == other.vault_id &&
    key_id == other.key_id &&
    secret_compartment_id == other.secret_compartment_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 313

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


293
294
295
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 293

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



302
303
304
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 302

def hash
  [display_name, description, compartment_id, freeform_tags, defined_tags, fqdn, ip_address, subnet_id, database_id, username, password, connection_string, wallet, alias_name, vault_id, key_id, secret_compartment_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



346
347
348
349
350
351
352
353
354
355
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 346

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



340
341
342
# File 'lib/oci/golden_gate/models/create_database_registration_details.rb', line 340

def to_s
  to_hash.to_s
end