Class: OCI::GoldenGate::Models::CreateOggDeploymentDetails
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::CreateOggDeploymentDetails
- Defined in:
- lib/oci/golden_gate/models/create_ogg_deployment_details.rb
Overview
Deployment Data for creating an OggDeployment
Instance Attribute Summary collapse
-
#admin_password ⇒ String
**[Required]** The password associated with the GoldenGate deployment console username.
-
#admin_username ⇒ String
**[Required]** The GoldenGate deployment console username.
-
#certificate ⇒ String
A PEM-encoded SSL certificate.
-
#deployment_name ⇒ String
**[Required]** The name given to the GoldenGate service deployment.
-
#key ⇒ String
A PEM-encoded private key.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOggDeploymentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateOggDeploymentDetails
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 73 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.deployment_name = attributes[:'deploymentName'] if attributes[:'deploymentName'] raise 'You cannot provide both :deploymentName and :deployment_name' if attributes.key?(:'deploymentName') && attributes.key?(:'deployment_name') self.deployment_name = attributes[:'deployment_name'] if attributes[:'deployment_name'] self.admin_username = attributes[:'adminUsername'] if attributes[:'adminUsername'] raise 'You cannot provide both :adminUsername and :admin_username' if attributes.key?(:'adminUsername') && attributes.key?(:'admin_username') self.admin_username = attributes[:'admin_username'] if attributes[:'admin_username'] self.admin_password = attributes[:'adminPassword'] if attributes[:'adminPassword'] raise 'You cannot provide both :adminPassword and :admin_password' if attributes.key?(:'adminPassword') && attributes.key?(:'admin_password') self.admin_password = attributes[:'admin_password'] if attributes[:'admin_password'] self.certificate = attributes[:'certificate'] if attributes[:'certificate'] self.key = attributes[:'key'] if attributes[:'key'] end |
Instance Attribute Details
#admin_password ⇒ String
**[Required]** The password associated with the GoldenGate deployment console username. The password must be 8 to 30 characters long and must contain at least 1 uppercase, 1 lowercase, 1 numeric, and 1 special character. Special characters such as u2018$u2019, u2018^u2019, or u2018?u2019 are not allowed.
24 25 26 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 24 def admin_password @admin_password end |
#admin_username ⇒ String
**[Required]** The GoldenGate deployment console username.
19 20 21 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 19 def admin_username @admin_username end |
#certificate ⇒ String
A PEM-encoded SSL certificate.
29 30 31 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 29 def certificate @certificate end |
#deployment_name ⇒ String
**[Required]** The name given to the GoldenGate service deployment. The name must be 1 to 32 characters long, must contain only alphanumeric characters and must start with a letter.
14 15 16 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 14 def deployment_name @deployment_name end |
#key ⇒ String
A PEM-encoded private key.
34 35 36 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 34 def key @key end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'deployment_name': :'deploymentName', 'admin_username': :'adminUsername', 'admin_password': :'adminPassword', 'certificate': :'certificate', 'key': :'key' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'deployment_name': :'String', 'admin_username': :'String', 'admin_password': :'String', 'certificate': :'String', 'key': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 109 def ==(other) return true if equal?(other) self.class == other.class && deployment_name == other.deployment_name && admin_username == other.admin_username && admin_password == other.admin_password && certificate == other.certificate && key == other.key end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 143 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
123 124 125 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 123 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
132 133 134 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 132 def hash [deployment_name, admin_username, admin_password, certificate, key].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 176 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
170 171 172 |
# File 'lib/oci/golden_gate/models/create_ogg_deployment_details.rb', line 170 def to_s to_hash.to_s end |