Class: OCI::GoldenGate::Models::DatabaseRegistration
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::DatabaseRegistration
- Defined in:
- lib/oci/golden_gate/models/database_registration.rb
Overview
Represents the metadata description of a database used by deployments in the same compartment.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#alias_name ⇒ String
[Required] Credential store alias.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
-
#connection_string ⇒ String
Connect descriptor or Easy Connect Naming method that Oracle GoldenGate uses to connect to a database.
-
#database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database being referenced.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource.
-
#description ⇒ String
Metadata about this specific object.
-
#display_name ⇒ String
[Required] An object’s Display Name.
-
#fqdn ⇒ String
[Required] A three-label Fully Qualified Domain Name (FQDN) for a resource.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the databaseRegistration being referenced.
-
#ip_address ⇒ String
[Required] The private IP address in the customer’s VCN of the customer’s endpoint, typically a database.
-
#key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer "Master" key being referenced.
-
#lifecycle_details ⇒ String
Describes the object’s current state in detail.
-
#lifecycle_state ⇒ String
Possible lifecycle states.
-
#rce_private_ip ⇒ String
A Private Endpoint IP Address created in the customer’s subnet.
-
#secret_compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the the GGS Secret will be created.
-
#secret_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer GGS Secret being referenced.
-
#subnet_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
-
#time_created ⇒ DateTime
The time the resource was created.
-
#time_updated ⇒ DateTime
The time the resource was last updated.
-
#username ⇒ String
[Required] The username Oracle GoldenGate uses to connect the associated RDBMS.
-
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer vault being referenced.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseRegistration
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseRegistration
Initializes the object
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 232 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.fqdn = attributes[:'fqdn'] if attributes[:'fqdn'] self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress'] raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.rce_private_ip = attributes[:'rcePrivateIp'] if attributes[:'rcePrivateIp'] raise 'You cannot provide both :rcePrivateIp and :rce_private_ip' if attributes.key?(:'rcePrivateIp') && attributes.key?(:'rce_private_ip') self.rce_private_ip = attributes[:'rce_private_ip'] if attributes[:'rce_private_ip'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.username = attributes[:'username'] if attributes[:'username'] self.connection_string = attributes[:'connectionString'] if attributes[:'connectionString'] raise 'You cannot provide both :connectionString and :connection_string' if attributes.key?(:'connectionString') && attributes.key?(:'connection_string') self.connection_string = attributes[:'connection_string'] if attributes[:'connection_string'] self.alias_name = attributes[:'aliasName'] if attributes[:'aliasName'] raise 'You cannot provide both :aliasName and :alias_name' if attributes.key?(:'aliasName') && attributes.key?(:'alias_name') self.alias_name = attributes[:'alias_name'] if attributes[:'alias_name'] self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId'] raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id') self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id'] self.key_id = attributes[:'keyId'] if attributes[:'keyId'] raise 'You cannot provide both :keyId and :key_id' if attributes.key?(:'keyId') && attributes.key?(:'key_id') self.key_id = attributes[:'key_id'] if attributes[:'key_id'] self.secret_compartment_id = attributes[:'secretCompartmentId'] if attributes[:'secretCompartmentId'] raise 'You cannot provide both :secretCompartmentId and :secret_compartment_id' if attributes.key?(:'secretCompartmentId') && attributes.key?(:'secret_compartment_id') self.secret_compartment_id = attributes[:'secret_compartment_id'] if attributes[:'secret_compartment_id'] self.secret_id = attributes[:'secretId'] if attributes[:'secretId'] raise 'You cannot provide both :secretId and :secret_id' if attributes.key?(:'secretId') && attributes.key?(:'secret_id') self.secret_id = attributes[:'secret_id'] if attributes[:'secret_id'] end |
Instance Attribute Details
#alias_name ⇒ String
[Required] Credential store alias.
119 120 121 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 119 def alias_name @alias_name end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
41 42 43 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 41 def compartment_id @compartment_id end |
#connection_string ⇒ String
Connect descriptor or Easy Connect Naming method that Oracle GoldenGate uses to connect to a database.
114 115 116 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 114 def connection_string @connection_string end |
#database_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database being referenced.
93 94 95 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 93 def database_id @database_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
73 74 75 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 73 def end |
#description ⇒ String
Metadata about this specific object.
36 37 38 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 36 def description @description end |
#display_name ⇒ String
[Required] An object’s Display Name.
31 32 33 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 31 def display_name @display_name end |
#fqdn ⇒ String
[Required] A three-label Fully Qualified Domain Name (FQDN) for a resource.
78 79 80 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 78 def fqdn @fqdn end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`
67 68 69 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 67 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the databaseRegistration being referenced.
26 27 28 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 26 def id @id end |
#ip_address ⇒ String
[Required] The private IP address in the customer’s VCN of the customer’s endpoint, typically a database.
83 84 85 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 83 def ip_address @ip_address end |
#key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer "Master" key being referenced. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this key to manage secrets.
129 130 131 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 129 def key_id @key_id end |
#lifecycle_details ⇒ String
Describes the object’s current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.
61 62 63 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 61 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Possible lifecycle states.
56 57 58 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 56 def lifecycle_state @lifecycle_state end |
#rce_private_ip ⇒ String
A Private Endpoint IP Address created in the customer’s subnet. A customer database can expect network traffic initiated by GGS from this IP address and send network traffic to this IP address, typically in response to requests from GGS (OGG). The customer may utilize this IP address in Security Lists or Network Security Groups (NSG) as needed.
98 99 100 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 98 def rce_private_ip @rce_private_ip end |
#secret_compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the the GGS Secret will be created. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this Compartment in which to create a Secret.
134 135 136 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 134 def secret_compartment_id @secret_compartment_id end |
#secret_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer GGS Secret being referenced. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this Secret
139 140 141 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 139 def secret_id @secret_id end |
#subnet_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.
88 89 90 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 88 def subnet_id @subnet_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{free-tier-retain: true}`
104 105 106 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 104 def end |
#time_created ⇒ DateTime
The time the resource was created. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
46 47 48 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 46 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the resource was last updated. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
51 52 53 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 51 def time_updated @time_updated end |
#username ⇒ String
[Required] The username Oracle GoldenGate uses to connect the associated RDBMS. This username must already exist and be available for use by the database. It must conform to the security requirements implemented by the database including length, case sensitivity, and so on.
109 110 111 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 109 def username @username end |
#vault_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer vault being referenced. If provided, this will reference a vault which the customer will be required to ensure the policies are established to permit the GoldenGate Service to manage secrets contained within this vault.
124 125 126 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 124 def vault_id @vault_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 142 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'fqdn': :'fqdn', 'ip_address': :'ipAddress', 'subnet_id': :'subnetId', 'database_id': :'databaseId', 'rce_private_ip': :'rcePrivateIp', 'system_tags': :'systemTags', 'username': :'username', 'connection_string': :'connectionString', 'alias_name': :'aliasName', 'vault_id': :'vaultId', 'key_id': :'keyId', 'secret_compartment_id': :'secretCompartmentId', 'secret_id': :'secretId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 173 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'fqdn': :'String', 'ip_address': :'String', 'subnet_id': :'String', 'database_id': :'String', 'rce_private_ip': :'String', 'system_tags': :'Hash<String, Hash<String, Object>>', 'username': :'String', 'connection_string': :'String', 'alias_name': :'String', 'vault_id': :'String', 'key_id': :'String', 'secret_compartment_id': :'String', 'secret_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 381 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && fqdn == other.fqdn && ip_address == other.ip_address && subnet_id == other.subnet_id && database_id == other.database_id && rce_private_ip == other.rce_private_ip && == other. && username == other.username && connection_string == other.connection_string && alias_name == other.alias_name && vault_id == other.vault_id && key_id == other.key_id && secret_compartment_id == other.secret_compartment_id && secret_id == other.secret_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 433 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
413 414 415 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 413 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
422 423 424 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 422 def hash [id, display_name, description, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, , , fqdn, ip_address, subnet_id, database_id, rce_private_ip, , username, connection_string, alias_name, vault_id, key_id, secret_compartment_id, secret_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
466 467 468 469 470 471 472 473 474 475 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 466 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
460 461 462 |
# File 'lib/oci/golden_gate/models/database_registration.rb', line 460 def to_s to_hash.to_s end |