Class: OCI::GoldenGate::Models::DatabaseRegistrationSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/golden_gate/models/database_registration_summary.rb

Overview

Summary of the DatabaseRegistration.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DatabaseRegistrationSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :fqdn (String)

    The value to assign to the #fqdn property

  • :subnet_id (String)

    The value to assign to the #subnet_id property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property

  • :database_id (String)

    The value to assign to the #database_id property

  • :username (String)

    The value to assign to the #username property

  • :connection_string (String)

    The value to assign to the #connection_string property

  • :alias_name (String)

    The value to assign to the #alias_name property

  • :secret_id (String)

    The value to assign to the #secret_id property



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 192

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.fqdn = attributes[:'fqdn'] if attributes[:'fqdn']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.username = attributes[:'username'] if attributes[:'username']

  self.connection_string = attributes[:'connectionString'] if attributes[:'connectionString']

  raise 'You cannot provide both :connectionString and :connection_string' if attributes.key?(:'connectionString') && attributes.key?(:'connection_string')

  self.connection_string = attributes[:'connection_string'] if attributes[:'connection_string']

  self.alias_name = attributes[:'aliasName'] if attributes[:'aliasName']

  raise 'You cannot provide both :aliasName and :alias_name' if attributes.key?(:'aliasName') && attributes.key?(:'alias_name')

  self.alias_name = attributes[:'alias_name'] if attributes[:'alias_name']

  self.secret_id = attributes[:'secretId'] if attributes[:'secretId']

  raise 'You cannot provide both :secretId and :secret_id' if attributes.key?(:'secretId') && attributes.key?(:'secret_id')

  self.secret_id = attributes[:'secret_id'] if attributes[:'secret_id']
end

Instance Attribute Details

#alias_nameString

Credential store alias.

Returns:

  • (String)


109
110
111
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 109

def alias_name
  @alias_name
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.

Returns:

  • (String)


41
42
43
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 41

def compartment_id
  @compartment_id
end

#connection_stringString

Connect descriptor or Easy Connect Naming method that Oracle GoldenGate uses to connect to a database.

Returns:

  • (String)


104
105
106
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 104

def connection_string
  @connection_string
end

#database_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database being referenced.

Returns:

  • (String)


94
95
96
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 94

def database_id
  @database_id
end

#defined_tagsHash<String, Hash<String, Object>>

Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


73
74
75
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 73

def defined_tags
  @defined_tags
end

#descriptionString

Metadata about this specific object.

Returns:

  • (String)


36
37
38
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 36

def description
  @description
end

#display_nameString

[Required] An object’s Display Name.

Returns:

  • (String)


31
32
33
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 31

def display_name
  @display_name
end

#fqdnString

[Required] A three-label Fully Qualified Domain Name (FQDN) for a resource.

Returns:

  • (String)


78
79
80
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 78

def fqdn
  @fqdn
end

#freeform_tagsHash<String, String>

A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


67
68
69
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 67

def freeform_tags
  @freeform_tags
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the databaseRegistration being referenced.

Returns:

  • (String)


26
27
28
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 26

def id
  @id
end

#lifecycle_detailsString

Describes the object’s current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.

Returns:

  • (String)


61
62
63
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 61

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

Possible lifecycle states.

Returns:

  • (String)


56
57
58
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 56

def lifecycle_state
  @lifecycle_state
end

#secret_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the customer GGS Secret being referenced. If provided, this will reference a key which the customer will be required to ensure the policies are established to permit the GoldenGate Service to utilize this Secret

Returns:

  • (String)


114
115
116
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 114

def secret_id
  @secret_id
end

#subnet_idString

The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.

Returns:

  • (String)


83
84
85
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 83

def subnet_id
  @subnet_id
end

#system_tagsHash<String, Hash<String, Object>>

The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{free-tier-retain: true}`

Returns:

  • (Hash<String, Hash<String, Object>>)


89
90
91
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 89

def system_tags
  @system_tags
end

#time_createdDateTime

The time the resource was created. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.

Returns:

  • (DateTime)


46
47
48
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 46

def time_created
  @time_created
end

#time_updatedDateTime

The time the resource was last updated. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.

Returns:

  • (DateTime)


51
52
53
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 51

def time_updated
  @time_updated
end

#usernameString

The username Oracle GoldenGate uses to connect the associated RDBMS. This username must already exist and be available for use by the database. It must conform to the security requirements implemented by the database including length, case sensitivity, and so on.

Returns:

  • (String)


99
100
101
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 99

def username
  @username
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 117

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'fqdn': :'fqdn',
    'subnet_id': :'subnetId',
    'system_tags': :'systemTags',
    'database_id': :'databaseId',
    'username': :'username',
    'connection_string': :'connectionString',
    'alias_name': :'aliasName',
    'secret_id': :'secretId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 143

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'fqdn': :'String',
    'subnet_id': :'String',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'database_id': :'String',
    'username': :'String',
    'connection_string': :'String',
    'alias_name': :'String',
    'secret_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 311

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    fqdn == other.fqdn &&
    subnet_id == other.subnet_id &&
    system_tags == other.system_tags &&
    database_id == other.database_id &&
    username == other.username &&
    connection_string == other.connection_string &&
    alias_name == other.alias_name &&
    secret_id == other.secret_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 358

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


338
339
340
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 338

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



347
348
349
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 347

def hash
  [id, display_name, description, compartment_id, time_created, time_updated, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, fqdn, subnet_id, system_tags, database_id, username, connection_string, alias_name, secret_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



391
392
393
394
395
396
397
398
399
400
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 391

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



385
386
387
# File 'lib/oci/golden_gate/models/database_registration_summary.rb', line 385

def to_s
  to_hash.to_s
end