Class: OCI::GoldenGate::Models::Deployment
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::Deployment
- Defined in:
- lib/oci/golden_gate/models/deployment.rb
Overview
A container for your OCI GoldenGate resources, such as the OCI GoldenGate deployment console.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LICENSE_MODEL_ENUM =
[ LICENSE_MODEL_LICENSE_INCLUDED = 'LICENSE_INCLUDED'.freeze, LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = 'BRING_YOUR_OWN_LICENSE'.freeze, LICENSE_MODEL_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DEPLOYMENT_TYPE_ENUM =
[ DEPLOYMENT_TYPE_OGG = 'OGG'.freeze, DEPLOYMENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
-
#cpu_core_count ⇒ Integer
[Required] The Minimum number of OCPUs to be made available for this Deployment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource.
-
#deployment_backup_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup being referenced.
-
#deployment_type ⇒ String
[Required] The deployment type.
-
#deployment_url ⇒ String
The URL of a resource.
-
#description ⇒ String
Metadata about this specific object.
-
#display_name ⇒ String
An object’s Display Name.
-
#fqdn ⇒ String
A three-label Fully Qualified Domain Name (FQDN) for a resource.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
-
#is_auto_scaling_enabled ⇒ BOOLEAN
[Required] Indicates if auto scaling is enabled for the Deployment’s CPU core count.
-
#is_healthy ⇒ BOOLEAN
True if all of the aggregate resources are working correctly.
-
#is_latest_version ⇒ BOOLEAN
Indicates if the resource is the the latest available version.
-
#is_public ⇒ BOOLEAN
True if this object is publicly available.
-
#license_model ⇒ String
[Required] The Oracle license model that applies to a Deployment.
-
#lifecycle_details ⇒ String
Describes the object’s current state in detail.
-
#lifecycle_state ⇒ String
Possible lifecycle states.
-
#nsg_ids ⇒ Array<String>
An array of [Network Security Group](docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm) OCIDs used to define network access for a deployment.
- #ogg_data ⇒ OCI::GoldenGate::Models::OggDeployment
-
#private_ip_address ⇒ String
The private IP address in the customer’s VCN representing the access point for the associated endpoint service in the GoldenGate service VCN.
-
#public_ip_address ⇒ String
The public IP address representing the access point for the Deployment.
-
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
-
#time_created ⇒ DateTime
The time the resource was created.
-
#time_updated ⇒ DateTime
The time the resource was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Deployment
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Deployment
Initializes the object
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 265 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.deployment_backup_id = attributes[:'deploymentBackupId'] if attributes[:'deploymentBackupId'] raise 'You cannot provide both :deploymentBackupId and :deployment_backup_id' if attributes.key?(:'deploymentBackupId') && attributes.key?(:'deployment_backup_id') self.deployment_backup_id = attributes[:'deployment_backup_id'] if attributes[:'deployment_backup_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.is_healthy = attributes[:'isHealthy'] unless attributes[:'isHealthy'].nil? raise 'You cannot provide both :isHealthy and :is_healthy' if attributes.key?(:'isHealthy') && attributes.key?(:'is_healthy') self.is_healthy = attributes[:'is_healthy'] unless attributes[:'is_healthy'].nil? self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.fqdn = attributes[:'fqdn'] if attributes[:'fqdn'] self.license_model = attributes[:'licenseModel'] if attributes[:'licenseModel'] raise 'You cannot provide both :licenseModel and :license_model' if attributes.key?(:'licenseModel') && attributes.key?(:'license_model') self.license_model = attributes[:'license_model'] if attributes[:'license_model'] self.cpu_core_count = attributes[:'cpuCoreCount'] if attributes[:'cpuCoreCount'] raise 'You cannot provide both :cpuCoreCount and :cpu_core_count' if attributes.key?(:'cpuCoreCount') && attributes.key?(:'cpu_core_count') self.cpu_core_count = attributes[:'cpu_core_count'] if attributes[:'cpu_core_count'] self.is_auto_scaling_enabled = attributes[:'isAutoScalingEnabled'] unless attributes[:'isAutoScalingEnabled'].nil? raise 'You cannot provide both :isAutoScalingEnabled and :is_auto_scaling_enabled' if attributes.key?(:'isAutoScalingEnabled') && attributes.key?(:'is_auto_scaling_enabled') self.is_auto_scaling_enabled = attributes[:'is_auto_scaling_enabled'] unless attributes[:'is_auto_scaling_enabled'].nil? self.nsg_ids = attributes[:'nsgIds'] if attributes[:'nsgIds'] raise 'You cannot provide both :nsgIds and :nsg_ids' if attributes.key?(:'nsgIds') && attributes.key?(:'nsg_ids') self.nsg_ids = attributes[:'nsg_ids'] if attributes[:'nsg_ids'] self.is_public = attributes[:'isPublic'] unless attributes[:'isPublic'].nil? raise 'You cannot provide both :isPublic and :is_public' if attributes.key?(:'isPublic') && attributes.key?(:'is_public') self.is_public = attributes[:'is_public'] unless attributes[:'is_public'].nil? self.public_ip_address = attributes[:'publicIpAddress'] if attributes[:'publicIpAddress'] raise 'You cannot provide both :publicIpAddress and :public_ip_address' if attributes.key?(:'publicIpAddress') && attributes.key?(:'public_ip_address') self.public_ip_address = attributes[:'public_ip_address'] if attributes[:'public_ip_address'] self.private_ip_address = attributes[:'privateIpAddress'] if attributes[:'privateIpAddress'] raise 'You cannot provide both :privateIpAddress and :private_ip_address' if attributes.key?(:'privateIpAddress') && attributes.key?(:'private_ip_address') self.private_ip_address = attributes[:'private_ip_address'] if attributes[:'private_ip_address'] self.deployment_url = attributes[:'deploymentUrl'] if attributes[:'deploymentUrl'] raise 'You cannot provide both :deploymentUrl and :deployment_url' if attributes.key?(:'deploymentUrl') && attributes.key?(:'deployment_url') self.deployment_url = attributes[:'deployment_url'] if attributes[:'deployment_url'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.is_latest_version = attributes[:'isLatestVersion'] unless attributes[:'isLatestVersion'].nil? raise 'You cannot provide both :isLatestVersion and :is_latest_version' if attributes.key?(:'isLatestVersion') && attributes.key?(:'is_latest_version') self.is_latest_version = attributes[:'is_latest_version'] unless attributes[:'is_latest_version'].nil? self.deployment_type = attributes[:'deploymentType'] if attributes[:'deploymentType'] raise 'You cannot provide both :deploymentType and :deployment_type' if attributes.key?(:'deploymentType') && attributes.key?(:'deployment_type') self.deployment_type = attributes[:'deployment_type'] if attributes[:'deployment_type'] self.ogg_data = attributes[:'oggData'] if attributes[:'oggData'] raise 'You cannot provide both :oggData and :ogg_data' if attributes.key?(:'oggData') && attributes.key?(:'ogg_data') self.ogg_data = attributes[:'ogg_data'] if attributes[:'ogg_data'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
52 53 54 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 52 def compartment_id @compartment_id end |
#cpu_core_count ⇒ Integer
[Required] The Minimum number of OCPUs to be made available for this Deployment.
114 115 116 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 114 def cpu_core_count @cpu_core_count end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
89 90 91 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 89 def end |
#deployment_backup_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup being referenced.
57 58 59 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 57 def deployment_backup_id @deployment_backup_id end |
#deployment_type ⇒ String
[Required] The deployment type.
160 161 162 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 160 def deployment_type @deployment_type end |
#deployment_url ⇒ String
The URL of a resource.
144 145 146 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 144 def deployment_url @deployment_url end |
#description ⇒ String
Metadata about this specific object.
47 48 49 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 47 def description @description end |
#display_name ⇒ String
An object’s Display Name.
42 43 44 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 42 def display_name @display_name end |
#fqdn ⇒ String
A three-label Fully Qualified Domain Name (FQDN) for a resource.
104 105 106 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 104 def fqdn @fqdn end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`
83 84 85 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 83 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
37 38 39 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 37 def id @id end |
#is_auto_scaling_enabled ⇒ BOOLEAN
[Required] Indicates if auto scaling is enabled for the Deployment’s CPU core count.
119 120 121 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 119 def is_auto_scaling_enabled @is_auto_scaling_enabled end |
#is_healthy ⇒ BOOLEAN
True if all of the aggregate resources are working correctly.
94 95 96 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 94 def is_healthy @is_healthy end |
#is_latest_version ⇒ BOOLEAN
Indicates if the resource is the the latest available version.
155 156 157 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 155 def is_latest_version @is_latest_version end |
#is_public ⇒ BOOLEAN
True if this object is publicly available.
129 130 131 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 129 def is_public @is_public end |
#license_model ⇒ String
[Required] The Oracle license model that applies to a Deployment.
109 110 111 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 109 def license_model @license_model end |
#lifecycle_details ⇒ String
Describes the object’s current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.
77 78 79 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 77 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Possible lifecycle states.
72 73 74 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 72 def lifecycle_state @lifecycle_state end |
#nsg_ids ⇒ Array<String>
An array of [Network Security Group](docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm) OCIDs used to define network access for a deployment.
124 125 126 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 124 def nsg_ids @nsg_ids end |
#ogg_data ⇒ OCI::GoldenGate::Models::OggDeployment
163 164 165 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 163 def ogg_data @ogg_data end |
#private_ip_address ⇒ String
The private IP address in the customer’s VCN representing the access point for the associated endpoint service in the GoldenGate service VCN.
139 140 141 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 139 def private_ip_address @private_ip_address end |
#public_ip_address ⇒ String
The public IP address representing the access point for the Deployment.
134 135 136 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 134 def public_ip_address @public_ip_address end |
#subnet_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the subnet being referenced.
99 100 101 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 99 def subnet_id @subnet_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{free-tier-retain: true}`
150 151 152 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 150 def end |
#time_created ⇒ DateTime
The time the resource was created. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
62 63 64 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 62 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the resource was last updated. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
67 68 69 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 67 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 166 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'deployment_backup_id': :'deploymentBackupId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'is_healthy': :'isHealthy', 'subnet_id': :'subnetId', 'fqdn': :'fqdn', 'license_model': :'licenseModel', 'cpu_core_count': :'cpuCoreCount', 'is_auto_scaling_enabled': :'isAutoScalingEnabled', 'nsg_ids': :'nsgIds', 'is_public': :'isPublic', 'public_ip_address': :'publicIpAddress', 'private_ip_address': :'privateIpAddress', 'deployment_url': :'deploymentUrl', 'system_tags': :'systemTags', 'is_latest_version': :'isLatestVersion', 'deployment_type': :'deploymentType', 'ogg_data': :'oggData' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 200 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'deployment_backup_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'is_healthy': :'BOOLEAN', 'subnet_id': :'String', 'fqdn': :'String', 'license_model': :'String', 'cpu_core_count': :'Integer', 'is_auto_scaling_enabled': :'BOOLEAN', 'nsg_ids': :'Array<String>', 'is_public': :'BOOLEAN', 'public_ip_address': :'String', 'private_ip_address': :'String', 'deployment_url': :'String', 'system_tags': :'Hash<String, Hash<String, Object>>', 'is_latest_version': :'BOOLEAN', 'deployment_type': :'String', 'ogg_data': :'OCI::GoldenGate::Models::OggDeployment' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 462 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && deployment_backup_id == other.deployment_backup_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && is_healthy == other.is_healthy && subnet_id == other.subnet_id && fqdn == other.fqdn && license_model == other.license_model && cpu_core_count == other.cpu_core_count && is_auto_scaling_enabled == other.is_auto_scaling_enabled && nsg_ids == other.nsg_ids && is_public == other.is_public && public_ip_address == other.public_ip_address && private_ip_address == other.private_ip_address && deployment_url == other.deployment_url && == other. && is_latest_version == other.is_latest_version && deployment_type == other.deployment_type && ogg_data == other.ogg_data end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 517 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
497 498 499 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 497 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
506 507 508 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 506 def hash [id, display_name, description, compartment_id, deployment_backup_id, time_created, time_updated, lifecycle_state, lifecycle_details, , , is_healthy, subnet_id, fqdn, license_model, cpu_core_count, is_auto_scaling_enabled, nsg_ids, is_public, public_ip_address, private_ip_address, deployment_url, , is_latest_version, deployment_type, ogg_data].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
550 551 552 553 554 555 556 557 558 559 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 550 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
544 545 546 |
# File 'lib/oci/golden_gate/models/deployment.rb', line 544 def to_s to_hash.to_s end |