Class: OCI::GoldenGate::Models::DeploymentBackup
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::DeploymentBackup
- Defined in:
- lib/oci/golden_gate/models/deployment_backup.rb
Overview
A backup of the current state of the GoldenGate deployment. Can be used to restore a deployment, or create a new deployment with that state as the starting deployment state.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- BACKUP_TYPE_ENUM =
[ BACKUP_TYPE_INCREMENTAL = 'INCREMENTAL'.freeze, BACKUP_TYPE_FULL = 'FULL'.freeze, BACKUP_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#backup_type ⇒ String
Possible Deployment backup types.
-
#bucket_name ⇒ String
Name of the bucket where the object is to be uploaded in the object storage.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource.
-
#deployment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
-
#display_name ⇒ String
An object’s Display Name.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup being referenced.
-
#is_automatic ⇒ BOOLEAN
True if this object is automatically created.
-
#lifecycle_details ⇒ String
Describes the object’s current state in detail.
-
#lifecycle_state ⇒ String
[Required] Possible lifecycle states.
-
#namespace_name ⇒ String
Name of namespace that serves as a container for all of your buckets.
-
#object_name ⇒ String
Name of the object to be uploaded to object storage.
-
#ogg_version ⇒ String
[Required] Version of OGG.
-
#size_in_bytes ⇒ Float
The size of the backup stored in object storage (in bytes).
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
-
#time_backup_finished ⇒ DateTime
The time of the resource backup finish.
-
#time_created ⇒ DateTime
The time the resource was created.
-
#time_of_backup ⇒ DateTime
The time of the resource backup.
-
#time_updated ⇒ DateTime
The time the resource was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeploymentBackup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DeploymentBackup
Initializes the object
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 216 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.deployment_id = attributes[:'deploymentId'] if attributes[:'deploymentId'] raise 'You cannot provide both :deploymentId and :deployment_id' if attributes.key?(:'deploymentId') && attributes.key?(:'deployment_id') self.deployment_id = attributes[:'deployment_id'] if attributes[:'deployment_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.is_automatic = attributes[:'isAutomatic'] unless attributes[:'isAutomatic'].nil? raise 'You cannot provide both :isAutomatic and :is_automatic' if attributes.key?(:'isAutomatic') && attributes.key?(:'is_automatic') self.is_automatic = attributes[:'is_automatic'] unless attributes[:'is_automatic'].nil? self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_of_backup = attributes[:'timeOfBackup'] if attributes[:'timeOfBackup'] raise 'You cannot provide both :timeOfBackup and :time_of_backup' if attributes.key?(:'timeOfBackup') && attributes.key?(:'time_of_backup') self.time_of_backup = attributes[:'time_of_backup'] if attributes[:'time_of_backup'] self.time_backup_finished = attributes[:'timeBackupFinished'] if attributes[:'timeBackupFinished'] raise 'You cannot provide both :timeBackupFinished and :time_backup_finished' if attributes.key?(:'timeBackupFinished') && attributes.key?(:'time_backup_finished') self.time_backup_finished = attributes[:'time_backup_finished'] if attributes[:'time_backup_finished'] self.size_in_bytes = attributes[:'sizeInBytes'] if attributes[:'sizeInBytes'] raise 'You cannot provide both :sizeInBytes and :size_in_bytes' if attributes.key?(:'sizeInBytes') && attributes.key?(:'size_in_bytes') self.size_in_bytes = attributes[:'size_in_bytes'] if attributes[:'size_in_bytes'] self.backup_type = attributes[:'backupType'] if attributes[:'backupType'] raise 'You cannot provide both :backupType and :backup_type' if attributes.key?(:'backupType') && attributes.key?(:'backup_type') self.backup_type = attributes[:'backup_type'] if attributes[:'backup_type'] self.ogg_version = attributes[:'oggVersion'] if attributes[:'oggVersion'] raise 'You cannot provide both :oggVersion and :ogg_version' if attributes.key?(:'oggVersion') && attributes.key?(:'ogg_version') self.ogg_version = attributes[:'ogg_version'] if attributes[:'ogg_version'] self.namespace_name = attributes[:'namespaceName'] if attributes[:'namespaceName'] raise 'You cannot provide both :namespaceName and :namespace_name' if attributes.key?(:'namespaceName') && attributes.key?(:'namespace_name') self.namespace_name = attributes[:'namespace_name'] if attributes[:'namespace_name'] self.bucket_name = attributes[:'bucketName'] if attributes[:'bucketName'] raise 'You cannot provide both :bucketName and :bucket_name' if attributes.key?(:'bucketName') && attributes.key?(:'bucket_name') self.bucket_name = attributes[:'bucket_name'] if attributes[:'bucket_name'] self.object_name = attributes[:'objectName'] if attributes[:'objectName'] raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name') self.object_name = attributes[:'object_name'] if attributes[:'object_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#backup_type ⇒ String
Possible Deployment backup types.
87 88 89 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 87 def backup_type @backup_type end |
#bucket_name ⇒ String
Name of the bucket where the object is to be uploaded in the object storage
100 101 102 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 100 def bucket_name @bucket_name end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
47 48 49 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 47 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
126 127 128 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 126 def end |
#deployment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
42 43 44 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 42 def deployment_id @deployment_id end |
#display_name ⇒ String
An object’s Display Name.
52 53 54 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 52 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`
120 121 122 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 120 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup being referenced.
37 38 39 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 37 def id @id end |
#is_automatic ⇒ BOOLEAN
True if this object is automatically created
57 58 59 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 57 def is_automatic @is_automatic end |
#lifecycle_details ⇒ String
Describes the object’s current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.
67 68 69 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 67 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] Possible lifecycle states.
62 63 64 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 62 def lifecycle_state @lifecycle_state end |
#namespace_name ⇒ String
Name of namespace that serves as a container for all of your buckets
96 97 98 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 96 def namespace_name @namespace_name end |
#object_name ⇒ String
Name of the object to be uploaded to object storage
104 105 106 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 104 def object_name @object_name end |
#ogg_version ⇒ String
[Required] Version of OGG
92 93 94 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 92 def ogg_version @ogg_version end |
#size_in_bytes ⇒ Float
The size of the backup stored in object storage (in bytes)
82 83 84 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 82 def size_in_bytes @size_in_bytes end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{free-tier-retain: true}`
132 133 134 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 132 def end |
#time_backup_finished ⇒ DateTime
The time of the resource backup finish. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
77 78 79 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 77 def time_backup_finished @time_backup_finished end |
#time_created ⇒ DateTime
The time the resource was created. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
109 110 111 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 109 def time_created @time_created end |
#time_of_backup ⇒ DateTime
The time of the resource backup. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
72 73 74 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 72 def time_of_backup @time_of_backup end |
#time_updated ⇒ DateTime
The time the resource was last updated. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
114 115 116 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 114 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 135 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'deployment_id': :'deploymentId', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'is_automatic': :'isAutomatic', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_of_backup': :'timeOfBackup', 'time_backup_finished': :'timeBackupFinished', 'size_in_bytes': :'sizeInBytes', 'backup_type': :'backupType', 'ogg_version': :'oggVersion', 'namespace_name': :'namespaceName', 'bucket_name': :'bucketName', 'object_name': :'objectName', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 163 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'deployment_id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'is_automatic': :'BOOLEAN', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_of_backup': :'DateTime', 'time_backup_finished': :'DateTime', 'size_in_bytes': :'Float', 'backup_type': :'String', 'ogg_version': :'String', 'namespace_name': :'String', 'bucket_name': :'String', 'object_name': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 372 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && deployment_id == other.deployment_id && compartment_id == other.compartment_id && display_name == other.display_name && is_automatic == other.is_automatic && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_of_backup == other.time_of_backup && time_backup_finished == other.time_backup_finished && size_in_bytes == other.size_in_bytes && backup_type == other.backup_type && ogg_version == other.ogg_version && namespace_name == other.namespace_name && bucket_name == other.bucket_name && object_name == other.object_name && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 421 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
401 402 403 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 401 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
410 411 412 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 410 def hash [id, deployment_id, compartment_id, display_name, is_automatic, lifecycle_state, lifecycle_details, time_of_backup, time_backup_finished, size_in_bytes, backup_type, ogg_version, namespace_name, bucket_name, object_name, time_created, time_updated, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
454 455 456 457 458 459 460 461 462 463 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 454 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
448 449 450 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 448 def to_s to_hash.to_s end |