Class: OCI::GoldenGate::Models::DeploymentBackup
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::DeploymentBackup
- Defined in:
- lib/oci/golden_gate/models/deployment_backup.rb
Overview
A backup of the current state of the GoldenGate deployment. Can be used to restore a deployment, or create a new deployment with that state as the starting deployment state.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- BACKUP_TYPE_ENUM =
[ BACKUP_TYPE_INCREMENTAL = 'INCREMENTAL'.freeze, BACKUP_TYPE_FULL = 'FULL'.freeze, BACKUP_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#backup_type ⇒ String
Possible Deployment backup types.
-
#bucket_name ⇒ String
Name of the bucket where the object is to be uploaded in the object storage.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource.
-
#deployment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
-
#display_name ⇒ String
An object’s Display Name.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup being referenced.
-
#is_automatic ⇒ BOOLEAN
True if this object is automatically created.
-
#lifecycle_details ⇒ String
Describes the object’s current state in detail.
-
#lifecycle_state ⇒ String
[Required] Possible lifecycle states.
-
#namespace_name ⇒ String
Name of namespace that serves as a container for all of your buckets.
-
#object_name ⇒ String
Name of the object to be uploaded to object storage.
-
#ogg_version ⇒ String
[Required] Version of OGG.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
-
#time_created ⇒ DateTime
The time the resource was created.
-
#time_of_backup ⇒ DateTime
The time of the resource backup.
-
#time_updated ⇒ DateTime
The time the resource was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeploymentBackup
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DeploymentBackup
Initializes the object
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 195 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.deployment_id = attributes[:'deploymentId'] if attributes[:'deploymentId'] raise 'You cannot provide both :deploymentId and :deployment_id' if attributes.key?(:'deploymentId') && attributes.key?(:'deployment_id') self.deployment_id = attributes[:'deployment_id'] if attributes[:'deployment_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.is_automatic = attributes[:'isAutomatic'] unless attributes[:'isAutomatic'].nil? raise 'You cannot provide both :isAutomatic and :is_automatic' if attributes.key?(:'isAutomatic') && attributes.key?(:'is_automatic') self.is_automatic = attributes[:'is_automatic'] unless attributes[:'is_automatic'].nil? self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_of_backup = attributes[:'timeOfBackup'] if attributes[:'timeOfBackup'] raise 'You cannot provide both :timeOfBackup and :time_of_backup' if attributes.key?(:'timeOfBackup') && attributes.key?(:'time_of_backup') self.time_of_backup = attributes[:'time_of_backup'] if attributes[:'time_of_backup'] self.backup_type = attributes[:'backupType'] if attributes[:'backupType'] raise 'You cannot provide both :backupType and :backup_type' if attributes.key?(:'backupType') && attributes.key?(:'backup_type') self.backup_type = attributes[:'backup_type'] if attributes[:'backup_type'] self.ogg_version = attributes[:'oggVersion'] if attributes[:'oggVersion'] raise 'You cannot provide both :oggVersion and :ogg_version' if attributes.key?(:'oggVersion') && attributes.key?(:'ogg_version') self.ogg_version = attributes[:'ogg_version'] if attributes[:'ogg_version'] self.namespace_name = attributes[:'namespaceName'] if attributes[:'namespaceName'] raise 'You cannot provide both :namespaceName and :namespace_name' if attributes.key?(:'namespaceName') && attributes.key?(:'namespace_name') self.namespace_name = attributes[:'namespace_name'] if attributes[:'namespace_name'] self.bucket_name = attributes[:'bucketName'] if attributes[:'bucketName'] raise 'You cannot provide both :bucketName and :bucket_name' if attributes.key?(:'bucketName') && attributes.key?(:'bucket_name') self.bucket_name = attributes[:'bucket_name'] if attributes[:'bucket_name'] self.object_name = attributes[:'objectName'] if attributes[:'objectName'] raise 'You cannot provide both :objectName and :object_name' if attributes.key?(:'objectName') && attributes.key?(:'object_name') self.object_name = attributes[:'object_name'] if attributes[:'object_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#backup_type ⇒ String
Possible Deployment backup types.
72 73 74 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 72 def backup_type @backup_type end |
#bucket_name ⇒ String
Name of the bucket where the object is to be uploaded in the object storage
85 86 87 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 85 def bucket_name @bucket_name end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
42 43 44 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 42 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
111 112 113 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 111 def end |
#deployment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
37 38 39 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 37 def deployment_id @deployment_id end |
#display_name ⇒ String
An object’s Display Name.
47 48 49 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 47 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`
105 106 107 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 105 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the backup being referenced.
32 33 34 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 32 def id @id end |
#is_automatic ⇒ BOOLEAN
True if this object is automatically created
52 53 54 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 52 def is_automatic @is_automatic end |
#lifecycle_details ⇒ String
Describes the object’s current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.
62 63 64 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 62 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] Possible lifecycle states.
57 58 59 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 57 def lifecycle_state @lifecycle_state end |
#namespace_name ⇒ String
Name of namespace that serves as a container for all of your buckets
81 82 83 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 81 def namespace_name @namespace_name end |
#object_name ⇒ String
Name of the object to be uploaded to object storage
89 90 91 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 89 def object_name @object_name end |
#ogg_version ⇒ String
[Required] Version of OGG
77 78 79 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 77 def ogg_version @ogg_version end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{free-tier-retain: true}`
117 118 119 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 117 def end |
#time_created ⇒ DateTime
The time the resource was created. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
94 95 96 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 94 def time_created @time_created end |
#time_of_backup ⇒ DateTime
The time of the resource backup. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
67 68 69 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 67 def time_of_backup @time_of_backup end |
#time_updated ⇒ DateTime
The time the resource was last updated. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
99 100 101 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 99 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 120 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'deployment_id': :'deploymentId', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'is_automatic': :'isAutomatic', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_of_backup': :'timeOfBackup', 'backup_type': :'backupType', 'ogg_version': :'oggVersion', 'namespace_name': :'namespaceName', 'bucket_name': :'bucketName', 'object_name': :'objectName', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 146 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'deployment_id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'is_automatic': :'BOOLEAN', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_of_backup': :'DateTime', 'backup_type': :'String', 'ogg_version': :'String', 'namespace_name': :'String', 'bucket_name': :'String', 'object_name': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 339 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && deployment_id == other.deployment_id && compartment_id == other.compartment_id && display_name == other.display_name && is_automatic == other.is_automatic && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_of_backup == other.time_of_backup && backup_type == other.backup_type && ogg_version == other.ogg_version && namespace_name == other.namespace_name && bucket_name == other.bucket_name && object_name == other.object_name && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 386 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
366 367 368 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 366 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
375 376 377 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 375 def hash [id, deployment_id, compartment_id, display_name, is_automatic, lifecycle_state, lifecycle_details, time_of_backup, backup_type, ogg_version, namespace_name, bucket_name, object_name, time_created, time_updated, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
419 420 421 422 423 424 425 426 427 428 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 419 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
413 414 415 |
# File 'lib/oci/golden_gate/models/deployment_backup.rb', line 413 def to_s to_hash.to_s end |