Class: OCI::GoldenGate::Models::DeploymentUpgrade
- Inherits:
-
Object
- Object
- OCI::GoldenGate::Models::DeploymentUpgrade
- Defined in:
- lib/oci/golden_gate/models/deployment_upgrade.rb
Overview
A container for your OCI GoldenGate Upgrade information.
Constant Summary collapse
- DEPLOYMENT_UPGRADE_TYPE_ENUM =
[ DEPLOYMENT_UPGRADE_TYPE_MANUAL = 'MANUAL'.freeze, DEPLOYMENT_UPGRADE_TYPE_AUTOMATIC = 'AUTOMATIC'.freeze, DEPLOYMENT_UPGRADE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_SUB_STATE_ENUM =
[ LIFECYCLE_SUB_STATE_RECOVERING = 'RECOVERING'.freeze, LIFECYCLE_SUB_STATE_STARTING = 'STARTING'.freeze, LIFECYCLE_SUB_STATE_STOPPING = 'STOPPING'.freeze, LIFECYCLE_SUB_STATE_MOVING = 'MOVING'.freeze, LIFECYCLE_SUB_STATE_UPGRADING = 'UPGRADING'.freeze, LIFECYCLE_SUB_STATE_RESTORING = 'RESTORING'.freeze, LIFECYCLE_SUB_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze, LIFECYCLE_SUB_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource.
-
#deployment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
-
#deployment_upgrade_type ⇒ String
[Required] The type of the deployment upgrade: MANUAL or AUTOMATIC.
-
#description ⇒ String
Metadata about this specific object.
-
#display_name ⇒ String
An object’s Display Name.
-
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment upgrade being referenced.
-
#lifecycle_details ⇒ String
Describes the object’s current state in detail.
-
#lifecycle_state ⇒ String
Possible lifecycle states.
-
#lifecycle_sub_state ⇒ String
Possible GGS lifecycle sub-states.
-
#ogg_version ⇒ String
Version of OGG.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
-
#time_created ⇒ DateTime
The time the resource was created.
-
#time_finished ⇒ DateTime
The date and time the request was finished.
-
#time_started ⇒ DateTime
The date and time the request was started.
-
#time_updated ⇒ DateTime
The time the resource was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeploymentUpgrade
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DeploymentUpgrade
Initializes the object
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 206 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.deployment_id = attributes[:'deploymentId'] if attributes[:'deploymentId'] raise 'You cannot provide both :deploymentId and :deployment_id' if attributes.key?(:'deploymentId') && attributes.key?(:'deployment_id') self.deployment_id = attributes[:'deployment_id'] if attributes[:'deployment_id'] self.deployment_upgrade_type = attributes[:'deploymentUpgradeType'] if attributes[:'deploymentUpgradeType'] raise 'You cannot provide both :deploymentUpgradeType and :deployment_upgrade_type' if attributes.key?(:'deploymentUpgradeType') && attributes.key?(:'deployment_upgrade_type') self.deployment_upgrade_type = attributes[:'deployment_upgrade_type'] if attributes[:'deployment_upgrade_type'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] self.ogg_version = attributes[:'oggVersion'] if attributes[:'oggVersion'] raise 'You cannot provide both :oggVersion and :ogg_version' if attributes.key?(:'oggVersion') && attributes.key?(:'ogg_version') self.ogg_version = attributes[:'ogg_version'] if attributes[:'ogg_version'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_sub_state = attributes[:'lifecycleSubState'] if attributes[:'lifecycleSubState'] raise 'You cannot provide both :lifecycleSubState and :lifecycle_sub_state' if attributes.key?(:'lifecycleSubState') && attributes.key?(:'lifecycle_sub_state') self.lifecycle_sub_state = attributes[:'lifecycle_sub_state'] if attributes[:'lifecycle_sub_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
63 64 65 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 63 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
125 126 127 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 125 def @defined_tags end |
#deployment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
68 69 70 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 68 def deployment_id @deployment_id end |
#deployment_upgrade_type ⇒ String
[Required] The type of the deployment upgrade: MANUAL or AUTOMATIC
73 74 75 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 73 def deployment_upgrade_type @deployment_upgrade_type end |
#description ⇒ String
Metadata about this specific object.
58 59 60 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 58 def description @description end |
#display_name ⇒ String
An object’s Display Name.
53 54 55 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 53 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`
119 120 121 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 119 def @freeform_tags end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the deployment upgrade being referenced.
48 49 50 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 48 def id @id end |
#lifecycle_details ⇒ String
Describes the object’s current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.
113 114 115 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 113 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
Possible lifecycle states.
103 104 105 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 103 def lifecycle_state @lifecycle_state end |
#lifecycle_sub_state ⇒ String
Possible GGS lifecycle sub-states.
108 109 110 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 108 def lifecycle_sub_state @lifecycle_sub_state end |
#ogg_version ⇒ String
Version of OGG
88 89 90 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 88 def ogg_version @ogg_version end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{free-tier-retain: true}`
131 132 133 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 131 def @system_tags end |
#time_created ⇒ DateTime
The time the resource was created. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
93 94 95 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 93 def time_created @time_created end |
#time_finished ⇒ DateTime
The date and time the request was finished. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
83 84 85 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 83 def time_finished @time_finished end |
#time_started ⇒ DateTime
The date and time the request was started. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
78 79 80 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 78 def time_started @time_started end |
#time_updated ⇒ DateTime
The time the resource was last updated. The format is defined by [RFC3339](tools.ietf.org/html/rfc3339), such as 2016-08-25T21:10:29.600Z.
98 99 100 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 98 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 134 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'deployment_id': :'deploymentId', 'deployment_upgrade_type': :'deploymentUpgradeType', 'time_started': :'timeStarted', 'time_finished': :'timeFinished', 'ogg_version': :'oggVersion', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_sub_state': :'lifecycleSubState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 159 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'deployment_id': :'String', 'deployment_upgrade_type': :'String', 'time_started': :'DateTime', 'time_finished': :'DateTime', 'ogg_version': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_sub_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 353 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && deployment_id == other.deployment_id && deployment_upgrade_type == other.deployment_upgrade_type && time_started == other.time_started && time_finished == other.time_finished && ogg_version == other.ogg_version && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_sub_state == other.lifecycle_sub_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 399 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
379 380 381 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 379 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
388 389 390 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 388 def hash [id, display_name, description, compartment_id, deployment_id, deployment_upgrade_type, time_started, time_finished, ogg_version, time_created, time_updated, lifecycle_state, lifecycle_sub_state, lifecycle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
432 433 434 435 436 437 438 439 440 441 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 432 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
426 427 428 |
# File 'lib/oci/golden_gate/models/deployment_upgrade.rb', line 426 def to_s to_hash.to_s end |