Class: OCI::GoldenGate::Models::UpdateDatabaseRegistrationDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/golden_gate/models/update_database_registration_details.rb

Overview

The information to update for a DatabaseRegistration.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateDatabaseRegistrationDetails

Initializes the object

Options Hash (attributes):

  • :display_name (String)

    The value to assign to the #display_name property

  • :description (String)

    The value to assign to the #description property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :fqdn (String)

    The value to assign to the #fqdn property

  • :username (String)

    The value to assign to the #username property

  • :password (String)

    The value to assign to the #password property

  • :connection_string (String)

    The value to assign to the #connection_string property

  • :wallet (String)

    The value to assign to the #wallet property

  • :alias_name (String)

    The value to assign to the #alias_name property



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 115

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.fqdn = attributes[:'fqdn'] if attributes[:'fqdn']

  self.username = attributes[:'username'] if attributes[:'username']

  self.password = attributes[:'password'] if attributes[:'password']

  self.connection_string = attributes[:'connectionString'] if attributes[:'connectionString']

  raise 'You cannot provide both :connectionString and :connection_string' if attributes.key?(:'connectionString') && attributes.key?(:'connection_string')

  self.connection_string = attributes[:'connection_string'] if attributes[:'connection_string']

  self.wallet = attributes[:'wallet'] if attributes[:'wallet']

  self.alias_name = attributes[:'aliasName'] if attributes[:'aliasName']

  raise 'You cannot provide both :aliasName and :alias_name' if attributes.key?(:'aliasName') && attributes.key?(:'alias_name')

  self.alias_name = attributes[:'alias_name'] if attributes[:'alias_name']
end

Instance Attribute Details

#alias_nameString

Credential store alias.



61
62
63
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 61

def alias_name
  @alias_name
end

#connection_stringString

Connect descriptor or Easy Connect Naming method that Oracle GoldenGate uses to connect to a database.



51
52
53
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 51

def connection_string
  @connection_string
end

#defined_tagsHash<String, Hash<String, Object>>

Tags defined for this resource. Each key is predefined and scoped to a namespace. Example: ‘{\“bar-key\”: \“value\”}`



31
32
33
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 31

def defined_tags
  @defined_tags
end

#descriptionString

Metadata about this specific object.



19
20
21
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 19

def description
  @description
end

#display_nameString

An object’s Display Name.



14
15
16
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 14

def display_name
  @display_name
end

#fqdnString

A three-label Fully Qualified Domain Name (FQDN) for a resource.



36
37
38
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 36

def fqdn
  @fqdn
end

#freeform_tagsHash<String, String>

A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘\“value\”`



25
26
27
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 25

def freeform_tags
  @freeform_tags
end

#passwordString

The password Oracle GoldenGate uses to connect the associated RDBMS. It must conform to the specific security requirements implemented by the database including length, case sensitivity, and so on.



46
47
48
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 46

def password
  @password
end

#usernameString

The username Oracle GoldenGate uses to connect the associated RDBMS. This username must already exist and be available for use by the database. It must conform to the security requirements implemented by the database including length, case sensitivity, and so on.



41
42
43
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 41

def username
  @username
end

#walletString

The wallet contents Oracle GoldenGate uses to make connections to a database. This attribute is expected to be base64 encoded.



56
57
58
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 56

def wallet
  @wallet
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 64

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'description': :'description',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'fqdn': :'fqdn',
    'username': :'username',
    'password': :'password',
    'connection_string': :'connectionString',
    'wallet': :'wallet',
    'alias_name': :'aliasName'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 82

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'description': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'fqdn': :'String',
    'username': :'String',
    'password': :'String',
    'connection_string': :'String',
    'wallet': :'String',
    'alias_name': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 169

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    description == other.description &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    fqdn == other.fqdn &&
    username == other.username &&
    password == other.password &&
    connection_string == other.connection_string &&
    wallet == other.wallet &&
    alias_name == other.alias_name
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 208

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


188
189
190
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 188

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



197
198
199
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 197

def hash
  [display_name, description, freeform_tags, defined_tags, fqdn, username, password, connection_string, wallet, alias_name].hash
end

#to_hashHash

Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



235
236
237
# File 'lib/oci/golden_gate/models/update_database_registration_details.rb', line 235

def to_s
  to_hash.to_s
end