Class: OCI::Identity::Models::CreateTagDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/identity/models/create_tag_details.rb

Overview

CreateTagDetails model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateTagDetails

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/oci/identity/models/create_tag_details.rb', line 95

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.is_cost_tracking = attributes[:'isCostTracking'] unless attributes[:'isCostTracking'].nil?

  raise 'You cannot provide both :isCostTracking and :is_cost_tracking' if attributes.key?(:'isCostTracking') && attributes.key?(:'is_cost_tracking')

  self.is_cost_tracking = attributes[:'is_cost_tracking'] unless attributes[:'is_cost_tracking'].nil?

  self.validator = attributes[:'validator'] if attributes[:'validator']
end

Instance Attribute Details

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:



34
35
36
# File 'lib/oci/identity/models/create_tag_details.rb', line 34

def defined_tags
  @defined_tags
end

#descriptionString

[Required] The description you assign to the tag during creation.

Returns:



18
19
20
# File 'lib/oci/identity/models/create_tag_details.rb', line 18

def description
  @description
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:



26
27
28
# File 'lib/oci/identity/models/create_tag_details.rb', line 26

def freeform_tags
  @freeform_tags
end

#is_cost_trackingBOOLEAN

Indicates whether the tag is enabled for cost tracking.

Returns:



39
40
41
# File 'lib/oci/identity/models/create_tag_details.rb', line 39

def is_cost_tracking
  @is_cost_tracking
end

#nameString

[Required] The name you assign to the tag during creation. This is the tag key definition. The name must be unique within the tag namespace and cannot be changed.

Returns:



14
15
16
# File 'lib/oci/identity/models/create_tag_details.rb', line 14

def name
  @name
end

#validatorOCI::Identity::Models::BaseTagDefinitionValidator

The tag must have a value type, which is specified with a validator. Tags can use either a static value or a list of possible values. Static values are entered by a user applying the tag to a resource. Lists are created by you and the user must apply a value from the list. Lists are validiated.

If you use the default validiator (or don’t define a validator), the user applying the tag enters a value. No additional validation is performed.

To clear the validator, call UpdateTag with [DefaultTagDefinitionValidator](docs.cloud.oracle.com/api/#/en/identity/latest/datatypes/DefaultTagDefinitionValidator).

Returns:



53
54
55
# File 'lib/oci/identity/models/create_tag_details.rb', line 53

def validator
  @validator
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/identity/models/create_tag_details.rb', line 56

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'name',
    'description': :'description',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'is_cost_tracking': :'isCostTracking',
    'validator': :'validator'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/oci/identity/models/create_tag_details.rb', line 70

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'name': :'String',
    'description': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'is_cost_tracking': :'BOOLEAN',
    'validator': :'OCI::Identity::Models::BaseTagDefinitionValidator'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



133
134
135
136
137
138
139
140
141
142
143
# File 'lib/oci/identity/models/create_tag_details.rb', line 133

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    description == other.description &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    is_cost_tracking == other.is_cost_tracking &&
    validator == other.validator
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/oci/identity/models/create_tag_details.rb', line 168

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



148
149
150
# File 'lib/oci/identity/models/create_tag_details.rb', line 148

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



157
158
159
# File 'lib/oci/identity/models/create_tag_details.rb', line 157

def hash
  [name, description, freeform_tags, defined_tags, is_cost_tracking, validator].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



201
202
203
204
205
206
207
208
209
210
# File 'lib/oci/identity/models/create_tag_details.rb', line 201

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



195
196
197
# File 'lib/oci/identity/models/create_tag_details.rb', line 195

def to_s
  to_hash.to_s
end