Class: OCI::Identity::Models::DbCredentialSummary
- Inherits:
-
Object
- Object
- OCI::Identity::Models::DbCredentialSummary
- Defined in:
- lib/oci/identity/models/db_credential_summary.rb
Overview
As the name suggests, an DbCredentialSummary object contains information about an DbCredential. The DB credential is used for DB authentication with the [DB Service].
Instance Attribute Summary collapse
-
#description ⇒ String
The description you assign to the DB credential.
-
#id ⇒ String
The OCID of the DB credential.
-
#lifecycle_state ⇒ String
The credential’s current state.
-
#time_created ⇒ DateTime
Date and time the
DbCredentialobject was created, in the format defined by RFC3339. -
#time_expires ⇒ DateTime
Date and time when this credential will expire, in the format defined by RFC3339.
-
#user_id ⇒ String
The OCID of the user the DB credential belongs to.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbCredentialSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbCredentialSummary
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.user_id = attributes[:'userId'] if attributes[:'userId'] raise 'You cannot provide both :userId and :user_id' if attributes.key?(:'userId') && attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] if attributes[:'user_id'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_expires = attributes[:'timeExpires'] if attributes[:'timeExpires'] raise 'You cannot provide both :timeExpires and :time_expires' if attributes.key?(:'timeExpires') && attributes.key?(:'time_expires') self.time_expires = attributes[:'time_expires'] if attributes[:'time_expires'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#description ⇒ String
The description you assign to the DB credential. Does not have to be unique, and it’s changeable.
23 24 25 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 23 def description @description end |
#id ⇒ String
The OCID of the DB credential.
15 16 17 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 15 def id @id end |
#lifecycle_state ⇒ String
The credential’s current state. After creating a DB credential, make sure its lifecycleState changes from CREATING to ACTIVE before using it.
44 45 46 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 44 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
Date and time the DbCredential object was created, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
30 31 32 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 30 def time_created @time_created end |
#time_expires ⇒ DateTime
Date and time when this credential will expire, in the format defined by RFC3339. Null if it never expires.
Example: 2016-08-25T21:10:29.600Z
38 39 40 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 38 def time_expires @time_expires end |
#user_id ⇒ String
The OCID of the user the DB credential belongs to.
19 20 21 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 19 def user_id @user_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 47 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'user_id': :'userId', 'description': :'description', 'time_created': :'timeCreated', 'time_expires': :'timeExpires', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'user_id': :'String', 'description': :'String', 'time_created': :'DateTime', 'time_expires': :'DateTime', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 128 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && user_id == other.user_id && description == other.description && time_created == other.time_created && time_expires == other.time_expires && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 163 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
143 144 145 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 143 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 152 def hash [id, user_id, description, time_created, time_expires, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
190 191 192 |
# File 'lib/oci/identity/models/db_credential_summary.rb', line 190 def to_s to_hash.to_s end |