Class: OCI::Identity::Models::NetworkSourcesSummary
- Inherits:
-
Object
- Object
- OCI::Identity::Models::NetworkSourcesSummary
- Defined in:
- lib/oci/identity/models/network_sources_summary.rb
Overview
A network source specifies a list of source IP addresses that are allowed to make authorization requests. Use the network source in policy statements to restrict access to only requests that come from the specified IPs. For more information, see [Managing Network Sources](docs.cloud.oracle.com/Content/Identity/Tasks/managingnetworksources.htm).
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the tenancy (root compartment) containing the network source.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description you assign to the network source.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
The OCID of the network source.
-
#name ⇒ String
The name you assign to the network source during creation.
-
#public_source_list ⇒ Array<String>
A list of allowed public IP addresses and CIDR ranges.
-
#services ⇒ Array<String>
A list of services allowed to make on-behalf-of requests.
-
#time_created ⇒ DateTime
Date and time the group was created, in the format defined by RFC3339.
-
#virtual_source_list ⇒ Array<OCI::Identity::Models::NetworkSourcesVirtualSourceList>
A list of allowed VCN OCID and IP range pairs.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkSourcesSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NetworkSourcesSummary
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 121 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.public_source_list = attributes[:'publicSourceList'] if attributes[:'publicSourceList'] raise 'You cannot provide both :publicSourceList and :public_source_list' if attributes.key?(:'publicSourceList') && attributes.key?(:'public_source_list') self.public_source_list = attributes[:'public_source_list'] if attributes[:'public_source_list'] self.virtual_source_list = attributes[:'virtualSourceList'] if attributes[:'virtualSourceList'] raise 'You cannot provide both :virtualSourceList and :virtual_source_list' if attributes.key?(:'virtualSourceList') && attributes.key?(:'virtual_source_list') self.virtual_source_list = attributes[:'virtual_source_list'] if attributes[:'virtual_source_list'] self.services = attributes[:'services'] if attributes[:'services'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the tenancy (root compartment) containing the network source.
19 20 21 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 19 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
67 68 69 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 67 def end |
#description ⇒ String
The description you assign to the network source. Does not have to be unique, and it’s changeable.
29 30 31 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 29 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
60 61 62 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 60 def end |
#id ⇒ String
The OCID of the network source.
15 16 17 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 15 def id @id end |
#name ⇒ String
The name you assign to the network source during creation. The name must be unique across the tenancy and cannot be changed.
25 26 27 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 25 def name @name end |
#public_source_list ⇒ Array<String>
A list of allowed public IP addresses and CIDR ranges.
34 35 36 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 34 def public_source_list @public_source_list end |
#services ⇒ Array<String>
A list of services allowed to make on-behalf-of requests. These requests can have different source IPs than those specified in the network source. Currently, only all and none are supported. The default is all.
46 47 48 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 46 def services @services end |
#time_created ⇒ DateTime
Date and time the group was created, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
53 54 55 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 53 def time_created @time_created end |
#virtual_source_list ⇒ Array<OCI::Identity::Models::NetworkSourcesVirtualSourceList>
A list of allowed VCN OCID and IP range pairs. Example:‘"vcnId": "ocid1.vcn.oc1.iad.aaaaaaaaexampleuniqueID", "ipRanges": [ "129.213.39.0/24" ]`
40 41 42 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 40 def virtual_source_list @virtual_source_list end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 70 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'public_source_list': :'publicSourceList', 'virtual_source_list': :'virtualSourceList', 'services': :'services', 'time_created': :'timeCreated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 88 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'public_source_list': :'Array<String>', 'virtual_source_list': :'Array<OCI::Identity::Models::NetworkSourcesVirtualSourceList>', 'services': :'Array<String>', 'time_created': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 179 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && name == other.name && description == other.description && public_source_list == other.public_source_list && virtual_source_list == other.virtual_source_list && services == other.services && time_created == other.time_created && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 218 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
198 199 200 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 198 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 207 def hash [id, compartment_id, name, description, public_source_list, virtual_source_list, services, time_created, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 251 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
245 246 247 |
# File 'lib/oci/identity/models/network_sources_summary.rb', line 245 def to_s to_hash.to_s end |