Class: OCI::Identity::Models::NetworkSourcesSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/identity/models/network_sources_summary.rb

Overview

A network source defines a list of source IPs that are allowed to make auth requests More info needed here

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ NetworkSourcesSummary

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/oci/identity/models/network_sources_summary.rb', line 98

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.public_source_list = attributes[:'publicSourceList'] if attributes[:'publicSourceList']

  raise 'You cannot provide both :publicSourceList and :public_source_list' if attributes.key?(:'publicSourceList') && attributes.key?(:'public_source_list')

  self.public_source_list = attributes[:'public_source_list'] if attributes[:'public_source_list']

  self.virtual_source_list = attributes[:'virtualSourceList'] if attributes[:'virtualSourceList']

  raise 'You cannot provide both :virtualSourceList and :virtual_source_list' if attributes.key?(:'virtualSourceList') && attributes.key?(:'virtual_source_list')

  self.virtual_source_list = attributes[:'virtual_source_list'] if attributes[:'virtual_source_list']

  self.services = attributes[:'services'] if attributes[:'services']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']
end

Instance Attribute Details

#compartment_idString

The OCID of the tenancy containing the network source.

Returns:



17
18
19
# File 'lib/oci/identity/models/network_sources_summary.rb', line 17

def compartment_id
  @compartment_id
end

#descriptionString

The description you assign to the network source. Does not have to be unique, and it’s changeable.

Returns:



27
28
29
# File 'lib/oci/identity/models/network_sources_summary.rb', line 27

def description
  @description
end

#idString

The OCID of the network source.

Returns:



13
14
15
# File 'lib/oci/identity/models/network_sources_summary.rb', line 13

def id
  @id
end

#nameString

The name you assign to the network source during creation. The name must be unique across the tenancy and cannot be changed.

Returns:



23
24
25
# File 'lib/oci/identity/models/network_sources_summary.rb', line 23

def name
  @name
end

#public_source_listArray<String>

A list of allowed public IPs and CIDR ranges

Returns:



32
33
34
# File 'lib/oci/identity/models/network_sources_summary.rb', line 32

def public_source_list
  @public_source_list
end

#servicesArray<String>

A list of OCIservices allowed to make on behalf of requests which may have different source ips. At this time only the values of all or none are supported.

Returns:



43
44
45
# File 'lib/oci/identity/models/network_sources_summary.rb', line 43

def services
  @services
end

#time_createdDateTime

Date and time the group was created, in the format defined by RFC3339.

Example: 2016-08-25T21:10:29.600Z

Returns:



50
51
52
# File 'lib/oci/identity/models/network_sources_summary.rb', line 50

def time_created
  @time_created
end

#virtual_source_listArray<OCI::Identity::Models::NetworkSourcesVirtualSourceList>

A list of allowed VCN ocid/IP range pairs

Returns:



37
38
39
# File 'lib/oci/identity/models/network_sources_summary.rb', line 37

def virtual_source_list
  @virtual_source_list
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/identity/models/network_sources_summary.rb', line 53

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'name': :'name',
    'description': :'description',
    'public_source_list': :'publicSourceList',
    'virtual_source_list': :'virtualSourceList',
    'services': :'services',
    'time_created': :'timeCreated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/identity/models/network_sources_summary.rb', line 69

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'name': :'String',
    'description': :'String',
    'public_source_list': :'Array<String>',
    'virtual_source_list': :'Array<OCI::Identity::Models::NetworkSourcesVirtualSourceList>',
    'services': :'Array<String>',
    'time_created': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/identity/models/network_sources_summary.rb', line 144

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    name == other.name &&
    description == other.description &&
    public_source_list == other.public_source_list &&
    virtual_source_list == other.virtual_source_list &&
    services == other.services &&
    time_created == other.time_created
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/oci/identity/models/network_sources_summary.rb', line 181

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


161
162
163
# File 'lib/oci/identity/models/network_sources_summary.rb', line 161

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



170
171
172
# File 'lib/oci/identity/models/network_sources_summary.rb', line 170

def hash
  [id, compartment_id, name, description, public_source_list, virtual_source_list, services, time_created].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
# File 'lib/oci/identity/models/network_sources_summary.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



208
209
210
# File 'lib/oci/identity/models/network_sources_summary.rb', line 208

def to_s
  to_hash.to_s
end