Class: OCI::Identity::Models::Saml2IdentityProvider
- Inherits:
-
IdentityProvider
- Object
- IdentityProvider
- OCI::Identity::Models::Saml2IdentityProvider
- Defined in:
- lib/oci/identity/models/saml2_identity_provider.rb
Overview
A special type of IdentityProvider that supports the SAML 2.0 protocol. For more information, see [Identity Providers and Federation](docs.cloud.oracle.com/Content/Identity/Concepts/federation.htm).
Constant Summary
Constants inherited from IdentityProvider
IdentityProvider::LIFECYCLE_STATE_ENUM
Instance Attribute Summary collapse
-
#freeform_attributes ⇒ Hash<String, String>
Extra name value pairs associated with this identity provider.
-
#metadata ⇒ String
The XML that contains the information required for federating Identity with SAML2 Identity Provider.
-
#metadata_url ⇒ String
[Required] The URL for retrieving the identity provider’s metadata, which contains information required for federating.
-
#redirect_url ⇒ String
[Required] The URL to redirect federated users to for authentication with the identity provider.
-
#signing_certificate ⇒ String
[Required] The identity provider’s signing certificate used by the IAM Service to validate the SAML2 token.
Attributes inherited from IdentityProvider
#compartment_id, #defined_tags, #description, #freeform_tags, #id, #inactive_status, #lifecycle_state, #name, #product_type, #protocol, #time_created
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Saml2IdentityProvider
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from IdentityProvider
Constructor Details
#initialize(attributes = {}) ⇒ Saml2IdentityProvider
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 112 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['protocol'] = 'SAML2' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self. = attributes[:'metadataUrl'] if attributes[:'metadataUrl'] raise 'You cannot provide both :metadataUrl and :metadata_url' if attributes.key?(:'metadataUrl') && attributes.key?(:'metadata_url') self. = attributes[:'metadata_url'] if attributes[:'metadata_url'] self. = attributes[:'metadata'] if attributes[:'metadata'] self.signing_certificate = attributes[:'signingCertificate'] if attributes[:'signingCertificate'] raise 'You cannot provide both :signingCertificate and :signing_certificate' if attributes.key?(:'signingCertificate') && attributes.key?(:'signing_certificate') self.signing_certificate = attributes[:'signing_certificate'] if attributes[:'signing_certificate'] self.redirect_url = attributes[:'redirectUrl'] if attributes[:'redirectUrl'] raise 'You cannot provide both :redirectUrl and :redirect_url' if attributes.key?(:'redirectUrl') && attributes.key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] if attributes[:'redirect_url'] self.freeform_attributes = attributes[:'freeformAttributes'] if attributes[:'freeformAttributes'] raise 'You cannot provide both :freeformAttributes and :freeform_attributes' if attributes.key?(:'freeformAttributes') && attributes.key?(:'freeform_attributes') self.freeform_attributes = attributes[:'freeform_attributes'] if attributes[:'freeform_attributes'] end |
Instance Attribute Details
#freeform_attributes ⇒ Hash<String, String>
Extra name value pairs associated with this identity provider. Example: ‘"app_sf3kdjf3"`
41 42 43 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 41 def freeform_attributes @freeform_attributes end |
#metadata ⇒ String
The XML that contains the information required for federating Identity with SAML2 Identity Provider.
23 24 25 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 23 def end |
#metadata_url ⇒ String
[Required] The URL for retrieving the identity provider’s metadata, which contains information required for federating.
18 19 20 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 18 def end |
#redirect_url ⇒ String
[Required] The URL to redirect federated users to for authentication with the identity provider.
35 36 37 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 35 def redirect_url @redirect_url end |
#signing_certificate ⇒ String
[Required] The identity provider’s signing certificate used by the IAM Service to validate the SAML2 token.
29 30 31 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 29 def signing_certificate @signing_certificate end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'product_type': :'productType', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'inactive_status': :'inactiveStatus', 'protocol': :'protocol', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'metadata_url': :'metadataUrl', 'metadata': :'metadata', 'signing_certificate': :'signingCertificate', 'redirect_url': :'redirectUrl', 'freeform_attributes': :'freeformAttributes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'product_type': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'inactive_status': :'Integer', 'protocol': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'metadata_url': :'String', 'metadata': :'String', 'signing_certificate': :'String', 'redirect_url': :'String', 'freeform_attributes': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 156 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && name == other.name && description == other.description && product_type == other.product_type && time_created == other.time_created && lifecycle_state == other.lifecycle_state && inactive_status == other.inactive_status && protocol == other.protocol && == other. && == other. && == other. && == other. && signing_certificate == other.signing_certificate && redirect_url == other.redirect_url && freeform_attributes == other.freeform_attributes end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 201 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
181 182 183 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 181 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
190 191 192 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 190 def hash [id, compartment_id, name, description, product_type, time_created, lifecycle_state, inactive_status, protocol, , , , , signing_certificate, redirect_url, freeform_attributes].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 243 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
228 229 230 |
# File 'lib/oci/identity/models/saml2_identity_provider.rb', line 228 def to_s to_hash.to_s end |