Class: OCI::Identity::Models::User

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/identity/models/user.rb

Overview

An individual employee or system that needs to manage or use your company’s Oracle Cloud Infrastructure resources. Users might need to launch instances, manage remote disks, work with your cloud network, etc. Users have one or more IAM Service credentials (ApiKey, UIPassword, SwiftPassword and AuthToken). For more information, see [User Credentials](docs.cloud.oracle.com/Content/Identity/Concepts/usercredentials.htm)). End users of your application are not typically IAM Service users. For conceptual information about users and other IAM Service components, see [Overview of the IAM Service](docs.cloud.oracle.com/Content/Identity/Concepts/overview.htm).

These users are created directly within the Oracle Cloud Infrastructure system, via the IAM service. They are different from *federated users*, who authenticate themselves to the Oracle Cloud Infrastructure Console via an identity provider. For more information, see [Identity Providers and Federation](docs.cloud.oracle.com/Content/Identity/Concepts/federation.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ User

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/oci/identity/models/user.rb', line 231

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.email = attributes[:'email'] if attributes[:'email']

  self.email_verified = attributes[:'emailVerified'] unless attributes[:'emailVerified'].nil?

  raise 'You cannot provide both :emailVerified and :email_verified' if attributes.key?(:'emailVerified') && attributes.key?(:'email_verified')

  self.email_verified = attributes[:'email_verified'] unless attributes[:'email_verified'].nil?

  self.db_user_name = attributes[:'dbUserName'] if attributes[:'dbUserName']

  raise 'You cannot provide both :dbUserName and :db_user_name' if attributes.key?(:'dbUserName') && attributes.key?(:'db_user_name')

  self.db_user_name = attributes[:'db_user_name'] if attributes[:'db_user_name']

  self.identity_provider_id = attributes[:'identityProviderId'] if attributes[:'identityProviderId']

  raise 'You cannot provide both :identityProviderId and :identity_provider_id' if attributes.key?(:'identityProviderId') && attributes.key?(:'identity_provider_id')

  self.identity_provider_id = attributes[:'identity_provider_id'] if attributes[:'identity_provider_id']

  self.external_identifier = attributes[:'externalIdentifier'] if attributes[:'externalIdentifier']

  raise 'You cannot provide both :externalIdentifier and :external_identifier' if attributes.key?(:'externalIdentifier') && attributes.key?(:'external_identifier')

  self.external_identifier = attributes[:'external_identifier'] if attributes[:'external_identifier']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.inactive_status = attributes[:'inactiveStatus'] if attributes[:'inactiveStatus']

  raise 'You cannot provide both :inactiveStatus and :inactive_status' if attributes.key?(:'inactiveStatus') && attributes.key?(:'inactive_status')

  self.inactive_status = attributes[:'inactive_status'] if attributes[:'inactive_status']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.capabilities = attributes[:'capabilities'] if attributes[:'capabilities']

  self.is_mfa_activated = attributes[:'isMfaActivated'] unless attributes[:'isMfaActivated'].nil?

  raise 'You cannot provide both :isMfaActivated and :is_mfa_activated' if attributes.key?(:'isMfaActivated') && attributes.key?(:'is_mfa_activated')

  self.is_mfa_activated = attributes[:'is_mfa_activated'] unless attributes[:'is_mfa_activated'].nil?

  self. = attributes[:'lastSuccessfulLoginTime'] if attributes[:'lastSuccessfulLoginTime']

  raise 'You cannot provide both :lastSuccessfulLoginTime and :last_successful_login_time' if attributes.key?(:'lastSuccessfulLoginTime') && attributes.key?(:'last_successful_login_time')

  self. = attributes[:'last_successful_login_time'] if attributes[:'last_successful_login_time']

  self. = attributes[:'previousSuccessfulLoginTime'] if attributes[:'previousSuccessfulLoginTime']

  raise 'You cannot provide both :previousSuccessfulLoginTime and :previous_successful_login_time' if attributes.key?(:'previousSuccessfulLoginTime') && attributes.key?(:'previous_successful_login_time')

  self. = attributes[:'previous_successful_login_time'] if attributes[:'previous_successful_login_time']
end

Instance Attribute Details

#capabilitiesOCI::Identity::Models::UserCapabilities



119
120
121
# File 'lib/oci/identity/models/user.rb', line 119

def capabilities
  @capabilities
end

#compartment_idString

[Required] The OCID of the tenancy containing the user.

Returns:

  • (String)


46
47
48
# File 'lib/oci/identity/models/user.rb', line 46

def compartment_id
  @compartment_id
end

#db_user_nameString

DB username of the DB credential. Has to be unique across the tenancy.

Returns:

  • (String)


70
71
72
# File 'lib/oci/identity/models/user.rb', line 70

def db_user_name
  @db_user_name
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


116
117
118
# File 'lib/oci/identity/models/user.rb', line 116

def defined_tags
  @defined_tags
end

#descriptionString

[Required] The description you assign to the user. Does not have to be unique, and it’s changeable.

Returns:

  • (String)


56
57
58
# File 'lib/oci/identity/models/user.rb', line 56

def description
  @description
end

#emailString

The email address you assign to the user. The email address must be unique across all users in the tenancy.

Returns:

  • (String)


62
63
64
# File 'lib/oci/identity/models/user.rb', line 62

def email
  @email
end

#email_verifiedBOOLEAN

Whether the email address has been validated.

Returns:

  • (BOOLEAN)


66
67
68
# File 'lib/oci/identity/models/user.rb', line 66

def email_verified
  @email_verified
end

#external_identifierString

Identifier of the user in the identity provider

Returns:

  • (String)


78
79
80
# File 'lib/oci/identity/models/user.rb', line 78

def external_identifier
  @external_identifier
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


109
110
111
# File 'lib/oci/identity/models/user.rb', line 109

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the user.

Returns:

  • (String)


42
43
44
# File 'lib/oci/identity/models/user.rb', line 42

def id
  @id
end

#identity_provider_idString

The OCID of the IdentityProvider this user belongs to.

Returns:

  • (String)


74
75
76
# File 'lib/oci/identity/models/user.rb', line 74

def identity_provider_id
  @identity_provider_id
end

#inactive_statusInteger

Returned only if the user’s lifecycleState is INACTIVE. A 16-bit value showing the reason why the user is inactive:

  • bit 0: SUSPENDED (reserved for future use)

  • bit 1: DISABLED (reserved for future use)

  • bit 2: BLOCKED (the user has exceeded the maximum number of failed login attempts for the Console)

Returns:

  • (Integer)


101
102
103
# File 'lib/oci/identity/models/user.rb', line 101

def inactive_status
  @inactive_status
end

#is_mfa_activatedBOOLEAN

[Required] Flag indicates if MFA has been activated for the user.

Returns:

  • (BOOLEAN)


123
124
125
# File 'lib/oci/identity/models/user.rb', line 123

def is_mfa_activated
  @is_mfa_activated
end

#last_successful_login_timeDateTime

The date and time of when the user most recently logged in the format defined by RFC3339 (ex. 2016-08-25T21:10:29.600Z). If there is no login history, this field is null.

For illustrative purposes, suppose we have a user who has logged in at July 1st, 2020 at 1200 PST and logged out 30 minutes later. They then login again on July 2nd, 2020 at 1500 PST.

Their previousSuccessfulLoginTime would be 2020-07-01:19:00.000Z.

Their lastSuccessfulLoginTime would be 2020-07-02:22:00.000Z.

Returns:

  • (DateTime)


138
139
140
# File 'lib/oci/identity/models/user.rb', line 138

def 
  
end

#lifecycle_stateString

[Required] The user’s current state. After creating a user, make sure its lifecycleState changes from CREATING to ACTIVE before using it.

Returns:

  • (String)


91
92
93
# File 'lib/oci/identity/models/user.rb', line 91

def lifecycle_state
  @lifecycle_state
end

#nameString

[Required] The name you assign to the user during creation. This is the user’s login for the Console. The name must be unique across all users in the tenancy and cannot be changed.

Returns:

  • (String)


52
53
54
# File 'lib/oci/identity/models/user.rb', line 52

def name
  @name
end

#previous_successful_login_timeDateTime

The date and time of when the user most recently logged in the format defined by RFC3339 (ex. 2016-08-25T21:10:29.600Z). If there is no login history, this field is null.

For illustrative purposes, suppose we have a user who has logged in at July 1st, 2020 at 1200 PST and logged out 30 minutes later. They then login again on July 2nd, 2020 at 1500 PST.

Their previousSuccessfulLoginTime would be 2020-07-01:19:00.000Z.

Their lastSuccessfulLoginTime would be 2020-07-02:22:00.000Z.

Returns:

  • (DateTime)


153
154
155
# File 'lib/oci/identity/models/user.rb', line 153

def 
  
end

#time_createdDateTime

[Required] Date and time the user was created, in the format defined by RFC3339.

Example: 2016-08-25T21:10:29.600Z

Returns:

  • (DateTime)


85
86
87
# File 'lib/oci/identity/models/user.rb', line 85

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/oci/identity/models/user.rb', line 156

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'name': :'name',
    'description': :'description',
    'email': :'email',
    'email_verified': :'emailVerified',
    'db_user_name': :'dbUserName',
    'identity_provider_id': :'identityProviderId',
    'external_identifier': :'externalIdentifier',
    'time_created': :'timeCreated',
    'lifecycle_state': :'lifecycleState',
    'inactive_status': :'inactiveStatus',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'capabilities': :'capabilities',
    'is_mfa_activated': :'isMfaActivated',
    'last_successful_login_time': :'lastSuccessfulLoginTime',
    'previous_successful_login_time': :'previousSuccessfulLoginTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/oci/identity/models/user.rb', line 182

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'name': :'String',
    'description': :'String',
    'email': :'String',
    'email_verified': :'BOOLEAN',
    'db_user_name': :'String',
    'identity_provider_id': :'String',
    'external_identifier': :'String',
    'time_created': :'DateTime',
    'lifecycle_state': :'String',
    'inactive_status': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'capabilities': :'OCI::Identity::Models::UserCapabilities',
    'is_mfa_activated': :'BOOLEAN',
    'last_successful_login_time': :'DateTime',
    'previous_successful_login_time': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/oci/identity/models/user.rb', line 346

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    name == other.name &&
    description == other.description &&
    email == other.email &&
    email_verified == other.email_verified &&
    db_user_name == other.db_user_name &&
    identity_provider_id == other.identity_provider_id &&
    external_identifier == other.external_identifier &&
    time_created == other.time_created &&
    lifecycle_state == other.lifecycle_state &&
    inactive_status == other.inactive_status &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    capabilities == other.capabilities &&
    is_mfa_activated == other.is_mfa_activated &&
     == other. &&
     == other.
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/oci/identity/models/user.rb', line 393

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


373
374
375
# File 'lib/oci/identity/models/user.rb', line 373

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



382
383
384
# File 'lib/oci/identity/models/user.rb', line 382

def hash
  [id, compartment_id, name, description, email, email_verified, db_user_name, identity_provider_id, external_identifier, time_created, lifecycle_state, inactive_status, freeform_tags, defined_tags, capabilities, is_mfa_activated, , ].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



426
427
428
429
430
431
432
433
434
435
# File 'lib/oci/identity/models/user.rb', line 426

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



420
421
422
# File 'lib/oci/identity/models/user.rb', line 420

def to_s
  to_hash.to_s
end