Class: OCI::Identity::Models::User
- Inherits:
-
Object
- Object
- OCI::Identity::Models::User
- Defined in:
- lib/oci/identity/models/user.rb
Overview
An individual employee or system that needs to manage or use your company’s Oracle Cloud Infrastructure resources. Users might need to launch instances, manage remote disks, work with your cloud network, etc. Users have one or more IAM Service credentials (ApiKey, UIPassword, SwiftPassword and AuthToken). For more information, see [User Credentials](docs.cloud.oracle.com/Content/Identity/Concepts/usercredentials.htm)). End users of your application are not typically IAM Service users. For conceptual information about users and other IAM Service components, see [Overview of the IAM Service](docs.cloud.oracle.com/Content/Identity/Concepts/overview.htm).
These users are created directly within the Oracle Cloud Infrastructure system, via the IAM service. They are different from *federated users*, who authenticate themselves to the Oracle Cloud Infrastructure Console via an identity provider. For more information, see [Identity Providers and Federation](docs.cloud.oracle.com/Content/Identity/Concepts/federation.htm).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #capabilities ⇒ OCI::Identity::Models::UserCapabilities
-
#compartment_id ⇒ String
[Required] The OCID of the tenancy containing the user.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
[Required] The description you assign to the user.
-
#email ⇒ String
The email address you assign to the user.
-
#email_verified ⇒ BOOLEAN
Whether the email address has been validated.
-
#external_identifier ⇒ String
Identifier of the user in the identity provider.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The OCID of the user.
-
#identity_provider_id ⇒ String
The OCID of the
IdentityProviderthis user belongs to. -
#inactive_status ⇒ Integer
Returned only if the user’s
lifecycleStateis INACTIVE. -
#is_mfa_activated ⇒ BOOLEAN
[Required] Flag indicates if MFA has been activated for the user.
-
#last_successful_login_time ⇒ DateTime
The date and time of when the user most recently logged in the format defined by RFC3339 (ex.
2016-08-25T21:10:29.600Z). -
#lifecycle_state ⇒ String
[Required] The user’s current state.
-
#name ⇒ String
[Required] The name you assign to the user during creation.
-
#previous_successful_login_time ⇒ DateTime
The date and time of when the user most recently logged in the format defined by RFC3339 (ex.
2016-08-25T21:10:29.600Z). -
#time_created ⇒ DateTime
[Required] Date and time the user was created, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ User
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ User
Initializes the object
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/oci/identity/models/user.rb', line 224 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.email = attributes[:'email'] if attributes[:'email'] self.email_verified = attributes[:'emailVerified'] unless attributes[:'emailVerified'].nil? raise 'You cannot provide both :emailVerified and :email_verified' if attributes.key?(:'emailVerified') && attributes.key?(:'email_verified') self.email_verified = attributes[:'email_verified'] unless attributes[:'email_verified'].nil? self.identity_provider_id = attributes[:'identityProviderId'] if attributes[:'identityProviderId'] raise 'You cannot provide both :identityProviderId and :identity_provider_id' if attributes.key?(:'identityProviderId') && attributes.key?(:'identity_provider_id') self.identity_provider_id = attributes[:'identity_provider_id'] if attributes[:'identity_provider_id'] self.external_identifier = attributes[:'externalIdentifier'] if attributes[:'externalIdentifier'] raise 'You cannot provide both :externalIdentifier and :external_identifier' if attributes.key?(:'externalIdentifier') && attributes.key?(:'external_identifier') self.external_identifier = attributes[:'external_identifier'] if attributes[:'external_identifier'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.inactive_status = attributes[:'inactiveStatus'] if attributes[:'inactiveStatus'] raise 'You cannot provide both :inactiveStatus and :inactive_status' if attributes.key?(:'inactiveStatus') && attributes.key?(:'inactive_status') self.inactive_status = attributes[:'inactive_status'] if attributes[:'inactive_status'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.capabilities = attributes[:'capabilities'] if attributes[:'capabilities'] self.is_mfa_activated = attributes[:'isMfaActivated'] unless attributes[:'isMfaActivated'].nil? raise 'You cannot provide both :isMfaActivated and :is_mfa_activated' if attributes.key?(:'isMfaActivated') && attributes.key?(:'is_mfa_activated') self.is_mfa_activated = attributes[:'is_mfa_activated'] unless attributes[:'is_mfa_activated'].nil? self.last_successful_login_time = attributes[:'lastSuccessfulLoginTime'] if attributes[:'lastSuccessfulLoginTime'] raise 'You cannot provide both :lastSuccessfulLoginTime and :last_successful_login_time' if attributes.key?(:'lastSuccessfulLoginTime') && attributes.key?(:'last_successful_login_time') self.last_successful_login_time = attributes[:'last_successful_login_time'] if attributes[:'last_successful_login_time'] self.previous_successful_login_time = attributes[:'previousSuccessfulLoginTime'] if attributes[:'previousSuccessfulLoginTime'] raise 'You cannot provide both :previousSuccessfulLoginTime and :previous_successful_login_time' if attributes.key?(:'previousSuccessfulLoginTime') && attributes.key?(:'previous_successful_login_time') self.previous_successful_login_time = attributes[:'previous_successful_login_time'] if attributes[:'previous_successful_login_time'] end |
Instance Attribute Details
#capabilities ⇒ OCI::Identity::Models::UserCapabilities
115 116 117 |
# File 'lib/oci/identity/models/user.rb', line 115 def capabilities @capabilities end |
#compartment_id ⇒ String
[Required] The OCID of the tenancy containing the user.
46 47 48 |
# File 'lib/oci/identity/models/user.rb', line 46 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
112 113 114 |
# File 'lib/oci/identity/models/user.rb', line 112 def end |
#description ⇒ String
[Required] The description you assign to the user. Does not have to be unique, and it’s changeable.
56 57 58 |
# File 'lib/oci/identity/models/user.rb', line 56 def description @description end |
#email ⇒ String
The email address you assign to the user. The email address must be unique across all users in the tenancy.
62 63 64 |
# File 'lib/oci/identity/models/user.rb', line 62 def email @email end |
#email_verified ⇒ BOOLEAN
Whether the email address has been validated.
66 67 68 |
# File 'lib/oci/identity/models/user.rb', line 66 def email_verified @email_verified end |
#external_identifier ⇒ String
Identifier of the user in the identity provider
74 75 76 |
# File 'lib/oci/identity/models/user.rb', line 74 def external_identifier @external_identifier end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
105 106 107 |
# File 'lib/oci/identity/models/user.rb', line 105 def end |
#id ⇒ String
[Required] The OCID of the user.
42 43 44 |
# File 'lib/oci/identity/models/user.rb', line 42 def id @id end |
#identity_provider_id ⇒ String
The OCID of the IdentityProvider this user belongs to.
70 71 72 |
# File 'lib/oci/identity/models/user.rb', line 70 def identity_provider_id @identity_provider_id end |
#inactive_status ⇒ Integer
Returned only if the user’s lifecycleState is INACTIVE. A 16-bit value showing the reason why the user is inactive:
-
bit 0: SUSPENDED (reserved for future use)
-
bit 1: DISABLED (reserved for future use)
-
bit 2: BLOCKED (the user has exceeded the maximum number of failed login attempts for the Console)
97 98 99 |
# File 'lib/oci/identity/models/user.rb', line 97 def inactive_status @inactive_status end |
#is_mfa_activated ⇒ BOOLEAN
[Required] Flag indicates if MFA has been activated for the user.
119 120 121 |
# File 'lib/oci/identity/models/user.rb', line 119 def is_mfa_activated @is_mfa_activated end |
#last_successful_login_time ⇒ DateTime
The date and time of when the user most recently logged in the format defined by RFC3339 (ex. 2016-08-25T21:10:29.600Z). If there is no login history, this field is null.
For illustrative purposes, suppose we have a user who has logged in at July 1st, 2020 at 1200 PST and logged out 30 minutes later. They then login again on July 2nd, 2020 at 1500 PST.
Their previousSuccessfulLoginTime would be 2020-07-01:19:00.000Z.
Their lastSuccessfulLoginTime would be 2020-07-02:22:00.000Z.
134 135 136 |
# File 'lib/oci/identity/models/user.rb', line 134 def last_successful_login_time @last_successful_login_time end |
#lifecycle_state ⇒ String
[Required] The user’s current state. After creating a user, make sure its lifecycleState changes from CREATING to ACTIVE before using it.
87 88 89 |
# File 'lib/oci/identity/models/user.rb', line 87 def lifecycle_state @lifecycle_state end |
#name ⇒ String
[Required] The name you assign to the user during creation. This is the user’s login for the Console. The name must be unique across all users in the tenancy and cannot be changed.
52 53 54 |
# File 'lib/oci/identity/models/user.rb', line 52 def name @name end |
#previous_successful_login_time ⇒ DateTime
The date and time of when the user most recently logged in the format defined by RFC3339 (ex. 2016-08-25T21:10:29.600Z). If there is no login history, this field is null.
For illustrative purposes, suppose we have a user who has logged in at July 1st, 2020 at 1200 PST and logged out 30 minutes later. They then login again on July 2nd, 2020 at 1500 PST.
Their previousSuccessfulLoginTime would be 2020-07-01:19:00.000Z.
Their lastSuccessfulLoginTime would be 2020-07-02:22:00.000Z.
149 150 151 |
# File 'lib/oci/identity/models/user.rb', line 149 def previous_successful_login_time @previous_successful_login_time end |
#time_created ⇒ DateTime
[Required] Date and time the user was created, in the format defined by RFC3339.
Example: 2016-08-25T21:10:29.600Z
81 82 83 |
# File 'lib/oci/identity/models/user.rb', line 81 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/identity/models/user.rb', line 152 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'email': :'email', 'email_verified': :'emailVerified', 'identity_provider_id': :'identityProviderId', 'external_identifier': :'externalIdentifier', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'inactive_status': :'inactiveStatus', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'capabilities': :'capabilities', 'is_mfa_activated': :'isMfaActivated', 'last_successful_login_time': :'lastSuccessfulLoginTime', 'previous_successful_login_time': :'previousSuccessfulLoginTime' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/identity/models/user.rb', line 177 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'email': :'String', 'email_verified': :'BOOLEAN', 'identity_provider_id': :'String', 'external_identifier': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'inactive_status': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'capabilities': :'OCI::Identity::Models::UserCapabilities', 'is_mfa_activated': :'BOOLEAN', 'last_successful_login_time': :'DateTime', 'previous_successful_login_time': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/oci/identity/models/user.rb', line 333 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && name == other.name && description == other.description && email == other.email && email_verified == other.email_verified && identity_provider_id == other.identity_provider_id && external_identifier == other.external_identifier && time_created == other.time_created && lifecycle_state == other.lifecycle_state && inactive_status == other.inactive_status && == other. && == other. && capabilities == other.capabilities && is_mfa_activated == other.is_mfa_activated && last_successful_login_time == other.last_successful_login_time && previous_successful_login_time == other.previous_successful_login_time end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/oci/identity/models/user.rb', line 379 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
359 360 361 |
# File 'lib/oci/identity/models/user.rb', line 359 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
368 369 370 |
# File 'lib/oci/identity/models/user.rb', line 368 def hash [id, compartment_id, name, description, email, email_verified, identity_provider_id, external_identifier, time_created, lifecycle_state, inactive_status, , , capabilities, is_mfa_activated, last_successful_login_time, previous_successful_login_time].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
412 413 414 415 416 417 418 419 420 421 |
# File 'lib/oci/identity/models/user.rb', line 412 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
406 407 408 |
# File 'lib/oci/identity/models/user.rb', line 406 def to_s to_hash.to_s end |