Class: OCI::Integration::Models::CreateIntegrationInstanceDetails
- Inherits:
-
Object
- Object
- OCI::Integration::Models::CreateIntegrationInstanceDetails
- Defined in:
- lib/oci/integration/models/create_integration_instance_details.rb
Overview
The information about new IntegrationInstance.
Constant Summary collapse
- INTEGRATION_INSTANCE_TYPE_ENUM =
[ INTEGRATION_INSTANCE_TYPE_STANDARD = 'STANDARD'.freeze, INTEGRATION_INSTANCE_TYPE_ENTERPRISE = 'ENTERPRISE'.freeze ].freeze
- CONSUMPTION_MODEL_ENUM =
[ CONSUMPTION_MODEL_UCM = 'UCM'.freeze, CONSUMPTION_MODEL_GOV = 'GOV'.freeze, CONSUMPTION_MODEL_OIC4_SAAS = 'OIC4SAAS'.freeze ].freeze
Instance Attribute Summary collapse
-
#alternate_custom_endpoints ⇒ Array<OCI::Integration::Models::CreateCustomEndpointDetails>
A list of alternate custom endpoints to be used for the integration instance URL (contact Oracle for alternateCustomEndpoints availability for a specific instance).
-
#compartment_id ⇒ String
[Required] Compartment Identifier.
-
#consumption_model ⇒ String
Optional parameter specifying which entitlement to use for billing purposes.
- #custom_endpoint ⇒ OCI::Integration::Models::CreateCustomEndpointDetails
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#display_name ⇒ String
[Required] Integration Instance Identifier.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#idcs_at ⇒ String
IDCS Authentication token.
-
#integration_instance_type ⇒ String
[Required] Standard or Enterprise type.
-
#is_byol ⇒ BOOLEAN
[Required] Bring your own license.
-
#is_file_server_enabled ⇒ BOOLEAN
The file server is enabled or not.
-
#is_visual_builder_enabled ⇒ BOOLEAN
Visual Builder is enabled or not.
-
#message_packs ⇒ Integer
[Required] The number of configured message packs.
- #network_endpoint_details ⇒ OCI::Integration::Models::NetworkEndpointDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateIntegrationInstanceDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateIntegrationInstanceDetails
Initializes the object
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 147 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.integration_instance_type = attributes[:'integrationInstanceType'] if attributes[:'integrationInstanceType'] raise 'You cannot provide both :integrationInstanceType and :integration_instance_type' if attributes.key?(:'integrationInstanceType') && attributes.key?(:'integration_instance_type') self.integration_instance_type = attributes[:'integration_instance_type'] if attributes[:'integration_instance_type'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.is_byol = attributes[:'isByol'] unless attributes[:'isByol'].nil? raise 'You cannot provide both :isByol and :is_byol' if attributes.key?(:'isByol') && attributes.key?(:'is_byol') self.is_byol = attributes[:'is_byol'] unless attributes[:'is_byol'].nil? self.idcs_at = attributes[:'idcsAt'] if attributes[:'idcsAt'] raise 'You cannot provide both :idcsAt and :idcs_at' if attributes.key?(:'idcsAt') && attributes.key?(:'idcs_at') self.idcs_at = attributes[:'idcs_at'] if attributes[:'idcs_at'] self. = attributes[:'messagePacks'] if attributes[:'messagePacks'] raise 'You cannot provide both :messagePacks and :message_packs' if attributes.key?(:'messagePacks') && attributes.key?(:'message_packs') self. = attributes[:'message_packs'] if attributes[:'message_packs'] self.is_visual_builder_enabled = attributes[:'isVisualBuilderEnabled'] unless attributes[:'isVisualBuilderEnabled'].nil? raise 'You cannot provide both :isVisualBuilderEnabled and :is_visual_builder_enabled' if attributes.key?(:'isVisualBuilderEnabled') && attributes.key?(:'is_visual_builder_enabled') self.is_visual_builder_enabled = attributes[:'is_visual_builder_enabled'] unless attributes[:'is_visual_builder_enabled'].nil? self.custom_endpoint = attributes[:'customEndpoint'] if attributes[:'customEndpoint'] raise 'You cannot provide both :customEndpoint and :custom_endpoint' if attributes.key?(:'customEndpoint') && attributes.key?(:'custom_endpoint') self.custom_endpoint = attributes[:'custom_endpoint'] if attributes[:'custom_endpoint'] self.alternate_custom_endpoints = attributes[:'alternateCustomEndpoints'] if attributes[:'alternateCustomEndpoints'] raise 'You cannot provide both :alternateCustomEndpoints and :alternate_custom_endpoints' if attributes.key?(:'alternateCustomEndpoints') && attributes.key?(:'alternate_custom_endpoints') self.alternate_custom_endpoints = attributes[:'alternate_custom_endpoints'] if attributes[:'alternate_custom_endpoints'] self.consumption_model = attributes[:'consumptionModel'] if attributes[:'consumptionModel'] raise 'You cannot provide both :consumptionModel and :consumption_model' if attributes.key?(:'consumptionModel') && attributes.key?(:'consumption_model') self.consumption_model = attributes[:'consumption_model'] if attributes[:'consumption_model'] self.is_file_server_enabled = attributes[:'isFileServerEnabled'] unless attributes[:'isFileServerEnabled'].nil? self.is_file_server_enabled = false if is_file_server_enabled.nil? && !attributes.key?(:'isFileServerEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isFileServerEnabled and :is_file_server_enabled' if attributes.key?(:'isFileServerEnabled') && attributes.key?(:'is_file_server_enabled') self.is_file_server_enabled = attributes[:'is_file_server_enabled'] unless attributes[:'is_file_server_enabled'].nil? self.is_file_server_enabled = false if is_file_server_enabled.nil? && !attributes.key?(:'isFileServerEnabled') && !attributes.key?(:'is_file_server_enabled') # rubocop:disable Style/StringLiterals self.network_endpoint_details = attributes[:'networkEndpointDetails'] if attributes[:'networkEndpointDetails'] raise 'You cannot provide both :networkEndpointDetails and :network_endpoint_details' if attributes.key?(:'networkEndpointDetails') && attributes.key?(:'network_endpoint_details') self.network_endpoint_details = attributes[:'network_endpoint_details'] if attributes[:'network_endpoint_details'] end |
Instance Attribute Details
#alternate_custom_endpoints ⇒ Array<OCI::Integration::Models::CreateCustomEndpointDetails>
A list of alternate custom endpoints to be used for the integration instance URL (contact Oracle for alternateCustomEndpoints availability for a specific instance).
70 71 72 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 70 def alternate_custom_endpoints @alternate_custom_endpoints end |
#compartment_id ⇒ String
[Required] Compartment Identifier.
27 28 29 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 27 def compartment_id @compartment_id end |
#consumption_model ⇒ String
Optional parameter specifying which entitlement to use for billing purposes. Only required if the account possesses more than one entitlement.
74 75 76 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 74 def consumption_model @consumption_model end |
#custom_endpoint ⇒ OCI::Integration::Models::CreateCustomEndpointDetails
64 65 66 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 64 def custom_endpoint @custom_endpoint end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: ‘{"bar-key": "value"}`
45 46 47 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 45 def end |
#display_name ⇒ String
[Required] Integration Instance Identifier.
23 24 25 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 23 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
38 39 40 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 38 def end |
#idcs_at ⇒ String
IDCS Authentication token. This is required for all realms with IDCS. Its optional as its not required for non IDCS realms.
53 54 55 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 53 def idcs_at @idcs_at end |
#integration_instance_type ⇒ String
[Required] Standard or Enterprise type
31 32 33 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 31 def integration_instance_type @integration_instance_type end |
#is_byol ⇒ BOOLEAN
[Required] Bring your own license.
49 50 51 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 49 def is_byol @is_byol end |
#is_file_server_enabled ⇒ BOOLEAN
The file server is enabled or not.
78 79 80 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 78 def is_file_server_enabled @is_file_server_enabled end |
#is_visual_builder_enabled ⇒ BOOLEAN
Visual Builder is enabled or not.
61 62 63 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 61 def is_visual_builder_enabled @is_visual_builder_enabled end |
#message_packs ⇒ Integer
[Required] The number of configured message packs
57 58 59 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 57 def end |
#network_endpoint_details ⇒ OCI::Integration::Models::NetworkEndpointDetails
81 82 83 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 81 def network_endpoint_details @network_endpoint_details end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 84 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'integration_instance_type': :'integrationInstanceType', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'is_byol': :'isByol', 'idcs_at': :'idcsAt', 'message_packs': :'messagePacks', 'is_visual_builder_enabled': :'isVisualBuilderEnabled', 'custom_endpoint': :'customEndpoint', 'alternate_custom_endpoints': :'alternateCustomEndpoints', 'consumption_model': :'consumptionModel', 'is_file_server_enabled': :'isFileServerEnabled', 'network_endpoint_details': :'networkEndpointDetails' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 106 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'integration_instance_type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'is_byol': :'BOOLEAN', 'idcs_at': :'String', 'message_packs': :'Integer', 'is_visual_builder_enabled': :'BOOLEAN', 'custom_endpoint': :'OCI::Integration::Models::CreateCustomEndpointDetails', 'alternate_custom_endpoints': :'Array<OCI::Integration::Models::CreateCustomEndpointDetails>', 'consumption_model': :'String', 'is_file_server_enabled': :'BOOLEAN', 'network_endpoint_details': :'OCI::Integration::Models::NetworkEndpointDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 263 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && integration_instance_type == other.integration_instance_type && == other. && == other. && is_byol == other.is_byol && idcs_at == other.idcs_at && == other. && is_visual_builder_enabled == other.is_visual_builder_enabled && custom_endpoint == other.custom_endpoint && alternate_custom_endpoints == other.alternate_custom_endpoints && consumption_model == other.consumption_model && is_file_server_enabled == other.is_file_server_enabled && network_endpoint_details == other.network_endpoint_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 306 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
286 287 288 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 286 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
295 296 297 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 295 def hash [display_name, compartment_id, integration_instance_type, , , is_byol, idcs_at, , is_visual_builder_enabled, custom_endpoint, alternate_custom_endpoints, consumption_model, is_file_server_enabled, network_endpoint_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
339 340 341 342 343 344 345 346 347 348 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 339 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
333 334 335 |
# File 'lib/oci/integration/models/create_integration_instance_details.rb', line 333 def to_s to_hash.to_s end |