Class: OCI::Jms::JavaManagementServiceClient
- Inherits:
-
Object
- Object
- OCI::Jms::JavaManagementServiceClient
- Defined in:
- lib/oci/jms/java_management_service_client.rb
Overview
API for the Java Management Service. Use this API to view and manage Fleets.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#change_fleet_compartment(fleet_id, change_fleet_compartment_details, opts = {}) ⇒ Response
Move a specified Fleet into the compartment identified in the POST form.
-
#create_fleet(create_fleet_details, opts = {}) ⇒ Response
Create a new Fleet using the information provided.
-
#delete_fleet(fleet_id, opts = {}) ⇒ Response
Deletes the Fleet specified by an identifier.
-
#get_fleet(fleet_id, opts = {}) ⇒ Response
Retrieve a Fleet with the specified identifier.
-
#get_fleet_agent_configuration(fleet_id, opts = {}) ⇒ Response
Retrieve a Fleet Agent Configuration for the specified Fleet.
-
#get_work_request(work_request_id, opts = {}) ⇒ Response
Retrieve the details of a work request with the specified ID.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ JavaManagementServiceClient
constructor
Creates a new JavaManagementServiceClient.
-
#list_fleets(opts = {}) ⇒ Response
Returns a list of all the Fleets contained by a compartment.
-
#list_work_request_errors(work_request_id, opts = {}) ⇒ Response
Retrieve a (paginated) list of errors for a specified work request.
-
#list_work_request_logs(work_request_id, opts = {}) ⇒ Response
Retrieve a (paginated) list of logs for a specified work request.
-
#list_work_requests(opts = {}) ⇒ Response
List the work requests in a compartment.
-
#logger ⇒ Logger
The logger for this client.
-
#request_summarized_application_usage(fleet_id, request_summarized_application_usage_details, opts = {}) ⇒ Response
List application usage in a specified Fleet filtered by form parameters.
-
#request_summarized_installation_usage(fleet_id, request_summarized_installation_usage_details, opts = {}) ⇒ Response
List Java installation usage in a specified Fleet filtered by form parameters.
-
#request_summarized_jre_usage(fleet_id, request_summarized_jre_usage_details, opts = {}) ⇒ Response
List Java Runtime usage in a specified Fleet filtered by form parameters.
-
#request_summarized_managed_instance_usage(fleet_id, request_summarized_managed_instance_usage_details, opts = {}) ⇒ Response
List managed instance usage in a specified Fleet filtered by form parameters.
-
#summarize_application_usage(fleet_id, opts = {}) ⇒ Response
List application usage in a Fleet filtered by query parameters.
-
#summarize_installation_usage(fleet_id, opts = {}) ⇒ Response
List Java installation usage in a Fleet filtered by query parameters.
-
#summarize_jre_usage(fleet_id, opts = {}) ⇒ Response
List Java Runtime usage in a specified Fleet filtered by query parameters.
-
#summarize_managed_instance_usage(fleet_id, opts = {}) ⇒ Response
List managed instance usage in a Fleet filtered by query parameters.
-
#update_fleet(fleet_id, update_fleet_details, opts = {}) ⇒ Response
Update the Fleet specified by an identifier.
-
#update_fleet_agent_configuration(fleet_id, update_fleet_agent_configuration_details, opts = {}) ⇒ Response
Update the Fleet Agent Configuration for the specified Fleet.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ JavaManagementServiceClient
Creates a new JavaManagementServiceClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/jms/java_management_service_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20210610' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "JavaManagementServiceClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/jms/java_management_service_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/jms/java_management_service_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/jms/java_management_service_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/jms/java_management_service_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#change_fleet_compartment(fleet_id, change_fleet_compartment_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/change_fleet_compartment.rb.html) to see an example of how to use change_fleet_compartment API.
Move a specified Fleet into the compartment identified in the POST form. When provided, If-Match is checked against ETag values of the resource.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/jms/java_management_service_client.rb', line 123 def change_fleet_compartment(fleet_id, change_fleet_compartment_details, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#change_fleet_compartment.' if logger raise "Missing the required parameter 'fleet_id' when calling change_fleet_compartment." if fleet_id.nil? raise "Missing the required parameter 'change_fleet_compartment_details' when calling change_fleet_compartment." if change_fleet_compartment_details.nil? raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/actions/changeCompartment'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(change_fleet_compartment_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#change_fleet_compartment') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#create_fleet(create_fleet_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/create_fleet.rb.html) to see an example of how to use create_fleet API.
Create a new Fleet using the information provided.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/jms/java_management_service_client.rb', line 187 def create_fleet(create_fleet_details, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#create_fleet.' if logger raise "Missing the required parameter 'create_fleet_details' when calling create_fleet." if create_fleet_details.nil? path = '/fleets' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_fleet_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#create_fleet') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_fleet(fleet_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/delete_fleet.rb.html) to see an example of how to use delete_fleet API.
Deletes the Fleet specified by an identifier.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/oci/jms/java_management_service_client.rb', line 247 def delete_fleet(fleet_id, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#delete_fleet.' if logger raise "Missing the required parameter 'fleet_id' when calling delete_fleet." if fleet_id.nil? raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#delete_fleet') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_fleet(fleet_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/get_fleet.rb.html) to see an example of how to use get_fleet API.
Retrieve a Fleet with the specified identifier.
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/oci/jms/java_management_service_client.rb', line 301 def get_fleet(fleet_id, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#get_fleet.' if logger raise "Missing the required parameter 'fleet_id' when calling get_fleet." if fleet_id.nil? raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#get_fleet') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::Fleet' ) end # rubocop:enable Metrics/BlockLength end |
#get_fleet_agent_configuration(fleet_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/get_fleet_agent_configuration.rb.html) to see an example of how to use get_fleet_agent_configuration API.
Retrieve a Fleet Agent Configuration for the specified Fleet.
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/oci/jms/java_management_service_client.rb', line 355 def get_fleet_agent_configuration(fleet_id, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#get_fleet_agent_configuration.' if logger raise "Missing the required parameter 'fleet_id' when calling get_fleet_agent_configuration." if fleet_id.nil? raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/agentConfiguration'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#get_fleet_agent_configuration') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::FleetAgentConfiguration' ) end # rubocop:enable Metrics/BlockLength end |
#get_work_request(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/get_work_request.rb.html) to see an example of how to use get_work_request API.
Retrieve the details of a work request with the specified ID.
409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/oci/jms/java_management_service_client.rb', line 409 def get_work_request(work_request_id, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#get_work_request.' if logger raise "Missing the required parameter 'work_request_id' when calling get_work_request." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#get_work_request') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::WorkRequest' ) end # rubocop:enable Metrics/BlockLength end |
#list_fleets(opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/list_fleets.rb.html) to see an example of how to use list_fleets API.
Returns a list of all the Fleets contained by a compartment.
476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 |
# File 'lib/oci/jms/java_management_service_client.rb', line 476 def list_fleets(opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#list_fleets.' if logger if opts[:lifecycle_state] && !OCI::Jms::Models::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::Jms::Models::LIFECYCLE_STATE_ENUM.' end if opts[:sort_order] && !OCI::Jms::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::Jms::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !OCI::Jms::Models::SORT_BY_ENUM.include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of the values in OCI::Jms::Models::SORT_BY_ENUM.' end path = '/fleets' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id] query_params[:id] = opts[:id] if opts[:id] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#list_fleets') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::FleetCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_errors(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/list_work_request_errors.rb.html) to see an example of how to use list_work_request_errors API.
Retrieve a (paginated) list of errors for a specified work request.
551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/oci/jms/java_management_service_client.rb', line 551 def list_work_request_errors(work_request_id, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#list_work_request_errors.' if logger raise "Missing the required parameter 'work_request_id' when calling list_work_request_errors." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/errors'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#list_work_request_errors') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::WorkRequestErrorCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_request_logs(work_request_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/list_work_request_logs.rb.html) to see an example of how to use list_work_request_logs API.
Retrieve a (paginated) list of logs for a specified work request.
610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 |
# File 'lib/oci/jms/java_management_service_client.rb', line 610 def list_work_request_logs(work_request_id, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#list_work_request_logs.' if logger raise "Missing the required parameter 'work_request_id' when calling list_work_request_logs." if work_request_id.nil? raise "Parameter value for 'work_request_id' must not be blank" if OCI::Internal::Util.blank_string?(work_request_id) path = '/workRequests/{workRequestId}/logs'.sub('{workRequestId}', work_request_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#list_work_request_logs') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::WorkRequestLogEntryCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_work_requests(opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/list_work_requests.rb.html) to see an example of how to use list_work_requests API.
List the work requests in a compartment.
670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 |
# File 'lib/oci/jms/java_management_service_client.rb', line 670 def list_work_requests(opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#list_work_requests.' if logger path = '/workRequests' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id] query_params[:id] = opts[:id] if opts[:id] query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#list_work_requests') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::WorkRequestCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/jms/java_management_service_client.rb', line 92 def logger @api_client.config.logger end |
#request_summarized_application_usage(fleet_id, request_summarized_application_usage_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/request_summarized_application_usage.rb.html) to see an example of how to use request_summarized_application_usage API.
List application usage in a specified Fleet filtered by form parameters.
729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 |
# File 'lib/oci/jms/java_management_service_client.rb', line 729 def request_summarized_application_usage(fleet_id, request_summarized_application_usage_details, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#request_summarized_application_usage.' if logger raise "Missing the required parameter 'fleet_id' when calling request_summarized_application_usage." if fleet_id.nil? raise "Missing the required parameter 'request_summarized_application_usage_details' when calling request_summarized_application_usage." if request_summarized_application_usage_details.nil? raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/actions/summarizeApplicationUsage'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(request_summarized_application_usage_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#request_summarized_application_usage') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::ApplicationUsageCollection' ) end # rubocop:enable Metrics/BlockLength end |
#request_summarized_installation_usage(fleet_id, request_summarized_installation_usage_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/request_summarized_installation_usage.rb.html) to see an example of how to use request_summarized_installation_usage API.
List Java installation usage in a specified Fleet filtered by form parameters.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 |
# File 'lib/oci/jms/java_management_service_client.rb', line 789 def request_summarized_installation_usage(fleet_id, request_summarized_installation_usage_details, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#request_summarized_installation_usage.' if logger raise "Missing the required parameter 'fleet_id' when calling request_summarized_installation_usage." if fleet_id.nil? raise "Missing the required parameter 'request_summarized_installation_usage_details' when calling request_summarized_installation_usage." if request_summarized_installation_usage_details.nil? raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/actions/summarizeInstallationUsage'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(request_summarized_installation_usage_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#request_summarized_installation_usage') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::InstallationUsageCollection' ) end # rubocop:enable Metrics/BlockLength end |
#request_summarized_jre_usage(fleet_id, request_summarized_jre_usage_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/request_summarized_jre_usage.rb.html) to see an example of how to use request_summarized_jre_usage API.
List Java Runtime usage in a specified Fleet filtered by form parameters.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 |
# File 'lib/oci/jms/java_management_service_client.rb', line 849 def request_summarized_jre_usage(fleet_id, request_summarized_jre_usage_details, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#request_summarized_jre_usage.' if logger raise "Missing the required parameter 'fleet_id' when calling request_summarized_jre_usage." if fleet_id.nil? raise "Missing the required parameter 'request_summarized_jre_usage_details' when calling request_summarized_jre_usage." if request_summarized_jre_usage_details.nil? raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/actions/summarizeJreUsage'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(request_summarized_jre_usage_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#request_summarized_jre_usage') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::JreUsageCollection' ) end # rubocop:enable Metrics/BlockLength end |
#request_summarized_managed_instance_usage(fleet_id, request_summarized_managed_instance_usage_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/request_summarized_managed_instance_usage.rb.html) to see an example of how to use request_summarized_managed_instance_usage API.
List managed instance usage in a specified Fleet filtered by form parameters.
909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 |
# File 'lib/oci/jms/java_management_service_client.rb', line 909 def request_summarized_managed_instance_usage(fleet_id, request_summarized_managed_instance_usage_details, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#request_summarized_managed_instance_usage.' if logger raise "Missing the required parameter 'fleet_id' when calling request_summarized_managed_instance_usage." if fleet_id.nil? raise "Missing the required parameter 'request_summarized_managed_instance_usage_details' when calling request_summarized_managed_instance_usage." if request_summarized_managed_instance_usage_details.nil? raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/actions/summarizeManagedInstanceUsage'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(request_summarized_managed_instance_usage_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#request_summarized_managed_instance_usage') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::ManagedInstanceUsageCollection' ) end # rubocop:enable Metrics/BlockLength end |
#summarize_application_usage(fleet_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/summarize_application_usage.rb.html) to see an example of how to use summarize_application_usage API.
List application usage in a Fleet filtered by query parameters.
990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/oci/jms/java_management_service_client.rb', line 990 def summarize_application_usage(fleet_id, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#summarize_application_usage.' if logger raise "Missing the required parameter 'fleet_id' when calling summarize_application_usage." if fleet_id.nil? fields_allowable_values = %w[approximateJreCount approximateInstallationCount approximateManagedInstanceCount] if opts[:fields] && !opts[:fields].empty? opts[:fields].each do |val_to_check| unless fields_allowable_values.include?(val_to_check) raise 'Invalid value for "fields", must be one of approximateJreCount, approximateInstallationCount, approximateManagedInstanceCount.' end end end if opts[:sort_order] && !OCI::Jms::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::Jms::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !OCI::Jms::Models::APPLICATION_SORT_BY_ENUM.include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of the values in OCI::Jms::Models::APPLICATION_SORT_BY_ENUM.' end raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/actions/summarizeApplicationUsage'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:applicationId] = opts[:application_id] if opts[:application_id] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:applicationType] = opts[:application_type] if opts[:application_type] query_params[:jreVendor] = opts[:jre_vendor] if opts[:jre_vendor] query_params[:jreDistribution] = opts[:jre_distribution] if opts[:jre_distribution] query_params[:jreVersion] = opts[:jre_version] if opts[:jre_version] query_params[:installationPath] = opts[:installation_path] if opts[:installation_path] query_params[:managedInstanceId] = opts[:managed_instance_id] if opts[:managed_instance_id] query_params[:fields] = OCI::ApiClient.build_collection_params(opts[:fields], :csv) if opts[:fields] && !opts[:fields].empty? query_params[:timeStart] = opts[:time_start] if opts[:time_start] query_params[:timeEnd] = opts[:time_end] if opts[:time_end] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#summarize_application_usage') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::ApplicationUsageCollection' ) end # rubocop:enable Metrics/BlockLength end |
#summarize_installation_usage(fleet_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/summarize_installation_usage.rb.html) to see an example of how to use summarize_installation_usage API.
List Java installation usage in a Fleet filtered by query parameters.
1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 |
# File 'lib/oci/jms/java_management_service_client.rb', line 1098 def summarize_installation_usage(fleet_id, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#summarize_installation_usage.' if logger raise "Missing the required parameter 'fleet_id' when calling summarize_installation_usage." if fleet_id.nil? fields_allowable_values = %w[approximateApplicationCount approximateManagedInstanceCount] if opts[:fields] && !opts[:fields].empty? opts[:fields].each do |val_to_check| unless fields_allowable_values.include?(val_to_check) raise 'Invalid value for "fields", must be one of approximateApplicationCount, approximateManagedInstanceCount.' end end end if opts[:sort_order] && !OCI::Jms::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::Jms::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !OCI::Jms::Models::INSTALLATION_SORT_BY_ENUM.include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of the values in OCI::Jms::Models::INSTALLATION_SORT_BY_ENUM.' end raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/actions/summarizeInstallationUsage'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:jreVendor] = opts[:jre_vendor] if opts[:jre_vendor] query_params[:jreDistribution] = opts[:jre_distribution] if opts[:jre_distribution] query_params[:jreVersion] = opts[:jre_version] if opts[:jre_version] query_params[:installationPath] = opts[:installation_path] if opts[:installation_path] query_params[:applicationId] = opts[:application_id] if opts[:application_id] query_params[:managedInstanceId] = opts[:managed_instance_id] if opts[:managed_instance_id] query_params[:fields] = OCI::ApiClient.build_collection_params(opts[:fields], :csv) if opts[:fields] && !opts[:fields].empty? query_params[:timeStart] = opts[:time_start] if opts[:time_start] query_params[:timeEnd] = opts[:time_end] if opts[:time_end] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#summarize_installation_usage') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::InstallationUsageCollection' ) end # rubocop:enable Metrics/BlockLength end |
#summarize_jre_usage(fleet_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/summarize_jre_usage.rb.html) to see an example of how to use summarize_jre_usage API.
List Java Runtime usage in a specified Fleet filtered by query parameters.
1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/oci/jms/java_management_service_client.rb', line 1204 def summarize_jre_usage(fleet_id, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#summarize_jre_usage.' if logger raise "Missing the required parameter 'fleet_id' when calling summarize_jre_usage." if fleet_id.nil? fields_allowable_values = %w[approximateInstallationCount approximateApplicationCount approximateManagedInstanceCount] if opts[:fields] && !opts[:fields].empty? opts[:fields].each do |val_to_check| unless fields_allowable_values.include?(val_to_check) raise 'Invalid value for "fields", must be one of approximateInstallationCount, approximateApplicationCount, approximateManagedInstanceCount.' end end end if opts[:sort_order] && !OCI::Jms::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::Jms::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !OCI::Jms::Models::JRE_SORT_BY_ENUM.include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of the values in OCI::Jms::Models::JRE_SORT_BY_ENUM.' end raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/actions/summarizeJreUsage'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:jreVendor] = opts[:jre_vendor] if opts[:jre_vendor] query_params[:jreDistribution] = opts[:jre_distribution] if opts[:jre_distribution] query_params[:jreVersion] = opts[:jre_version] if opts[:jre_version] query_params[:applicationId] = opts[:application_id] if opts[:application_id] query_params[:managedInstanceId] = opts[:managed_instance_id] if opts[:managed_instance_id] query_params[:fields] = OCI::ApiClient.build_collection_params(opts[:fields], :csv) if opts[:fields] && !opts[:fields].empty? query_params[:timeStart] = opts[:time_start] if opts[:time_start] query_params[:timeEnd] = opts[:time_end] if opts[:time_end] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#summarize_jre_usage') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::JreUsageCollection' ) end # rubocop:enable Metrics/BlockLength end |
#summarize_managed_instance_usage(fleet_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/summarize_managed_instance_usage.rb.html) to see an example of how to use summarize_managed_instance_usage API.
List managed instance usage in a Fleet filtered by query parameters.
1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 |
# File 'lib/oci/jms/java_management_service_client.rb', line 1310 def summarize_managed_instance_usage(fleet_id, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#summarize_managed_instance_usage.' if logger raise "Missing the required parameter 'fleet_id' when calling summarize_managed_instance_usage." if fleet_id.nil? if opts[:managed_instance_type] && !OCI::Jms::Models::MANAGED_INSTANCE_TYPE_ENUM.include?(opts[:managed_instance_type]) raise 'Invalid value for "managed_instance_type", must be one of the values in OCI::Jms::Models::MANAGED_INSTANCE_TYPE_ENUM.' end fields_allowable_values = %w[approximateJreCount approximateInstallationCount approximateApplicationCount] if opts[:fields] && !opts[:fields].empty? opts[:fields].each do |val_to_check| unless fields_allowable_values.include?(val_to_check) raise 'Invalid value for "fields", must be one of approximateJreCount, approximateInstallationCount, approximateApplicationCount.' end end end if opts[:sort_order] && !OCI::Jms::Models::SORT_ORDER_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::Jms::Models::SORT_ORDER_ENUM.' end if opts[:sort_by] && !OCI::Jms::Models::MANAGED_INSTANCE_SORT_BY_ENUM.include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of the values in OCI::Jms::Models::MANAGED_INSTANCE_SORT_BY_ENUM.' end raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/actions/summarizeManagedInstanceUsage'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:managedInstanceId] = opts[:managed_instance_id] if opts[:managed_instance_id] query_params[:managedInstanceType] = opts[:managed_instance_type] if opts[:managed_instance_type] query_params[:jreVendor] = opts[:jre_vendor] if opts[:jre_vendor] query_params[:jreDistribution] = opts[:jre_distribution] if opts[:jre_distribution] query_params[:jreVersion] = opts[:jre_version] if opts[:jre_version] query_params[:installationPath] = opts[:installation_path] if opts[:installation_path] query_params[:applicationId] = opts[:application_id] if opts[:application_id] query_params[:fields] = OCI::ApiClient.build_collection_params(opts[:fields], :csv) if opts[:fields] && !opts[:fields].empty? query_params[:timeStart] = opts[:time_start] if opts[:time_start] query_params[:timeEnd] = opts[:time_end] if opts[:time_end] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#summarize_managed_instance_usage') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Jms::Models::ManagedInstanceUsageCollection' ) end # rubocop:enable Metrics/BlockLength end |
#update_fleet(fleet_id, update_fleet_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/update_fleet.rb.html) to see an example of how to use update_fleet API.
Update the Fleet specified by an identifier.
1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 |
# File 'lib/oci/jms/java_management_service_client.rb', line 1407 def update_fleet(fleet_id, update_fleet_details, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#update_fleet.' if logger raise "Missing the required parameter 'fleet_id' when calling update_fleet." if fleet_id.nil? raise "Missing the required parameter 'update_fleet_details' when calling update_fleet." if update_fleet_details.nil? raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_fleet_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#update_fleet') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#update_fleet_agent_configuration(fleet_id, update_fleet_agent_configuration_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/jms/update_fleet_agent_configuration.rb.html) to see an example of how to use update_fleet_agent_configuration API.
Update the Fleet Agent Configuration for the specified Fleet.
1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 |
# File 'lib/oci/jms/java_management_service_client.rb', line 1469 def update_fleet_agent_configuration(fleet_id, update_fleet_agent_configuration_details, opts = {}) logger.debug 'Calling operation JavaManagementServiceClient#update_fleet_agent_configuration.' if logger raise "Missing the required parameter 'fleet_id' when calling update_fleet_agent_configuration." if fleet_id.nil? raise "Missing the required parameter 'update_fleet_agent_configuration_details' when calling update_fleet_agent_configuration." if update_fleet_agent_configuration_details.nil? raise "Parameter value for 'fleet_id' must not be blank" if OCI::Internal::Util.blank_string?(fleet_id) path = '/fleets/{fleetId}/agentConfiguration'.sub('{fleetId}', fleet_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_fleet_agent_configuration_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'JavaManagementServiceClient#update_fleet_agent_configuration') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |