Class: OCI::Jms::Models::ApplicationUsage
- Inherits:
-
Object
- Object
- OCI::Jms::Models::ApplicationUsage
- Defined in:
- lib/oci/jms/models/application_usage.rb
Overview
Application usage during a specified time period. An application is a Java application that can be executed by a Java Runtime installation. An application is independent of the Java Runtime or its installation.
Instance Attribute Summary collapse
-
#application_id ⇒ String
[Required] An internal identifier for the application that is unique to a Fleet.
-
#application_type ⇒ String
[Required] The type of the application, denoted by how the application was started.
-
#approximate_installation_count ⇒ Integer
The approximate count of installations running this application.
-
#approximate_jre_count ⇒ Integer
The approximate count of Java Runtimes running this application.
-
#approximate_managed_instance_count ⇒ Integer
The approximate count of managed instances reporting this application.
-
#display_name ⇒ String
[Required] The name of the application.
-
#time_end ⇒ DateTime
Upper bound of the specified time period filter.
-
#time_first_seen ⇒ DateTime
The date and time the resource was first reported to JMS.
-
#time_last_seen ⇒ DateTime
The date and time the resource was last reported to JMS.
-
#time_start ⇒ DateTime
Lower bound of the specified time period filter.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationUsage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationUsage
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/jms/models/application_usage.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.application_id = attributes[:'applicationId'] if attributes[:'applicationId'] raise 'You cannot provide both :applicationId and :application_id' if attributes.key?(:'applicationId') && attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] if attributes[:'application_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.application_type = attributes[:'applicationType'] if attributes[:'applicationType'] raise 'You cannot provide both :applicationType and :application_type' if attributes.key?(:'applicationType') && attributes.key?(:'application_type') self.application_type = attributes[:'application_type'] if attributes[:'application_type'] self.approximate_installation_count = attributes[:'approximateInstallationCount'] if attributes[:'approximateInstallationCount'] raise 'You cannot provide both :approximateInstallationCount and :approximate_installation_count' if attributes.key?(:'approximateInstallationCount') && attributes.key?(:'approximate_installation_count') self.approximate_installation_count = attributes[:'approximate_installation_count'] if attributes[:'approximate_installation_count'] self.approximate_jre_count = attributes[:'approximateJreCount'] if attributes[:'approximateJreCount'] raise 'You cannot provide both :approximateJreCount and :approximate_jre_count' if attributes.key?(:'approximateJreCount') && attributes.key?(:'approximate_jre_count') self.approximate_jre_count = attributes[:'approximate_jre_count'] if attributes[:'approximate_jre_count'] self.approximate_managed_instance_count = attributes[:'approximateManagedInstanceCount'] if attributes[:'approximateManagedInstanceCount'] raise 'You cannot provide both :approximateManagedInstanceCount and :approximate_managed_instance_count' if attributes.key?(:'approximateManagedInstanceCount') && attributes.key?(:'approximate_managed_instance_count') self.approximate_managed_instance_count = attributes[:'approximate_managed_instance_count'] if attributes[:'approximate_managed_instance_count'] self.time_start = attributes[:'timeStart'] if attributes[:'timeStart'] raise 'You cannot provide both :timeStart and :time_start' if attributes.key?(:'timeStart') && attributes.key?(:'time_start') self.time_start = attributes[:'time_start'] if attributes[:'time_start'] self.time_end = attributes[:'timeEnd'] if attributes[:'timeEnd'] raise 'You cannot provide both :timeEnd and :time_end' if attributes.key?(:'timeEnd') && attributes.key?(:'time_end') self.time_end = attributes[:'time_end'] if attributes[:'time_end'] self.time_first_seen = attributes[:'timeFirstSeen'] if attributes[:'timeFirstSeen'] raise 'You cannot provide both :timeFirstSeen and :time_first_seen' if attributes.key?(:'timeFirstSeen') && attributes.key?(:'time_first_seen') self.time_first_seen = attributes[:'time_first_seen'] if attributes[:'time_first_seen'] self.time_last_seen = attributes[:'timeLastSeen'] if attributes[:'timeLastSeen'] raise 'You cannot provide both :timeLastSeen and :time_last_seen' if attributes.key?(:'timeLastSeen') && attributes.key?(:'time_last_seen') self.time_last_seen = attributes[:'time_last_seen'] if attributes[:'time_last_seen'] end |
Instance Attribute Details
#application_id ⇒ String
[Required] An internal identifier for the application that is unique to a Fleet.
16 17 18 |
# File 'lib/oci/jms/models/application_usage.rb', line 16 def application_id @application_id end |
#application_type ⇒ String
[Required] The type of the application, denoted by how the application was started.
24 25 26 |
# File 'lib/oci/jms/models/application_usage.rb', line 24 def application_type @application_type end |
#approximate_installation_count ⇒ Integer
The approximate count of installations running this application.
28 29 30 |
# File 'lib/oci/jms/models/application_usage.rb', line 28 def approximate_installation_count @approximate_installation_count end |
#approximate_jre_count ⇒ Integer
The approximate count of Java Runtimes running this application.
32 33 34 |
# File 'lib/oci/jms/models/application_usage.rb', line 32 def approximate_jre_count @approximate_jre_count end |
#approximate_managed_instance_count ⇒ Integer
The approximate count of managed instances reporting this application.
36 37 38 |
# File 'lib/oci/jms/models/application_usage.rb', line 36 def approximate_managed_instance_count @approximate_managed_instance_count end |
#display_name ⇒ String
[Required] The name of the application.
20 21 22 |
# File 'lib/oci/jms/models/application_usage.rb', line 20 def display_name @display_name end |
#time_end ⇒ DateTime
Upper bound of the specified time period filter.
44 45 46 |
# File 'lib/oci/jms/models/application_usage.rb', line 44 def time_end @time_end end |
#time_first_seen ⇒ DateTime
The date and time the resource was first reported to JMS. This is potentially before the specified time period provided by the filters. For example, a resource can be first reported to JMS before the start of a specified time period, if it is also reported during the time period.
52 53 54 |
# File 'lib/oci/jms/models/application_usage.rb', line 52 def time_first_seen @time_first_seen end |
#time_last_seen ⇒ DateTime
The date and time the resource was last reported to JMS. This is potentially after the specified time period provided by the filters. For example, a resource can be last reported to JMS before the start of a specified time period, if it is also reported during the time period.
60 61 62 |
# File 'lib/oci/jms/models/application_usage.rb', line 60 def time_last_seen @time_last_seen end |
#time_start ⇒ DateTime
Lower bound of the specified time period filter.
40 41 42 |
# File 'lib/oci/jms/models/application_usage.rb', line 40 def time_start @time_start end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/jms/models/application_usage.rb', line 63 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'application_id': :'applicationId', 'display_name': :'displayName', 'application_type': :'applicationType', 'approximate_installation_count': :'approximateInstallationCount', 'approximate_jre_count': :'approximateJreCount', 'approximate_managed_instance_count': :'approximateManagedInstanceCount', 'time_start': :'timeStart', 'time_end': :'timeEnd', 'time_first_seen': :'timeFirstSeen', 'time_last_seen': :'timeLastSeen' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/jms/models/application_usage.rb', line 81 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'application_id': :'String', 'display_name': :'String', 'application_type': :'String', 'approximate_installation_count': :'Integer', 'approximate_jre_count': :'Integer', 'approximate_managed_instance_count': :'Integer', 'time_start': :'DateTime', 'time_end': :'DateTime', 'time_first_seen': :'DateTime', 'time_last_seen': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/oci/jms/models/application_usage.rb', line 188 def ==(other) return true if equal?(other) self.class == other.class && application_id == other.application_id && display_name == other.display_name && application_type == other.application_type && approximate_installation_count == other.approximate_installation_count && approximate_jre_count == other.approximate_jre_count && approximate_managed_instance_count == other.approximate_managed_instance_count && time_start == other.time_start && time_end == other.time_end && time_first_seen == other.time_first_seen && time_last_seen == other.time_last_seen end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/jms/models/application_usage.rb', line 227 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
207 208 209 |
# File 'lib/oci/jms/models/application_usage.rb', line 207 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/oci/jms/models/application_usage.rb', line 216 def hash [application_id, display_name, application_type, approximate_installation_count, approximate_jre_count, approximate_managed_instance_count, time_start, time_end, time_first_seen, time_last_seen].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/jms/models/application_usage.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
254 255 256 |
# File 'lib/oci/jms/models/application_usage.rb', line 254 def to_s to_hash.to_s end |