Class: OCI::Jms::Models::Fleet
- Inherits:
-
Object
- Object
- OCI::Jms::Models::Fleet
- Defined in:
- lib/oci/jms/models/fleet.rb
Overview
A Fleet is the primary collection with which users interact when using Java Management Service.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#approximate_application_count ⇒ Integer
**[Required]** The approximate count of all unique applications in the Fleet in the past seven days.
-
#approximate_installation_count ⇒ Integer
**[Required]** The approximate count of all unique Java installations in the Fleet in the past seven days.
-
#approximate_jre_count ⇒ Integer
**[Required]** The approximate count of all unique Java Runtimes in the Fleet in the past seven days.
-
#approximate_managed_instance_count ⇒ Integer
**[Required]** The approximate count of all unique managed instances in the Fleet in the past seven days.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment of the Fleet.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
**[Required]** The Fleet's description.
-
#display_name ⇒ String
**[Required]** The name of the Fleet.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Fleet.
- #inventory_log ⇒ OCI::Jms::Models::CustomLog
-
#lifecycle_state ⇒ String
**[Required]** The lifecycle state of the Fleet.
- #operation_log ⇒ OCI::Jms::Models::CustomLog
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
**[Required]** The creation date and time of the Fleet (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Fleet
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Fleet
Initializes the object
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/oci/jms/models/fleet.rb', line 167 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.approximate_jre_count = attributes[:'approximateJreCount'] if attributes[:'approximateJreCount'] raise 'You cannot provide both :approximateJreCount and :approximate_jre_count' if attributes.key?(:'approximateJreCount') && attributes.key?(:'approximate_jre_count') self.approximate_jre_count = attributes[:'approximate_jre_count'] if attributes[:'approximate_jre_count'] self.approximate_installation_count = attributes[:'approximateInstallationCount'] if attributes[:'approximateInstallationCount'] raise 'You cannot provide both :approximateInstallationCount and :approximate_installation_count' if attributes.key?(:'approximateInstallationCount') && attributes.key?(:'approximate_installation_count') self.approximate_installation_count = attributes[:'approximate_installation_count'] if attributes[:'approximate_installation_count'] self.approximate_application_count = attributes[:'approximateApplicationCount'] if attributes[:'approximateApplicationCount'] raise 'You cannot provide both :approximateApplicationCount and :approximate_application_count' if attributes.key?(:'approximateApplicationCount') && attributes.key?(:'approximate_application_count') self.approximate_application_count = attributes[:'approximate_application_count'] if attributes[:'approximate_application_count'] self.approximate_managed_instance_count = attributes[:'approximateManagedInstanceCount'] if attributes[:'approximateManagedInstanceCount'] raise 'You cannot provide both :approximateManagedInstanceCount and :approximate_managed_instance_count' if attributes.key?(:'approximateManagedInstanceCount') && attributes.key?(:'approximate_managed_instance_count') self.approximate_managed_instance_count = attributes[:'approximate_managed_instance_count'] if attributes[:'approximate_managed_instance_count'] self.inventory_log = attributes[:'inventoryLog'] if attributes[:'inventoryLog'] raise 'You cannot provide both :inventoryLog and :inventory_log' if attributes.key?(:'inventoryLog') && attributes.key?(:'inventory_log') self.inventory_log = attributes[:'inventory_log'] if attributes[:'inventory_log'] self.operation_log = attributes[:'operationLog'] if attributes[:'operationLog'] raise 'You cannot provide both :operationLog and :operation_log' if attributes.key?(:'operationLog') && attributes.key?(:'operation_log') self.operation_log = attributes[:'operation_log'] if attributes[:'operation_log'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#approximate_application_count ⇒ Integer
**[Required]** The approximate count of all unique applications in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
56 57 58 |
# File 'lib/oci/jms/models/fleet.rb', line 56 def approximate_application_count @approximate_application_count end |
#approximate_installation_count ⇒ Integer
**[Required]** The approximate count of all unique Java installations in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
50 51 52 |
# File 'lib/oci/jms/models/fleet.rb', line 50 def approximate_installation_count @approximate_installation_count end |
#approximate_jre_count ⇒ Integer
**[Required]** The approximate count of all unique Java Runtimes in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
44 45 46 |
# File 'lib/oci/jms/models/fleet.rb', line 44 def approximate_jre_count @approximate_jre_count end |
#approximate_managed_instance_count ⇒ Integer
**[Required]** The approximate count of all unique managed instances in the Fleet in the past seven days. This metric is provided on a best-effort manner, and is not taken into account when computing the resource ETag.
62 63 64 |
# File 'lib/oci/jms/models/fleet.rb', line 62 def approximate_managed_instance_count @approximate_managed_instance_count end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment of the Fleet.
38 39 40 |
# File 'lib/oci/jms/models/fleet.rb', line 38 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`. (See [Understanding Free-form Tags](docs.cloud.oracle.com/Content/Tagging/Tasks/managingtagsandtagnamespaces.htm)).
83 84 85 |
# File 'lib/oci/jms/models/fleet.rb', line 83 def @defined_tags end |
#description ⇒ String
**[Required]** The Fleet's description.
33 34 35 |
# File 'lib/oci/jms/models/fleet.rb', line 33 def description @description end |
#display_name ⇒ String
**[Required]** The name of the Fleet.
29 30 31 |
# File 'lib/oci/jms/models/fleet.rb', line 29 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`. (See [Managing Tags and Tag Namespaces](docs.cloud.oracle.com/Content/Tagging/Concepts/understandingfreeformtags.htm).)
89 90 91 |
# File 'lib/oci/jms/models/fleet.rb', line 89 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Fleet.
25 26 27 |
# File 'lib/oci/jms/models/fleet.rb', line 25 def id @id end |
#inventory_log ⇒ OCI::Jms::Models::CustomLog
65 66 67 |
# File 'lib/oci/jms/models/fleet.rb', line 65 def inventory_log @inventory_log end |
#lifecycle_state ⇒ String
**[Required]** The lifecycle state of the Fleet.
77 78 79 |
# File 'lib/oci/jms/models/fleet.rb', line 77 def lifecycle_state @lifecycle_state end |
#operation_log ⇒ OCI::Jms::Models::CustomLog
68 69 70 |
# File 'lib/oci/jms/models/fleet.rb', line 68 def operation_log @operation_log end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). System tags can be viewed by users, but can only be created by the system.
Example: `{"free-tier-retained": "true"}`
98 99 100 |
# File 'lib/oci/jms/models/fleet.rb', line 98 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The creation date and time of the Fleet (formatted according to [RFC3339](datatracker.ietf.org/doc/html/rfc3339)).
73 74 75 |
# File 'lib/oci/jms/models/fleet.rb', line 73 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/oci/jms/models/fleet.rb', line 101 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'approximate_jre_count': :'approximateJreCount', 'approximate_installation_count': :'approximateInstallationCount', 'approximate_application_count': :'approximateApplicationCount', 'approximate_managed_instance_count': :'approximateManagedInstanceCount', 'inventory_log': :'inventoryLog', 'operation_log': :'operationLog', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/jms/models/fleet.rb', line 124 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'approximate_jre_count': :'Integer', 'approximate_installation_count': :'Integer', 'approximate_application_count': :'Integer', 'approximate_managed_instance_count': :'Integer', 'inventory_log': :'OCI::Jms::Models::CustomLog', 'operation_log': :'OCI::Jms::Models::CustomLog', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/oci/jms/models/fleet.rb', line 276 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && approximate_jre_count == other.approximate_jre_count && approximate_installation_count == other.approximate_installation_count && approximate_application_count == other.approximate_application_count && approximate_managed_instance_count == other.approximate_managed_instance_count && inventory_log == other.inventory_log && operation_log == other.operation_log && time_created == other.time_created && lifecycle_state == other.lifecycle_state && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/oci/jms/models/fleet.rb', line 320 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
300 301 302 |
# File 'lib/oci/jms/models/fleet.rb', line 300 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/oci/jms/models/fleet.rb', line 309 def hash [id, display_name, description, compartment_id, approximate_jre_count, approximate_installation_count, approximate_application_count, approximate_managed_instance_count, inventory_log, operation_log, time_created, lifecycle_state, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 362 |
# File 'lib/oci/jms/models/fleet.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
347 348 349 |
# File 'lib/oci/jms/models/fleet.rb', line 347 def to_s to_hash.to_s end |