Class: OCI::Jms::Models::InstallationUsage

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/jms/models/installation_usage.rb

Overview

Installation usage during a specified time period. An installation is a collection of deployed instances of a specific Java Runtime that share the same install path.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InstallationUsage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :jre_vendor (String)

    The value to assign to the #jre_vendor property

  • :jre_distribution (String)

    The value to assign to the #jre_distribution property

  • :jre_version (String)

    The value to assign to the #jre_version property

  • :path (String)

    The value to assign to the #path property

  • :os (String)

    The value to assign to the #os property

  • :architecture (String)

    The value to assign to the #architecture property

  • :approximate_application_count (Integer)

    The value to assign to the #approximate_application_count property

  • :approximate_managed_instance_count (Integer)

    The value to assign to the #approximate_managed_instance_count property

  • :time_start (DateTime)

    The value to assign to the #time_start property

  • :time_end (DateTime)

    The value to assign to the #time_end property

  • :time_first_seen (DateTime)

    The value to assign to the #time_first_seen property

  • :time_last_seen (DateTime)

    The value to assign to the #time_last_seen property



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/jms/models/installation_usage.rb', line 126

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.jre_vendor = attributes[:'jreVendor'] if attributes[:'jreVendor']

  raise 'You cannot provide both :jreVendor and :jre_vendor' if attributes.key?(:'jreVendor') && attributes.key?(:'jre_vendor')

  self.jre_vendor = attributes[:'jre_vendor'] if attributes[:'jre_vendor']

  self.jre_distribution = attributes[:'jreDistribution'] if attributes[:'jreDistribution']

  raise 'You cannot provide both :jreDistribution and :jre_distribution' if attributes.key?(:'jreDistribution') && attributes.key?(:'jre_distribution')

  self.jre_distribution = attributes[:'jre_distribution'] if attributes[:'jre_distribution']

  self.jre_version = attributes[:'jreVersion'] if attributes[:'jreVersion']

  raise 'You cannot provide both :jreVersion and :jre_version' if attributes.key?(:'jreVersion') && attributes.key?(:'jre_version')

  self.jre_version = attributes[:'jre_version'] if attributes[:'jre_version']

  self.path = attributes[:'path'] if attributes[:'path']

  self.os = attributes[:'os'] if attributes[:'os']

  self.architecture = attributes[:'architecture'] if attributes[:'architecture']

  self.approximate_application_count = attributes[:'approximateApplicationCount'] if attributes[:'approximateApplicationCount']

  raise 'You cannot provide both :approximateApplicationCount and :approximate_application_count' if attributes.key?(:'approximateApplicationCount') && attributes.key?(:'approximate_application_count')

  self.approximate_application_count = attributes[:'approximate_application_count'] if attributes[:'approximate_application_count']

  self.approximate_managed_instance_count = attributes[:'approximateManagedInstanceCount'] if attributes[:'approximateManagedInstanceCount']

  raise 'You cannot provide both :approximateManagedInstanceCount and :approximate_managed_instance_count' if attributes.key?(:'approximateManagedInstanceCount') && attributes.key?(:'approximate_managed_instance_count')

  self.approximate_managed_instance_count = attributes[:'approximate_managed_instance_count'] if attributes[:'approximate_managed_instance_count']

  self.time_start = attributes[:'timeStart'] if attributes[:'timeStart']

  raise 'You cannot provide both :timeStart and :time_start' if attributes.key?(:'timeStart') && attributes.key?(:'time_start')

  self.time_start = attributes[:'time_start'] if attributes[:'time_start']

  self.time_end = attributes[:'timeEnd'] if attributes[:'timeEnd']

  raise 'You cannot provide both :timeEnd and :time_end' if attributes.key?(:'timeEnd') && attributes.key?(:'time_end')

  self.time_end = attributes[:'time_end'] if attributes[:'time_end']

  self.time_first_seen = attributes[:'timeFirstSeen'] if attributes[:'timeFirstSeen']

  raise 'You cannot provide both :timeFirstSeen and :time_first_seen' if attributes.key?(:'timeFirstSeen') && attributes.key?(:'time_first_seen')

  self.time_first_seen = attributes[:'time_first_seen'] if attributes[:'time_first_seen']

  self.time_last_seen = attributes[:'timeLastSeen'] if attributes[:'timeLastSeen']

  raise 'You cannot provide both :timeLastSeen and :time_last_seen' if attributes.key?(:'timeLastSeen') && attributes.key?(:'time_last_seen')

  self.time_last_seen = attributes[:'time_last_seen'] if attributes[:'time_last_seen']
end

Instance Attribute Details

#approximate_application_countInteger

The approximate count of applications running on this installation

Returns:

  • (Integer)


38
39
40
# File 'lib/oci/jms/models/installation_usage.rb', line 38

def approximate_application_count
  @approximate_application_count
end

#approximate_managed_instance_countInteger

The approximate count of managed instances reporting this installation

Returns:

  • (Integer)


42
43
44
# File 'lib/oci/jms/models/installation_usage.rb', line 42

def approximate_managed_instance_count
  @approximate_managed_instance_count
end

#architectureString

[Required] The architecture of the operating system for the installation.

Returns:

  • (String)


34
35
36
# File 'lib/oci/jms/models/installation_usage.rb', line 34

def architecture
  @architecture
end

#jre_distributionString

[Required] The distribution of the Java Runtime that is deployed with the installation.

Returns:

  • (String)


18
19
20
# File 'lib/oci/jms/models/installation_usage.rb', line 18

def jre_distribution
  @jre_distribution
end

#jre_vendorString

[Required] The vendor of the Java Runtime that is deployed with the installation.

Returns:

  • (String)


14
15
16
# File 'lib/oci/jms/models/installation_usage.rb', line 14

def jre_vendor
  @jre_vendor
end

#jre_versionString

[Required] The version of the Java Runtime that is deployed with the installation.

Returns:

  • (String)


22
23
24
# File 'lib/oci/jms/models/installation_usage.rb', line 22

def jre_version
  @jre_version
end

#osString

[Required] The Operating System for the installation.

Returns:

  • (String)


30
31
32
# File 'lib/oci/jms/models/installation_usage.rb', line 30

def os
  @os
end

#pathString

[Required] The file system path of the installation.

Returns:

  • (String)


26
27
28
# File 'lib/oci/jms/models/installation_usage.rb', line 26

def path
  @path
end

#time_endDateTime

Upper bound of the specified time period filter.

Returns:

  • (DateTime)


50
51
52
# File 'lib/oci/jms/models/installation_usage.rb', line 50

def time_end
  @time_end
end

#time_first_seenDateTime

The date and time the resource was first reported to JMS. This is potentially before the specified time period provided by the filters. For example, a resource can be first reported to JMS before the start of a specified time period, if it is also reported during the time period.

Returns:

  • (DateTime)


58
59
60
# File 'lib/oci/jms/models/installation_usage.rb', line 58

def time_first_seen
  @time_first_seen
end

#time_last_seenDateTime

The date and time the resource was last reported to JMS. This is potentially after the specified time period provided by the filters. For example, a resource can be last reported to JMS before the start of a specified time period, if it is also reported during the time period.

Returns:

  • (DateTime)


66
67
68
# File 'lib/oci/jms/models/installation_usage.rb', line 66

def time_last_seen
  @time_last_seen
end

#time_startDateTime

Lower bound of the specified time period filter.

Returns:

  • (DateTime)


46
47
48
# File 'lib/oci/jms/models/installation_usage.rb', line 46

def time_start
  @time_start
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/oci/jms/models/installation_usage.rb', line 69

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'jre_vendor': :'jreVendor',
    'jre_distribution': :'jreDistribution',
    'jre_version': :'jreVersion',
    'path': :'path',
    'os': :'os',
    'architecture': :'architecture',
    'approximate_application_count': :'approximateApplicationCount',
    'approximate_managed_instance_count': :'approximateManagedInstanceCount',
    'time_start': :'timeStart',
    'time_end': :'timeEnd',
    'time_first_seen': :'timeFirstSeen',
    'time_last_seen': :'timeLastSeen'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/oci/jms/models/installation_usage.rb', line 89

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'jre_vendor': :'String',
    'jre_distribution': :'String',
    'jre_version': :'String',
    'path': :'String',
    'os': :'String',
    'architecture': :'String',
    'approximate_application_count': :'Integer',
    'approximate_managed_instance_count': :'Integer',
    'time_start': :'DateTime',
    'time_end': :'DateTime',
    'time_first_seen': :'DateTime',
    'time_last_seen': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/jms/models/installation_usage.rb', line 200

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    jre_vendor == other.jre_vendor &&
    jre_distribution == other.jre_distribution &&
    jre_version == other.jre_version &&
    path == other.path &&
    os == other.os &&
    architecture == other.architecture &&
    approximate_application_count == other.approximate_application_count &&
    approximate_managed_instance_count == other.approximate_managed_instance_count &&
    time_start == other.time_start &&
    time_end == other.time_end &&
    time_first_seen == other.time_first_seen &&
    time_last_seen == other.time_last_seen
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/oci/jms/models/installation_usage.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/oci/jms/models/installation_usage.rb', line 221

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



230
231
232
# File 'lib/oci/jms/models/installation_usage.rb', line 230

def hash
  [jre_vendor, jre_distribution, jre_version, path, os, architecture, approximate_application_count, approximate_managed_instance_count, time_start, time_end, time_first_seen, time_last_seen].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/jms/models/installation_usage.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



268
269
270
# File 'lib/oci/jms/models/installation_usage.rb', line 268

def to_s
  to_hash.to_s
end