Class: OCI::KeyManagement::Models::KeySummary
- Inherits:
-
Object
- Object
- OCI::KeyManagement::Models::KeySummary
- Defined in:
- lib/oci/key_management/models/key_summary.rb
Overview
KeySummary model.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ENABLING = 'ENABLING'.freeze, LIFECYCLE_STATE_ENABLED = 'ENABLED'.freeze, LIFECYCLE_STATE_DISABLING = 'DISABLING'.freeze, LIFECYCLE_STATE_DISABLED = 'DISABLED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_PENDING_DELETION = 'PENDING_DELETION'.freeze, LIFECYCLE_STATE_SCHEDULING_DELETION = 'SCHEDULING_DELETION'.freeze, LIFECYCLE_STATE_CANCELLING_DELETION = 'CANCELLING_DELETION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the key.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#display_name ⇒ String
[Required] A user-friendly name for the key.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope.
-
#id ⇒ String
[Required] The OCID of the key.
-
#lifecycle_state ⇒ String
[Required] The key’s current state.
-
#time_created ⇒ DateTime
[Required] The date and time the key was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#vault_id ⇒ String
[Required] The OCID of the vault that contains the key.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ KeySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ KeySummary
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/key_management/models/key_summary.rb', line 115 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.vault_id = attributes[:'vaultId'] if attributes[:'vaultId'] raise 'You cannot provide both :vaultId and :vault_id' if attributes.key?(:'vaultId') && attributes.key?(:'vault_id') self.vault_id = attributes[:'vault_id'] if attributes[:'vault_id'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the key.
26 27 28 |
# File 'lib/oci/key_management/models/key_summary.rb', line 26 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: ‘{"bar-key": "foo-value"}`
32 33 34 |
# File 'lib/oci/key_management/models/key_summary.rb', line 32 def @defined_tags end |
#display_name ⇒ String
[Required] A user-friendly name for the key. It does not have to be unique, and it is changeable. Avoid entering confidential information.
38 39 40 |
# File 'lib/oci/key_management/models/key_summary.rb', line 38 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`
45 46 47 |
# File 'lib/oci/key_management/models/key_summary.rb', line 45 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of the key.
49 50 51 |
# File 'lib/oci/key_management/models/key_summary.rb', line 49 def id @id end |
#lifecycle_state ⇒ String
[Required] The key’s current state.
Example: ENABLED
56 57 58 |
# File 'lib/oci/key_management/models/key_summary.rb', line 56 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
[Required] The date and time the key was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Example: 2018-04-03T21:10:29.600Z
63 64 65 |
# File 'lib/oci/key_management/models/key_summary.rb', line 63 def time_created @time_created end |
#vault_id ⇒ String
[Required] The OCID of the vault that contains the key.
67 68 69 |
# File 'lib/oci/key_management/models/key_summary.rb', line 67 def vault_id @vault_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/oci/key_management/models/key_summary.rb', line 70 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'vault_id': :'vaultId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/key_management/models/key_summary.rb', line 86 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'vault_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/oci/key_management/models/key_summary.rb', line 186 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_state == other.lifecycle_state && time_created == other.time_created && vault_id == other.vault_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/key_management/models/key_summary.rb', line 223 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
203 204 205 |
# File 'lib/oci/key_management/models/key_summary.rb', line 203 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/oci/key_management/models/key_summary.rb', line 212 def hash [compartment_id, , display_name, , id, lifecycle_state, time_created, vault_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 |
# File 'lib/oci/key_management/models/key_summary.rb', line 256 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
250 251 252 |
# File 'lib/oci/key_management/models/key_summary.rb', line 250 def to_s to_hash.to_s end |