Class: KeyManagement::Models::Vault
- Inherits:
-
Object
- Object
- KeyManagement::Models::Vault
- Defined in:
- lib/oci/key_management/models/vault.rb
Overview
Vault model.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_PENDING_DELETION = 'PENDING_DELETION'.freeze, LIFECYCLE_STATE_SCHEDULING_DELETION = 'SCHEDULING_DELETION'.freeze, LIFECYCLE_STATE_CANCELLING_DELETION = 'CANCELLING_DELETION'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_BACKUP_IN_PROGRESS = 'BACKUP_IN_PROGRESS'.freeze, LIFECYCLE_STATE_RESTORING = 'RESTORING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- VAULT_TYPE_ENUM =
[ VAULT_TYPE_VIRTUAL_PRIVATE = 'VIRTUAL_PRIVATE'.freeze, VAULT_TYPE_DEFAULT = 'DEFAULT'.freeze, VAULT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains this vault.
-
#crypto_endpoint ⇒ String
**[Required]** The service endpoint to perform cryptographic operations against.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** A user-friendly name for the vault.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
**[Required]** The OCID of the vault.
- #is_primary ⇒ BOOLEAN
-
#lifecycle_state ⇒ String
**[Required]** The vault's current lifecycle state.
-
#management_endpoint ⇒ String
**[Required]** The service endpoint to perform management operations against.
- #replica_details ⇒ OCI::KeyManagement::Models::VaultReplicaDetails
-
#restored_from_vault_id ⇒ String
The OCID of the vault from which this vault was restored, if it was restored from a backup file.
-
#time_created ⇒ DateTime
**[Required]** The date and time this vault was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_of_deletion ⇒ DateTime
An optional property to indicate when to delete the vault, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#vault_type ⇒ String
**[Required]** The type of vault.
-
#wrappingkey_id ⇒ String
**[Required]** The OCID of the vault's wrapping key.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Vault
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Vault
Initializes the object
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/oci/key_management/models/vault.rb', line 181 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.crypto_endpoint = attributes[:'cryptoEndpoint'] if attributes[:'cryptoEndpoint'] raise 'You cannot provide both :cryptoEndpoint and :crypto_endpoint' if attributes.key?(:'cryptoEndpoint') && attributes.key?(:'crypto_endpoint') self.crypto_endpoint = attributes[:'crypto_endpoint'] if attributes[:'crypto_endpoint'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.management_endpoint = attributes[:'managementEndpoint'] if attributes[:'managementEndpoint'] raise 'You cannot provide both :managementEndpoint and :management_endpoint' if attributes.key?(:'managementEndpoint') && attributes.key?(:'management_endpoint') self.management_endpoint = attributes[:'management_endpoint'] if attributes[:'management_endpoint'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_of_deletion = attributes[:'timeOfDeletion'] if attributes[:'timeOfDeletion'] raise 'You cannot provide both :timeOfDeletion and :time_of_deletion' if attributes.key?(:'timeOfDeletion') && attributes.key?(:'time_of_deletion') self.time_of_deletion = attributes[:'time_of_deletion'] if attributes[:'time_of_deletion'] self.vault_type = attributes[:'vaultType'] if attributes[:'vaultType'] raise 'You cannot provide both :vaultType and :vault_type' if attributes.key?(:'vaultType') && attributes.key?(:'vault_type') self.vault_type = attributes[:'vault_type'] if attributes[:'vault_type'] self.restored_from_vault_id = attributes[:'restoredFromVaultId'] if attributes[:'restoredFromVaultId'] raise 'You cannot provide both :restoredFromVaultId and :restored_from_vault_id' if attributes.key?(:'restoredFromVaultId') && attributes.key?(:'restored_from_vault_id') self.restored_from_vault_id = attributes[:'restored_from_vault_id'] if attributes[:'restored_from_vault_id'] self.wrappingkey_id = attributes[:'wrappingkeyId'] if attributes[:'wrappingkeyId'] raise 'You cannot provide both :wrappingkeyId and :wrappingkey_id' if attributes.key?(:'wrappingkeyId') && attributes.key?(:'wrappingkey_id') self.wrappingkey_id = attributes[:'wrappingkey_id'] if attributes[:'wrappingkey_id'] self.replica_details = attributes[:'replicaDetails'] if attributes[:'replicaDetails'] raise 'You cannot provide both :replicaDetails and :replica_details' if attributes.key?(:'replicaDetails') && attributes.key?(:'replica_details') self.replica_details = attributes[:'replica_details'] if attributes[:'replica_details'] self.is_primary = attributes[:'isPrimary'] unless attributes[:'isPrimary'].nil? raise 'You cannot provide both :isPrimary and :is_primary' if attributes.key?(:'isPrimary') && attributes.key?(:'is_primary') self.is_primary = attributes[:'is_primary'] unless attributes[:'is_primary'].nil? end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment that contains this vault.
33 34 35 |
# File 'lib/oci/key_management/models/vault.rb', line 33 def compartment_id @compartment_id end |
#crypto_endpoint ⇒ String
**[Required]** The service endpoint to perform cryptographic operations against. Cryptographic operations include [Encrypt](docs.cloud.oracle.com/api/#/en/key/latest/EncryptedData/Encrypt), [Decrypt](docs.cloud.oracle.com/api/#/en/key/latest/DecryptedData/Decrypt), and [GenerateDataEncryptionKey](docs.cloud.oracle.com/api/#/en/key/latest/GeneratedKey/GenerateDataEncryptionKey) operations.
40 41 42 |
# File 'lib/oci/key_management/models/vault.rb', line 40 def crypto_endpoint @crypto_endpoint end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
47 48 49 |
# File 'lib/oci/key_management/models/vault.rb', line 47 def @defined_tags end |
#display_name ⇒ String
**[Required]** A user-friendly name for the vault. It does not have to be unique, and it is changeable. Avoid entering confidential information.
53 54 55 |
# File 'lib/oci/key_management/models/vault.rb', line 53 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
60 61 62 |
# File 'lib/oci/key_management/models/vault.rb', line 60 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the vault.
64 65 66 |
# File 'lib/oci/key_management/models/vault.rb', line 64 def id @id end |
#is_primary ⇒ BOOLEAN
112 113 114 |
# File 'lib/oci/key_management/models/vault.rb', line 112 def is_primary @is_primary end |
#lifecycle_state ⇒ String
**[Required]** The vault's current lifecycle state.
Example: `DELETED`
71 72 73 |
# File 'lib/oci/key_management/models/vault.rb', line 71 def lifecycle_state @lifecycle_state end |
#management_endpoint ⇒ String
**[Required]** The service endpoint to perform management operations against. Management operations include "Create," "Update," "List," "Get," and "Delete" operations.
76 77 78 |
# File 'lib/oci/key_management/models/vault.rb', line 76 def management_endpoint @management_endpoint end |
#replica_details ⇒ OCI::KeyManagement::Models::VaultReplicaDetails
109 110 111 |
# File 'lib/oci/key_management/models/vault.rb', line 109 def replica_details @replica_details end |
#restored_from_vault_id ⇒ String
The OCID of the vault from which this vault was restored, if it was restored from a backup file. If you restore a vault to the same region, the vault retains the same OCID that it had when you backed up the vault.
102 103 104 |
# File 'lib/oci/key_management/models/vault.rb', line 102 def restored_from_vault_id @restored_from_vault_id end |
#time_created ⇒ DateTime
**[Required]** The date and time this vault was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Example: `2018-04-03T21:10:29.600Z`
83 84 85 |
# File 'lib/oci/key_management/models/vault.rb', line 83 def time_created @time_created end |
#time_of_deletion ⇒ DateTime
An optional property to indicate when to delete the vault, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: `2018-04-03T21:10:29.600Z`
89 90 91 |
# File 'lib/oci/key_management/models/vault.rb', line 89 def time_of_deletion @time_of_deletion end |
#vault_type ⇒ String
**[Required]** The type of vault. Each type of vault stores the key with different degrees of isolation and has different options and pricing.
95 96 97 |
# File 'lib/oci/key_management/models/vault.rb', line 95 def vault_type @vault_type end |
#wrappingkey_id ⇒ String
**[Required]** The OCID of the vault's wrapping key.
106 107 108 |
# File 'lib/oci/key_management/models/vault.rb', line 106 def wrappingkey_id @wrappingkey_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/key_management/models/vault.rb', line 115 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'crypto_endpoint': :'cryptoEndpoint', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'lifecycle_state': :'lifecycleState', 'management_endpoint': :'managementEndpoint', 'time_created': :'timeCreated', 'time_of_deletion': :'timeOfDeletion', 'vault_type': :'vaultType', 'restored_from_vault_id': :'restoredFromVaultId', 'wrappingkey_id': :'wrappingkeyId', 'replica_details': :'replicaDetails', 'is_primary': :'isPrimary' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/key_management/models/vault.rb', line 138 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'crypto_endpoint': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'lifecycle_state': :'String', 'management_endpoint': :'String', 'time_created': :'DateTime', 'time_of_deletion': :'DateTime', 'vault_type': :'String', 'restored_from_vault_id': :'String', 'wrappingkey_id': :'String', 'replica_details': :'OCI::KeyManagement::Models::VaultReplicaDetails', 'is_primary': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/oci/key_management/models/vault.rb', line 307 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && crypto_endpoint == other.crypto_endpoint && == other. && display_name == other.display_name && == other. && id == other.id && lifecycle_state == other.lifecycle_state && management_endpoint == other.management_endpoint && time_created == other.time_created && time_of_deletion == other.time_of_deletion && vault_type == other.vault_type && restored_from_vault_id == other.restored_from_vault_id && wrappingkey_id == other.wrappingkey_id && replica_details == other.replica_details && is_primary == other.is_primary end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/oci/key_management/models/vault.rb', line 351 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
331 332 333 |
# File 'lib/oci/key_management/models/vault.rb', line 331 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
340 341 342 |
# File 'lib/oci/key_management/models/vault.rb', line 340 def hash [compartment_id, crypto_endpoint, , display_name, , id, lifecycle_state, management_endpoint, time_created, time_of_deletion, vault_type, restored_from_vault_id, wrappingkey_id, replica_details, is_primary].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
384 385 386 387 388 389 390 391 392 393 |
# File 'lib/oci/key_management/models/vault.rb', line 384 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
378 379 380 |
# File 'lib/oci/key_management/models/vault.rb', line 378 def to_s to_hash.to_s end |