Class: OCI::KeyManagement::Models::WrappedImportKey
- Inherits:
-
Object
- Object
- OCI::KeyManagement::Models::WrappedImportKey
- Defined in:
- lib/oci/key_management/models/wrapped_import_key.rb
Overview
WrappedImportKey model.
Constant Summary collapse
- WRAPPING_ALGORITHM_ENUM =
[ WRAPPING_ALGORITHM_RSA_OAEP_SHA256 = 'RSA_OAEP_SHA256'.freeze, WRAPPING_ALGORITHM_RSA_OAEP_AES_SHA256 = 'RSA_OAEP_AES_SHA256'.freeze ].freeze
Instance Attribute Summary collapse
-
#key_material ⇒ String
[Required] The key material to import, wrapped by the vault’s RSA public wrapping key and base64-encoded.
-
#wrapping_algorithm ⇒ String
[Required] The wrapping mechanism to use during key import.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WrappedImportKey
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WrappedImportKey
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 56 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.key_material = attributes[:'keyMaterial'] if attributes[:'keyMaterial'] raise 'You cannot provide both :keyMaterial and :key_material' if attributes.key?(:'keyMaterial') && attributes.key?(:'key_material') self.key_material = attributes[:'key_material'] if attributes[:'key_material'] self.wrapping_algorithm = attributes[:'wrappingAlgorithm'] if attributes[:'wrappingAlgorithm'] raise 'You cannot provide both :wrappingAlgorithm and :wrapping_algorithm' if attributes.key?(:'wrappingAlgorithm') && attributes.key?(:'wrapping_algorithm') self.wrapping_algorithm = attributes[:'wrapping_algorithm'] if attributes[:'wrapping_algorithm'] end |
Instance Attribute Details
#key_material ⇒ String
[Required] The key material to import, wrapped by the vault’s RSA public wrapping key and base64-encoded.
17 18 19 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 17 def key_material @key_material end |
#wrapping_algorithm ⇒ String
[Required] The wrapping mechanism to use during key import. RSA_OAEP_AES_SHA256 invokes the RSA AES key wrap mechanism, which generates a temporary AES key. The temporary AES key is wrapped by the vault’s RSA public wrapping key, creating a wrapped temporary AES key. The temporary AES key is also used to wrap the private key material. The wrapped temporary AES key and the wrapped exportable key material are concatenated, producing concatenated blob output that jointly represents them. RSA_OAEP_SHA256 means that the exportable key material is wrapped by the vault’s RSA public wrapping key.
26 27 28 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 26 def wrapping_algorithm @wrapping_algorithm end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 29 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'key_material': :'keyMaterial', 'wrapping_algorithm': :'wrappingAlgorithm' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'key_material': :'String', 'wrapping_algorithm': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
90 91 92 93 94 95 96 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 90 def ==(other) return true if equal?(other) self.class == other.class && key_material == other.key_material && wrapping_algorithm == other.wrapping_algorithm end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 121 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
101 102 103 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 101 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
110 111 112 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 110 def hash [key_material, wrapping_algorithm].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 154 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
148 149 150 |
# File 'lib/oci/key_management/models/wrapped_import_key.rb', line 148 def to_s to_hash.to_s end |