Class: OCI::LoadBalancer::Models::CreateListenerDetails
- Inherits:
-
Object
- Object
- OCI::LoadBalancer::Models::CreateListenerDetails
- Defined in:
- lib/oci/load_balancer/models/create_listener_details.rb
Overview
The configuration details for adding a listener to a backend set. For more information on listener configuration, see [Managing Load Balancer Listeners](docs.cloud.oracle.com/Content/Balance/Tasks/managinglisteners.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Instance Attribute Summary collapse
- #connection_configuration ⇒ OCI::LoadBalancer::Models::ConnectionConfiguration
-
#default_backend_set_name ⇒ String
[Required] The name of the associated backend set.
-
#hostname_names ⇒ Array<String>
An array of hostname resource names.
-
#name ⇒ String
[Required] A friendly name for the listener.
-
#path_route_set_name ⇒ String
Deprecated.
-
#port ⇒ Integer
[Required] The communication port for the listener.
-
#protocol ⇒ String
[Required] The protocol on which the listener accepts connection requests.
-
#routing_policy_name ⇒ String
The name of the routing policy applied to this listener’s traffic.
-
#rule_set_names ⇒ Array<String>
The names of the RuleSet to apply to the listener.
- #ssl_configuration ⇒ OCI::LoadBalancer::Models::SSLConfigurationDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateListenerDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateListenerDetails
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 132 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.default_backend_set_name = attributes[:'defaultBackendSetName'] if attributes[:'defaultBackendSetName'] raise 'You cannot provide both :defaultBackendSetName and :default_backend_set_name' if attributes.key?(:'defaultBackendSetName') && attributes.key?(:'default_backend_set_name') self.default_backend_set_name = attributes[:'default_backend_set_name'] if attributes[:'default_backend_set_name'] self.port = attributes[:'port'] if attributes[:'port'] self.protocol = attributes[:'protocol'] if attributes[:'protocol'] self.hostname_names = attributes[:'hostnameNames'] if attributes[:'hostnameNames'] raise 'You cannot provide both :hostnameNames and :hostname_names' if attributes.key?(:'hostnameNames') && attributes.key?(:'hostname_names') self.hostname_names = attributes[:'hostname_names'] if attributes[:'hostname_names'] self.path_route_set_name = attributes[:'pathRouteSetName'] if attributes[:'pathRouteSetName'] raise 'You cannot provide both :pathRouteSetName and :path_route_set_name' if attributes.key?(:'pathRouteSetName') && attributes.key?(:'path_route_set_name') self.path_route_set_name = attributes[:'path_route_set_name'] if attributes[:'path_route_set_name'] self.ssl_configuration = attributes[:'sslConfiguration'] if attributes[:'sslConfiguration'] raise 'You cannot provide both :sslConfiguration and :ssl_configuration' if attributes.key?(:'sslConfiguration') && attributes.key?(:'ssl_configuration') self.ssl_configuration = attributes[:'ssl_configuration'] if attributes[:'ssl_configuration'] self.connection_configuration = attributes[:'connectionConfiguration'] if attributes[:'connectionConfiguration'] raise 'You cannot provide both :connectionConfiguration and :connection_configuration' if attributes.key?(:'connectionConfiguration') && attributes.key?(:'connection_configuration') self.connection_configuration = attributes[:'connection_configuration'] if attributes[:'connection_configuration'] self.name = attributes[:'name'] if attributes[:'name'] self.routing_policy_name = attributes[:'routingPolicyName'] if attributes[:'routingPolicyName'] raise 'You cannot provide both :routingPolicyName and :routing_policy_name' if attributes.key?(:'routingPolicyName') && attributes.key?(:'routing_policy_name') self.routing_policy_name = attributes[:'routing_policy_name'] if attributes[:'routing_policy_name'] self.rule_set_names = attributes[:'ruleSetNames'] if attributes[:'ruleSetNames'] raise 'You cannot provide both :ruleSetNames and :rule_set_names' if attributes.key?(:'ruleSetNames') && attributes.key?(:'rule_set_names') self.rule_set_names = attributes[:'rule_set_names'] if attributes[:'rule_set_names'] end |
Instance Attribute Details
#connection_configuration ⇒ OCI::LoadBalancer::Models::ConnectionConfiguration
56 57 58 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 56 def connection_configuration @connection_configuration end |
#default_backend_set_name ⇒ String
[Required] The name of the associated backend set.
Example: example_backend_set
20 21 22 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 20 def default_backend_set_name @default_backend_set_name end |
#hostname_names ⇒ Array<String>
An array of hostname resource names.
40 41 42 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 40 def hostname_names @hostname_names end |
#name ⇒ String
[Required] A friendly name for the listener. It must be unique and it cannot be changed. Avoid entering confidential information.
Example: example_listener
64 65 66 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 64 def name @name end |
#path_route_set_name ⇒ String
Deprecated. Please use routingPolicies instead.
The name of the set of path-based routing rules, PathRouteSet, applied to this listener’s traffic.
Example: example_path_route_set
50 51 52 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 50 def path_route_set_name @path_route_set_name end |
#port ⇒ Integer
[Required] The communication port for the listener.
Example: 80
27 28 29 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 27 def port @port end |
#protocol ⇒ String
[Required] The protocol on which the listener accepts connection requests. To get a list of valid protocols, use the list_protocols operation.
Example: HTTP
36 37 38 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 36 def protocol @protocol end |
#routing_policy_name ⇒ String
The name of the routing policy applied to this listener’s traffic.
Example: example_routing_policy
71 72 73 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 71 def routing_policy_name @routing_policy_name end |
#rule_set_names ⇒ Array<String>
The names of the RuleSet to apply to the listener.
Example: ["example_rule_set"]
78 79 80 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 78 def rule_set_names @rule_set_names end |
#ssl_configuration ⇒ OCI::LoadBalancer::Models::SSLConfigurationDetails
53 54 55 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 53 def ssl_configuration @ssl_configuration end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 81 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'default_backend_set_name': :'defaultBackendSetName', 'port': :'port', 'protocol': :'protocol', 'hostname_names': :'hostnameNames', 'path_route_set_name': :'pathRouteSetName', 'ssl_configuration': :'sslConfiguration', 'connection_configuration': :'connectionConfiguration', 'name': :'name', 'routing_policy_name': :'routingPolicyName', 'rule_set_names': :'ruleSetNames' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 99 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'default_backend_set_name': :'String', 'port': :'Integer', 'protocol': :'String', 'hostname_names': :'Array<String>', 'path_route_set_name': :'String', 'ssl_configuration': :'OCI::LoadBalancer::Models::SSLConfigurationDetails', 'connection_configuration': :'OCI::LoadBalancer::Models::ConnectionConfiguration', 'name': :'String', 'routing_policy_name': :'String', 'rule_set_names': :'Array<String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 194 def ==(other) return true if equal?(other) self.class == other.class && default_backend_set_name == other.default_backend_set_name && port == other.port && protocol == other.protocol && hostname_names == other.hostname_names && path_route_set_name == other.path_route_set_name && ssl_configuration == other.ssl_configuration && connection_configuration == other.connection_configuration && name == other.name && routing_policy_name == other.routing_policy_name && rule_set_names == other.rule_set_names end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 233 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
213 214 215 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 213 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 222 def hash [default_backend_set_name, port, protocol, hostname_names, path_route_set_name, ssl_configuration, connection_configuration, name, routing_policy_name, rule_set_names].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 266 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
260 261 262 |
# File 'lib/oci/load_balancer/models/create_listener_details.rb', line 260 def to_s to_hash.to_s end |