Class: OCI::LoadBalancer::Models::CreateLoadBalancerDetails
- Inherits:
-
Object
- Object
- OCI::LoadBalancer::Models::CreateLoadBalancerDetails
- Defined in:
- lib/oci/load_balancer/models/create_load_balancer_details.rb
Overview
The configuration details for creating a load balancer.
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Instance Attribute Summary collapse
- #backend_sets ⇒ Hash<String, OCI::LoadBalancer::Models::BackendSetDetails>
- #certificates ⇒ Hash<String, OCI::LoadBalancer::Models::CertificateDetails>
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which to create the load balancer.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
- #hostnames ⇒ Hash<String, OCI::LoadBalancer::Models::HostnameDetails>
-
#is_private ⇒ BOOLEAN
Whether the load balancer has a VCN-local (private) IP address.
- #listeners ⇒ Hash<String, OCI::LoadBalancer::Models::ListenerDetails>
-
#network_security_group_ids ⇒ Array<String>
The array of NSG [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) to be used by this Load Balancer.
- #path_route_sets ⇒ Hash<String, OCI::LoadBalancer::Models::PathRouteSetDetails>
- #rule_sets ⇒ Hash<String, OCI::LoadBalancer::Models::RuleSetDetails>
-
#shape_name ⇒ String
[Required] A template that determines the total pre-provisioned bandwidth (ingress plus egress).
-
#subnet_ids ⇒ Array<String>
[Required] An array of subnet [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateLoadBalancerDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateLoadBalancerDetails
Initializes the object
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 155 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName'] raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name') self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name'] self.is_private = attributes[:'isPrivate'] unless attributes[:'isPrivate'].nil? self.is_private = false if is_private.nil? && !attributes.key?(:'isPrivate') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPrivate and :is_private' if attributes.key?(:'isPrivate') && attributes.key?(:'is_private') self.is_private = attributes[:'is_private'] unless attributes[:'is_private'].nil? self.is_private = false if is_private.nil? && !attributes.key?(:'isPrivate') && !attributes.key?(:'is_private') # rubocop:disable Style/StringLiterals self.listeners = attributes[:'listeners'] if attributes[:'listeners'] self.hostnames = attributes[:'hostnames'] if attributes[:'hostnames'] self.backend_sets = attributes[:'backendSets'] if attributes[:'backendSets'] raise 'You cannot provide both :backendSets and :backend_sets' if attributes.key?(:'backendSets') && attributes.key?(:'backend_sets') self.backend_sets = attributes[:'backend_sets'] if attributes[:'backend_sets'] self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds'] raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids') self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids'] self.subnet_ids = attributes[:'subnetIds'] if attributes[:'subnetIds'] raise 'You cannot provide both :subnetIds and :subnet_ids' if attributes.key?(:'subnetIds') && attributes.key?(:'subnet_ids') self.subnet_ids = attributes[:'subnet_ids'] if attributes[:'subnet_ids'] self.certificates = attributes[:'certificates'] if attributes[:'certificates'] self.path_route_sets = attributes[:'pathRouteSets'] if attributes[:'pathRouteSets'] raise 'You cannot provide both :pathRouteSets and :path_route_sets' if attributes.key?(:'pathRouteSets') && attributes.key?(:'path_route_sets') self.path_route_sets = attributes[:'path_route_sets'] if attributes[:'path_route_sets'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.rule_sets = attributes[:'ruleSets'] if attributes[:'ruleSets'] raise 'You cannot provide both :ruleSets and :rule_sets' if attributes.key?(:'ruleSets') && attributes.key?(:'rule_sets') self.rule_sets = attributes[:'rule_sets'] if attributes[:'rule_sets'] end |
Instance Attribute Details
#backend_sets ⇒ Hash<String, OCI::LoadBalancer::Models::BackendSetDetails>
55 56 57 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 55 def backend_sets @backend_sets end |
#certificates ⇒ Hash<String, OCI::LoadBalancer::Models::CertificateDetails>
67 68 69 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 67 def certificates @certificates end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which to create the load balancer.
14 15 16 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 14 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
86 87 88 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 86 def end |
#display_name ⇒ String
[Required] A user-friendly name. It does not have to be unique, and it is changeable. Avoid entering confidential information.
Example: example_load_balancer
22 23 24 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 22 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
78 79 80 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 78 def end |
#hostnames ⇒ Hash<String, OCI::LoadBalancer::Models::HostnameDetails>
52 53 54 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 52 def hostnames @hostnames end |
#is_private ⇒ BOOLEAN
Whether the load balancer has a VCN-local (private) IP address.
If "true", the service assigns a private IP address to the load balancer.
If "false", the service assigns a public IP address to the load balancer.
A public load balancer is accessible from the internet, depending on your VCN’s [security list rules](docs.cloud.oracle.com/Content/Network/Concepts/securitylists.htm). For more information about public and private load balancers, see [How Load Balancing Works](docs.cloud.oracle.com/Content/Balance/Concepts/balanceoverview.htm#how-load-balancing-works).
Example: true
46 47 48 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 46 def is_private @is_private end |
#listeners ⇒ Hash<String, OCI::LoadBalancer::Models::ListenerDetails>
49 50 51 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 49 def listeners @listeners end |
#network_security_group_ids ⇒ Array<String>
The array of NSG [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) to be used by this Load Balancer.
60 61 62 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 60 def network_security_group_ids @network_security_group_ids end |
#path_route_sets ⇒ Hash<String, OCI::LoadBalancer::Models::PathRouteSetDetails>
70 71 72 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 70 def path_route_sets @path_route_sets end |
#rule_sets ⇒ Hash<String, OCI::LoadBalancer::Models::RuleSetDetails>
89 90 91 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 89 def rule_sets @rule_sets end |
#shape_name ⇒ String
[Required] A template that determines the total pre-provisioned bandwidth (ingress plus egress). To get a list of available shapes, use the list_shapes operation.
Example: 100Mbps
31 32 33 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 31 def shape_name @shape_name end |
#subnet_ids ⇒ Array<String>
[Required] An array of subnet [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
64 65 66 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 64 def subnet_ids @subnet_ids end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 92 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'shape_name': :'shapeName', 'is_private': :'isPrivate', 'listeners': :'listeners', 'hostnames': :'hostnames', 'backend_sets': :'backendSets', 'network_security_group_ids': :'networkSecurityGroupIds', 'subnet_ids': :'subnetIds', 'certificates': :'certificates', 'path_route_sets': :'pathRouteSets', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'rule_sets': :'ruleSets' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 114 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'shape_name': :'String', 'is_private': :'BOOLEAN', 'listeners': :'Hash<String, OCI::LoadBalancer::Models::ListenerDetails>', 'hostnames': :'Hash<String, OCI::LoadBalancer::Models::HostnameDetails>', 'backend_sets': :'Hash<String, OCI::LoadBalancer::Models::BackendSetDetails>', 'network_security_group_ids': :'Array<String>', 'subnet_ids': :'Array<String>', 'certificates': :'Hash<String, OCI::LoadBalancer::Models::CertificateDetails>', 'path_route_sets': :'Hash<String, OCI::LoadBalancer::Models::PathRouteSetDetails>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'rule_sets': :'Hash<String, OCI::LoadBalancer::Models::RuleSetDetails>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 243 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && shape_name == other.shape_name && is_private == other.is_private && listeners == other.listeners && hostnames == other.hostnames && backend_sets == other.backend_sets && network_security_group_ids == other.network_security_group_ids && subnet_ids == other.subnet_ids && certificates == other.certificates && path_route_sets == other.path_route_sets && == other. && == other. && rule_sets == other.rule_sets end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 286 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
266 267 268 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 266 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 275 def hash [compartment_id, display_name, shape_name, is_private, listeners, hostnames, backend_sets, network_security_group_ids, subnet_ids, certificates, path_route_sets, , , rule_sets].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
319 320 321 322 323 324 325 326 327 328 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 319 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
313 314 315 |
# File 'lib/oci/load_balancer/models/create_load_balancer_details.rb', line 313 def to_s to_hash.to_s end |