Class: OCI::LoadBalancer::Models::LoadBalancer

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/load_balancer/models/load_balancer.rb

Overview

The properties that define a load balancer. For more information, see [Managing a Load Balancer](docs.cloud.oracle.com/Content/Balance/Tasks/managingloadbalancer.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

For information about endpoints and signing API requests, see [About the API](docs.cloud.oracle.com/Content/API/Concepts/usingapi.htm). For information about available SDKs and tools, see [SDKS and Other Tools](docs.cloud.oracle.com/Content/API/Concepts/sdks.htm).

Constant Summary collapse

LIFECYCLE_STATE_ENUM =

rubocop:disable Metrics/LineLength

[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LoadBalancer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 196

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.ip_addresses = attributes[:'ipAddresses'] if attributes[:'ipAddresses']

  raise 'You cannot provide both :ipAddresses and :ip_addresses' if attributes.key?(:'ipAddresses') && attributes.key?(:'ip_addresses')

  self.ip_addresses = attributes[:'ip_addresses'] if attributes[:'ip_addresses']

  self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName']

  raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name')

  self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name']

  self.is_private = attributes[:'isPrivate'] unless attributes[:'isPrivate'].nil?

  raise 'You cannot provide both :isPrivate and :is_private' if attributes.key?(:'isPrivate') && attributes.key?(:'is_private')

  self.is_private = attributes[:'is_private'] unless attributes[:'is_private'].nil?

  self.subnet_ids = attributes[:'subnetIds'] if attributes[:'subnetIds']

  raise 'You cannot provide both :subnetIds and :subnet_ids' if attributes.key?(:'subnetIds') && attributes.key?(:'subnet_ids')

  self.subnet_ids = attributes[:'subnet_ids'] if attributes[:'subnet_ids']

  self.listeners = attributes[:'listeners'] if attributes[:'listeners']

  self.hostnames = attributes[:'hostnames'] if attributes[:'hostnames']

  self.certificates = attributes[:'certificates'] if attributes[:'certificates']

  self.backend_sets = attributes[:'backendSets'] if attributes[:'backendSets']

  raise 'You cannot provide both :backendSets and :backend_sets' if attributes.key?(:'backendSets') && attributes.key?(:'backend_sets')

  self.backend_sets = attributes[:'backend_sets'] if attributes[:'backend_sets']

  self.path_route_sets = attributes[:'pathRouteSets'] if attributes[:'pathRouteSets']

  raise 'You cannot provide both :pathRouteSets and :path_route_sets' if attributes.key?(:'pathRouteSets') && attributes.key?(:'path_route_sets')

  self.path_route_sets = attributes[:'path_route_sets'] if attributes[:'path_route_sets']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.rule_sets = attributes[:'ruleSets'] if attributes[:'ruleSets']

  raise 'You cannot provide both :ruleSets and :rule_sets' if attributes.key?(:'ruleSets') && attributes.key?(:'rule_sets')

  self.rule_sets = attributes[:'rule_sets'] if attributes[:'rule_sets']
end

Instance Attribute Details

#backend_setsHash<String, OCI::LoadBalancer::Models::BackendSet>

Returns:



99
100
101
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 99

def backend_sets
  @backend_sets
end

#certificatesHash<String, OCI::LoadBalancer::Models::Certificate>

Returns:



96
97
98
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 96

def certificates
  @certificates
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the load balancer.

Returns:

  • (String)


35
36
37
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 35

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"CostCenter": "42"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


118
119
120
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 118

def defined_tags
  @defined_tags
end

#display_nameString

[Required] A user-friendly name. It does not have to be unique, and it is changeable.

Example: example_load_balancer

Returns:

  • (String)


42
43
44
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 42

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘"Finance"`

Returns:

  • (Hash<String, String>)


110
111
112
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 110

def freeform_tags
  @freeform_tags
end

#hostnamesHash<String, OCI::LoadBalancer::Models::Hostname>

Returns:



93
94
95
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 93

def hostnames
  @hostnames
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the load balancer.

Returns:

  • (String)


31
32
33
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 31

def id
  @id
end

#ip_addressesArray<OCI::LoadBalancer::Models::IpAddress>

An array of IP addresses.



59
60
61
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 59

def ip_addresses
  @ip_addresses
end

#is_privateBOOLEAN

Whether the load balancer has a VCN-local (private) IP address.

If "true", the service assigns a private IP address to the load balancer.

If "false", the service assigns a public IP address to the load balancer.

A public load balancer is accessible from the internet, depending on your VCN’s [security list rules](docs.cloud.oracle.com/Content/Network/Concepts/securitylists.htm). For more information about public and private load balancers, see [How Load Balancing Works](docs.cloud.oracle.com/Content/Balance/Concepts/balanceoverview.htm#how-load-balancing-works).

Example: true

Returns:

  • (BOOLEAN)


83
84
85
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 83

def is_private
  @is_private
end

#lifecycle_stateString

[Required] The current state of the load balancer.

Returns:

  • (String)


47
48
49
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 47

def lifecycle_state
  @lifecycle_state
end

#listenersHash<String, OCI::LoadBalancer::Models::Listener>

Returns:



90
91
92
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 90

def listeners
  @listeners
end

#path_route_setsHash<String, OCI::LoadBalancer::Models::PathRouteSet>

Returns:



102
103
104
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 102

def path_route_sets
  @path_route_sets
end

#rule_setsHash<String, OCI::LoadBalancer::Models::RuleSet>

Returns:



121
122
123
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 121

def rule_sets
  @rule_sets
end

#shape_nameString

[Required] A template that determines the total pre-provisioned bandwidth (ingress plus egress). To get a list of available shapes, use the list_shapes operation.

Example: 100Mbps

Returns:

  • (String)


68
69
70
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 68

def shape_name
  @shape_name
end

#subnet_idsArray<String>

Returns:

  • (Array<String>)


87
88
89
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 87

def subnet_ids
  @subnet_ids
end

#time_createdDateTime

[Required] The date and time the load balancer was created, in the format defined by RFC3339.

Example: 2016-08-25T21:10:29.600Z

Returns:

  • (DateTime)


54
55
56
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 54

def time_created
  @time_created
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 124

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'ip_addresses': :'ipAddresses',
    'shape_name': :'shapeName',
    'is_private': :'isPrivate',
    'subnet_ids': :'subnetIds',
    'listeners': :'listeners',
    'hostnames': :'hostnames',
    'certificates': :'certificates',
    'backend_sets': :'backendSets',
    'path_route_sets': :'pathRouteSets',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'rule_sets': :'ruleSets'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 149

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'display_name': :'String',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'ip_addresses': :'Array<OCI::LoadBalancer::Models::IpAddress>',
    'shape_name': :'String',
    'is_private': :'BOOLEAN',
    'subnet_ids': :'Array<String>',
    'listeners': :'Hash<String, OCI::LoadBalancer::Models::Listener>',
    'hostnames': :'Hash<String, OCI::LoadBalancer::Models::Hostname>',
    'certificates': :'Hash<String, OCI::LoadBalancer::Models::Certificate>',
    'backend_sets': :'Hash<String, OCI::LoadBalancer::Models::BackendSet>',
    'path_route_sets': :'Hash<String, OCI::LoadBalancer::Models::PathRouteSet>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'rule_sets': :'Hash<String, OCI::LoadBalancer::Models::RuleSet>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 311

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    ip_addresses == other.ip_addresses &&
    shape_name == other.shape_name &&
    is_private == other.is_private &&
    subnet_ids == other.subnet_ids &&
    listeners == other.listeners &&
    hostnames == other.hostnames &&
    certificates == other.certificates &&
    backend_sets == other.backend_sets &&
    path_route_sets == other.path_route_sets &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    rule_sets == other.rule_sets
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 357

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


337
338
339
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 337

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



346
347
348
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 346

def hash
  [id, compartment_id, display_name, lifecycle_state, time_created, ip_addresses, shape_name, is_private, subnet_ids, listeners, hostnames, certificates, backend_sets, path_route_sets, freeform_tags, defined_tags, rule_sets].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



390
391
392
393
394
395
396
397
398
399
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 390

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



384
385
386
# File 'lib/oci/load_balancer/models/load_balancer.rb', line 384

def to_s
  to_hash.to_s
end