Class: OCI::LoadBalancer::Models::UpdateBackendSetDetails
- Inherits:
-
Object
- Object
- OCI::LoadBalancer::Models::UpdateBackendSetDetails
- Defined in:
- lib/oci/load_balancer/models/update_backend_set_details.rb
Overview
The configuration details for updating a load balancer backend set. For more information on backend set configuration, see [Managing Backend Sets](docs.cloud.oracle.com/Content/Balance/Tasks/managingbackendsets.htm).
Warning: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Instance Attribute Summary collapse
-
#backends ⇒ Array<OCI::LoadBalancer::Models::BackendDetails>
This attribute is required.
-
#health_checker ⇒ OCI::LoadBalancer::Models::HealthCheckerDetails
This attribute is required.
-
#policy ⇒ String
[Required] The load balancer policy for the backend set.
- #session_persistence_configuration ⇒ OCI::LoadBalancer::Models::SessionPersistenceConfigurationDetails
- #ssl_configuration ⇒ OCI::LoadBalancer::Models::SSLConfigurationDetails
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateBackendSetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateBackendSetDetails
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 73 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.policy = attributes[:'policy'] if attributes[:'policy'] self.backends = attributes[:'backends'] if attributes[:'backends'] self.health_checker = attributes[:'healthChecker'] if attributes[:'healthChecker'] raise 'You cannot provide both :healthChecker and :health_checker' if attributes.key?(:'healthChecker') && attributes.key?(:'health_checker') self.health_checker = attributes[:'health_checker'] if attributes[:'health_checker'] self.ssl_configuration = attributes[:'sslConfiguration'] if attributes[:'sslConfiguration'] raise 'You cannot provide both :sslConfiguration and :ssl_configuration' if attributes.key?(:'sslConfiguration') && attributes.key?(:'ssl_configuration') self.ssl_configuration = attributes[:'ssl_configuration'] if attributes[:'ssl_configuration'] self.session_persistence_configuration = attributes[:'sessionPersistenceConfiguration'] if attributes[:'sessionPersistenceConfiguration'] raise 'You cannot provide both :sessionPersistenceConfiguration and :session_persistence_configuration' if attributes.key?(:'sessionPersistenceConfiguration') && attributes.key?(:'session_persistence_configuration') self.session_persistence_configuration = attributes[:'session_persistence_configuration'] if attributes[:'session_persistence_configuration'] end |
Instance Attribute Details
#backends ⇒ Array<OCI::LoadBalancer::Models::BackendDetails>
This attribute is required.
24 25 26 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 24 def backends @backends end |
#health_checker ⇒ OCI::LoadBalancer::Models::HealthCheckerDetails
This attribute is required.
28 29 30 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 28 def health_checker @health_checker end |
#policy ⇒ String
[Required] The load balancer policy for the backend set. To get a list of available policies, use the list_policies operation.
Example: LEAST_CONNECTIONS
20 21 22 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 20 def policy @policy end |
#session_persistence_configuration ⇒ OCI::LoadBalancer::Models::SessionPersistenceConfigurationDetails
34 35 36 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 34 def session_persistence_configuration @session_persistence_configuration end |
#ssl_configuration ⇒ OCI::LoadBalancer::Models::SSLConfigurationDetails
31 32 33 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 31 def ssl_configuration @ssl_configuration end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'policy': :'policy', 'backends': :'backends', 'health_checker': :'healthChecker', 'ssl_configuration': :'sslConfiguration', 'session_persistence_configuration': :'sessionPersistenceConfiguration' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'policy': :'String', 'backends': :'Array<OCI::LoadBalancer::Models::BackendDetails>', 'health_checker': :'OCI::LoadBalancer::Models::HealthCheckerDetails', 'ssl_configuration': :'OCI::LoadBalancer::Models::SSLConfigurationDetails', 'session_persistence_configuration': :'OCI::LoadBalancer::Models::SessionPersistenceConfigurationDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
109 110 111 112 113 114 115 116 117 118 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 109 def ==(other) return true if equal?(other) self.class == other.class && policy == other.policy && backends == other.backends && health_checker == other.health_checker && ssl_configuration == other.ssl_configuration && session_persistence_configuration == other.session_persistence_configuration end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 143 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
123 124 125 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 123 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
132 133 134 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 132 def hash [policy, backends, health_checker, ssl_configuration, session_persistence_configuration].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 176 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
170 171 172 |
# File 'lib/oci/load_balancer/models/update_backend_set_details.rb', line 170 def to_s to_hash.to_s end |