Method: OCI::LoadBalancer::Models::WorkRequest#message
- Defined in:
- lib/oci/load_balancer/models/work_request.rb
#message ⇒ String
[Required] A collection of data, related to the load balancer provisioning process, that helps with debugging in the event of failure. Possible data elements include:
-
workflow name
-
event ID
-
work request ID
-
load balancer ID
-
workflow completion message
54 55 56 |
# File 'lib/oci/load_balancer/models/work_request.rb', line 54 def @message end |