Class: OCI::LogAnalytics::Models::CreateLogAnalyticsObjectCollectionRuleDetails
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::CreateLogAnalyticsObjectCollectionRuleDetails
- Defined in:
- lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb
Overview
The configuration details of collection rule to enable automatic log collection from an object storage bucket.
Constant Summary collapse
- COLLECTION_TYPE_ENUM =
[ COLLECTION_TYPE_LIVE = 'LIVE'.freeze, COLLECTION_TYPE_HISTORIC = 'HISTORIC'.freeze, COLLECTION_TYPE_HISTORIC_LIVE = 'HISTORIC_LIVE'.freeze ].freeze
Instance Attribute Summary collapse
-
#char_encoding ⇒ String
An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing.
-
#collection_type ⇒ String
The type of collection.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to which this rule belongs.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A string that describes the details of the rule.
-
#entity_id ⇒ String
Logging Analytics entity OCID.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_enabled ⇒ BOOLEAN
Whether or not this rule is currently enabled.
-
#log_group_id ⇒ String
[Required] Logging Analytics Log group OCID to associate the processed logs with.
-
#log_source_name ⇒ String
[Required] Name of the Logging Analytics Source to use for the processing.
-
#name ⇒ String
[Required] A unique name given to the rule.
-
#os_bucket_name ⇒ String
[Required] Name of the Object Storage bucket.
-
#os_namespace ⇒ String
[Required] Object Storage namespace.
-
#overrides ⇒ Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>
The override is used to modify some important configuration properties for objects matching a specific pattern inside the bucket.
-
#poll_since ⇒ String
The oldest time of the file in the bucket to consider for collection.
-
#poll_till ⇒ String
The newest time of the file in the bucket to consider for collection.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateLogAnalyticsObjectCollectionRuleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateLogAnalyticsObjectCollectionRuleDetails
Initializes the object
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 172 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.os_namespace = attributes[:'osNamespace'] if attributes[:'osNamespace'] raise 'You cannot provide both :osNamespace and :os_namespace' if attributes.key?(:'osNamespace') && attributes.key?(:'os_namespace') self.os_namespace = attributes[:'os_namespace'] if attributes[:'os_namespace'] self.os_bucket_name = attributes[:'osBucketName'] if attributes[:'osBucketName'] raise 'You cannot provide both :osBucketName and :os_bucket_name' if attributes.key?(:'osBucketName') && attributes.key?(:'os_bucket_name') self.os_bucket_name = attributes[:'os_bucket_name'] if attributes[:'os_bucket_name'] self.collection_type = attributes[:'collectionType'] if attributes[:'collectionType'] self.collection_type = "LIVE" if collection_type.nil? && !attributes.key?(:'collectionType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :collectionType and :collection_type' if attributes.key?(:'collectionType') && attributes.key?(:'collection_type') self.collection_type = attributes[:'collection_type'] if attributes[:'collection_type'] self.collection_type = "LIVE" if collection_type.nil? && !attributes.key?(:'collectionType') && !attributes.key?(:'collection_type') # rubocop:disable Style/StringLiterals self.poll_since = attributes[:'pollSince'] if attributes[:'pollSince'] self.poll_since = "CURRENT_TIME" if poll_since.nil? && !attributes.key?(:'pollSince') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :pollSince and :poll_since' if attributes.key?(:'pollSince') && attributes.key?(:'poll_since') self.poll_since = attributes[:'poll_since'] if attributes[:'poll_since'] self.poll_since = "CURRENT_TIME" if poll_since.nil? && !attributes.key?(:'pollSince') && !attributes.key?(:'poll_since') # rubocop:disable Style/StringLiterals self.poll_till = attributes[:'pollTill'] if attributes[:'pollTill'] self.poll_till = "null" if poll_till.nil? && !attributes.key?(:'pollTill') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :pollTill and :poll_till' if attributes.key?(:'pollTill') && attributes.key?(:'poll_till') self.poll_till = attributes[:'poll_till'] if attributes[:'poll_till'] self.poll_till = "null" if poll_till.nil? && !attributes.key?(:'pollTill') && !attributes.key?(:'poll_till') # rubocop:disable Style/StringLiterals self.log_group_id = attributes[:'logGroupId'] if attributes[:'logGroupId'] raise 'You cannot provide both :logGroupId and :log_group_id' if attributes.key?(:'logGroupId') && attributes.key?(:'log_group_id') self.log_group_id = attributes[:'log_group_id'] if attributes[:'log_group_id'] self.log_source_name = attributes[:'logSourceName'] if attributes[:'logSourceName'] raise 'You cannot provide both :logSourceName and :log_source_name' if attributes.key?(:'logSourceName') && attributes.key?(:'log_source_name') self.log_source_name = attributes[:'log_source_name'] if attributes[:'log_source_name'] self.entity_id = attributes[:'entityId'] if attributes[:'entityId'] raise 'You cannot provide both :entityId and :entity_id' if attributes.key?(:'entityId') && attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] if attributes[:'entity_id'] self.char_encoding = attributes[:'charEncoding'] if attributes[:'charEncoding'] raise 'You cannot provide both :charEncoding and :char_encoding' if attributes.key?(:'charEncoding') && attributes.key?(:'char_encoding') self.char_encoding = attributes[:'char_encoding'] if attributes[:'char_encoding'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals self.overrides = attributes[:'overrides'] if attributes[:'overrides'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] end |
Instance Attribute Details
#char_encoding ⇒ String
An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing. It is recommended to set this value as ISO_8859_1 when configuring content of the objects having more numeric characters, and very few alphabets. For e.g. this applies when configuring VCN Flow Logs.
76 77 78 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 76 def char_encoding @char_encoding end |
#collection_type ⇒ String
The type of collection.
42 43 44 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 42 def collection_type @collection_type end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to which this rule belongs.
29 30 31 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 29 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
94 95 96 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 94 def end |
#description ⇒ String
A string that describes the details of the rule. It does not have to be unique, and can be changed. Avoid entering confidential information.
25 26 27 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 25 def description @description end |
#entity_id ⇒ String
Logging Analytics entity OCID. Associates the processed logs with the given entity (optional).
68 69 70 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 68 def entity_id @entity_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
100 101 102 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 100 def end |
#is_enabled ⇒ BOOLEAN
Whether or not this rule is currently enabled.
81 82 83 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 81 def is_enabled @is_enabled end |
#log_group_id ⇒ String
[Required] Logging Analytics Log group OCID to associate the processed logs with.
60 61 62 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 60 def log_group_id @log_group_id end |
#log_source_name ⇒ String
[Required] Name of the Logging Analytics Source to use for the processing.
64 65 66 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 64 def log_source_name @log_source_name end |
#name ⇒ String
[Required] A unique name given to the rule. The name must be unique within the tenancy, and cannot be modified.
19 20 21 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 19 def name @name end |
#os_bucket_name ⇒ String
[Required] Name of the Object Storage bucket.
37 38 39 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 37 def os_bucket_name @os_bucket_name end |
#os_namespace ⇒ String
[Required] Object Storage namespace.
33 34 35 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 33 def os_namespace @os_namespace end |
#overrides ⇒ Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>
The override is used to modify some important configuration properties for objects matching a specific pattern inside the bucket. Supported propeties for override are: logSourceName, charEncoding, entityId. Supported matchType for override are "contains".
88 89 90 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 88 def overrides @overrides end |
#poll_since ⇒ String
The oldest time of the file in the bucket to consider for collection. Accepted values are: BEGINNING or CURRENT_TIME or RFC3339 formatted datetime string. Use this for HISTORIC or HISTORIC_LIVE collection types. When collectionType is LIVE, specifying pollSince value other than CURRENT_TIME will result in error.
49 50 51 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 49 def poll_since @poll_since end |
#poll_till ⇒ String
The newest time of the file in the bucket to consider for collection. Accepted values are: CURRENT_TIME or RFC3339 formatted datetime string. Use this for HISTORIC collection type. When collectionType is LIVE or HISTORIC_LIVE, specifying pollTill will result in error.
56 57 58 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 56 def poll_till @poll_till end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 103 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'compartment_id': :'compartmentId', 'os_namespace': :'osNamespace', 'os_bucket_name': :'osBucketName', 'collection_type': :'collectionType', 'poll_since': :'pollSince', 'poll_till': :'pollTill', 'log_group_id': :'logGroupId', 'log_source_name': :'logSourceName', 'entity_id': :'entityId', 'char_encoding': :'charEncoding', 'is_enabled': :'isEnabled', 'overrides': :'overrides', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 127 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'compartment_id': :'String', 'os_namespace': :'String', 'os_bucket_name': :'String', 'collection_type': :'String', 'poll_since': :'String', 'poll_till': :'String', 'log_group_id': :'String', 'log_source_name': :'String', 'entity_id': :'String', 'char_encoding': :'String', 'is_enabled': :'BOOLEAN', 'overrides': :'Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 286 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && compartment_id == other.compartment_id && os_namespace == other.os_namespace && os_bucket_name == other.os_bucket_name && collection_type == other.collection_type && poll_since == other.poll_since && poll_till == other.poll_till && log_group_id == other.log_group_id && log_source_name == other.log_source_name && entity_id == other.entity_id && char_encoding == other.char_encoding && is_enabled == other.is_enabled && overrides == other.overrides && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 331 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
311 312 313 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 311 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
320 321 322 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 320 def hash [name, description, compartment_id, os_namespace, os_bucket_name, collection_type, poll_since, poll_till, log_group_id, log_source_name, entity_id, char_encoding, is_enabled, overrides, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
364 365 366 367 368 369 370 371 372 373 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 364 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
358 359 360 |
# File 'lib/oci/log_analytics/models/create_log_analytics_object_collection_rule_details.rb', line 358 def to_s to_hash.to_s end |