Class: OCI::LogAnalytics::Models::EstimateRecallDataSizeResult
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::EstimateRecallDataSizeResult
- Defined in:
- lib/oci/log_analytics/models/estimate_recall_data_size_result.rb
Overview
This is the size and time range of data to be recalled
Instance Attribute Summary collapse
-
#is_overlapping_with_existing_recalls ⇒ BOOLEAN
This indicates if the time range of data to be recalled overlaps with existing recalled data.
-
#size_in_bytes ⇒ Integer
[Required] This is the size in bytes.
-
#time_data_ended ⇒ DateTime
[Required] This is the end of the time range of data to be recalled.
-
#time_data_started ⇒ DateTime
[Required] This is the start of the time range of data to be recalled.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EstimateRecallDataSizeResult
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EstimateRecallDataSizeResult
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 63 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_data_ended = attributes[:'timeDataEnded'] if attributes[:'timeDataEnded'] raise 'You cannot provide both :timeDataEnded and :time_data_ended' if attributes.key?(:'timeDataEnded') && attributes.key?(:'time_data_ended') self.time_data_ended = attributes[:'time_data_ended'] if attributes[:'time_data_ended'] self.time_data_started = attributes[:'timeDataStarted'] if attributes[:'timeDataStarted'] raise 'You cannot provide both :timeDataStarted and :time_data_started' if attributes.key?(:'timeDataStarted') && attributes.key?(:'time_data_started') self.time_data_started = attributes[:'time_data_started'] if attributes[:'time_data_started'] self.size_in_bytes = attributes[:'sizeInBytes'] if attributes[:'sizeInBytes'] raise 'You cannot provide both :sizeInBytes and :size_in_bytes' if attributes.key?(:'sizeInBytes') && attributes.key?(:'size_in_bytes') self.size_in_bytes = attributes[:'size_in_bytes'] if attributes[:'size_in_bytes'] self.is_overlapping_with_existing_recalls = attributes[:'isOverlappingWithExistingRecalls'] unless attributes[:'isOverlappingWithExistingRecalls'].nil? raise 'You cannot provide both :isOverlappingWithExistingRecalls and :is_overlapping_with_existing_recalls' if attributes.key?(:'isOverlappingWithExistingRecalls') && attributes.key?(:'is_overlapping_with_existing_recalls') self.is_overlapping_with_existing_recalls = attributes[:'is_overlapping_with_existing_recalls'] unless attributes[:'is_overlapping_with_existing_recalls'].nil? end |
Instance Attribute Details
#is_overlapping_with_existing_recalls ⇒ BOOLEAN
This indicates if the time range of data to be recalled overlaps with existing recalled data
27 28 29 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 27 def is_overlapping_with_existing_recalls @is_overlapping_with_existing_recalls end |
#size_in_bytes ⇒ Integer
[Required] This is the size in bytes
23 24 25 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 23 def size_in_bytes @size_in_bytes end |
#time_data_ended ⇒ DateTime
[Required] This is the end of the time range of data to be recalled. timeDataStarted and timeDataEnded delineate the time range of the archived data to be recalled. They may not be exact the same as the parameters in the request input (EstimateRecallDataSizeDetails).
15 16 17 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 15 def time_data_ended @time_data_ended end |
#time_data_started ⇒ DateTime
[Required] This is the start of the time range of data to be recalled
19 20 21 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 19 def time_data_started @time_data_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 30 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_data_ended': :'timeDataEnded', 'time_data_started': :'timeDataStarted', 'size_in_bytes': :'sizeInBytes', 'is_overlapping_with_existing_recalls': :'isOverlappingWithExistingRecalls' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 42 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_data_ended': :'DateTime', 'time_data_started': :'DateTime', 'size_in_bytes': :'Integer', 'is_overlapping_with_existing_recalls': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
101 102 103 104 105 106 107 108 109 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 101 def ==(other) return true if equal?(other) self.class == other.class && time_data_ended == other.time_data_ended && time_data_started == other.time_data_started && size_in_bytes == other.size_in_bytes && is_overlapping_with_existing_recalls == other.is_overlapping_with_existing_recalls end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 134 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
114 115 116 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 114 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
123 124 125 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 123 def hash [time_data_ended, time_data_started, size_in_bytes, is_overlapping_with_existing_recalls].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 167 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
161 162 163 |
# File 'lib/oci/log_analytics/models/estimate_recall_data_size_result.rb', line 161 def to_s to_hash.to_s end |