Class: OCI::LogAnalytics::Models::HighlightGroupsCommandDescriptor
- Inherits:
-
AbstractCommandDescriptor
- Object
- AbstractCommandDescriptor
- OCI::LogAnalytics::Models::HighlightGroupsCommandDescriptor
- Defined in:
- lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb
Overview
Command descriptor for querylanguage HIGHLIGHTGROUPS command.
Constant Summary
Constants inherited from AbstractCommandDescriptor
AbstractCommandDescriptor::NAME_ENUM
Instance Attribute Summary collapse
-
#color ⇒ String
User specified color to highlight matches with if found.
-
#fields ⇒ Array<String>
List of fields to search for terms or phrases to highlight.
-
#keywords ⇒ Array<String>
List of terms or phrases to highlight if found.
-
#priority ⇒ String
User specified priority assigned to highlighted matches if found.
-
#sub_queries ⇒ Array<OCI::LogAnalytics::Models::ParseQueryOutput>
List of subQueries specified as highlightgroups command arguments.
Attributes inherited from AbstractCommandDescriptor
#category, #declared_fields, #display_query_string, #internal_query_string, #name, #referenced_fields
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HighlightGroupsCommandDescriptor
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from AbstractCommandDescriptor
Constructor Details
#initialize(attributes = {}) ⇒ HighlightGroupsCommandDescriptor
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['name'] = 'HIGHLIGHT_GROUPS' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.color = attributes[:'color'] if attributes[:'color'] self.priority = attributes[:'priority'] if attributes[:'priority'] self.fields = attributes[:'fields'] if attributes[:'fields'] self.keywords = attributes[:'keywords'] if attributes[:'keywords'] self.sub_queries = attributes[:'subQueries'] if attributes[:'subQueries'] raise 'You cannot provide both :subQueries and :sub_queries' if attributes.key?(:'subQueries') && attributes.key?(:'sub_queries') self.sub_queries = attributes[:'sub_queries'] if attributes[:'sub_queries'] end |
Instance Attribute Details
#color ⇒ String
User specified color to highlight matches with if found.
15 16 17 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 15 def color @color end |
#fields ⇒ Array<String>
List of fields to search for terms or phrases to highlight.
25 26 27 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 25 def fields @fields end |
#keywords ⇒ Array<String>
List of terms or phrases to highlight if found.
30 31 32 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 30 def keywords @keywords end |
#priority ⇒ String
User specified priority assigned to highlighted matches if found.
20 21 22 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 20 def priority @priority end |
#sub_queries ⇒ Array<OCI::LogAnalytics::Models::ParseQueryOutput>
List of subQueries specified as highlightgroups command arguments
35 36 37 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 35 def sub_queries @sub_queries end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'display_query_string': :'displayQueryString', 'internal_query_string': :'internalQueryString', 'category': :'category', 'referenced_fields': :'referencedFields', 'declared_fields': :'declaredFields', 'color': :'color', 'priority': :'priority', 'fields': :'fields', 'keywords': :'keywords', 'sub_queries': :'subQueries' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'display_query_string': :'String', 'internal_query_string': :'String', 'category': :'String', 'referenced_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>', 'declared_fields': :'Array<OCI::LogAnalytics::Models::AbstractField>', 'color': :'String', 'priority': :'String', 'fields': :'Array<String>', 'keywords': :'Array<String>', 'sub_queries': :'Array<OCI::LogAnalytics::Models::ParseQueryOutput>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 123 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && display_query_string == other.display_query_string && internal_query_string == other.internal_query_string && category == other.category && referenced_fields == other.referenced_fields && declared_fields == other.declared_fields && color == other.color && priority == other.priority && fields == other.fields && keywords == other.keywords && sub_queries == other.sub_queries end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 163 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
143 144 145 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 143 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 152 def hash [name, display_query_string, internal_query_string, category, referenced_fields, declared_fields, color, priority, fields, keywords, sub_queries].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
190 191 192 |
# File 'lib/oci/log_analytics/models/highlight_groups_command_descriptor.rb', line 190 def to_s to_hash.to_s end |