Class: OCI::LogAnalytics::Models::LogAnalyticsEntity

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/log_analytics/models/log_analytics_entity.rb

Overview

Description of a log analytics entity.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LogAnalyticsEntity

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 211

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.entity_type_name = attributes[:'entityTypeName'] if attributes[:'entityTypeName']

  raise 'You cannot provide both :entityTypeName and :entity_type_name' if attributes.key?(:'entityTypeName') && attributes.key?(:'entity_type_name')

  self.entity_type_name = attributes[:'entity_type_name'] if attributes[:'entity_type_name']

  self.entity_type_internal_name = attributes[:'entityTypeInternalName'] if attributes[:'entityTypeInternalName']

  raise 'You cannot provide both :entityTypeInternalName and :entity_type_internal_name' if attributes.key?(:'entityTypeInternalName') && attributes.key?(:'entity_type_internal_name')

  self.entity_type_internal_name = attributes[:'entity_type_internal_name'] if attributes[:'entity_type_internal_name']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

  self.management_agent_id = attributes[:'managementAgentId'] if attributes[:'managementAgentId']

  raise 'You cannot provide both :managementAgentId and :management_agent_id' if attributes.key?(:'managementAgentId') && attributes.key?(:'management_agent_id')

  self.management_agent_id = attributes[:'management_agent_id'] if attributes[:'management_agent_id']

  self.management_agent_display_name = attributes[:'managementAgentDisplayName'] if attributes[:'managementAgentDisplayName']

  raise 'You cannot provide both :managementAgentDisplayName and :management_agent_display_name' if attributes.key?(:'managementAgentDisplayName') && attributes.key?(:'management_agent_display_name')

  self.management_agent_display_name = attributes[:'management_agent_display_name'] if attributes[:'management_agent_display_name']

  self.management_agent_compartment_id = attributes[:'managementAgentCompartmentId'] if attributes[:'managementAgentCompartmentId']

  raise 'You cannot provide both :managementAgentCompartmentId and :management_agent_compartment_id' if attributes.key?(:'managementAgentCompartmentId') && attributes.key?(:'management_agent_compartment_id')

  self.management_agent_compartment_id = attributes[:'management_agent_compartment_id'] if attributes[:'management_agent_compartment_id']

  self.timezone_region = attributes[:'timezoneRegion'] if attributes[:'timezoneRegion']

  raise 'You cannot provide both :timezoneRegion and :timezone_region' if attributes.key?(:'timezoneRegion') && attributes.key?(:'timezone_region')

  self.timezone_region = attributes[:'timezone_region'] if attributes[:'timezone_region']

  self.properties = attributes[:'properties'] if attributes[:'properties']

  self.creation_source = attributes[:'creationSource'] if attributes[:'creationSource']

  raise 'You cannot provide both :creationSource and :creation_source' if attributes.key?(:'creationSource') && attributes.key?(:'creation_source')

  self.creation_source = attributes[:'creation_source'] if attributes[:'creation_source']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.are_logs_collected = attributes[:'areLogsCollected'] unless attributes[:'areLogsCollected'].nil?

  raise 'You cannot provide both :areLogsCollected and :are_logs_collected' if attributes.key?(:'areLogsCollected') && attributes.key?(:'are_logs_collected')

  self.are_logs_collected = attributes[:'are_logs_collected'] unless attributes[:'are_logs_collected'].nil?

  self.cloud_resource_id = attributes[:'cloudResourceId'] if attributes[:'cloudResourceId']

  raise 'You cannot provide both :cloudResourceId and :cloud_resource_id' if attributes.key?(:'cloudResourceId') && attributes.key?(:'cloud_resource_id')

  self.cloud_resource_id = attributes[:'cloud_resource_id'] if attributes[:'cloud_resource_id']

  self.hostname = attributes[:'hostname'] if attributes[:'hostname']

  self.source_id = attributes[:'sourceId'] if attributes[:'sourceId']

  raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id')

  self.source_id = attributes[:'source_id'] if attributes[:'source_id']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#are_logs_collectedBOOLEAN

The Boolean flag to indicate if logs are collected for an entity for log analytics usage.

Returns:

  • (BOOLEAN)


94
95
96
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 94

def are_logs_collected
  @are_logs_collected
end

#cloud_resource_idString

The OCID of the Cloud resource which this entity is a representation of. This may be blank when the entity represents a non-cloud resource that the customer may have on their premises.

Returns:

  • (String)


100
101
102
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 100

def cloud_resource_id
  @cloud_resource_id
end

#compartment_idString

[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).

Returns:

  • (String)


31
32
33
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 31

def compartment_id
  @compartment_id
end

#creation_sourceOCI::LogAnalytics::Models::CreationSource



79
80
81
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 79

def creation_source
  @creation_source
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


124
125
126
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 124

def defined_tags
  @defined_tags
end

#entity_type_internal_nameString

[Required] Internal name for the log analytics entity type.

Returns:

  • (String)


41
42
43
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 41

def entity_type_internal_name
  @entity_type_internal_name
end

#entity_type_nameString

[Required] Log analytics entity type name.

Returns:

  • (String)


36
37
38
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 36

def entity_type_name
  @entity_type_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


118
119
120
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 118

def freeform_tags
  @freeform_tags
end

#hostnameString

The hostname where the entity represented here is actually present. This would be the output one would get if they run ‘echo $HOSTNAME` on Linux or an equivalent OS command. This may be different from management agents host since logs may be collected remotely.

Returns:

  • (String)


107
108
109
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 107

def hostname
  @hostname
end

#idString

[Required] The log analytics entity OCID. This ID is a reference used by log analytics features and it represents a resource that is provisioned and managed by the customer on their premises or on the cloud.

Returns:

  • (String)


22
23
24
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 22

def id
  @id
end

#lifecycle_detailsString

[Required] lifecycleDetails has additional information regarding substeps such as management agent plugin deployment.

Returns:

  • (String)


51
52
53
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 51

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the log analytics entity.

Returns:

  • (String)


46
47
48
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 46

def lifecycle_state
  @lifecycle_state
end

#management_agent_compartment_idString

Management agent (management-agents resource kind) compartment OCID

Returns:

  • (String)


66
67
68
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 66

def management_agent_compartment_id
  @management_agent_compartment_id
end

#management_agent_display_nameString

Management agent (management-agents resource kind) display name

Returns:

  • (String)


61
62
63
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 61

def management_agent_display_name
  @management_agent_display_name
end

#management_agent_idString

The OCID of the Management Agent.

Returns:

  • (String)


56
57
58
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 56

def management_agent_id
  @management_agent_id
end

#nameString

[Required] Log analytics entity name.

Returns:

  • (String)


27
28
29
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 27

def name
  @name
end

#propertiesHash<String, String>

The name/value pairs for parameter values to be used in file patterns specified in log sources.

Returns:

  • (Hash<String, String>)


76
77
78
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 76

def properties
  @properties
end

#source_idString

This indicates the type of source. It is primarily for Enterprise Manager Repository ID.

Returns:

  • (String)


112
113
114
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 112

def source_id
  @source_id
end

#time_createdDateTime

[Required] The date and time the resource was created, in the format defined by RFC3339.

Returns:

  • (DateTime)


84
85
86
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 84

def time_created
  @time_created
end

#time_updatedDateTime

[Required] The date and time the resource was last updated, in the format defined by RFC3339.

Returns:

  • (DateTime)


89
90
91
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 89

def time_updated
  @time_updated
end

#timezone_regionString

The timezone region of the log analytics entity.

Returns:

  • (String)


71
72
73
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 71

def timezone_region
  @timezone_region
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 127

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'name': :'name',
    'compartment_id': :'compartmentId',
    'entity_type_name': :'entityTypeName',
    'entity_type_internal_name': :'entityTypeInternalName',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'management_agent_id': :'managementAgentId',
    'management_agent_display_name': :'managementAgentDisplayName',
    'management_agent_compartment_id': :'managementAgentCompartmentId',
    'timezone_region': :'timezoneRegion',
    'properties': :'properties',
    'creation_source': :'creationSource',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'are_logs_collected': :'areLogsCollected',
    'cloud_resource_id': :'cloudResourceId',
    'hostname': :'hostname',
    'source_id': :'sourceId',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 156

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'name': :'String',
    'compartment_id': :'String',
    'entity_type_name': :'String',
    'entity_type_internal_name': :'String',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'management_agent_id': :'String',
    'management_agent_display_name': :'String',
    'management_agent_compartment_id': :'String',
    'timezone_region': :'String',
    'properties': :'Hash<String, String>',
    'creation_source': :'OCI::LogAnalytics::Models::CreationSource',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'are_logs_collected': :'BOOLEAN',
    'cloud_resource_id': :'String',
    'hostname': :'String',
    'source_id': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 348

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    name == other.name &&
    compartment_id == other.compartment_id &&
    entity_type_name == other.entity_type_name &&
    entity_type_internal_name == other.entity_type_internal_name &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    management_agent_id == other.management_agent_id &&
    management_agent_display_name == other.management_agent_display_name &&
    management_agent_compartment_id == other.management_agent_compartment_id &&
    timezone_region == other.timezone_region &&
    properties == other.properties &&
    creation_source == other.creation_source &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    are_logs_collected == other.are_logs_collected &&
    cloud_resource_id == other.cloud_resource_id &&
    hostname == other.hostname &&
    source_id == other.source_id &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 398

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


378
379
380
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 378

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



387
388
389
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 387

def hash
  [id, name, compartment_id, entity_type_name, entity_type_internal_name, lifecycle_state, lifecycle_details, management_agent_id, management_agent_display_name, management_agent_compartment_id, timezone_region, properties, creation_source, time_created, time_updated, are_logs_collected, cloud_resource_id, hostname, source_id, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



431
432
433
434
435
436
437
438
439
440
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 431

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



425
426
427
# File 'lib/oci/log_analytics/models/log_analytics_entity.rb', line 425

def to_s
  to_hash.to_s
end