Class: OCI::LogAnalytics::Models::LogAnalyticsEntitySummary
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsEntitySummary
- Defined in:
- lib/oci/log_analytics/models/log_analytics_entity_summary.rb
Overview
Summary of a log analytics entity.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#are_logs_collected ⇒ BOOLEAN
The Boolean flag to indicate if logs are collected for an entity for log analytics usage.
-
#cloud_resource_id ⇒ String
The OCID of the Cloud resource which this entity is a representation of.
-
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
- #creation_source ⇒ OCI::LogAnalytics::Models::CreationSource
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#entity_type_internal_name ⇒ String
[Required] Internal name for the log analytics entity type.
-
#entity_type_name ⇒ String
[Required] Log analytics entity type name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The log analytics entity OCID.
-
#lifecycle_details ⇒ String
[Required] lifecycleDetails has additional information regarding substeps such as management agent plugin deployment.
-
#lifecycle_state ⇒ String
[Required] The current state of the log analytics entity.
-
#management_agent_id ⇒ String
The OCID of the Management Agent.
-
#name ⇒ String
[Required] Log analytics entity name.
-
#source_id ⇒ String
This indicates the type of source.
-
#time_created ⇒ DateTime
[Required] The date and time the resource was created, in the format defined by RFC3339.
-
#time_updated ⇒ DateTime
[Required] The date and time the resource was last updated, in the format defined by RFC3339.
-
#timezone_region ⇒ String
The timezone region of the log analytics entity.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsEntitySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsEntitySummary
Initializes the object
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 177 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.entity_type_name = attributes[:'entityTypeName'] if attributes[:'entityTypeName'] raise 'You cannot provide both :entityTypeName and :entity_type_name' if attributes.key?(:'entityTypeName') && attributes.key?(:'entity_type_name') self.entity_type_name = attributes[:'entity_type_name'] if attributes[:'entity_type_name'] self.entity_type_internal_name = attributes[:'entityTypeInternalName'] if attributes[:'entityTypeInternalName'] raise 'You cannot provide both :entityTypeInternalName and :entity_type_internal_name' if attributes.key?(:'entityTypeInternalName') && attributes.key?(:'entity_type_internal_name') self.entity_type_internal_name = attributes[:'entity_type_internal_name'] if attributes[:'entity_type_internal_name'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.management_agent_id = attributes[:'managementAgentId'] if attributes[:'managementAgentId'] raise 'You cannot provide both :managementAgentId and :management_agent_id' if attributes.key?(:'managementAgentId') && attributes.key?(:'management_agent_id') self.management_agent_id = attributes[:'management_agent_id'] if attributes[:'management_agent_id'] self.cloud_resource_id = attributes[:'cloudResourceId'] if attributes[:'cloudResourceId'] raise 'You cannot provide both :cloudResourceId and :cloud_resource_id' if attributes.key?(:'cloudResourceId') && attributes.key?(:'cloud_resource_id') self.cloud_resource_id = attributes[:'cloud_resource_id'] if attributes[:'cloud_resource_id'] self.timezone_region = attributes[:'timezoneRegion'] if attributes[:'timezoneRegion'] raise 'You cannot provide both :timezoneRegion and :timezone_region' if attributes.key?(:'timezoneRegion') && attributes.key?(:'timezone_region') self.timezone_region = attributes[:'timezone_region'] if attributes[:'timezone_region'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.are_logs_collected = attributes[:'areLogsCollected'] unless attributes[:'areLogsCollected'].nil? raise 'You cannot provide both :areLogsCollected and :are_logs_collected' if attributes.key?(:'areLogsCollected') && attributes.key?(:'are_logs_collected') self.are_logs_collected = attributes[:'are_logs_collected'] unless attributes[:'are_logs_collected'].nil? self.source_id = attributes[:'sourceId'] if attributes[:'sourceId'] raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] if attributes[:'source_id'] self.creation_source = attributes[:'creationSource'] if attributes[:'creationSource'] raise 'You cannot provide both :creationSource and :creation_source' if attributes.key?(:'creationSource') && attributes.key?(:'creation_source') self.creation_source = attributes[:'creation_source'] if attributes[:'creation_source'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#are_logs_collected ⇒ BOOLEAN
The Boolean flag to indicate if logs are collected for an entity for log analytics usage.
82 83 84 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 82 def are_logs_collected @are_logs_collected end |
#cloud_resource_id ⇒ String
The OCID of the Cloud resource which this entity is a representation of. This may be blank when the entity represents a non-cloud resource that the customer may have on their premises.
62 63 64 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 62 def cloud_resource_id @cloud_resource_id end |
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
31 32 33 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 31 def compartment_id @compartment_id end |
#creation_source ⇒ OCI::LogAnalytics::Models::CreationSource
90 91 92 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 90 def creation_source @creation_source end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
102 103 104 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 102 def end |
#entity_type_internal_name ⇒ String
[Required] Internal name for the log analytics entity type.
41 42 43 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 41 def entity_type_internal_name @entity_type_internal_name end |
#entity_type_name ⇒ String
[Required] Log analytics entity type name.
36 37 38 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 36 def entity_type_name @entity_type_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
96 97 98 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 96 def end |
#id ⇒ String
[Required] The log analytics entity OCID. This ID is a reference used by log analytics features and it represents a resource that is provisioned and managed by the customer on their premises or on the cloud.
22 23 24 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 22 def id @id end |
#lifecycle_details ⇒ String
[Required] lifecycleDetails has additional information regarding substeps such as management agent plugin deployment.
51 52 53 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 51 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the log analytics entity.
46 47 48 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 46 def lifecycle_state @lifecycle_state end |
#management_agent_id ⇒ String
The OCID of the Management Agent.
56 57 58 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 56 def management_agent_id @management_agent_id end |
#name ⇒ String
[Required] Log analytics entity name.
27 28 29 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 27 def name @name end |
#source_id ⇒ String
This indicates the type of source. It is primarily for Enterprise Manager Repository ID.
87 88 89 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 87 def source_id @source_id end |
#time_created ⇒ DateTime
[Required] The date and time the resource was created, in the format defined by RFC3339.
72 73 74 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 72 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time the resource was last updated, in the format defined by RFC3339.
77 78 79 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 77 def time_updated @time_updated end |
#timezone_region ⇒ String
The timezone region of the log analytics entity.
67 68 69 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 67 def timezone_region @timezone_region end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 105 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'compartment_id': :'compartmentId', 'entity_type_name': :'entityTypeName', 'entity_type_internal_name': :'entityTypeInternalName', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'management_agent_id': :'managementAgentId', 'cloud_resource_id': :'cloudResourceId', 'timezone_region': :'timezoneRegion', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'are_logs_collected': :'areLogsCollected', 'source_id': :'sourceId', 'creation_source': :'creationSource', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 130 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'compartment_id': :'String', 'entity_type_name': :'String', 'entity_type_internal_name': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'management_agent_id': :'String', 'cloud_resource_id': :'String', 'timezone_region': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'are_logs_collected': :'BOOLEAN', 'source_id': :'String', 'creation_source': :'OCI::LogAnalytics::Models::CreationSource', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 298 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && compartment_id == other.compartment_id && entity_type_name == other.entity_type_name && entity_type_internal_name == other.entity_type_internal_name && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && management_agent_id == other.management_agent_id && cloud_resource_id == other.cloud_resource_id && timezone_region == other.timezone_region && time_created == other.time_created && time_updated == other.time_updated && are_logs_collected == other.are_logs_collected && source_id == other.source_id && creation_source == other.creation_source && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 344 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
324 325 326 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 324 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
333 334 335 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 333 def hash [id, name, compartment_id, entity_type_name, entity_type_internal_name, lifecycle_state, lifecycle_details, management_agent_id, cloud_resource_id, timezone_region, time_created, time_updated, are_logs_collected, source_id, creation_source, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 377 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
371 372 373 |
# File 'lib/oci/log_analytics/models/log_analytics_entity_summary.rb', line 371 def to_s to_hash.to_s end |