Class: OCI::LogAnalytics::Models::LogAnalyticsObjectCollectionRule
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsObjectCollectionRule
- Defined in:
- lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb
Overview
The configuration details of an Object Storage based collection rule.
Constant Summary collapse
- COLLECTION_TYPE_ENUM =
[ COLLECTION_TYPE_LIVE = 'LIVE'.freeze, COLLECTION_TYPE_HISTORIC = 'HISTORIC'.freeze, COLLECTION_TYPE_HISTORIC_LIVE = 'HISTORIC_LIVE'.freeze, COLLECTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#char_encoding ⇒ String
An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing.
-
#collection_type ⇒ String
[Required] The type of collection.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to which this rule belongs.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A string that describes the details of the rule.
-
#entity_id ⇒ String
Log Analytics entity OCID to associate the processed logs with.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of this rule.
-
#lifecycle_details ⇒ String
A detailed status of the life cycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the rule.
-
#log_group_id ⇒ String
[Required] Log Analytics Log group OCID to associate the processed logs with.
-
#log_source_name ⇒ String
[Required] Name of the Log Analytics Source to use for the processing.
-
#name ⇒ String
[Required] A unique name to the rule.
-
#os_bucket_name ⇒ String
[Required] Name of the Object Storage bucket.
-
#os_namespace ⇒ String
[Required] Object Storage namespace.
-
#overrides ⇒ Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>
Use this to override some property values which are defined at bucket level to the scope of object.
-
#poll_since ⇒ String
[Required] The oldest time of the file in the bucket to consider for collection.
-
#poll_till ⇒ String
The oldest time of the file in the bucket to consider for collection.
-
#time_created ⇒ DateTime
[Required] The time when this rule was created.
-
#time_updated ⇒ DateTime
[Required] The time when this rule was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsObjectCollectionRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsObjectCollectionRule
Initializes the object
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 211 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.os_namespace = attributes[:'osNamespace'] if attributes[:'osNamespace'] raise 'You cannot provide both :osNamespace and :os_namespace' if attributes.key?(:'osNamespace') && attributes.key?(:'os_namespace') self.os_namespace = attributes[:'os_namespace'] if attributes[:'os_namespace'] self.os_bucket_name = attributes[:'osBucketName'] if attributes[:'osBucketName'] raise 'You cannot provide both :osBucketName and :os_bucket_name' if attributes.key?(:'osBucketName') && attributes.key?(:'os_bucket_name') self.os_bucket_name = attributes[:'os_bucket_name'] if attributes[:'os_bucket_name'] self.collection_type = attributes[:'collectionType'] if attributes[:'collectionType'] self.collection_type = "LIVE" if collection_type.nil? && !attributes.key?(:'collectionType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :collectionType and :collection_type' if attributes.key?(:'collectionType') && attributes.key?(:'collection_type') self.collection_type = attributes[:'collection_type'] if attributes[:'collection_type'] self.collection_type = "LIVE" if collection_type.nil? && !attributes.key?(:'collectionType') && !attributes.key?(:'collection_type') # rubocop:disable Style/StringLiterals self.poll_since = attributes[:'pollSince'] if attributes[:'pollSince'] self.poll_since = "CURRENT_TIME" if poll_since.nil? && !attributes.key?(:'pollSince') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :pollSince and :poll_since' if attributes.key?(:'pollSince') && attributes.key?(:'poll_since') self.poll_since = attributes[:'poll_since'] if attributes[:'poll_since'] self.poll_since = "CURRENT_TIME" if poll_since.nil? && !attributes.key?(:'pollSince') && !attributes.key?(:'poll_since') # rubocop:disable Style/StringLiterals self.poll_till = attributes[:'pollTill'] if attributes[:'pollTill'] self.poll_till = "null" if poll_till.nil? && !attributes.key?(:'pollTill') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :pollTill and :poll_till' if attributes.key?(:'pollTill') && attributes.key?(:'poll_till') self.poll_till = attributes[:'poll_till'] if attributes[:'poll_till'] self.poll_till = "null" if poll_till.nil? && !attributes.key?(:'pollTill') && !attributes.key?(:'poll_till') # rubocop:disable Style/StringLiterals self.log_group_id = attributes[:'logGroupId'] if attributes[:'logGroupId'] raise 'You cannot provide both :logGroupId and :log_group_id' if attributes.key?(:'logGroupId') && attributes.key?(:'log_group_id') self.log_group_id = attributes[:'log_group_id'] if attributes[:'log_group_id'] self.log_source_name = attributes[:'logSourceName'] if attributes[:'logSourceName'] raise 'You cannot provide both :logSourceName and :log_source_name' if attributes.key?(:'logSourceName') && attributes.key?(:'log_source_name') self.log_source_name = attributes[:'log_source_name'] if attributes[:'log_source_name'] self.entity_id = attributes[:'entityId'] if attributes[:'entityId'] raise 'You cannot provide both :entityId and :entity_id' if attributes.key?(:'entityId') && attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] if attributes[:'entity_id'] self.char_encoding = attributes[:'charEncoding'] if attributes[:'charEncoding'] raise 'You cannot provide both :charEncoding and :char_encoding' if attributes.key?(:'charEncoding') && attributes.key?(:'char_encoding') self.char_encoding = attributes[:'char_encoding'] if attributes[:'char_encoding'] self.overrides = attributes[:'overrides'] if attributes[:'overrides'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] end |
Instance Attribute Details
#char_encoding ⇒ String
An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing. It is recommended to set this value as ISO_8589_1 when configuring content of the objects having more numeric characters, and very few alphabets. For e.g. this applies when configuring VCN Flow Logs.
91 92 93 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 91 def char_encoding @char_encoding end |
#collection_type ⇒ String
[Required] The type of collection. Accepted values are: LIVE. Collection type LIVE indicates to enable log collection from the time of this rule creation, and continue until the rule exists.
57 58 59 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 57 def collection_type @collection_type end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to which this rule belongs.
41 42 43 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 41 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{\“bar-key\”: \“value\”}`
121 122 123 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 121 def end |
#description ⇒ String
A string that describes the details of the rule. It does not have to be unique, and can be changed. Avoid entering confidential information.
37 38 39 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 37 def description @description end |
#entity_id ⇒ String
Log Analytics entity OCID to associate the processed logs with.
83 84 85 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 83 def entity_id @entity_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘\“value\”`
127 128 129 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 127 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of this rule.
27 28 29 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 27 def id @id end |
#lifecycle_details ⇒ String
A detailed status of the life cycle state.
107 108 109 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 107 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the rule.
103 104 105 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 103 def lifecycle_state @lifecycle_state end |
#log_group_id ⇒ String
[Required] Log Analytics Log group OCID to associate the processed logs with.
75 76 77 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 75 def log_group_id @log_group_id end |
#log_source_name ⇒ String
[Required] Name of the Log Analytics Source to use for the processing.
79 80 81 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 79 def log_source_name @log_source_name end |
#name ⇒ String
[Required] A unique name to the rule. The name must be unique, within the tenancy, and cannot be changed.
31 32 33 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 31 def name @name end |
#os_bucket_name ⇒ String
[Required] Name of the Object Storage bucket.
49 50 51 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 49 def os_bucket_name @os_bucket_name end |
#os_namespace ⇒ String
[Required] Object Storage namespace.
45 46 47 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 45 def os_namespace @os_namespace end |
#overrides ⇒ Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>
Use this to override some property values which are defined at bucket level to the scope of object. Supported propeties for override are, logSourceName, charEncoding. Supported matchType for override are \“contains\”.
98 99 100 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 98 def overrides @overrides end |
#poll_since ⇒ String
[Required] The oldest time of the file in the bucket to consider for collection. Accepted values are: BEGINNING or CURRENT_TIME or RFC3339 formatted datetime string. When collectionType is LIVE, specifying pollSince value other than CURRENT_TIME will result in error.
64 65 66 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 64 def poll_since @poll_since end |
#poll_till ⇒ String
The oldest time of the file in the bucket to consider for collection. Accepted values are: CURRENT_TIME or RFC3339 formatted datetime string. When collectionType is LIVE, specifying pollTill will result in error.
71 72 73 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 71 def poll_till @poll_till end |
#time_created ⇒ DateTime
[Required] The time when this rule was created. An RFC3339 formatted datetime string.
111 112 113 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 111 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The time when this rule was last updated. An RFC3339 formatted datetime string.
115 116 117 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 115 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 130 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'description': :'description', 'compartment_id': :'compartmentId', 'os_namespace': :'osNamespace', 'os_bucket_name': :'osBucketName', 'collection_type': :'collectionType', 'poll_since': :'pollSince', 'poll_till': :'pollTill', 'log_group_id': :'logGroupId', 'log_source_name': :'logSourceName', 'entity_id': :'entityId', 'char_encoding': :'charEncoding', 'overrides': :'overrides', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 158 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'description': :'String', 'compartment_id': :'String', 'os_namespace': :'String', 'os_bucket_name': :'String', 'collection_type': :'String', 'poll_since': :'String', 'poll_till': :'String', 'log_group_id': :'String', 'log_source_name': :'String', 'entity_id': :'String', 'char_encoding': :'String', 'overrides': :'Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 361 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && compartment_id == other.compartment_id && os_namespace == other.os_namespace && os_bucket_name == other.os_bucket_name && collection_type == other.collection_type && poll_since == other.poll_since && poll_till == other.poll_till && log_group_id == other.log_group_id && log_source_name == other.log_source_name && entity_id == other.entity_id && char_encoding == other.char_encoding && overrides == other.overrides && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 410 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
390 391 392 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 390 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
399 400 401 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 399 def hash [id, name, description, compartment_id, os_namespace, os_bucket_name, collection_type, poll_since, poll_till, log_group_id, log_source_name, entity_id, char_encoding, overrides, lifecycle_state, lifecycle_details, time_created, time_updated, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
443 444 445 446 447 448 449 450 451 452 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 443 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
437 438 439 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule.rb', line 437 def to_s to_hash.to_s end |