Class: OCI::LogAnalytics::Models::LogAnalyticsObjectCollectionRuleSummary
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsObjectCollectionRuleSummary
- Defined in:
- lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb
Overview
The summary of an Object Storage based collection rule.
Constant Summary collapse
- COLLECTION_TYPE_ENUM =
[ COLLECTION_TYPE_LIVE = 'LIVE'.freeze, COLLECTION_TYPE_HISTORIC = 'HISTORIC'.freeze, COLLECTION_TYPE_HISTORIC_LIVE = 'HISTORIC_LIVE'.freeze, COLLECTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#collection_type ⇒ String
[Required] The type of collection.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to which this rule belongs.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A unique name given to the rule.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of this rule.
-
#lifecycle_details ⇒ String
A detailed status of the life cycle state.
-
#lifecycle_state ⇒ String
[Required] The current state of the rule.
-
#name ⇒ String
[Required] A unique name to the rule.
-
#os_bucket_name ⇒ String
[Required] Name of the Object Storage bucket.
-
#os_namespace ⇒ String
[Required] Object Storage namespace.
-
#time_created ⇒ DateTime
[Required] The time when this rule was created.
-
#time_updated ⇒ DateTime
[Required] The time when this rule was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsObjectCollectionRuleSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsObjectCollectionRuleSummary
Initializes the object
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 143 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.os_namespace = attributes[:'osNamespace'] if attributes[:'osNamespace'] raise 'You cannot provide both :osNamespace and :os_namespace' if attributes.key?(:'osNamespace') && attributes.key?(:'os_namespace') self.os_namespace = attributes[:'os_namespace'] if attributes[:'os_namespace'] self.os_bucket_name = attributes[:'osBucketName'] if attributes[:'osBucketName'] raise 'You cannot provide both :osBucketName and :os_bucket_name' if attributes.key?(:'osBucketName') && attributes.key?(:'os_bucket_name') self.os_bucket_name = attributes[:'os_bucket_name'] if attributes[:'os_bucket_name'] self.collection_type = attributes[:'collectionType'] if attributes[:'collectionType'] self.collection_type = "LIVE" if collection_type.nil? && !attributes.key?(:'collectionType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :collectionType and :collection_type' if attributes.key?(:'collectionType') && attributes.key?(:'collection_type') self.collection_type = attributes[:'collection_type'] if attributes[:'collection_type'] self.collection_type = "LIVE" if collection_type.nil? && !attributes.key?(:'collectionType') && !attributes.key?(:'collection_type') # rubocop:disable Style/StringLiterals self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] end |
Instance Attribute Details
#collection_type ⇒ String
[Required] The type of collection. Accepted values are: LIVE. Collection type LIVE indicates to enable log collection from the time of this rule creation, and continue until the rule exists.
51 52 53 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 51 def collection_type @collection_type end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to which this rule belongs.
35 36 37 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 35 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{\“bar-key\”: \“value\”}`
74 75 76 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 74 def @defined_tags end |
#description ⇒ String
A unique name given to the rule. The name must be unique within the tenancy, and cannot be modified. Avoid entering confidential information.
31 32 33 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 31 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘\“value\”`
80 81 82 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 80 def @freeform_tags end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of this rule.
21 22 23 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 21 def id @id end |
#lifecycle_details ⇒ String
A detailed status of the life cycle state.
60 61 62 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 60 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the rule.
56 57 58 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 56 def lifecycle_state @lifecycle_state end |
#name ⇒ String
[Required] A unique name to the rule. The name must be unique, within the tenancy, and cannot be changed.
25 26 27 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 25 def name @name end |
#os_bucket_name ⇒ String
[Required] Name of the Object Storage bucket.
43 44 45 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 43 def os_bucket_name @os_bucket_name end |
#os_namespace ⇒ String
[Required] Object Storage namespace.
39 40 41 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 39 def os_namespace @os_namespace end |
#time_created ⇒ DateTime
[Required] The time when this rule was created. An RFC3339 formatted datetime string.
64 65 66 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 64 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The time when this rule was last updated. An RFC3339 formatted datetime string.
68 69 70 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 68 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 83 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'description': :'description', 'compartment_id': :'compartmentId', 'os_namespace': :'osNamespace', 'os_bucket_name': :'osBucketName', 'collection_type': :'collectionType', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 104 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'description': :'String', 'compartment_id': :'String', 'os_namespace': :'String', 'os_bucket_name': :'String', 'collection_type': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 238 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && compartment_id == other.compartment_id && os_namespace == other.os_namespace && os_bucket_name == other.os_bucket_name && collection_type == other.collection_type && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 280 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
260 261 262 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 260 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
269 270 271 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 269 def hash [id, name, description, compartment_id, os_namespace, os_bucket_name, collection_type, lifecycle_state, lifecycle_details, time_created, time_updated, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
313 314 315 316 317 318 319 320 321 322 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 313 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
307 308 309 |
# File 'lib/oci/log_analytics/models/log_analytics_object_collection_rule_summary.rb', line 307 def to_s to_hash.to_s end |