Class: OCI::LogAnalytics::Models::LogAnalyticsPatternFilter
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::LogAnalyticsPatternFilter
- Defined in:
- lib/oci/log_analytics/models/log_analytics_pattern_filter.rb
Overview
LogAnalyticsPatternFilter
Instance Attribute Summary collapse
-
#agent_version ⇒ String
agent version.
-
#is_in_use ⇒ BOOLEAN
is in use flag.
-
#operating_system ⇒ String
operating system.
- #pattern ⇒ OCI::LogAnalytics::Models::LogAnalyticsSourcePattern
-
#pattern_id ⇒ Integer
pattern Id.
- #source ⇒ OCI::LogAnalytics::Models::LogAnalyticsSource
-
#source_id ⇒ Integer
source Id.
-
#version ⇒ String
version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LogAnalyticsPatternFilter
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LogAnalyticsPatternFilter
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.pattern = attributes[:'pattern'] if attributes[:'pattern'] self.agent_version = attributes[:'agentVersion'] if attributes[:'agentVersion'] raise 'You cannot provide both :agentVersion and :agent_version' if attributes.key?(:'agentVersion') && attributes.key?(:'agent_version') self.agent_version = attributes[:'agent_version'] if attributes[:'agent_version'] self.is_in_use = attributes[:'isInUse'] unless attributes[:'isInUse'].nil? raise 'You cannot provide both :isInUse and :is_in_use' if attributes.key?(:'isInUse') && attributes.key?(:'is_in_use') self.is_in_use = attributes[:'is_in_use'] unless attributes[:'is_in_use'].nil? self. = attributes[:'operatingSystem'] if attributes[:'operatingSystem'] raise 'You cannot provide both :operatingSystem and :operating_system' if attributes.key?(:'operatingSystem') && attributes.key?(:'operating_system') self. = attributes[:'operating_system'] if attributes[:'operating_system'] self.pattern_id = attributes[:'patternId'] if attributes[:'patternId'] raise 'You cannot provide both :patternId and :pattern_id' if attributes.key?(:'patternId') && attributes.key?(:'pattern_id') self.pattern_id = attributes[:'pattern_id'] if attributes[:'pattern_id'] self.source_id = attributes[:'sourceId'] if attributes[:'sourceId'] raise 'You cannot provide both :sourceId and :source_id' if attributes.key?(:'sourceId') && attributes.key?(:'source_id') self.source_id = attributes[:'source_id'] if attributes[:'source_id'] self.version = attributes[:'version'] if attributes[:'version'] self.source = attributes[:'source'] if attributes[:'source'] end |
Instance Attribute Details
#agent_version ⇒ String
agent version
15 16 17 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 15 def agent_version @agent_version end |
#is_in_use ⇒ BOOLEAN
is in use flag
19 20 21 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 19 def is_in_use @is_in_use end |
#operating_system ⇒ String
operating system
23 24 25 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 23 def @operating_system end |
#pattern ⇒ OCI::LogAnalytics::Models::LogAnalyticsSourcePattern
11 12 13 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 11 def pattern @pattern end |
#pattern_id ⇒ Integer
pattern Id
27 28 29 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 27 def pattern_id @pattern_id end |
#source ⇒ OCI::LogAnalytics::Models::LogAnalyticsSource
38 39 40 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 38 def source @source end |
#source_id ⇒ Integer
source Id
31 32 33 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 31 def source_id @source_id end |
#version ⇒ String
version
35 36 37 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 35 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 41 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'pattern': :'pattern', 'agent_version': :'agentVersion', 'is_in_use': :'isInUse', 'operating_system': :'operatingSystem', 'pattern_id': :'patternId', 'source_id': :'sourceId', 'version': :'version', 'source': :'source' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'pattern': :'OCI::LogAnalytics::Models::LogAnalyticsSourcePattern', 'agent_version': :'String', 'is_in_use': :'BOOLEAN', 'operating_system': :'String', 'pattern_id': :'Integer', 'source_id': :'Integer', 'version': :'String', 'source': :'OCI::LogAnalytics::Models::LogAnalyticsSource' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 136 def ==(other) return true if equal?(other) self.class == other.class && pattern == other.pattern && agent_version == other.agent_version && is_in_use == other.is_in_use && == other. && pattern_id == other.pattern_id && source_id == other.source_id && version == other.version && source == other.source end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
153 154 155 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 153 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 162 def hash [pattern, agent_version, is_in_use, , pattern_id, source_id, version, source].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
200 201 202 |
# File 'lib/oci/log_analytics/models/log_analytics_pattern_filter.rb', line 200 def to_s to_hash.to_s end |