Class: OCI::LogAnalytics::Models::QueryWorkRequest
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::QueryWorkRequest
- Defined in:
- lib/oci/log_analytics/models/query_work_request.rb
Overview
Job details outlining parameters specified when job was submitted.
Constant Summary collapse
- STATUS_ENUM =
[ STATUS_ACCEPTED = 'ACCEPTED'.freeze, STATUS_CANCELED = 'CANCELED'.freeze, STATUS_FAILED = 'FAILED'.freeze, STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze, STATUS_SUCCEEDED = 'SUCCEEDED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- OPERATION_TYPE_ENUM =
[ OPERATION_TYPE_EXECUTE_QUERY_JOB = 'EXECUTE_QUERY_JOB'.freeze, OPERATION_TYPE_EXECUTE_PURGE_JOB = 'EXECUTE_PURGE_JOB'.freeze, OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- MODE_ENUM =
[ MODE_FOREGROUND = 'FOREGROUND'.freeze, MODE_BACKGROUND = 'BACKGROUND'.freeze, MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SUB_SYSTEM_ENUM =
[ SUB_SYSTEM_LOG = 'LOG'.freeze, SUB_SYSTEM_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
-
#display_query_string ⇒ String
[Required] Display version of the user speciified queryString.
-
#id ⇒ String
[Required] Unique OCID identifier to reference this query job work Request with.
-
#internal_query_string ⇒ String
[Required] Internal version of the user specified queryString.
-
#mode ⇒ String
[Required] Current execution mode for the job.
-
#operation_type ⇒ String
Asynchronous action name.
-
#percent_complete ⇒ Integer
Percentage progress completion of the query.
-
#scope_filters ⇒ Array<OCI::LogAnalytics::Models::ScopeFilter>
List of filters applied when the query executed.
-
#status ⇒ String
Work request status.
-
#sub_system ⇒ String
[Required] Default subsystem to qualify fields with in the queryString if not specified.
-
#time_accepted ⇒ DateTime
When the work request was accepted.
-
#time_background_at ⇒ DateTime
When the job was put in to the background.
-
#time_expires ⇒ DateTime
When the job will expire.
- #time_filter ⇒ OCI::LogAnalytics::Models::TimeRange
-
#time_finished ⇒ DateTime
When the job finished execution.
-
#time_started ⇒ DateTime
[Required] When the job was started.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QueryWorkRequest
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ QueryWorkRequest
Initializes the object
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 180 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] self.time_expires = attributes[:'timeExpires'] if attributes[:'timeExpires'] raise 'You cannot provide both :timeExpires and :time_expires' if attributes.key?(:'timeExpires') && attributes.key?(:'time_expires') self.time_expires = attributes[:'time_expires'] if attributes[:'time_expires'] self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete'] raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete'] self.status = attributes[:'status'] if attributes[:'status'] self.operation_type = attributes[:'operationType'] if attributes[:'operationType'] raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type'] self.mode = attributes[:'mode'] if attributes[:'mode'] self.time_background_at = attributes[:'timeBackgroundAt'] if attributes[:'timeBackgroundAt'] raise 'You cannot provide both :timeBackgroundAt and :time_background_at' if attributes.key?(:'timeBackgroundAt') && attributes.key?(:'time_background_at') self.time_background_at = attributes[:'time_background_at'] if attributes[:'time_background_at'] self.time_filter = attributes[:'timeFilter'] if attributes[:'timeFilter'] raise 'You cannot provide both :timeFilter and :time_filter' if attributes.key?(:'timeFilter') && attributes.key?(:'time_filter') self.time_filter = attributes[:'time_filter'] if attributes[:'time_filter'] self.scope_filters = attributes[:'scopeFilters'] if attributes[:'scopeFilters'] raise 'You cannot provide both :scopeFilters and :scope_filters' if attributes.key?(:'scopeFilters') && attributes.key?(:'scope_filters') self.scope_filters = attributes[:'scope_filters'] if attributes[:'scope_filters'] self.sub_system = attributes[:'subSystem'] if attributes[:'subSystem'] raise 'You cannot provide both :subSystem and :sub_system' if attributes.key?(:'subSystem') && attributes.key?(:'sub_system') self.sub_system = attributes[:'sub_system'] if attributes[:'sub_system'] self.display_query_string = attributes[:'displayQueryString'] if attributes[:'displayQueryString'] raise 'You cannot provide both :displayQueryString and :display_query_string' if attributes.key?(:'displayQueryString') && attributes.key?(:'display_query_string') self.display_query_string = attributes[:'display_query_string'] if attributes[:'display_query_string'] self.internal_query_string = attributes[:'internalQueryString'] if attributes[:'internalQueryString'] raise 'You cannot provide both :internalQueryString and :internal_query_string' if attributes.key?(:'internalQueryString') && attributes.key?(:'internal_query_string') self.internal_query_string = attributes[:'internal_query_string'] if attributes[:'internal_query_string'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment Identifier [OCID] (docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
45 46 47 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 45 def compartment_id @compartment_id end |
#display_query_string ⇒ String
[Required] Display version of the user speciified queryString.
103 104 105 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 103 def display_query_string @display_query_string end |
#id ⇒ String
[Required] Unique OCID identifier to reference this query job work Request with.
41 42 43 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 41 def id @id end |
#internal_query_string ⇒ String
[Required] Internal version of the user specified queryString.
108 109 110 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 108 def internal_query_string @internal_query_string end |
#mode ⇒ String
[Required] Current execution mode for the job.
81 82 83 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 81 def mode @mode end |
#operation_type ⇒ String
Asynchronous action name.
77 78 79 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 77 def operation_type @operation_type end |
#percent_complete ⇒ Integer
Percentage progress completion of the query.
67 68 69 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 67 def percent_complete @percent_complete end |
#scope_filters ⇒ Array<OCI::LogAnalytics::Models::ScopeFilter>
List of filters applied when the query executed.
93 94 95 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 93 def scope_filters @scope_filters end |
#status ⇒ String
Work request status.
72 73 74 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 72 def status @status end |
#sub_system ⇒ String
[Required] Default subsystem to qualify fields with in the queryString if not specified.
98 99 100 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 98 def sub_system @sub_system end |
#time_accepted ⇒ DateTime
When the work request was accepted. Should match timeStarted in all cases.
54 55 56 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 54 def time_accepted @time_accepted end |
#time_background_at ⇒ DateTime
When the job was put in to the background.
85 86 87 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 85 def time_background_at @time_background_at end |
#time_expires ⇒ DateTime
When the job will expire.
62 63 64 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 62 def time_expires @time_expires end |
#time_filter ⇒ OCI::LogAnalytics::Models::TimeRange
88 89 90 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 88 def time_filter @time_filter end |
#time_finished ⇒ DateTime
When the job finished execution.
58 59 60 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 58 def time_finished @time_finished end |
#time_started ⇒ DateTime
[Required] When the job was started.
49 50 51 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 49 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 111 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'time_started': :'timeStarted', 'time_accepted': :'timeAccepted', 'time_finished': :'timeFinished', 'time_expires': :'timeExpires', 'percent_complete': :'percentComplete', 'status': :'status', 'operation_type': :'operationType', 'mode': :'mode', 'time_background_at': :'timeBackgroundAt', 'time_filter': :'timeFilter', 'scope_filters': :'scopeFilters', 'sub_system': :'subSystem', 'display_query_string': :'displayQueryString', 'internal_query_string': :'internalQueryString' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 135 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'time_started': :'DateTime', 'time_accepted': :'DateTime', 'time_finished': :'DateTime', 'time_expires': :'DateTime', 'percent_complete': :'Integer', 'status': :'String', 'operation_type': :'String', 'mode': :'String', 'time_background_at': :'DateTime', 'time_filter': :'OCI::LogAnalytics::Models::TimeRange', 'scope_filters': :'Array<OCI::LogAnalytics::Models::ScopeFilter>', 'sub_system': :'String', 'display_query_string': :'String', 'internal_query_string': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 330 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && time_started == other.time_started && time_accepted == other.time_accepted && time_finished == other.time_finished && time_expires == other.time_expires && percent_complete == other.percent_complete && status == other.status && operation_type == other.operation_type && mode == other.mode && time_background_at == other.time_background_at && time_filter == other.time_filter && scope_filters == other.scope_filters && sub_system == other.sub_system && display_query_string == other.display_query_string && internal_query_string == other.internal_query_string end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 375 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
355 356 357 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 355 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
364 365 366 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 364 def hash [id, compartment_id, time_started, time_accepted, time_finished, time_expires, percent_complete, status, operation_type, mode, time_background_at, time_filter, scope_filters, sub_system, display_query_string, internal_query_string].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
408 409 410 411 412 413 414 415 416 417 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 408 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
402 403 404 |
# File 'lib/oci/log_analytics/models/query_work_request.rb', line 402 def to_s to_hash.to_s end |