Class: OCI::LogAnalytics::Models::StreamAction

Inherits:
Action
  • Object
show all
Defined in:
lib/oci/log_analytics/models/stream_action.rb

Overview

Stream action for scheduled task.

Constant Summary

Constants inherited from Action

Action::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from Action

#type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Action

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ StreamAction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/oci/log_analytics/models/stream_action.rb', line 48

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'STREAM'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.saved_search_id = attributes[:'savedSearchId'] if attributes[:'savedSearchId']

  raise 'You cannot provide both :savedSearchId and :saved_search_id' if attributes.key?(:'savedSearchId') && attributes.key?(:'saved_search_id')

  self.saved_search_id = attributes[:'saved_search_id'] if attributes[:'saved_search_id']

  self.metric_extraction = attributes[:'metricExtraction'] if attributes[:'metricExtraction']

  raise 'You cannot provide both :metricExtraction and :metric_extraction' if attributes.key?(:'metricExtraction') && attributes.key?(:'metric_extraction')

  self.metric_extraction = attributes[:'metric_extraction'] if attributes[:'metric_extraction']
end

Instance Attribute Details

#metric_extractionOCI::LogAnalytics::Models::MetricExtraction



16
17
18
# File 'lib/oci/log_analytics/models/stream_action.rb', line 16

def metric_extraction
  @metric_extraction
end

#saved_search_idString

The ManagementSavedSearch id [OCID] utilized in the action.

Returns:

  • (String)


13
14
15
# File 'lib/oci/log_analytics/models/stream_action.rb', line 13

def saved_search_id
  @saved_search_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



19
20
21
22
23
24
25
26
27
# File 'lib/oci/log_analytics/models/stream_action.rb', line 19

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'saved_search_id': :'savedSearchId',
    'metric_extraction': :'metricExtraction'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



30
31
32
33
34
35
36
37
38
# File 'lib/oci/log_analytics/models/stream_action.rb', line 30

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'saved_search_id': :'String',
    'metric_extraction': :'OCI::LogAnalytics::Models::MetricExtraction'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



78
79
80
81
82
83
84
85
# File 'lib/oci/log_analytics/models/stream_action.rb', line 78

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    saved_search_id == other.saved_search_id &&
    metric_extraction == other.metric_extraction
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/oci/log_analytics/models/stream_action.rb', line 110

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


90
91
92
# File 'lib/oci/log_analytics/models/stream_action.rb', line 90

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



99
100
101
# File 'lib/oci/log_analytics/models/stream_action.rb', line 99

def hash
  [type, saved_search_id, metric_extraction].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



143
144
145
146
147
148
149
150
151
152
# File 'lib/oci/log_analytics/models/stream_action.rb', line 143

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



137
138
139
# File 'lib/oci/log_analytics/models/stream_action.rb', line 137

def to_s
  to_hash.to_s
end