Class: OCI::LogAnalytics::Models::UnprocessedDataBucket
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::UnprocessedDataBucket
- Defined in:
- lib/oci/log_analytics/models/unprocessed_data_bucket.rb
Overview
Configuration details of the bucket that stores unprocessed payloads.
Instance Attribute Summary collapse
-
#bucket_name ⇒ String
[Required] Name of the Object Storage bucket.
-
#is_enabled ⇒ BOOLEAN
Flag that specifies if this configuration is enabled or not.
-
#namespace ⇒ String
[Required] Object Storage namespace.
-
#time_created ⇒ DateTime
The time when this record is created.
-
#time_updated ⇒ DateTime
The latest time when this record is updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UnprocessedDataBucket
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UnprocessedDataBucket
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.namespace = attributes[:'namespace'] if attributes[:'namespace'] self.bucket_name = attributes[:'bucketName'] if attributes[:'bucketName'] raise 'You cannot provide both :bucketName and :bucket_name' if attributes.key?(:'bucketName') && attributes.key?(:'bucket_name') self.bucket_name = attributes[:'bucket_name'] if attributes[:'bucket_name'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#bucket_name ⇒ String
[Required] Name of the Object Storage bucket.
17 18 19 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 17 def bucket_name @bucket_name end |
#is_enabled ⇒ BOOLEAN
Flag that specifies if this configuration is enabled or not.
22 23 24 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 22 def is_enabled @is_enabled end |
#namespace ⇒ String
[Required] Object Storage namespace.
13 14 15 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 13 def namespace @namespace end |
#time_created ⇒ DateTime
The time when this record is created. An RFC3339 formatted datetime string.
26 27 28 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 26 def time_created @time_created end |
#time_updated ⇒ DateTime
The latest time when this record is updated. An RFC3339 formatted datetime string.
30 31 32 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 30 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'namespace': :'namespace', 'bucket_name': :'bucketName', 'is_enabled': :'isEnabled', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'namespace': :'String', 'bucket_name': :'String', 'is_enabled': :'BOOLEAN', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && namespace == other.namespace && bucket_name == other.bucket_name && is_enabled == other.is_enabled && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
134 135 136 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 134 def hash [namespace, bucket_name, is_enabled, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
172 173 174 |
# File 'lib/oci/log_analytics/models/unprocessed_data_bucket.rb', line 172 def to_s to_hash.to_s end |