Class: OCI::LogAnalytics::Models::UpdateLogAnalyticsEntityDetails
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::UpdateLogAnalyticsEntityDetails
- Defined in:
- lib/oci/log_analytics/models/update_log_analytics_entity_details.rb
Overview
Details of log analytics entity to be updated.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#hostname ⇒ String
The hostname where the entity represented here is actually present.
-
#management_agent_id ⇒ String
The OCID of the Management Agent.
-
#name ⇒ String
Log analytics entity name.
-
#properties ⇒ Hash<String, String>
The name/value pairs for parameter values to be used in file patterns specified in log sources.
-
#timezone_region ⇒ String
The timezone region of the log analytics entity.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateLogAnalyticsEntityDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateLogAnalyticsEntityDetails
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 93 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.management_agent_id = attributes[:'managementAgentId'] if attributes[:'managementAgentId'] raise 'You cannot provide both :managementAgentId and :management_agent_id' if attributes.key?(:'managementAgentId') && attributes.key?(:'management_agent_id') self.management_agent_id = attributes[:'management_agent_id'] if attributes[:'management_agent_id'] self.timezone_region = attributes[:'timezoneRegion'] if attributes[:'timezoneRegion'] raise 'You cannot provide both :timezoneRegion and :timezone_region' if attributes.key?(:'timezoneRegion') && attributes.key?(:'timezone_region') self.timezone_region = attributes[:'timezone_region'] if attributes[:'timezone_region'] self.hostname = attributes[:'hostname'] if attributes[:'hostname'] self.properties = attributes[:'properties'] if attributes[:'properties'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
48 49 50 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 48 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
42 43 44 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 42 def end |
#hostname ⇒ String
The hostname where the entity represented here is actually present. This would be the output one would get if they run ‘echo $HOSTNAME` on Linux or an equivalent OS command. This may be different from management agents host since logs may be collected remotely.
31 32 33 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 31 def hostname @hostname end |
#management_agent_id ⇒ String
The OCID of the Management Agent.
19 20 21 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 19 def management_agent_id @management_agent_id end |
#name ⇒ String
Log analytics entity name.
14 15 16 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 14 def name @name end |
#properties ⇒ Hash<String, String>
The name/value pairs for parameter values to be used in file patterns specified in log sources.
36 37 38 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 36 def properties @properties end |
#timezone_region ⇒ String
The timezone region of the log analytics entity.
24 25 26 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 24 def timezone_region @timezone_region end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 51 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'management_agent_id': :'managementAgentId', 'timezone_region': :'timezoneRegion', 'hostname': :'hostname', 'properties': :'properties', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'management_agent_id': :'String', 'timezone_region': :'String', 'hostname': :'String', 'properties': :'Hash<String, String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 137 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && management_agent_id == other.management_agent_id && timezone_region == other.timezone_region && hostname == other.hostname && properties == other.properties && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
153 154 155 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 153 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 162 def hash [name, management_agent_id, timezone_region, hostname, properties, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
200 201 202 |
# File 'lib/oci/log_analytics/models/update_log_analytics_entity_details.rb', line 200 def to_s to_hash.to_s end |