Class: OCI::LogAnalytics::Models::UpdateLogAnalyticsObjectCollectionRuleDetails
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::UpdateLogAnalyticsObjectCollectionRuleDetails
- Defined in:
- lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb
Overview
Configuration of the collection rule to be updated.
Instance Attribute Summary collapse
-
#char_encoding ⇒ String
An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A string that describes the details of the rule.
-
#entity_id ⇒ String
Logging Analytics entity OCID.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_enabled ⇒ BOOLEAN
Whether or not this rule is currently enabled.
-
#log_group_id ⇒ String
Logging Analytics Log group OCID to associate the processed logs with.
-
#log_source_name ⇒ String
Name of the Logging Analytics Source to use for the processing.
-
#object_name_filters ⇒ Array<String>
When the filters are provided, only the objects matching the filters are picked up for processing.
-
#overrides ⇒ Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>
Use this to override some property values which are defined at bucket level to the scope of object.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateLogAnalyticsObjectCollectionRuleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateLogAnalyticsObjectCollectionRuleDetails
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 120 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.log_group_id = attributes[:'logGroupId'] if attributes[:'logGroupId'] raise 'You cannot provide both :logGroupId and :log_group_id' if attributes.key?(:'logGroupId') && attributes.key?(:'log_group_id') self.log_group_id = attributes[:'log_group_id'] if attributes[:'log_group_id'] self.log_source_name = attributes[:'logSourceName'] if attributes[:'logSourceName'] raise 'You cannot provide both :logSourceName and :log_source_name' if attributes.key?(:'logSourceName') && attributes.key?(:'log_source_name') self.log_source_name = attributes[:'log_source_name'] if attributes[:'log_source_name'] self.entity_id = attributes[:'entityId'] if attributes[:'entityId'] raise 'You cannot provide both :entityId and :entity_id' if attributes.key?(:'entityId') && attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] if attributes[:'entity_id'] self.char_encoding = attributes[:'charEncoding'] if attributes[:'charEncoding'] raise 'You cannot provide both :charEncoding and :char_encoding' if attributes.key?(:'charEncoding') && attributes.key?(:'char_encoding') self.char_encoding = attributes[:'char_encoding'] if attributes[:'char_encoding'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.overrides = attributes[:'overrides'] if attributes[:'overrides'] self.object_name_filters = attributes[:'objectNameFilters'] if attributes[:'objectNameFilters'] raise 'You cannot provide both :objectNameFilters and :object_name_filters' if attributes.key?(:'objectNameFilters') && attributes.key?(:'object_name_filters') self.object_name_filters = attributes[:'object_name_filters'] if attributes[:'object_name_filters'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] end |
Instance Attribute Details
#char_encoding ⇒ String
An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing. It is recommended to set this value as ISO_8859_1 when configuring content of the objects having more numeric characters, and very few alphabets. For e.g. this applies when configuring VCN Flow Logs.
35 36 37 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 35 def char_encoding @char_encoding end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
60 61 62 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 60 def end |
#description ⇒ String
A string that describes the details of the rule. Avoid entering confidential information.
15 16 17 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 15 def description @description end |
#entity_id ⇒ String
Logging Analytics entity OCID. Associates the processed logs with the given entity (optional).
27 28 29 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 27 def entity_id @entity_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
66 67 68 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 66 def end |
#is_enabled ⇒ BOOLEAN
Whether or not this rule is currently enabled.
40 41 42 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 40 def is_enabled @is_enabled end |
#log_group_id ⇒ String
Logging Analytics Log group OCID to associate the processed logs with.
19 20 21 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 19 def log_group_id @log_group_id end |
#log_source_name ⇒ String
Name of the Logging Analytics Source to use for the processing.
23 24 25 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 23 def log_source_name @log_source_name end |
#object_name_filters ⇒ Array<String>
When the filters are provided, only the objects matching the filters are picked up for processing. The matchType supported is exact match and accommodates wildcard "*". For more information on filters, see [Event Filters](docs.oracle.com/en-us/iaas/Content/Events/Concepts/filterevents.htm).
54 55 56 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 54 def object_name_filters @object_name_filters end |
#overrides ⇒ Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>
Use this to override some property values which are defined at bucket level to the scope of object. Supported propeties for override are: logSourceName, charEncoding, entityId. Supported matchType for override are "contains".
47 48 49 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 47 def overrides @overrides end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'log_group_id': :'logGroupId', 'log_source_name': :'logSourceName', 'entity_id': :'entityId', 'char_encoding': :'charEncoding', 'is_enabled': :'isEnabled', 'overrides': :'overrides', 'object_name_filters': :'objectNameFilters', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 87 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'log_group_id': :'String', 'log_source_name': :'String', 'entity_id': :'String', 'char_encoding': :'String', 'is_enabled': :'BOOLEAN', 'overrides': :'Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>', 'object_name_filters': :'Array<String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 186 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && log_group_id == other.log_group_id && log_source_name == other.log_source_name && entity_id == other.entity_id && char_encoding == other.char_encoding && is_enabled == other.is_enabled && overrides == other.overrides && object_name_filters == other.object_name_filters && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 225 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
205 206 207 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 205 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 214 def hash [description, log_group_id, log_source_name, entity_id, char_encoding, is_enabled, overrides, object_name_filters, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
252 253 254 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 252 def to_s to_hash.to_s end |