Class: OCI::LogAnalytics::Models::UpdateLogAnalyticsObjectCollectionRuleDetails
- Inherits:
-
Object
- Object
- OCI::LogAnalytics::Models::UpdateLogAnalyticsObjectCollectionRuleDetails
- Defined in:
- lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb
Overview
To update the attributes of an Object Storage based collection rule.
Instance Attribute Summary collapse
-
#char_encoding ⇒ String
An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A string that describes the details of the rule.
-
#entity_id ⇒ String
Log Analytics entity OCID.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#log_group_id ⇒ String
Log Analytics Log group OCID to associate the processed logs with.
-
#log_source_name ⇒ String
Name of the Log Analytics Source to use for the processing.
-
#overrides ⇒ Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>
Use this to override some property values which are defined at bucket level to the scope of object.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateLogAnalyticsObjectCollectionRuleDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateLogAnalyticsObjectCollectionRuleDetails
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 102 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.log_group_id = attributes[:'logGroupId'] if attributes[:'logGroupId'] raise 'You cannot provide both :logGroupId and :log_group_id' if attributes.key?(:'logGroupId') && attributes.key?(:'log_group_id') self.log_group_id = attributes[:'log_group_id'] if attributes[:'log_group_id'] self.log_source_name = attributes[:'logSourceName'] if attributes[:'logSourceName'] raise 'You cannot provide both :logSourceName and :log_source_name' if attributes.key?(:'logSourceName') && attributes.key?(:'log_source_name') self.log_source_name = attributes[:'log_source_name'] if attributes[:'log_source_name'] self.entity_id = attributes[:'entityId'] if attributes[:'entityId'] raise 'You cannot provide both :entityId and :entity_id' if attributes.key?(:'entityId') && attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] if attributes[:'entity_id'] self.char_encoding = attributes[:'charEncoding'] if attributes[:'charEncoding'] raise 'You cannot provide both :charEncoding and :char_encoding' if attributes.key?(:'charEncoding') && attributes.key?(:'char_encoding') self.char_encoding = attributes[:'char_encoding'] if attributes[:'char_encoding'] self.overrides = attributes[:'overrides'] if attributes[:'overrides'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] end |
Instance Attribute Details
#char_encoding ⇒ String
An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing. It is recommended to set this value as ISO_8589_1 when configuring content of the objects having more numeric characters, and very few alphabets. For e.g. this applies when configuring VCN Flow Logs.
35 36 37 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 35 def char_encoding @char_encoding end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
Example: {\"foo-namespace\": {\"bar-key\": \"value\"}}
48 49 50 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 48 def end |
#description ⇒ String
A string that describes the details of the rule. Avoid entering confidential information.
15 16 17 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 15 def description @description end |
#entity_id ⇒ String
Log Analytics entity OCID. Associates the processed logs with the given entity (optional).
27 28 29 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 27 def entity_id @entity_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
Example: {\"bar-key\": \"value\"}
54 55 56 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 54 def end |
#log_group_id ⇒ String
Log Analytics Log group OCID to associate the processed logs with.
19 20 21 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 19 def log_group_id @log_group_id end |
#log_source_name ⇒ String
Name of the Log Analytics Source to use for the processing.
23 24 25 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 23 def log_source_name @log_source_name end |
#overrides ⇒ Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>
Use this to override some property values which are defined at bucket level to the scope of object. Supported propeties for override are, logSourceName, charEncoding. Supported matchType for override are "contains".
42 43 44 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 42 def overrides @overrides end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'log_group_id': :'logGroupId', 'log_source_name': :'logSourceName', 'entity_id': :'entityId', 'char_encoding': :'charEncoding', 'overrides': :'overrides', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 73 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'log_group_id': :'String', 'log_source_name': :'String', 'entity_id': :'String', 'char_encoding': :'String', 'overrides': :'Hash<String, Array<OCI::LogAnalytics::Models::PropertyOverride>>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 156 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && log_group_id == other.log_group_id && log_source_name == other.log_source_name && entity_id == other.entity_id && char_encoding == other.char_encoding && overrides == other.overrides && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 193 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
173 174 175 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 173 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
182 183 184 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 182 def hash [description, log_group_id, log_source_name, entity_id, char_encoding, overrides, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
226 227 228 229 230 231 232 233 234 235 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 226 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
220 221 222 |
# File 'lib/oci/log_analytics/models/update_log_analytics_object_collection_rule_details.rb', line 220 def to_s to_hash.to_s end |