Class: OCI::ManagementAgent::ManagementAgentClientCompositeOperations
- Inherits:
-
Object
- Object
- OCI::ManagementAgent::ManagementAgentClientCompositeOperations
- Defined in:
- lib/oci/management_agent/management_agent_client_composite_operations.rb
Overview
This class provides a wrapper around ManagementAgentClient and offers convenience methods for operations that would otherwise need to be chained together. For example, instead of performing an action on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource to enter a given state, you can call a single method in this class to accomplish the same functionality
Instance Attribute Summary collapse
-
#service_client ⇒ OCI::ManagementAgent::ManagementAgentClient
readonly
The ManagementAgentClient used to communicate with the service_client.
Instance Method Summary collapse
-
#create_management_agent_install_key_and_wait_for_state(create_management_agent_install_key_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#create_management_agent_install_key and then waits for the OCI::ManagementAgent::Models::ManagementAgentInstallKey acted upon to enter the given state(s).
-
#delete_management_agent_and_wait_for_state(management_agent_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#delete_management_agent and then waits for the OCI::ManagementAgent::Models::ManagementAgent acted upon to enter the given state(s).
-
#delete_management_agent_install_key_and_wait_for_state(management_agent_install_key_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#delete_management_agent_install_key and then waits for the OCI::ManagementAgent::Models::ManagementAgentInstallKey acted upon to enter the given state(s).
-
#deploy_plugins_and_wait_for_state(deploy_plugins_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#deploy_plugins and then waits for the OCI::ManagementAgent::Models::WorkRequest to enter the given state(s).
-
#initialize(service_client = OCI::ManagementAgent::ManagementAgentClient.new) ⇒ ManagementAgentClientCompositeOperations
constructor
Initializes a new ManagementAgentClientCompositeOperations.
-
#update_management_agent_and_wait_for_state(management_agent_id, update_management_agent_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#update_management_agent and then waits for the OCI::ManagementAgent::Models::ManagementAgent acted upon to enter the given state(s).
-
#update_management_agent_install_key_and_wait_for_state(management_agent_install_key_id, update_management_agent_install_key_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#update_management_agent_install_key and then waits for the OCI::ManagementAgent::Models::ManagementAgentInstallKey acted upon to enter the given state(s).
Constructor Details
#initialize(service_client = OCI::ManagementAgent::ManagementAgentClient.new) ⇒ ManagementAgentClientCompositeOperations
Initializes a new ManagementAgentClientCompositeOperations
20 21 22 |
# File 'lib/oci/management_agent/management_agent_client_composite_operations.rb', line 20 def initialize(service_client = OCI::ManagementAgent::ManagementAgentClient.new) @service_client = service_client end |
Instance Attribute Details
#service_client ⇒ OCI::ManagementAgent::ManagementAgentClient (readonly)
The OCI::ManagementAgent::ManagementAgentClient used to communicate with the service_client
14 15 16 |
# File 'lib/oci/management_agent/management_agent_client_composite_operations.rb', line 14 def service_client @service_client end |
Instance Method Details
#create_management_agent_install_key_and_wait_for_state(create_management_agent_install_key_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#create_management_agent_install_key and then waits for the OCI::ManagementAgent::Models::ManagementAgentInstallKey acted upon to enter the given state(s).
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/management_agent/management_agent_client_composite_operations.rb', line 39 def create_management_agent_install_key_and_wait_for_state(create_management_agent_install_key_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.create_management_agent_install_key(create_management_agent_install_key_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_management_agent_install_key(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#delete_management_agent_and_wait_for_state(management_agent_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#delete_management_agent and then waits for the OCI::ManagementAgent::Models::ManagementAgent acted upon to enter the given state(s).
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/oci/management_agent/management_agent_client_composite_operations.rb', line 78 def delete_management_agent_and_wait_for_state(management_agent_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) initial_get_result = @service_client.get_management_agent(management_agent_id) operation_result = @service_client.delete_management_agent(management_agent_id, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) begin waiter_result = initial_get_result.wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200, succeed_on_not_found: true ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#delete_management_agent_install_key_and_wait_for_state(management_agent_install_key_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#delete_management_agent_install_key and then waits for the OCI::ManagementAgent::Models::ManagementAgentInstallKey acted upon to enter the given state(s).
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/oci/management_agent/management_agent_client_composite_operations.rb', line 118 def delete_management_agent_install_key_and_wait_for_state(management_agent_install_key_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) initial_get_result = @service_client.get_management_agent_install_key(management_agent_install_key_id) operation_result = @service_client.delete_management_agent_install_key(management_agent_install_key_id, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) begin waiter_result = initial_get_result.wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200, succeed_on_not_found: true ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#deploy_plugins_and_wait_for_state(deploy_plugins_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#deploy_plugins and then waits for the OCI::ManagementAgent::Models::WorkRequest to enter the given state(s).
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/management_agent/management_agent_client_composite_operations.rb', line 158 def deploy_plugins_and_wait_for_state(deploy_plugins_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.deploy_plugins(deploy_plugins_details, base_operation_opts) use_util = OCI::ManagementAgent::Util.respond_to?(:wait_on_work_request) return operation_result if wait_for_states.empty? && !use_util lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.headers['opc-work-request-id'] begin if use_util waiter_result = OCI::ManagementAgent::Util.wait_on_work_request( @service_client, wait_for_resource_id, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) else waiter_result = @service_client.get_work_request(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:status) && lowered_wait_for_states.include?(response.data.status.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) end result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_management_agent_and_wait_for_state(management_agent_id, update_management_agent_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#update_management_agent and then waits for the OCI::ManagementAgent::Models::ManagementAgent acted upon to enter the given state(s).
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/oci/management_agent/management_agent_client_composite_operations.rb', line 208 def update_management_agent_and_wait_for_state(management_agent_id, update_management_agent_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_management_agent(management_agent_id, update_management_agent_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_management_agent(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |
#update_management_agent_install_key_and_wait_for_state(management_agent_install_key_id, update_management_agent_install_key_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) ⇒ OCI::Response
Calls OCI::ManagementAgent::ManagementAgentClient#update_management_agent_install_key and then waits for the OCI::ManagementAgent::Models::ManagementAgentInstallKey acted upon to enter the given state(s).
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/oci/management_agent/management_agent_client_composite_operations.rb', line 248 def update_management_agent_install_key_and_wait_for_state(management_agent_install_key_id, update_management_agent_install_key_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {}) operation_result = @service_client.update_management_agent_install_key(management_agent_install_key_id, update_management_agent_install_key_details, base_operation_opts) return operation_result if wait_for_states.empty? lowered_wait_for_states = wait_for_states.map(&:downcase) wait_for_resource_id = operation_result.data.id begin waiter_result = @service_client.get_management_agent_install_key(wait_for_resource_id).wait_until( eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) }, max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30, max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200 ) result_to_return = waiter_result return result_to_return rescue StandardError raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result]) end end |