Class: OCI::ManagementAgent::Models::CreateManagementAgentInstallKeyDetails
- Inherits:
-
Object
- Object
- OCI::ManagementAgent::Models::CreateManagementAgentInstallKeyDetails
- Defined in:
- lib/oci/management_agent/models/create_management_agent_install_key_details.rb
Overview
The information about new Management Agent install Key.
Instance Attribute Summary collapse
-
#allowed_key_install_count ⇒ Integer
Total number of install for this keys.
-
#compartment_id ⇒ String
[Required] Compartment Identifier.
-
#display_name ⇒ String
[Required] Management Agent install Key Name.
-
#time_expires ⇒ DateTime
date after which key would expire after creation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateManagementAgentInstallKeyDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateManagementAgentInstallKeyDetails
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 60 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.allowed_key_install_count = attributes[:'allowedKeyInstallCount'] if attributes[:'allowedKeyInstallCount'] raise 'You cannot provide both :allowedKeyInstallCount and :allowed_key_install_count' if attributes.key?(:'allowedKeyInstallCount') && attributes.key?(:'allowed_key_install_count') self.allowed_key_install_count = attributes[:'allowed_key_install_count'] if attributes[:'allowed_key_install_count'] self.time_expires = attributes[:'timeExpires'] if attributes[:'timeExpires'] raise 'You cannot provide both :timeExpires and :time_expires' if attributes.key?(:'timeExpires') && attributes.key?(:'time_expires') self.time_expires = attributes[:'time_expires'] if attributes[:'time_expires'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] end |
Instance Attribute Details
#allowed_key_install_count ⇒ Integer
Total number of install for this keys
16 17 18 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 16 def allowed_key_install_count @allowed_key_install_count end |
#compartment_id ⇒ String
[Required] Compartment Identifier
24 25 26 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 24 def compartment_id @compartment_id end |
#display_name ⇒ String
[Required] Management Agent install Key Name
12 13 14 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 12 def display_name @display_name end |
#time_expires ⇒ DateTime
date after which key would expire after creation
20 21 22 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 20 def time_expires @time_expires end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 27 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'allowed_key_install_count': :'allowedKeyInstallCount', 'time_expires': :'timeExpires', 'compartment_id': :'compartmentId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 39 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'allowed_key_install_count': :'Integer', 'time_expires': :'DateTime', 'compartment_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && allowed_key_install_count == other.allowed_key_install_count && time_expires == other.time_expires && compartment_id == other.compartment_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 131 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 120 def hash [display_name, allowed_key_install_count, time_expires, compartment_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
158 159 160 |
# File 'lib/oci/management_agent/models/create_management_agent_install_key_details.rb', line 158 def to_s to_hash.to_s end |