Class: OCI::ManagementAgent::Models::ManagementAgentImage
- Inherits:
-
Object
- Object
- OCI::ManagementAgent::Models::ManagementAgentImage
- Defined in:
- lib/oci/management_agent/models/management_agent_image.rb
Overview
Supported Agent downloads
Constant Summary collapse
- PLATFORM_TYPE_ENUM =
[ PLATFORM_TYPE_LINUX = 'LINUX'.freeze, PLATFORM_TYPE_WINDOWS = 'WINDOWS'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze ].freeze
Instance Attribute Summary collapse
-
#checksum ⇒ String
Agent image content SHA256 Hash.
-
#id ⇒ String
[Required] Agent image resource id.
-
#lifecycle_state ⇒ String
The current state of Management Agent Image.
-
#object_url ⇒ String
Object storage URL for download.
-
#platform_name ⇒ String
Agent image platform display name.
-
#platform_type ⇒ String
[Required] Agent image platform type.
-
#size ⇒ Float
Agent image size in bytes.
-
#version ⇒ String
[Required] Agent image version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManagementAgentImage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ManagementAgentImage
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 104 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.platform_type = attributes[:'platformType'] if attributes[:'platformType'] raise 'You cannot provide both :platformType and :platform_type' if attributes.key?(:'platformType') && attributes.key?(:'platform_type') self.platform_type = attributes[:'platform_type'] if attributes[:'platform_type'] self.platform_name = attributes[:'platformName'] if attributes[:'platformName'] raise 'You cannot provide both :platformName and :platform_name' if attributes.key?(:'platformName') && attributes.key?(:'platform_name') self.platform_name = attributes[:'platform_name'] if attributes[:'platform_name'] self.version = attributes[:'version'] if attributes[:'version'] self.size = attributes[:'size'] if attributes[:'size'] self.checksum = attributes[:'checksum'] if attributes[:'checksum'] self.object_url = attributes[:'objectUrl'] if attributes[:'objectUrl'] raise 'You cannot provide both :objectUrl and :object_url' if attributes.key?(:'objectUrl') && attributes.key?(:'object_url') self.object_url = attributes[:'object_url'] if attributes[:'object_url'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] end |
Instance Attribute Details
#checksum ⇒ String
Agent image content SHA256 Hash
48 49 50 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 48 def checksum @checksum end |
#id ⇒ String
[Required] Agent image resource id
28 29 30 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 28 def id @id end |
#lifecycle_state ⇒ String
The current state of Management Agent Image
56 57 58 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 56 def lifecycle_state @lifecycle_state end |
#object_url ⇒ String
Object storage URL for download
52 53 54 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 52 def object_url @object_url end |
#platform_name ⇒ String
Agent image platform display name
36 37 38 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 36 def platform_name @platform_name end |
#platform_type ⇒ String
[Required] Agent image platform type
32 33 34 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 32 def platform_type @platform_type end |
#size ⇒ Float
Agent image size in bytes
44 45 46 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 44 def size @size end |
#version ⇒ String
[Required] Agent image version
40 41 42 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 40 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 59 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'platform_type': :'platformType', 'platform_name': :'platformName', 'version': :'version', 'size': :'size', 'checksum': :'checksum', 'object_url': :'objectUrl', 'lifecycle_state': :'lifecycleState' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 75 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'platform_type': :'String', 'platform_name': :'String', 'version': :'String', 'size': :'Float', 'checksum': :'String', 'object_url': :'String', 'lifecycle_state': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 166 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && platform_type == other.platform_type && platform_name == other.platform_name && version == other.version && size == other.size && checksum == other.checksum && object_url == other.object_url && lifecycle_state == other.lifecycle_state end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 203 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
183 184 185 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 183 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 192 def hash [id, platform_type, platform_name, version, size, checksum, object_url, lifecycle_state].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
230 231 232 |
# File 'lib/oci/management_agent/models/management_agent_image.rb', line 230 def to_s to_hash.to_s end |