Class: OCI::ManagementAgent::Models::ManagementAgentImageSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/management_agent/models/management_agent_image_summary.rb

Overview

Supported Agent downloads

Constant Summary collapse

PLATFORM_TYPE_ENUM =
[
  PLATFORM_TYPE_LINUX = 'LINUX'.freeze,
  PLATFORM_TYPE_WINDOWS = 'WINDOWS'.freeze,
  PLATFORM_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ManagementAgentImageSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :platform_type (String)

    The value to assign to the #platform_type property

  • :platform_name (String)

    The value to assign to the #platform_name property

  • :version (String)

    The value to assign to the #version property

  • :size (Float)

    The value to assign to the #size property

  • :checksum (String)

    The value to assign to the #checksum property

  • :object_url (String)

    The value to assign to the #object_url property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 107

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.platform_type = attributes[:'platformType'] if attributes[:'platformType']

  raise 'You cannot provide both :platformType and :platform_type' if attributes.key?(:'platformType') && attributes.key?(:'platform_type')

  self.platform_type = attributes[:'platform_type'] if attributes[:'platform_type']

  self.platform_name = attributes[:'platformName'] if attributes[:'platformName']

  raise 'You cannot provide both :platformName and :platform_name' if attributes.key?(:'platformName') && attributes.key?(:'platform_name')

  self.platform_name = attributes[:'platform_name'] if attributes[:'platform_name']

  self.version = attributes[:'version'] if attributes[:'version']

  self.size = attributes[:'size'] if attributes[:'size']

  self.checksum = attributes[:'checksum'] if attributes[:'checksum']

  self.object_url = attributes[:'objectUrl'] if attributes[:'objectUrl']

  raise 'You cannot provide both :objectUrl and :object_url' if attributes.key?(:'objectUrl') && attributes.key?(:'object_url')

  self.object_url = attributes[:'object_url'] if attributes[:'object_url']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']
end

Instance Attribute Details

#checksumString

Agent image content SHA256 Hash

Returns:

  • (String)


51
52
53
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 51

def checksum
  @checksum
end

#idString

[Required] Agent image resource id

Returns:

  • (String)


31
32
33
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 31

def id
  @id
end

#lifecycle_stateString

The current state of Management Agent Image

Returns:

  • (String)


59
60
61
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 59

def lifecycle_state
  @lifecycle_state
end

#object_urlString

Object storage URL for download

Returns:

  • (String)


55
56
57
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 55

def object_url
  @object_url
end

#platform_nameString

Agent image platform display name

Returns:

  • (String)


39
40
41
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 39

def platform_name
  @platform_name
end

#platform_typeString

[Required] Agent image platform type

Returns:

  • (String)


35
36
37
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 35

def platform_type
  @platform_type
end

#sizeFloat

Agent image size in bytes

Returns:

  • (Float)


47
48
49
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 47

def size
  @size
end

#versionString

[Required] Agent image version

Returns:

  • (String)


43
44
45
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 43

def version
  @version
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 62

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'platform_type': :'platformType',
    'platform_name': :'platformName',
    'version': :'version',
    'size': :'size',
    'checksum': :'checksum',
    'object_url': :'objectUrl',
    'lifecycle_state': :'lifecycleState'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 78

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'platform_type': :'String',
    'platform_name': :'String',
    'version': :'String',
    'size': :'Float',
    'checksum': :'String',
    'object_url': :'String',
    'lifecycle_state': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 179

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    platform_type == other.platform_type &&
    platform_name == other.platform_name &&
    version == other.version &&
    size == other.size &&
    checksum == other.checksum &&
    object_url == other.object_url &&
    lifecycle_state == other.lifecycle_state
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 216

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


196
197
198
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 196

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



205
206
207
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 205

def hash
  [id, platform_type, platform_name, version, size, checksum, object_url, lifecycle_state].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



243
244
245
# File 'lib/oci/management_agent/models/management_agent_image_summary.rb', line 243

def to_s
  to_hash.to_s
end