Class: OCI::ManagementDashboard::Models::UpdateManagementDashboardDetails
- Inherits:
-
Object
- Object
- OCI::ManagementDashboard::Models::UpdateManagementDashboardDetails
- Defined in:
- lib/oci/management_dashboard/models/update_management_dashboard_details.rb
Overview
Properties of a dashboard. Dashboard ID must not be provided.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
OCID of the compartment in which the dashboard resides.
-
#data_config ⇒ Array<Object>
Array of JSON that contain data source options.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the dashboard.
-
#display_name ⇒ String
Display name of the dashboard.
-
#drilldown_config ⇒ Array<Object>
Drill-down configuration to define the destination of a drill-down action.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_favorite ⇒ BOOLEAN
Determines whether the dashboard is set as favorite.
-
#is_oob_dashboard ⇒ BOOLEAN
Determines whether the dashboard is an Out-of-the-Box (OOB) dashboard.
-
#is_show_description ⇒ BOOLEAN
Determines whether the description of the dashboard is displayed.
-
#is_show_in_home ⇒ BOOLEAN
Determines whether the dashboard will be displayed in Dashboard Home.
-
#metadata_version ⇒ String
Version of the metadata.
-
#nls ⇒ Object
JSON that contains internationalization options.
-
#parameters_config ⇒ Array<Object>
Defines parameters for the dashboard.
-
#provider_id ⇒ String
ID of the service (for example, log-analytics) that owns the dashboard.
-
#provider_name ⇒ String
Name of the service (for example, Logging Analytics) that owns the dashboard.
-
#provider_version ⇒ String
Version of the service that owns the dashboard.
-
#screen_image ⇒ String
Screen image of the dashboard.
-
#tiles ⇒ Array<OCI::ManagementDashboard::Models::ManagementDashboardTileDetails>
Array of dashboard tiles.
-
#type ⇒ String
Type of dashboard.
-
#ui_config ⇒ Object
JSON that contains user interface options.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateManagementDashboardDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateManagementDashboardDetails
Initializes the object
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 183 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.provider_id = attributes[:'providerId'] if attributes[:'providerId'] raise 'You cannot provide both :providerId and :provider_id' if attributes.key?(:'providerId') && attributes.key?(:'provider_id') self.provider_id = attributes[:'provider_id'] if attributes[:'provider_id'] self.provider_name = attributes[:'providerName'] if attributes[:'providerName'] raise 'You cannot provide both :providerName and :provider_name' if attributes.key?(:'providerName') && attributes.key?(:'provider_name') self.provider_name = attributes[:'provider_name'] if attributes[:'provider_name'] self.provider_version = attributes[:'providerVersion'] if attributes[:'providerVersion'] raise 'You cannot provide both :providerVersion and :provider_version' if attributes.key?(:'providerVersion') && attributes.key?(:'provider_version') self.provider_version = attributes[:'provider_version'] if attributes[:'provider_version'] self.tiles = attributes[:'tiles'] if attributes[:'tiles'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_oob_dashboard = attributes[:'isOobDashboard'] unless attributes[:'isOobDashboard'].nil? raise 'You cannot provide both :isOobDashboard and :is_oob_dashboard' if attributes.key?(:'isOobDashboard') && attributes.key?(:'is_oob_dashboard') self.is_oob_dashboard = attributes[:'is_oob_dashboard'] unless attributes[:'is_oob_dashboard'].nil? self.is_show_in_home = attributes[:'isShowInHome'] unless attributes[:'isShowInHome'].nil? raise 'You cannot provide both :isShowInHome and :is_show_in_home' if attributes.key?(:'isShowInHome') && attributes.key?(:'is_show_in_home') self.is_show_in_home = attributes[:'is_show_in_home'] unless attributes[:'is_show_in_home'].nil? self. = attributes[:'metadataVersion'] if attributes[:'metadataVersion'] raise 'You cannot provide both :metadataVersion and :metadata_version' if attributes.key?(:'metadataVersion') && attributes.key?(:'metadata_version') self. = attributes[:'metadata_version'] if attributes[:'metadata_version'] self.is_show_description = attributes[:'isShowDescription'] unless attributes[:'isShowDescription'].nil? raise 'You cannot provide both :isShowDescription and :is_show_description' if attributes.key?(:'isShowDescription') && attributes.key?(:'is_show_description') self.is_show_description = attributes[:'is_show_description'] unless attributes[:'is_show_description'].nil? self.screen_image = attributes[:'screenImage'] if attributes[:'screenImage'] raise 'You cannot provide both :screenImage and :screen_image' if attributes.key?(:'screenImage') && attributes.key?(:'screen_image') self.screen_image = attributes[:'screen_image'] if attributes[:'screen_image'] self.nls = attributes[:'nls'] if attributes[:'nls'] self.ui_config = attributes[:'uiConfig'] if attributes[:'uiConfig'] raise 'You cannot provide both :uiConfig and :ui_config' if attributes.key?(:'uiConfig') && attributes.key?(:'ui_config') self.ui_config = attributes[:'ui_config'] if attributes[:'ui_config'] self.data_config = attributes[:'dataConfig'] if attributes[:'dataConfig'] raise 'You cannot provide both :dataConfig and :data_config' if attributes.key?(:'dataConfig') && attributes.key?(:'data_config') self.data_config = attributes[:'data_config'] if attributes[:'data_config'] self.type = attributes[:'type'] if attributes[:'type'] self.is_favorite = attributes[:'isFavorite'] unless attributes[:'isFavorite'].nil? raise 'You cannot provide both :isFavorite and :is_favorite' if attributes.key?(:'isFavorite') && attributes.key?(:'is_favorite') self.is_favorite = attributes[:'is_favorite'] unless attributes[:'is_favorite'].nil? self.parameters_config = attributes[:'parametersConfig'] if attributes[:'parametersConfig'] raise 'You cannot provide both :parametersConfig and :parameters_config' if attributes.key?(:'parametersConfig') && attributes.key?(:'parameters_config') self.parameters_config = attributes[:'parameters_config'] if attributes[:'parameters_config'] self.drilldown_config = attributes[:'drilldownConfig'] if attributes[:'drilldownConfig'] raise 'You cannot provide both :drilldownConfig and :drilldown_config' if attributes.key?(:'drilldownConfig') && attributes.key?(:'drilldown_config') self.drilldown_config = attributes[:'drilldown_config'] if attributes[:'drilldown_config'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
OCID of the compartment in which the dashboard resides.
36 37 38 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 36 def compartment_id @compartment_id end |
#data_config ⇒ Array<Object>
Array of JSON that contain data source options.
68 69 70 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 68 def data_config @data_config end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
96 97 98 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 96 def @defined_tags end |
#description ⇒ String
Description of the dashboard.
32 33 34 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 32 def description @description end |
#display_name ⇒ String
Display name of the dashboard.
28 29 30 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 28 def display_name @display_name end |
#drilldown_config ⇒ Array<Object>
Drill-down configuration to define the destination of a drill-down action.
84 85 86 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 84 def drilldown_config @drilldown_config end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
90 91 92 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 90 def @freeform_tags end |
#is_favorite ⇒ BOOLEAN
Determines whether the dashboard is set as favorite.
76 77 78 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 76 def is_favorite @is_favorite end |
#is_oob_dashboard ⇒ BOOLEAN
Determines whether the dashboard is an Out-of-the-Box (OOB) dashboard. Note that OOB dashboards are only provided by Oracle and cannot be modified.
40 41 42 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 40 def is_oob_dashboard @is_oob_dashboard end |
#is_show_description ⇒ BOOLEAN
Determines whether the description of the dashboard is displayed.
52 53 54 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 52 def is_show_description @is_show_description end |
#is_show_in_home ⇒ BOOLEAN
Determines whether the dashboard will be displayed in Dashboard Home.
44 45 46 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 44 def is_show_in_home @is_show_in_home end |
#metadata_version ⇒ String
Version of the metadata.
48 49 50 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 48 def @metadata_version end |
#nls ⇒ Object
JSON that contains internationalization options.
60 61 62 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 60 def nls @nls end |
#parameters_config ⇒ Array<Object>
Defines parameters for the dashboard.
80 81 82 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 80 def parameters_config @parameters_config end |
#provider_id ⇒ String
ID of the service (for example, log-analytics) that owns the dashboard. Each service has a unique ID.
12 13 14 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 12 def provider_id @provider_id end |
#provider_name ⇒ String
Name of the service (for example, Logging Analytics) that owns the dashboard.
16 17 18 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 16 def provider_name @provider_name end |
#provider_version ⇒ String
Version of the service that owns the dashboard.
20 21 22 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 20 def provider_version @provider_version end |
#screen_image ⇒ String
Screen image of the dashboard.
56 57 58 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 56 def screen_image @screen_image end |
#tiles ⇒ Array<OCI::ManagementDashboard::Models::ManagementDashboardTileDetails>
Array of dashboard tiles.
24 25 26 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 24 def tiles @tiles end |
#type ⇒ String
Type of dashboard. NORMAL denotes a single dashboard and SET denotes a dashboard set.
72 73 74 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 72 def type @type end |
#ui_config ⇒ Object
JSON that contains user interface options.
64 65 66 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 64 def ui_config @ui_config end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 99 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'provider_id': :'providerId', 'provider_name': :'providerName', 'provider_version': :'providerVersion', 'tiles': :'tiles', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'is_oob_dashboard': :'isOobDashboard', 'is_show_in_home': :'isShowInHome', 'metadata_version': :'metadataVersion', 'is_show_description': :'isShowDescription', 'screen_image': :'screenImage', 'nls': :'nls', 'ui_config': :'uiConfig', 'data_config': :'dataConfig', 'type': :'type', 'is_favorite': :'isFavorite', 'parameters_config': :'parametersConfig', 'drilldown_config': :'drilldownConfig', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 128 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'provider_id': :'String', 'provider_name': :'String', 'provider_version': :'String', 'tiles': :'Array<OCI::ManagementDashboard::Models::ManagementDashboardTileDetails>', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'is_oob_dashboard': :'BOOLEAN', 'is_show_in_home': :'BOOLEAN', 'metadata_version': :'String', 'is_show_description': :'BOOLEAN', 'screen_image': :'String', 'nls': :'Object', 'ui_config': :'Object', 'data_config': :'Array<Object>', 'type': :'String', 'is_favorite': :'BOOLEAN', 'parameters_config': :'Array<Object>', 'drilldown_config': :'Array<Object>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 307 def ==(other) return true if equal?(other) self.class == other.class && provider_id == other.provider_id && provider_name == other.provider_name && provider_version == other.provider_version && tiles == other.tiles && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && is_oob_dashboard == other.is_oob_dashboard && is_show_in_home == other.is_show_in_home && == other. && is_show_description == other.is_show_description && screen_image == other.screen_image && nls == other.nls && ui_config == other.ui_config && data_config == other.data_config && type == other.type && is_favorite == other.is_favorite && parameters_config == other.parameters_config && drilldown_config == other.drilldown_config && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 357 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
337 338 339 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 337 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
346 347 348 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 346 def hash [provider_id, provider_name, provider_version, tiles, display_name, description, compartment_id, is_oob_dashboard, is_show_in_home, , is_show_description, screen_image, nls, ui_config, data_config, type, is_favorite, parameters_config, drilldown_config, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
390 391 392 393 394 395 396 397 398 399 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 390 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
384 385 386 |
# File 'lib/oci/management_dashboard/models/update_management_dashboard_details.rb', line 384 def to_s to_hash.to_s end |