Class: OCI::Marketplace::Models::ListingPackageSummary
- Inherits:
-
Object
- Object
- OCI::Marketplace::Models::ListingPackageSummary
- Defined in:
- lib/oci/marketplace/models/listing_package_summary.rb
Overview
The model for a summary of a package.
Constant Summary collapse
- PACKAGE_TYPE_ENUM =
[ PACKAGE_TYPE_ORCHESTRATION = 'ORCHESTRATION'.freeze, PACKAGE_TYPE_IMAGE = 'IMAGE'.freeze, PACKAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#listing_id ⇒ String
The ID of the listing that the specified package belongs to.
-
#package_type ⇒ String
The specified package's type.
-
#package_version ⇒ String
The version of the specified package.
- #pricing ⇒ OCI::Marketplace::Models::PricingModel
-
#regions ⇒ Array<OCI::Marketplace::Models::Region>
The regions where you can deploy the listing package.
-
#resource_id ⇒ String
The unique identifier for the package resource.
-
#time_created ⇒ DateTime
The date and time this listing package was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListingPackageSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ListingPackageSummary
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.listing_id = attributes[:'listingId'] if attributes[:'listingId'] raise 'You cannot provide both :listingId and :listing_id' if attributes.key?(:'listingId') && attributes.key?(:'listing_id') self.listing_id = attributes[:'listing_id'] if attributes[:'listing_id'] self.package_version = attributes[:'packageVersion'] if attributes[:'packageVersion'] raise 'You cannot provide both :packageVersion and :package_version' if attributes.key?(:'packageVersion') && attributes.key?(:'package_version') self.package_version = attributes[:'package_version'] if attributes[:'package_version'] self.package_type = attributes[:'packageType'] if attributes[:'packageType'] raise 'You cannot provide both :packageType and :package_type' if attributes.key?(:'packageType') && attributes.key?(:'package_type') self.package_type = attributes[:'package_type'] if attributes[:'package_type'] self.pricing = attributes[:'pricing'] if attributes[:'pricing'] self.regions = attributes[:'regions'] if attributes[:'regions'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#listing_id ⇒ String
The ID of the listing that the specified package belongs to.
19 20 21 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 19 def listing_id @listing_id end |
#package_type ⇒ String
The specified package's type.
27 28 29 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 27 def package_type @package_type end |
#package_version ⇒ String
The version of the specified package.
23 24 25 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 23 def package_version @package_version end |
#pricing ⇒ OCI::Marketplace::Models::PricingModel
30 31 32 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 30 def pricing @pricing end |
#regions ⇒ Array<OCI::Marketplace::Models::Region>
The regions where you can deploy the listing package. (Some packages have restrictions that limit their deployment to United States regions only.)
35 36 37 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 35 def regions @regions end |
#resource_id ⇒ String
The unique identifier for the package resource.
39 40 41 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 39 def resource_id @resource_id end |
#time_created ⇒ DateTime
The date and time this listing package was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Example: `2016-08-25T21:10:29.600Z`
47 48 49 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 47 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'listing_id': :'listingId', 'package_version': :'packageVersion', 'package_type': :'packageType', 'pricing': :'pricing', 'regions': :'regions', 'resource_id': :'resourceId', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'listing_id': :'String', 'package_version': :'String', 'package_type': :'String', 'pricing': :'OCI::Marketplace::Models::PricingModel', 'regions': :'Array<OCI::Marketplace::Models::Region>', 'resource_id': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 153 def ==(other) return true if equal?(other) self.class == other.class && listing_id == other.listing_id && package_version == other.package_version && package_type == other.package_type && pricing == other.pricing && regions == other.regions && resource_id == other.resource_id && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 189 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
169 170 171 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 169 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 178 def hash [listing_id, package_version, package_type, pricing, regions, resource_id, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/oci/marketplace/models/listing_package_summary.rb', line 216 def to_s to_hash.to_s end |