Class: OCI::Marketplace::Models::PublicationPackage
- Inherits:
-
Object
- Object
- OCI::Marketplace::Models::PublicationPackage
- Defined in:
- lib/oci/marketplace/models/publication_package.rb
Overview
A base object for all types of publication packages. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
Constant Summary collapse
- PACKAGE_TYPE_ENUM =
[ PACKAGE_TYPE_ORCHESTRATION = 'ORCHESTRATION'.freeze, PACKAGE_TYPE_IMAGE = 'IMAGE'.freeze, PACKAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the package.
-
#listing_id ⇒ String
**[Required]** The ID of the listing that the specified package belongs to.
- #operating_system ⇒ OCI::Marketplace::Models::OperatingSystem
-
#package_type ⇒ String
**[Required]** The specified package's type.
-
#resource_id ⇒ String
The unique identifier for the package resource.
-
#time_created ⇒ DateTime
The date and time the publication package was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#version ⇒ String
**[Required]** The package version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PublicationPackage
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PublicationPackage
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.listing_id = attributes[:'listingId'] if attributes[:'listingId'] raise 'You cannot provide both :listingId and :listing_id' if attributes.key?(:'listingId') && attributes.key?(:'listing_id') self.listing_id = attributes[:'listing_id'] if attributes[:'listing_id'] self.version = attributes[:'version'] if attributes[:'version'] self.package_type = attributes[:'packageType'] if attributes[:'packageType'] raise 'You cannot provide both :packageType and :package_type' if attributes.key?(:'packageType') && attributes.key?(:'package_type') self.package_type = attributes[:'package_type'] if attributes[:'package_type'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self. = attributes[:'operatingSystem'] if attributes[:'operatingSystem'] raise 'You cannot provide both :operatingSystem and :operating_system' if attributes.key?(:'operatingSystem') && attributes.key?(:'operating_system') self. = attributes[:'operating_system'] if attributes[:'operating_system'] end |
Instance Attribute Details
#description ⇒ String
A description of the package.
20 21 22 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 20 def description @description end |
#listing_id ⇒ String
**[Required]** The ID of the listing that the specified package belongs to.
24 25 26 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 24 def listing_id @listing_id end |
#operating_system ⇒ OCI::Marketplace::Models::OperatingSystem
47 48 49 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 47 def @operating_system end |
#package_type ⇒ String
**[Required]** The specified package's type.
32 33 34 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 32 def package_type @package_type end |
#resource_id ⇒ String
The unique identifier for the package resource.
36 37 38 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 36 def resource_id @resource_id end |
#time_created ⇒ DateTime
The date and time the publication package was created, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Example: `2016-08-25T21:10:29.600Z`
44 45 46 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 44 def time_created @time_created end |
#version ⇒ String
**[Required]** The package version.
28 29 30 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 28 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'listing_id': :'listingId', 'version': :'version', 'package_type': :'packageType', 'resource_id': :'resourceId', 'time_created': :'timeCreated', 'operating_system': :'operatingSystem' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 84 def self.get_subtype(object_hash) type = object_hash[:'packageType'] # rubocop:disable Style/SymbolLiteral return 'OCI::Marketplace::Models::OrchestrationPublicationPackage' if type == 'ORCHESTRATION' return 'OCI::Marketplace::Models::ImagePublicationPackage' if type == 'IMAGE' # TODO: Log a warning when the subtype is not found. 'OCI::Marketplace::Models::PublicationPackage' end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'listing_id': :'String', 'version': :'String', 'package_type': :'String', 'resource_id': :'String', 'time_created': :'DateTime', 'operating_system': :'OCI::Marketplace::Models::OperatingSystem' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 169 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && listing_id == other.listing_id && version == other.version && package_type == other.package_type && resource_id == other.resource_id && time_created == other.time_created && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 205 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
185 186 187 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 185 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 194 def hash [description, listing_id, version, package_type, resource_id, time_created, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 238 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
232 233 234 |
# File 'lib/oci/marketplace/models/publication_package.rb', line 232 def to_s to_hash.to_s end |