Class: OCI::Monitoring::Models::Alarm
- Inherits:
-
Object
- Object
- OCI::Monitoring::Models::Alarm
- Defined in:
- lib/oci/monitoring/models/alarm.rb
Overview
The properties that define an alarm. For information about alarms, see [Alarms Overview](docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#AlarmsOverview).
To use any of the API operations, you must be authorized in an IAM policy. If you’re not authorized, talk to an administrator. If you’re an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm).
For information about endpoints and signing API requests, see [About the API](docs.cloud.oracle.com/iaas/Content/API/Concepts/usingapi.htm). For information about available SDKs and tools, see [SDKS and Other Tools](docs.cloud.oracle.com/iaas/Content/API/Concepts/sdks.htm).
Constant Summary collapse
- SEVERITY_ENUM =
[ SEVERITY_CRITICAL = 'CRITICAL'.freeze, SEVERITY_ERROR = 'ERROR'.freeze, SEVERITY_WARNING = 'WARNING'.freeze, SEVERITY_INFO = 'INFO'.freeze, SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- MESSAGE_FORMAT_ENUM =
[ MESSAGE_FORMAT_RAW = 'RAW'.freeze, MESSAGE_FORMAT_PRETTY_JSON = 'PRETTY_JSON'.freeze, MESSAGE_FORMAT_ONS_OPTIMIZED = 'ONS_OPTIMIZED'.freeze, MESSAGE_FORMAT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#body ⇒ String
The human-readable content of the notification delivered.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the alarm.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#destinations ⇒ Array<String>
[Required] A list of destinations to which the notifications for this alarm will be delivered.
-
#display_name ⇒ String
[Required] A user-friendly name for the alarm.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the alarm.
-
#is_enabled ⇒ BOOLEAN
[Required] Whether the alarm is enabled.
-
#lifecycle_state ⇒ String
[Required] The current lifecycle state of the alarm.
-
#message_format ⇒ String
The format to use for notification messages sent from this alarm.
-
#metric_compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the metric being evaluated by the alarm.
-
#metric_compartment_id_in_subtree ⇒ BOOLEAN
When true, the alarm evaluates metrics from all compartments and subcompartments.
-
#namespace ⇒ String
[Required] The source service or application emitting the metric that is evaluated by the alarm.
-
#pending_duration ⇒ String
The period of time that the condition defined in the alarm must persist before the alarm state changes from "OK" to "FIRING".
-
#query ⇒ String
[Required] The Monitoring Query Language (MQL) expression to evaluate for the alarm.
-
#repeat_notification_duration ⇒ String
The frequency at which notifications are re-submitted, if the alarm keeps firing without interruption.
-
#resolution ⇒ String
The time between calculated aggregation windows for the alarm.
-
#resource_group ⇒ String
Resource group to match for metric data retrieved by the alarm.
-
#severity ⇒ String
[Required] The perceived type of response required when the alarm is in the "FIRING" state.
-
#suppression ⇒ OCI::Monitoring::Models::Suppression
The configuration details for suppressing an alarm.
-
#time_created ⇒ DateTime
[Required] The date and time the alarm was created.
-
#time_updated ⇒ DateTime
[Required] The date and time the alarm was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Alarm
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Alarm
Initializes the object
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/oci/monitoring/models/alarm.rb', line 324 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.metric_compartment_id = attributes[:'metricCompartmentId'] if attributes[:'metricCompartmentId'] raise 'You cannot provide both :metricCompartmentId and :metric_compartment_id' if attributes.key?(:'metricCompartmentId') && attributes.key?(:'metric_compartment_id') self.metric_compartment_id = attributes[:'metric_compartment_id'] if attributes[:'metric_compartment_id'] self.metric_compartment_id_in_subtree = attributes[:'metricCompartmentIdInSubtree'] unless attributes[:'metricCompartmentIdInSubtree'].nil? raise 'You cannot provide both :metricCompartmentIdInSubtree and :metric_compartment_id_in_subtree' if attributes.key?(:'metricCompartmentIdInSubtree') && attributes.key?(:'metric_compartment_id_in_subtree') self.metric_compartment_id_in_subtree = attributes[:'metric_compartment_id_in_subtree'] unless attributes[:'metric_compartment_id_in_subtree'].nil? self.namespace = attributes[:'namespace'] if attributes[:'namespace'] self.resource_group = attributes[:'resourceGroup'] if attributes[:'resourceGroup'] raise 'You cannot provide both :resourceGroup and :resource_group' if attributes.key?(:'resourceGroup') && attributes.key?(:'resource_group') self.resource_group = attributes[:'resource_group'] if attributes[:'resource_group'] self.query = attributes[:'query'] if attributes[:'query'] self.resolution = attributes[:'resolution'] if attributes[:'resolution'] self.pending_duration = attributes[:'pendingDuration'] if attributes[:'pendingDuration'] raise 'You cannot provide both :pendingDuration and :pending_duration' if attributes.key?(:'pendingDuration') && attributes.key?(:'pending_duration') self.pending_duration = attributes[:'pending_duration'] if attributes[:'pending_duration'] self.severity = attributes[:'severity'] if attributes[:'severity'] self.body = attributes[:'body'] if attributes[:'body'] self. = attributes[:'messageFormat'] if attributes[:'messageFormat'] self. = "RAW" if .nil? && !attributes.key?(:'messageFormat') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :messageFormat and :message_format' if attributes.key?(:'messageFormat') && attributes.key?(:'message_format') self. = attributes[:'message_format'] if attributes[:'message_format'] self. = "RAW" if .nil? && !attributes.key?(:'messageFormat') && !attributes.key?(:'message_format') # rubocop:disable Style/StringLiterals self.destinations = attributes[:'destinations'] if attributes[:'destinations'] self.repeat_notification_duration = attributes[:'repeatNotificationDuration'] if attributes[:'repeatNotificationDuration'] raise 'You cannot provide both :repeatNotificationDuration and :repeat_notification_duration' if attributes.key?(:'repeatNotificationDuration') && attributes.key?(:'repeat_notification_duration') self.repeat_notification_duration = attributes[:'repeat_notification_duration'] if attributes[:'repeat_notification_duration'] self.suppression = attributes[:'suppression'] if attributes[:'suppression'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#body ⇒ String
The human-readable content of the notification delivered. Oracle recommends providing guidance to operators for resolving the alarm condition. Consider adding links to standard runbook practices.
Example: ‘High CPU usage alert. Follow runbook instructions for resolution.`
162 163 164 |
# File 'lib/oci/monitoring/models/alarm.rb', line 162 def body @body end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the alarm.
60 61 62 |
# File 'lib/oci/monitoring/models/alarm.rb', line 60 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: ‘{"CostCenter": "42"}`
213 214 215 |
# File 'lib/oci/monitoring/models/alarm.rb', line 213 def end |
#destinations ⇒ Array<String>
[Required] A list of destinations to which the notifications for this alarm will be delivered. Each destination is represented by an [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) related to the supported destination service. For example, a destination using the Notifications service is represented by a topic OCID. Supported destination services: Notifications Service. Limit: One destination per supported destination service.
178 179 180 |
# File 'lib/oci/monitoring/models/alarm.rb', line 178 def destinations @destinations end |
#display_name ⇒ String
[Required] A user-friendly name for the alarm. It does not have to be unique, and it’s changeable.
This name is sent as the title for notifications related to this alarm.
Example: ‘High CPU Utilization`
55 56 57 |
# File 'lib/oci/monitoring/models/alarm.rb', line 55 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"Finance"`
207 208 209 |
# File 'lib/oci/monitoring/models/alarm.rb', line 207 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the alarm.
46 47 48 |
# File 'lib/oci/monitoring/models/alarm.rb', line 46 def id @id end |
#is_enabled ⇒ BOOLEAN
[Required] Whether the alarm is enabled.
Example: true
201 202 203 |
# File 'lib/oci/monitoring/models/alarm.rb', line 201 def is_enabled @is_enabled end |
#lifecycle_state ⇒ String
[Required] The current lifecycle state of the alarm.
Example: DELETED
220 221 222 |
# File 'lib/oci/monitoring/models/alarm.rb', line 220 def lifecycle_state @lifecycle_state end |
#message_format ⇒ String
The format to use for notification messages sent from this alarm. The formats are:
-
RAW- Raw JSON blob. Default value. -
PRETTY_JSON: JSON with new lines and indents. -
ONS_OPTIMIZED: Simplified, user-friendly layout. Applies only to messages sent through the Notifications service to the following subscription types: Email.
170 171 172 |
# File 'lib/oci/monitoring/models/alarm.rb', line 170 def end |
#metric_compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the metric being evaluated by the alarm.
66 67 68 |
# File 'lib/oci/monitoring/models/alarm.rb', line 66 def metric_compartment_id @metric_compartment_id end |
#metric_compartment_id_in_subtree ⇒ BOOLEAN
When true, the alarm evaluates metrics from all compartments and subcompartments. The parameter can only be set to true when metricCompartmentId is the tenancy OCID (the tenancy is the root compartment). A true value requires the user to have tenancy-level permissions. If this requirement is not met, then the call is rejected. When false, the alarm evaluates metrics from only the compartment specified in metricCompartmentId. Default is false.
Example: true
77 78 79 |
# File 'lib/oci/monitoring/models/alarm.rb', line 77 def metric_compartment_id_in_subtree @metric_compartment_id_in_subtree end |
#namespace ⇒ String
[Required] The source service or application emitting the metric that is evaluated by the alarm.
Example: oci_computeagent
84 85 86 |
# File 'lib/oci/monitoring/models/alarm.rb', line 84 def namespace @namespace end |
#pending_duration ⇒ String
The period of time that the condition defined in the alarm must persist before the alarm state changes from "OK" to "FIRING". For example, a value of 5 minutes means that the alarm must persist in breaching the condition for five minutes before the alarm updates its state to "FIRING".
The duration is specified as a string in ISO 8601 format (PT10M for ten minutes or PT1H for one hour). Minimum: PT1M. Maximum: PT1H. Default: PT1M.
Under the default value of PT1M, the first evaluation that breaches the alarm updates the state to "FIRING".
The alarm updates its status to "OK" when the breaching condition has been clear for the most recent minute.
Example: PT5M
146 147 148 |
# File 'lib/oci/monitoring/models/alarm.rb', line 146 def pending_duration @pending_duration end |
#query ⇒ String
[Required] The Monitoring Query Language (MQL) expression to evaluate for the alarm. The Alarms feature of the Monitoring service interprets results for each returned time series as Boolean values, where zero represents false and a non-zero value represents true. A true value means that the trigger rule condition has been met. The query must specify a metric, statistic, interval, and trigger rule (threshold or absence). Supported values for interval depend on the specified time range. More interval values are supported for smaller time ranges. You can optionally specify dimensions and grouping functions. Supported grouping functions: ‘grouping()`, `groupBy()`. For details about Monitoring Query Language (MQL), see [Monitoring Query Language (MQL) Reference](docs.cloud.oracle.com/iaas/Content/Monitoring/Reference/mql.htm). For available dimensions, review the metric definition for the supported service. See [Supported Services](docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#SupportedServices).
Example of threshold alarm:
-----
CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.groupBy(availabilityDomain).percentile(0.9) > 85
-----
Example of absence alarm:
-----
CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.absent()
-----
122 123 124 |
# File 'lib/oci/monitoring/models/alarm.rb', line 122 def query @query end |
#repeat_notification_duration ⇒ String
The frequency at which notifications are re-submitted, if the alarm keeps firing without interruption. Format defined by ISO 8601. For example, PT4H indicates four hours. Minimum: PT1M. Maximum: P30D.
Default value: null (notifications are not re-submitted).
Example: PT2H
189 190 191 |
# File 'lib/oci/monitoring/models/alarm.rb', line 189 def repeat_notification_duration @repeat_notification_duration end |
#resolution ⇒ String
The time between calculated aggregation windows for the alarm. Supported value: 1m
127 128 129 |
# File 'lib/oci/monitoring/models/alarm.rb', line 127 def resolution @resolution end |
#resource_group ⇒ String
Resource group to match for metric data retrieved by the alarm. A resource group is a custom string that you can match when retrieving custom metrics. Only one resource group can be applied per metric. A valid resourceGroup value starts with an alphabetical character and includes only alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).
Example: frontend-fleet
92 93 94 |
# File 'lib/oci/monitoring/models/alarm.rb', line 92 def resource_group @resource_group end |
#severity ⇒ String
[Required] The perceived type of response required when the alarm is in the "FIRING" state.
Example: CRITICAL
153 154 155 |
# File 'lib/oci/monitoring/models/alarm.rb', line 153 def severity @severity end |
#suppression ⇒ OCI::Monitoring::Models::Suppression
The configuration details for suppressing an alarm.
194 195 196 |
# File 'lib/oci/monitoring/models/alarm.rb', line 194 def suppression @suppression end |
#time_created ⇒ DateTime
[Required] The date and time the alarm was created. Format defined by RFC3339.
Example: 2019-02-01T01:02:29.600Z
227 228 229 |
# File 'lib/oci/monitoring/models/alarm.rb', line 227 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time the alarm was last updated. Format defined by RFC3339.
Example: 2019-02-03T01:02:29.600Z
234 235 236 |
# File 'lib/oci/monitoring/models/alarm.rb', line 234 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/monitoring/models/alarm.rb', line 237 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'metric_compartment_id': :'metricCompartmentId', 'metric_compartment_id_in_subtree': :'metricCompartmentIdInSubtree', 'namespace': :'namespace', 'resource_group': :'resourceGroup', 'query': :'query', 'resolution': :'resolution', 'pending_duration': :'pendingDuration', 'severity': :'severity', 'body': :'body', 'message_format': :'messageFormat', 'destinations': :'destinations', 'repeat_notification_duration': :'repeatNotificationDuration', 'suppression': :'suppression', 'is_enabled': :'isEnabled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/oci/monitoring/models/alarm.rb', line 267 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'compartment_id': :'String', 'metric_compartment_id': :'String', 'metric_compartment_id_in_subtree': :'BOOLEAN', 'namespace': :'String', 'resource_group': :'String', 'query': :'String', 'resolution': :'String', 'pending_duration': :'String', 'severity': :'String', 'body': :'String', 'message_format': :'String', 'destinations': :'Array<String>', 'repeat_notification_duration': :'String', 'suppression': :'OCI::Monitoring::Models::Suppression', 'is_enabled': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 |
# File 'lib/oci/monitoring/models/alarm.rb', line 479 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && compartment_id == other.compartment_id && metric_compartment_id == other.metric_compartment_id && metric_compartment_id_in_subtree == other.metric_compartment_id_in_subtree && namespace == other.namespace && resource_group == other.resource_group && query == other.query && resolution == other.resolution && pending_duration == other.pending_duration && severity == other.severity && body == other.body && == other. && destinations == other.destinations && repeat_notification_duration == other.repeat_notification_duration && suppression == other.suppression && is_enabled == other.is_enabled && == other. && == other. && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 |
# File 'lib/oci/monitoring/models/alarm.rb', line 530 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
510 511 512 |
# File 'lib/oci/monitoring/models/alarm.rb', line 510 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
519 520 521 |
# File 'lib/oci/monitoring/models/alarm.rb', line 519 def hash [id, display_name, compartment_id, metric_compartment_id, metric_compartment_id_in_subtree, namespace, resource_group, query, resolution, pending_duration, severity, body, , destinations, repeat_notification_duration, suppression, is_enabled, , , lifecycle_state, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
563 564 565 566 567 568 569 570 571 572 |
# File 'lib/oci/monitoring/models/alarm.rb', line 563 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
557 558 559 |
# File 'lib/oci/monitoring/models/alarm.rb', line 557 def to_s to_hash.to_s end |