Method: OCI::Monitoring::Models::Alarm#destinations
- Defined in:
- lib/oci/monitoring/models/alarm.rb
#destinations ⇒ Array<String>
[Required] A list of destinations to which the notifications for this alarm will be delivered. Each destination is represented by an [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) related to the supported destination service. For example, a destination using the Notifications service is represented by a topic OCID. Supported destination services: Notifications Service. Limit: One destination per supported destination service.
178 179 180 |
# File 'lib/oci/monitoring/models/alarm.rb', line 178 def destinations @destinations end |