Class: OCI::Monitoring::Models::Suppression
- Inherits:
-
Object
- Object
- OCI::Monitoring::Models::Suppression
- Defined in:
- lib/oci/monitoring/models/suppression.rb
Overview
The configuration details for suppressing an alarm. For information about alarms, see [Alarms Overview](docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#AlarmsOverview).
Instance Attribute Summary collapse
-
#description ⇒ String
Human-readable reason for suppressing alarm notifications.
-
#time_suppress_from ⇒ DateTime
[Required] The start date and time for the suppression to take place, inclusive.
-
#time_suppress_until ⇒ DateTime
[Required] The end date and time for the suppression to take place, inclusive.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Suppression
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Suppression
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/monitoring/models/suppression.rb', line 70 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.description = attributes[:'description'] if attributes[:'description'] self.time_suppress_from = attributes[:'timeSuppressFrom'] if attributes[:'timeSuppressFrom'] raise 'You cannot provide both :timeSuppressFrom and :time_suppress_from' if attributes.key?(:'timeSuppressFrom') && attributes.key?(:'time_suppress_from') self.time_suppress_from = attributes[:'time_suppress_from'] if attributes[:'time_suppress_from'] self.time_suppress_until = attributes[:'timeSuppressUntil'] if attributes[:'timeSuppressUntil'] raise 'You cannot provide both :timeSuppressUntil and :time_suppress_until' if attributes.key?(:'timeSuppressUntil') && attributes.key?(:'time_suppress_until') self.time_suppress_until = attributes[:'time_suppress_until'] if attributes[:'time_suppress_until'] end |
Instance Attribute Details
#description ⇒ String
Human-readable reason for suppressing alarm notifications. It does not have to be unique, and it’s changeable. Avoid entering confidential information.
Oracle recommends including tracking information for the event or associated work, such as a ticket number.
Example: ‘Planned outage due to change IT-1234.`
23 24 25 |
# File 'lib/oci/monitoring/models/suppression.rb', line 23 def description @description end |
#time_suppress_from ⇒ DateTime
[Required] The start date and time for the suppression to take place, inclusive. Format defined by RFC3339.
Example: 2019-02-01T01:02:29.600Z
30 31 32 |
# File 'lib/oci/monitoring/models/suppression.rb', line 30 def time_suppress_from @time_suppress_from end |
#time_suppress_until ⇒ DateTime
[Required] The end date and time for the suppression to take place, inclusive. Format defined by RFC3339.
Example: 2019-02-01T02:02:29.600Z
37 38 39 |
# File 'lib/oci/monitoring/models/suppression.rb', line 37 def time_suppress_until @time_suppress_until end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 |
# File 'lib/oci/monitoring/models/suppression.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'description': :'description', 'time_suppress_from': :'timeSuppressFrom', 'time_suppress_until': :'timeSuppressUntil' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 |
# File 'lib/oci/monitoring/models/suppression.rb', line 51 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'description': :'String', 'time_suppress_from': :'DateTime', 'time_suppress_until': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 |
# File 'lib/oci/monitoring/models/suppression.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && description == other.description && time_suppress_from == other.time_suppress_from && time_suppress_until == other.time_suppress_until end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/monitoring/models/suppression.rb', line 130 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
110 111 112 |
# File 'lib/oci/monitoring/models/suppression.rb', line 110 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
119 120 121 |
# File 'lib/oci/monitoring/models/suppression.rb', line 119 def hash [description, time_suppress_from, time_suppress_until].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/monitoring/models/suppression.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
157 158 159 |
# File 'lib/oci/monitoring/models/suppression.rb', line 157 def to_s to_hash.to_s end |