Class: OCI::Mysql::Models::AnalyticsClusterSummary
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::AnalyticsClusterSummary
- Defined in:
- lib/oci/mysql/models/analytics_cluster_summary.rb
Overview
DEPRECATED – please use HeatWave API instead. A summary of an Analytics Cluster.
Instance Attribute Summary collapse
-
#cluster_size ⇒ Integer
**[Required]** The number of analytics-processing compute instances, of the specified shape, in the Analytics Cluster.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the MySQL Analytics Cluster.
-
#shape_name ⇒ String
**[Required]** The shape determines resources to allocate to the Analytics Cluster nodes - CPU cores, memory.
-
#time_created ⇒ DateTime
**[Required]** The date and time the Analytics Cluster was created, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
-
#time_updated ⇒ DateTime
**[Required]** The time the Analytics Cluster was last updated, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnalyticsClusterSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AnalyticsClusterSummary
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 73 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName'] raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name') self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name'] self.cluster_size = attributes[:'clusterSize'] if attributes[:'clusterSize'] raise 'You cannot provide both :clusterSize and :cluster_size' if attributes.key?(:'clusterSize') && attributes.key?(:'cluster_size') self.cluster_size = attributes[:'cluster_size'] if attributes[:'cluster_size'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#cluster_size ⇒ Integer
**[Required]** The number of analytics-processing compute instances, of the specified shape, in the Analytics Cluster.
22 23 24 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 22 def cluster_size @cluster_size end |
#lifecycle_state ⇒ String
**[Required]** The current state of the MySQL Analytics Cluster.
26 27 28 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 26 def lifecycle_state @lifecycle_state end |
#shape_name ⇒ String
**[Required]** The shape determines resources to allocate to the Analytics Cluster nodes - CPU cores, memory.
16 17 18 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 16 def shape_name @shape_name end |
#time_created ⇒ DateTime
**[Required]** The date and time the Analytics Cluster was created, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
30 31 32 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 30 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The time the Analytics Cluster was last updated, as described by [RFC 3339](tools.ietf.org/rfc/rfc3339).
34 35 36 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 34 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 37 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'shape_name': :'shapeName', 'cluster_size': :'clusterSize', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 50 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'shape_name': :'String', 'cluster_size': :'Integer', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 123 124 125 126 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 117 def ==(other) return true if equal?(other) self.class == other.class && shape_name == other.shape_name && cluster_size == other.cluster_size && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 151 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
131 132 133 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 131 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
140 141 142 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 140 def hash [shape_name, cluster_size, lifecycle_state, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 184 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
178 179 180 |
# File 'lib/oci/mysql/models/analytics_cluster_summary.rb', line 178 def to_s to_hash.to_s end |