Class: OCI::Mysql::Models::BackupSummary
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::BackupSummary
- Defined in:
- lib/oci/mysql/models/backup_summary.rb
Overview
Details of Backups such as OCID, description, backupType, and so on.
To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Instance Attribute Summary collapse
-
#backup_size_in_gbs ⇒ Integer
The size of the backup in GiBs.
-
#backup_type ⇒ String
**[Required]** The type of backup.
-
#creation_type ⇒ String
**[Required]** If the backup was created automatically, or by a manual request.
-
#data_storage_size_in_gbs ⇒ Integer
Size of the data volume in GiBs.
-
#db_system_id ⇒ String
**[Required]** The OCID of the DB System the Backup is associated with.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
A user-supplied description of the backup.
-
#display_name ⇒ String
A user-supplied display name for the backup.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** OCID of the backup.
-
#lifecycle_state ⇒ String
**[Required]** The state of the backup.
-
#mysql_version ⇒ String
The version of the DB System used for backup.
-
#retention_in_days ⇒ Integer
Number of days to retain this backup.
-
#shape_name ⇒ String
The shape of the DB System instance used for backup.
-
#time_created ⇒ DateTime
**[Required]** The time the backup was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BackupSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BackupSummary
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 148 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.backup_type = attributes[:'backupType'] if attributes[:'backupType'] raise 'You cannot provide both :backupType and :backup_type' if attributes.key?(:'backupType') && attributes.key?(:'backup_type') self.backup_type = attributes[:'backup_type'] if attributes[:'backup_type'] self.creation_type = attributes[:'creationType'] if attributes[:'creationType'] raise 'You cannot provide both :creationType and :creation_type' if attributes.key?(:'creationType') && attributes.key?(:'creation_type') self.creation_type = attributes[:'creation_type'] if attributes[:'creation_type'] self.db_system_id = attributes[:'dbSystemId'] if attributes[:'dbSystemId'] raise 'You cannot provide both :dbSystemId and :db_system_id' if attributes.key?(:'dbSystemId') && attributes.key?(:'db_system_id') self.db_system_id = attributes[:'db_system_id'] if attributes[:'db_system_id'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.backup_size_in_gbs = attributes[:'backupSizeInGBs'] if attributes[:'backupSizeInGBs'] raise 'You cannot provide both :backupSizeInGBs and :backup_size_in_gbs' if attributes.key?(:'backupSizeInGBs') && attributes.key?(:'backup_size_in_gbs') self.backup_size_in_gbs = attributes[:'backup_size_in_gbs'] if attributes[:'backup_size_in_gbs'] self.retention_in_days = attributes[:'retentionInDays'] if attributes[:'retentionInDays'] raise 'You cannot provide both :retentionInDays and :retention_in_days' if attributes.key?(:'retentionInDays') && attributes.key?(:'retention_in_days') self.retention_in_days = attributes[:'retention_in_days'] if attributes[:'retention_in_days'] self.mysql_version = attributes[:'mysqlVersion'] if attributes[:'mysqlVersion'] raise 'You cannot provide both :mysqlVersion and :mysql_version' if attributes.key?(:'mysqlVersion') && attributes.key?(:'mysql_version') self.mysql_version = attributes[:'mysql_version'] if attributes[:'mysql_version'] self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName'] raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name') self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#backup_size_in_gbs ⇒ Integer
The size of the backup in GiBs.
55 56 57 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 55 def backup_size_in_gbs @backup_size_in_gbs end |
#backup_type ⇒ String
**[Required]** The type of backup.
39 40 41 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 39 def backup_type @backup_type end |
#creation_type ⇒ String
**[Required]** If the backup was created automatically, or by a manual request.
43 44 45 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 43 def creation_type @creation_type end |
#data_storage_size_in_gbs ⇒ Integer
Size of the data volume in GiBs.
51 52 53 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 51 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#db_system_id ⇒ String
**[Required]** The OCID of the DB System the Backup is associated with.
47 48 49 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 47 def db_system_id @db_system_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
79 80 81 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 79 def @defined_tags end |
#description ⇒ String
A user-supplied description of the backup.
27 28 29 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 27 def description @description end |
#display_name ⇒ String
A user-supplied display name for the backup.
23 24 25 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 23 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
73 74 75 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 73 def @freeform_tags end |
#id ⇒ String
**[Required]** OCID of the backup.
19 20 21 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 19 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The state of the backup.
35 36 37 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 35 def lifecycle_state @lifecycle_state end |
#mysql_version ⇒ String
The version of the DB System used for backup.
63 64 65 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 63 def mysql_version @mysql_version end |
#retention_in_days ⇒ Integer
Number of days to retain this backup.
59 60 61 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 59 def retention_in_days @retention_in_days end |
#shape_name ⇒ String
The shape of the DB System instance used for backup.
67 68 69 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 67 def shape_name @shape_name end |
#time_created ⇒ DateTime
**[Required]** The time the backup was created.
31 32 33 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 31 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 82 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'backup_type': :'backupType', 'creation_type': :'creationType', 'db_system_id': :'dbSystemId', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'backup_size_in_gbs': :'backupSizeInGBs', 'retention_in_days': :'retentionInDays', 'mysql_version': :'mysqlVersion', 'shape_name': :'shapeName', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 105 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'backup_type': :'String', 'creation_type': :'String', 'db_system_id': :'String', 'data_storage_size_in_gbs': :'Integer', 'backup_size_in_gbs': :'Integer', 'retention_in_days': :'Integer', 'mysql_version': :'String', 'shape_name': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 244 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && time_created == other.time_created && lifecycle_state == other.lifecycle_state && backup_type == other.backup_type && creation_type == other.creation_type && db_system_id == other.db_system_id && data_storage_size_in_gbs == other.data_storage_size_in_gbs && backup_size_in_gbs == other.backup_size_in_gbs && retention_in_days == other.retention_in_days && mysql_version == other.mysql_version && shape_name == other.shape_name && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 288 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
268 269 270 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 268 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
277 278 279 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 277 def hash [id, display_name, description, time_created, lifecycle_state, backup_type, creation_type, db_system_id, data_storage_size_in_gbs, backup_size_in_gbs, retention_in_days, mysql_version, shape_name, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
321 322 323 324 325 326 327 328 329 330 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 321 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
315 316 317 |
# File 'lib/oci/mysql/models/backup_summary.rb', line 315 def to_s to_hash.to_s end |