Class: OCI::Mysql::Models::CreateChannelDetails
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::CreateChannelDetails
- Defined in:
- lib/oci/mysql/models/create_channel_details.rb
Overview
Details required to create a Channel.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
User provided information about the Channel.
-
#display_name ⇒ String
The user-friendly name for the Channel.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair applied without any predefined name, type or scope.
-
#is_enabled ⇒ BOOLEAN
Whether the Channel should be enabled upon creation.
-
#source ⇒ OCI::Mysql::Models::CreateChannelSourceDetails
This attribute is required.
-
#target ⇒ OCI::Mysql::Models::CreateChannelTargetDetails
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateChannelDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateChannelDetails
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.is_enabled = attributes[:'isEnabled'] unless attributes[:'isEnabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isEnabled and :is_enabled' if attributes.key?(:'isEnabled') && attributes.key?(:'is_enabled') self.is_enabled = attributes[:'is_enabled'] unless attributes[:'is_enabled'].nil? self.is_enabled = true if is_enabled.nil? && !attributes.key?(:'isEnabled') && !attributes.key?(:'is_enabled') # rubocop:disable Style/StringLiterals self.source = attributes[:'source'] if attributes[:'source'] self.target = attributes[:'target'] if attributes[:'target'] self.description = attributes[:'description'] if attributes[:'description'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the compartment.
12 13 14 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 12 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: ‘{"bar-key": "value"}`
46 47 48 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 46 def @defined_tags end |
#description ⇒ String
User provided information about the Channel.
34 35 36 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 34 def description @description end |
#display_name ⇒ String
The user-friendly name for the Channel. It does not have to be unique.
16 17 18 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 16 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
40 41 42 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 40 def @freeform_tags end |
#is_enabled ⇒ BOOLEAN
Whether the Channel should be enabled upon creation. If set to true, the Channel will be asynchronously started as a result of the create Channel operation.
22 23 24 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 22 def is_enabled @is_enabled end |
#source ⇒ OCI::Mysql::Models::CreateChannelSourceDetails
This attribute is required.
26 27 28 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 26 def source @source end |
#target ⇒ OCI::Mysql::Models::CreateChannelTargetDetails
This attribute is required.
30 31 32 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 30 def target @target end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'is_enabled': :'isEnabled', 'source': :'source', 'target': :'target', 'description': :'description', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 65 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'is_enabled': :'BOOLEAN', 'source': :'OCI::Mysql::Models::CreateChannelSourceDetails', 'target': :'OCI::Mysql::Models::CreateChannelTargetDetails', 'description': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 146 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && is_enabled == other.is_enabled && source == other.source && target == other.target && description == other.description && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 172 def hash [compartment_id, display_name, is_enabled, source, target, description, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/mysql/models/create_channel_details.rb', line 210 def to_s to_hash.to_s end |