Class: OCI::Mysql::Models::CreateDbSystemDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/mysql/models/create_db_system_details.rb

Overview

Details required to create a DB System.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDbSystemDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 233

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.is_highly_available = attributes[:'isHighlyAvailable'] unless attributes[:'isHighlyAvailable'].nil?
  self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHighlyAvailable and :is_highly_available' if attributes.key?(:'isHighlyAvailable') && attributes.key?(:'is_highly_available')

  self.is_highly_available = attributes[:'is_highly_available'] unless attributes[:'is_highly_available'].nil?
  self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') && !attributes.key?(:'is_highly_available') # rubocop:disable Style/StringLiterals

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain']

  raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain')

  self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain']

  self.configuration_id = attributes[:'configurationId'] if attributes[:'configurationId']

  raise 'You cannot provide both :configurationId and :configuration_id' if attributes.key?(:'configurationId') && attributes.key?(:'configuration_id')

  self.configuration_id = attributes[:'configuration_id'] if attributes[:'configuration_id']

  self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName']

  raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name')

  self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name']

  self.mysql_version = attributes[:'mysqlVersion'] if attributes[:'mysqlVersion']

  raise 'You cannot provide both :mysqlVersion and :mysql_version' if attributes.key?(:'mysqlVersion') && attributes.key?(:'mysql_version')

  self.mysql_version = attributes[:'mysql_version'] if attributes[:'mysql_version']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.admin_username = attributes[:'adminUsername'] if attributes[:'adminUsername']

  raise 'You cannot provide both :adminUsername and :admin_username' if attributes.key?(:'adminUsername') && attributes.key?(:'admin_username')

  self.admin_username = attributes[:'admin_username'] if attributes[:'admin_username']

  self.admin_password = attributes[:'adminPassword'] if attributes[:'adminPassword']

  raise 'You cannot provide both :adminPassword and :admin_password' if attributes.key?(:'adminPassword') && attributes.key?(:'admin_password')

  self.admin_password = attributes[:'admin_password'] if attributes[:'admin_password']

  self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs']

  raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs')

  self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs']

  self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel']

  raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label')

  self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label']

  self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress']

  raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address')

  self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address']

  self.port = attributes[:'port'] if attributes[:'port']

  self.port_x = attributes[:'portX'] if attributes[:'portX']

  raise 'You cannot provide both :portX and :port_x' if attributes.key?(:'portX') && attributes.key?(:'port_x')

  self.port_x = attributes[:'port_x'] if attributes[:'port_x']

  self.backup_policy = attributes[:'backupPolicy'] if attributes[:'backupPolicy']

  raise 'You cannot provide both :backupPolicy and :backup_policy' if attributes.key?(:'backupPolicy') && attributes.key?(:'backup_policy')

  self.backup_policy = attributes[:'backup_policy'] if attributes[:'backup_policy']

  self.source = attributes[:'source'] if attributes[:'source']

  self.maintenance = attributes[:'maintenance'] if attributes[:'maintenance']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#admin_passwordString

[Required] The password for the administrative user. The password must be between 8 and 32 characters long, and must contain at least 1 numeric character, 1 lowercase character, 1 uppercase character, and 1 special (nonalphanumeric) character.

Returns:

  • (String)


87
88
89
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 87

def admin_password
  @admin_password
end

#admin_usernameString

[Required] The username for the administrative user.

Returns:

  • (String)


79
80
81
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 79

def admin_username
  @admin_username
end

#availability_domainString

The availability domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

In a failover scenario, the Read/Write endpoint is redirected to one of the other availability domains and the MySQL instance in that domain is promoted to the primary instance. This redirection does not affect the IP address of the DB System in any way.

For a standalone DB System, this defines the availability domain in which the DB System is placed.

Returns:

  • (String)


43
44
45
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 43

def availability_domain
  @availability_domain
end

#backup_policyOCI::Mysql::Models::CreateBackupPolicyDetails



125
126
127
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 125

def backup_policy
  @backup_policy
end

#compartment_idString

[Required] The OCID of the compartment.

Returns:

  • (String)


21
22
23
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 21

def compartment_id
  @compartment_id
end

#configuration_idString

The OCID of the Configuration to be used for this DB System.

Returns:

  • (String)


58
59
60
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 58

def configuration_id
  @configuration_id
end

#data_storage_size_in_gbsInteger

Initial size of the data volume in GBs that will be created and attached. Keep in mind that this only specifies the size of the database data volume, the log volume for the database will be scaled appropriately with its shape.

Returns:

  • (Integer)


94
95
96
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 94

def data_storage_size_in_gbs
  @data_storage_size_in_gbs
end

#defined_tagsHash<String, Hash<String, Object>>

Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


143
144
145
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 143

def defined_tags
  @defined_tags
end

#descriptionString

User-provided data about the DB System.

Returns:

  • (String)


17
18
19
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 17

def description
  @description
end

#display_nameString

The user-friendly name for the DB System. It does not have to be unique.

Returns:

  • (String)


13
14
15
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 13

def display_name
  @display_name
end

#fault_domainString

The fault domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

In a failover scenario, the Read/Write endpoint is redirected to one of the other fault domains and the MySQL instance in that domain is promoted to the primary instance. This redirection does not affect the IP address of the DB System in any way.

For a standalone DB System, this defines the fault domain in which the DB System is placed.

Returns:

  • (String)


54
55
56
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 54

def fault_domain
  @fault_domain
end

#freeform_tagsHash<String, String>

Simple key-value pair applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


137
138
139
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 137

def freeform_tags
  @freeform_tags
end

#hostname_labelString

The hostname for the primary endpoint of the DB System. Used for DNS.

The value is the hostname portion of the primary private IP’s fully qualified domain name (FQDN) (for example, "dbsystem-1" in FQDN "dbsystem-1.subnet123.vcn1.oraclevcn.com").

Must be unique across all VNICs in the subnet and comply with RFC 952 and RFC 1123.

Returns:

  • (String)


104
105
106
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 104

def hostname_label
  @hostname_label
end

#ip_addressString

The IP address the DB System is configured to listen on. A private IP address of your choice to assign to the primary endpoint of the DB System. Must be an available IP address within the subnet’s CIDR. If you don’t specify a value, Oracle automatically assigns a private IP address from the subnet. This should be a "dotted-quad" style IPv4 address.

Returns:

  • (String)


113
114
115
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 113

def ip_address
  @ip_address
end

#is_highly_availableBOOLEAN

Specifies if the DB System is highly available.

When creating a DB System with High Availability, three instances are created and placed according to your region- and subnet-type. The secondaries are placed automatically in the other two availability or fault domains. You can choose the preferred location of your primary instance, only.

Returns:

  • (BOOLEAN)


32
33
34
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 32

def is_highly_available
  @is_highly_available
end

#maintenanceOCI::Mysql::Models::CreateMaintenanceDetails



131
132
133
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 131

def maintenance
  @maintenance
end

#mysql_versionString

The specific MySQL version identifier.

Returns:

  • (String)


70
71
72
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 70

def mysql_version
  @mysql_version
end

#portInteger

The port for primary endpoint of the DB System to listen on.

Returns:

  • (Integer)


117
118
119
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 117

def port
  @port
end

#port_xInteger

The TCP network port on which X Plugin listens for connections. This is the X Plugin equivalent of port.

Returns:

  • (Integer)


122
123
124
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 122

def port_x
  @port_x
end

#shape_nameString

[Required] The name of the shape. The shape determines the resources allocated

  • CPU cores and memory for VM shapes; CPU cores, memory and storage

for non-VM (or bare metal) shapes. To get a list of shapes, use the list_shapes operation.

Returns:

  • (String)


66
67
68
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 66

def shape_name
  @shape_name
end

#sourceOCI::Mysql::Models::CreateDbSystemSourceDetails



128
129
130
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 128

def source
  @source
end

#subnet_idString

[Required] The OCID of the subnet the DB System is associated with.

Returns:

  • (String)


75
76
77
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 75

def subnet_id
  @subnet_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 146

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'is_highly_available': :'isHighlyAvailable',
    'availability_domain': :'availabilityDomain',
    'fault_domain': :'faultDomain',
    'configuration_id': :'configurationId',
    'shape_name': :'shapeName',
    'mysql_version': :'mysqlVersion',
    'subnet_id': :'subnetId',
    'admin_username': :'adminUsername',
    'admin_password': :'adminPassword',
    'data_storage_size_in_gbs': :'dataStorageSizeInGBs',
    'hostname_label': :'hostnameLabel',
    'ip_address': :'ipAddress',
    'port': :'port',
    'port_x': :'portX',
    'backup_policy': :'backupPolicy',
    'source': :'source',
    'maintenance': :'maintenance',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 176

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'is_highly_available': :'BOOLEAN',
    'availability_domain': :'String',
    'fault_domain': :'String',
    'configuration_id': :'String',
    'shape_name': :'String',
    'mysql_version': :'String',
    'subnet_id': :'String',
    'admin_username': :'String',
    'admin_password': :'String',
    'data_storage_size_in_gbs': :'Integer',
    'hostname_label': :'String',
    'ip_address': :'String',
    'port': :'Integer',
    'port_x': :'Integer',
    'backup_policy': :'OCI::Mysql::Models::CreateBackupPolicyDetails',
    'source': :'OCI::Mysql::Models::CreateDbSystemSourceDetails',
    'maintenance': :'OCI::Mysql::Models::CreateMaintenanceDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 365

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    is_highly_available == other.is_highly_available &&
    availability_domain == other.availability_domain &&
    fault_domain == other.fault_domain &&
    configuration_id == other.configuration_id &&
    shape_name == other.shape_name &&
    mysql_version == other.mysql_version &&
    subnet_id == other.subnet_id &&
    admin_username == other.admin_username &&
    admin_password == other.admin_password &&
    data_storage_size_in_gbs == other.data_storage_size_in_gbs &&
    hostname_label == other.hostname_label &&
    ip_address == other.ip_address &&
    port == other.port &&
    port_x == other.port_x &&
    backup_policy == other.backup_policy &&
    source == other.source &&
    maintenance == other.maintenance &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 416

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


396
397
398
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 396

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



405
406
407
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 405

def hash
  [display_name, description, compartment_id, is_highly_available, availability_domain, fault_domain, configuration_id, shape_name, mysql_version, subnet_id, admin_username, admin_password, data_storage_size_in_gbs, hostname_label, ip_address, port, port_x, backup_policy, source, maintenance, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



449
450
451
452
453
454
455
456
457
458
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 449

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



443
444
445
# File 'lib/oci/mysql/models/create_db_system_details.rb', line 443

def to_s
  to_hash.to_s
end