Class: OCI::Mysql::Models::DbSystem
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::DbSystem
- Defined in:
- lib/oci/mysql/models/db_system.rb
Overview
A DB System is the core logical unit of MySQL Database Service.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #analytics_cluster ⇒ OCI::Mysql::Models::AnalyticsClusterSummary
-
#availability_domain ⇒ String
The availability domain on which to deploy the Read/Write endpoint.
- #backup_policy ⇒ OCI::Mysql::Models::BackupPolicy
-
#channels ⇒ Array<OCI::Mysql::Models::ChannelSummary>
A list with a summary of all the Channels attached to the DB System.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment the DB System belongs in.
-
#configuration_id ⇒ String
The OCID of the Configuration to be used for Instances in this DB System.
- #current_placement ⇒ OCI::Mysql::Models::DbSystemPlacement
-
#data_storage_size_in_gbs ⇒ Integer
[Required] Initial size of the data volume in GiBs that will be created and attached.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
User-provided data about the DB System.
-
#display_name ⇒ String
[Required] The user-friendly name for the DB System.
-
#endpoints ⇒ Array<OCI::Mysql::Models::DbSystemEndpoint>
The network endpoints available for this DB System.
-
#fault_domain ⇒ String
The fault domain on which to deploy the Read/Write endpoint.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #heat_wave_cluster ⇒ OCI::Mysql::Models::HeatWaveClusterSummary
-
#hostname_label ⇒ String
The hostname for the primary endpoint of the DB System.
-
#id ⇒ String
[Required] The OCID of the DB System.
-
#ip_address ⇒ String
The IP address the DB System is configured to listen on.
-
#is_analytics_cluster_attached ⇒ BOOLEAN
DEPRECATED – please use
isHeatWaveClusterAttachedinstead. -
#is_heat_wave_cluster_attached ⇒ BOOLEAN
If the DB System has a HeatWave Cluster attached.
-
#is_highly_available ⇒ BOOLEAN
If the policy is to enable high availability of the instance, by maintaining secondary/failover capacity as necessary.
-
#lifecycle_details ⇒ String
Additional information about the current lifecycleState.
-
#lifecycle_state ⇒ String
[Required] The current state of the DB System.
-
#maintenance ⇒ OCI::Mysql::Models::MaintenanceDetails
This attribute is required.
-
#mysql_version ⇒ String
[Required] Name of the MySQL Version in use for the DB System.
-
#port ⇒ Integer
The port for primary endpoint of the DB System to listen on.
-
#port_x ⇒ Integer
The network port on which X Plugin listens for TCP/IP connections.
-
#shape_name ⇒ String
The shape of the primary instances of the DB System.
- #source ⇒ OCI::Mysql::Models::DbSystemSource
-
#subnet_id ⇒ String
[Required] The OCID of the subnet the DB System is associated with.
-
#time_created ⇒ DateTime
[Required] The date and time the DB System was created.
-
#time_updated ⇒ DateTime
[Required] The time the DB System was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbSystem
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbSystem
Initializes the object
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/oci/mysql/models/db_system.rb', line 304 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.is_highly_available = attributes[:'isHighlyAvailable'] unless attributes[:'isHighlyAvailable'].nil? self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHighlyAvailable and :is_highly_available' if attributes.key?(:'isHighlyAvailable') && attributes.key?(:'is_highly_available') self.is_highly_available = attributes[:'is_highly_available'] unless attributes[:'is_highly_available'].nil? self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') && !attributes.key?(:'is_highly_available') # rubocop:disable Style/StringLiterals self.current_placement = attributes[:'currentPlacement'] if attributes[:'currentPlacement'] raise 'You cannot provide both :currentPlacement and :current_placement' if attributes.key?(:'currentPlacement') && attributes.key?(:'current_placement') self.current_placement = attributes[:'current_placement'] if attributes[:'current_placement'] self.is_analytics_cluster_attached = attributes[:'isAnalyticsClusterAttached'] unless attributes[:'isAnalyticsClusterAttached'].nil? self.is_analytics_cluster_attached = false if is_analytics_cluster_attached.nil? && !attributes.key?(:'isAnalyticsClusterAttached') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isAnalyticsClusterAttached and :is_analytics_cluster_attached' if attributes.key?(:'isAnalyticsClusterAttached') && attributes.key?(:'is_analytics_cluster_attached') self.is_analytics_cluster_attached = attributes[:'is_analytics_cluster_attached'] unless attributes[:'is_analytics_cluster_attached'].nil? self.is_analytics_cluster_attached = false if is_analytics_cluster_attached.nil? && !attributes.key?(:'isAnalyticsClusterAttached') && !attributes.key?(:'is_analytics_cluster_attached') # rubocop:disable Style/StringLiterals self.analytics_cluster = attributes[:'analyticsCluster'] if attributes[:'analyticsCluster'] raise 'You cannot provide both :analyticsCluster and :analytics_cluster' if attributes.key?(:'analyticsCluster') && attributes.key?(:'analytics_cluster') self.analytics_cluster = attributes[:'analytics_cluster'] if attributes[:'analytics_cluster'] self.is_heat_wave_cluster_attached = attributes[:'isHeatWaveClusterAttached'] unless attributes[:'isHeatWaveClusterAttached'].nil? self.is_heat_wave_cluster_attached = false if is_heat_wave_cluster_attached.nil? && !attributes.key?(:'isHeatWaveClusterAttached') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHeatWaveClusterAttached and :is_heat_wave_cluster_attached' if attributes.key?(:'isHeatWaveClusterAttached') && attributes.key?(:'is_heat_wave_cluster_attached') self.is_heat_wave_cluster_attached = attributes[:'is_heat_wave_cluster_attached'] unless attributes[:'is_heat_wave_cluster_attached'].nil? self.is_heat_wave_cluster_attached = false if is_heat_wave_cluster_attached.nil? && !attributes.key?(:'isHeatWaveClusterAttached') && !attributes.key?(:'is_heat_wave_cluster_attached') # rubocop:disable Style/StringLiterals self.heat_wave_cluster = attributes[:'heatWaveCluster'] if attributes[:'heatWaveCluster'] raise 'You cannot provide both :heatWaveCluster and :heat_wave_cluster' if attributes.key?(:'heatWaveCluster') && attributes.key?(:'heat_wave_cluster') self.heat_wave_cluster = attributes[:'heat_wave_cluster'] if attributes[:'heat_wave_cluster'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain'] raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain') self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain'] self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName'] raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name') self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name'] self.mysql_version = attributes[:'mysqlVersion'] if attributes[:'mysqlVersion'] raise 'You cannot provide both :mysqlVersion and :mysql_version' if attributes.key?(:'mysqlVersion') && attributes.key?(:'mysql_version') self.mysql_version = attributes[:'mysql_version'] if attributes[:'mysql_version'] self.backup_policy = attributes[:'backupPolicy'] if attributes[:'backupPolicy'] raise 'You cannot provide both :backupPolicy and :backup_policy' if attributes.key?(:'backupPolicy') && attributes.key?(:'backup_policy') self.backup_policy = attributes[:'backup_policy'] if attributes[:'backup_policy'] self.source = attributes[:'source'] if attributes[:'source'] self.configuration_id = attributes[:'configurationId'] if attributes[:'configurationId'] raise 'You cannot provide both :configurationId and :configuration_id' if attributes.key?(:'configurationId') && attributes.key?(:'configuration_id') self.configuration_id = attributes[:'configuration_id'] if attributes[:'configuration_id'] self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs'] raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs') self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs'] self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel'] raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label') self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label'] self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress'] raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address'] self.port = attributes[:'port'] if attributes[:'port'] self.port_x = attributes[:'portX'] if attributes[:'portX'] raise 'You cannot provide both :portX and :port_x' if attributes.key?(:'portX') && attributes.key?(:'port_x') self.port_x = attributes[:'port_x'] if attributes[:'port_x'] self.endpoints = attributes[:'endpoints'] if attributes[:'endpoints'] self.channels = attributes[:'channels'] if attributes[:'channels'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.maintenance = attributes[:'maintenance'] if attributes[:'maintenance'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#analytics_cluster ⇒ OCI::Mysql::Models::AnalyticsClusterSummary
60 61 62 |
# File 'lib/oci/mysql/models/db_system.rb', line 60 def analytics_cluster @analytics_cluster end |
#availability_domain ⇒ String
The availability domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.
In a failover scenario, the Read/Write endpoint is redirected to one of the other availability domains and the MySQL instance in that domain is promoted to the primary instance. This redirection does not affect the IP address of the DB System in any way.
For a standalone DB System, this defines the availability domain in which the DB System is placed.
79 80 81 |
# File 'lib/oci/mysql/models/db_system.rb', line 79 def availability_domain @availability_domain end |
#backup_policy ⇒ OCI::Mysql::Models::BackupPolicy
106 107 108 |
# File 'lib/oci/mysql/models/db_system.rb', line 106 def backup_policy @backup_policy end |
#channels ⇒ Array<OCI::Mysql::Models::ChannelSummary>
A list with a summary of all the Channels attached to the DB System.
152 153 154 |
# File 'lib/oci/mysql/models/db_system.rb', line 152 def channels @channels end |
#compartment_id ⇒ String
[Required] The OCID of the compartment the DB System belongs in.
37 38 39 |
# File 'lib/oci/mysql/models/db_system.rb', line 37 def compartment_id @compartment_id end |
#configuration_id ⇒ String
The OCID of the Configuration to be used for Instances in this DB System.
113 114 115 |
# File 'lib/oci/mysql/models/db_system.rb', line 113 def configuration_id @configuration_id end |
#current_placement ⇒ OCI::Mysql::Models::DbSystemPlacement
51 52 53 |
# File 'lib/oci/mysql/models/db_system.rb', line 51 def current_placement @current_placement end |
#data_storage_size_in_gbs ⇒ Integer
[Required] Initial size of the data volume in GiBs that will be created and attached.
118 119 120 |
# File 'lib/oci/mysql/models/db_system.rb', line 118 def data_storage_size_in_gbs @data_storage_size_in_gbs end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
184 185 186 |
# File 'lib/oci/mysql/models/db_system.rb', line 184 def end |
#description ⇒ String
User-provided data about the DB System.
33 34 35 |
# File 'lib/oci/mysql/models/db_system.rb', line 33 def description @description end |
#display_name ⇒ String
[Required] The user-friendly name for the DB System. It does not have to be unique.
29 30 31 |
# File 'lib/oci/mysql/models/db_system.rb', line 29 def display_name @display_name end |
#endpoints ⇒ Array<OCI::Mysql::Models::DbSystemEndpoint>
The network endpoints available for this DB System.
148 149 150 |
# File 'lib/oci/mysql/models/db_system.rb', line 148 def endpoints @endpoints end |
#fault_domain ⇒ String
The fault domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.
In a failover scenario, the Read/Write endpoint is redirected to one of the other fault domains and the MySQL instance in that domain is promoted to the primary instance. This redirection does not affect the IP address of the DB System in any way.
For a standalone DB System, this defines the fault domain in which the DB System is placed.
90 91 92 |
# File 'lib/oci/mysql/models/db_system.rb', line 90 def fault_domain @fault_domain end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
178 179 180 |
# File 'lib/oci/mysql/models/db_system.rb', line 178 def end |
#heat_wave_cluster ⇒ OCI::Mysql::Models::HeatWaveClusterSummary
68 69 70 |
# File 'lib/oci/mysql/models/db_system.rb', line 68 def heat_wave_cluster @heat_wave_cluster end |
#hostname_label ⇒ String
The hostname for the primary endpoint of the DB System. Used for DNS. The value is the hostname portion of the primary private IP’s fully qualified domain name (FQDN) (for example, "dbsystem-1" in FQDN "dbsystem-1.subnet123.vcn1.oraclevcn.com"). Must be unique across all VNICs in the subnet and comply with RFC 952 and RFC 1123.
126 127 128 |
# File 'lib/oci/mysql/models/db_system.rb', line 126 def hostname_label @hostname_label end |
#id ⇒ String
[Required] The OCID of the DB System.
25 26 27 |
# File 'lib/oci/mysql/models/db_system.rb', line 25 def id @id end |
#ip_address ⇒ String
The IP address the DB System is configured to listen on. A private IP address of the primary endpoint of the DB System. Must be an available IP address within the subnet’s CIDR. This will be a "dotted-quad" style IPv4 address.
134 135 136 |
# File 'lib/oci/mysql/models/db_system.rb', line 134 def ip_address @ip_address end |
#is_analytics_cluster_attached ⇒ BOOLEAN
DEPRECATED – please use isHeatWaveClusterAttached instead. If the DB System has an Analytics Cluster attached.
57 58 59 |
# File 'lib/oci/mysql/models/db_system.rb', line 57 def is_analytics_cluster_attached @is_analytics_cluster_attached end |
#is_heat_wave_cluster_attached ⇒ BOOLEAN
If the DB System has a HeatWave Cluster attached.
65 66 67 |
# File 'lib/oci/mysql/models/db_system.rb', line 65 def is_heat_wave_cluster_attached @is_heat_wave_cluster_attached end |
#is_highly_available ⇒ BOOLEAN
If the policy is to enable high availability of the instance, by maintaining secondary/failover capacity as necessary.
48 49 50 |
# File 'lib/oci/mysql/models/db_system.rb', line 48 def is_highly_available @is_highly_available end |
#lifecycle_details ⇒ String
Additional information about the current lifecycleState.
160 161 162 |
# File 'lib/oci/mysql/models/db_system.rb', line 160 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the DB System.
156 157 158 |
# File 'lib/oci/mysql/models/db_system.rb', line 156 def lifecycle_state @lifecycle_state end |
#maintenance ⇒ OCI::Mysql::Models::MaintenanceDetails
This attribute is required.
164 165 166 |
# File 'lib/oci/mysql/models/db_system.rb', line 164 def maintenance @maintenance end |
#mysql_version ⇒ String
[Required] Name of the MySQL Version in use for the DB System.
103 104 105 |
# File 'lib/oci/mysql/models/db_system.rb', line 103 def mysql_version @mysql_version end |
#port ⇒ Integer
The port for primary endpoint of the DB System to listen on.
138 139 140 |
# File 'lib/oci/mysql/models/db_system.rb', line 138 def port @port end |
#port_x ⇒ Integer
The network port on which X Plugin listens for TCP/IP connections. This is the X Plugin equivalent of port.
143 144 145 |
# File 'lib/oci/mysql/models/db_system.rb', line 143 def port_x @port_x end |
#shape_name ⇒ String
The shape of the primary instances of the DB System. The shape determines resources allocated to a DB System - CPU cores and memory for VM shapes; CPU cores, memory and storage for non-VM (or bare metal) shapes. To get a list of shapes, use (the list_shapes operation.
99 100 101 |
# File 'lib/oci/mysql/models/db_system.rb', line 99 def shape_name @shape_name end |
#source ⇒ OCI::Mysql::Models::DbSystemSource
109 110 111 |
# File 'lib/oci/mysql/models/db_system.rb', line 109 def source @source end |
#subnet_id ⇒ String
[Required] The OCID of the subnet the DB System is associated with.
42 43 44 |
# File 'lib/oci/mysql/models/db_system.rb', line 42 def subnet_id @subnet_id end |
#time_created ⇒ DateTime
[Required] The date and time the DB System was created.
168 169 170 |
# File 'lib/oci/mysql/models/db_system.rb', line 168 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The time the DB System was last updated.
172 173 174 |
# File 'lib/oci/mysql/models/db_system.rb', line 172 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/oci/mysql/models/db_system.rb', line 187 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'subnet_id': :'subnetId', 'is_highly_available': :'isHighlyAvailable', 'current_placement': :'currentPlacement', 'is_analytics_cluster_attached': :'isAnalyticsClusterAttached', 'analytics_cluster': :'analyticsCluster', 'is_heat_wave_cluster_attached': :'isHeatWaveClusterAttached', 'heat_wave_cluster': :'heatWaveCluster', 'availability_domain': :'availabilityDomain', 'fault_domain': :'faultDomain', 'shape_name': :'shapeName', 'mysql_version': :'mysqlVersion', 'backup_policy': :'backupPolicy', 'source': :'source', 'configuration_id': :'configurationId', 'data_storage_size_in_gbs': :'dataStorageSizeInGBs', 'hostname_label': :'hostnameLabel', 'ip_address': :'ipAddress', 'port': :'port', 'port_x': :'portX', 'endpoints': :'endpoints', 'channels': :'channels', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'maintenance': :'maintenance', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/mysql/models/db_system.rb', line 227 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'subnet_id': :'String', 'is_highly_available': :'BOOLEAN', 'current_placement': :'OCI::Mysql::Models::DbSystemPlacement', 'is_analytics_cluster_attached': :'BOOLEAN', 'analytics_cluster': :'OCI::Mysql::Models::AnalyticsClusterSummary', 'is_heat_wave_cluster_attached': :'BOOLEAN', 'heat_wave_cluster': :'OCI::Mysql::Models::HeatWaveClusterSummary', 'availability_domain': :'String', 'fault_domain': :'String', 'shape_name': :'String', 'mysql_version': :'String', 'backup_policy': :'OCI::Mysql::Models::BackupPolicy', 'source': :'OCI::Mysql::Models::DbSystemSource', 'configuration_id': :'String', 'data_storage_size_in_gbs': :'Integer', 'hostname_label': :'String', 'ip_address': :'String', 'port': :'Integer', 'port_x': :'Integer', 'endpoints': :'Array<OCI::Mysql::Models::DbSystemEndpoint>', 'channels': :'Array<OCI::Mysql::Models::ChannelSummary>', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'maintenance': :'OCI::Mysql::Models::MaintenanceDetails', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/oci/mysql/models/db_system.rb', line 501 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && subnet_id == other.subnet_id && is_highly_available == other.is_highly_available && current_placement == other.current_placement && is_analytics_cluster_attached == other.is_analytics_cluster_attached && analytics_cluster == other.analytics_cluster && is_heat_wave_cluster_attached == other.is_heat_wave_cluster_attached && heat_wave_cluster == other.heat_wave_cluster && availability_domain == other.availability_domain && fault_domain == other.fault_domain && shape_name == other.shape_name && mysql_version == other.mysql_version && backup_policy == other.backup_policy && source == other.source && configuration_id == other.configuration_id && data_storage_size_in_gbs == other.data_storage_size_in_gbs && hostname_label == other.hostname_label && ip_address == other.ip_address && port == other.port && port_x == other.port_x && endpoints == other.endpoints && channels == other.channels && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && maintenance == other.maintenance && time_created == other.time_created && time_updated == other.time_updated && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 |
# File 'lib/oci/mysql/models/db_system.rb', line 562 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
542 543 544 |
# File 'lib/oci/mysql/models/db_system.rb', line 542 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
551 552 553 |
# File 'lib/oci/mysql/models/db_system.rb', line 551 def hash [id, display_name, description, compartment_id, subnet_id, is_highly_available, current_placement, is_analytics_cluster_attached, analytics_cluster, is_heat_wave_cluster_attached, heat_wave_cluster, availability_domain, fault_domain, shape_name, mysql_version, backup_policy, source, configuration_id, data_storage_size_in_gbs, hostname_label, ip_address, port, port_x, endpoints, channels, lifecycle_state, lifecycle_details, maintenance, time_created, time_updated, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
595 596 597 598 599 600 601 602 603 604 |
# File 'lib/oci/mysql/models/db_system.rb', line 595 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
589 590 591 |
# File 'lib/oci/mysql/models/db_system.rb', line 589 def to_s to_hash.to_s end |