Class: OCI::Mysql::Models::DbSystemSnapshot

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/mysql/models/db_system_snapshot.rb

Overview

Snapshot of the DbSystem details at the time of the backup

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DbSystemSnapshot

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 211

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain']

  raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain')

  self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain']

  self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName']

  raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name')

  self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name']

  self.mysql_version = attributes[:'mysqlVersion'] if attributes[:'mysqlVersion']

  raise 'You cannot provide both :mysqlVersion and :mysql_version' if attributes.key?(:'mysqlVersion') && attributes.key?(:'mysql_version')

  self.mysql_version = attributes[:'mysql_version'] if attributes[:'mysql_version']

  self.admin_username = attributes[:'adminUsername'] if attributes[:'adminUsername']

  raise 'You cannot provide both :adminUsername and :admin_username' if attributes.key?(:'adminUsername') && attributes.key?(:'admin_username')

  self.admin_username = attributes[:'admin_username'] if attributes[:'admin_username']

  self.backup_policy = attributes[:'backupPolicy'] if attributes[:'backupPolicy']

  raise 'You cannot provide both :backupPolicy and :backup_policy' if attributes.key?(:'backupPolicy') && attributes.key?(:'backup_policy')

  self.backup_policy = attributes[:'backup_policy'] if attributes[:'backup_policy']

  self.configuration_id = attributes[:'configurationId'] if attributes[:'configurationId']

  raise 'You cannot provide both :configurationId and :configuration_id' if attributes.key?(:'configurationId') && attributes.key?(:'configuration_id')

  self.configuration_id = attributes[:'configuration_id'] if attributes[:'configuration_id']

  self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs']

  raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs')

  self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs']

  self.hostname_label = attributes[:'hostnameLabel'] if attributes[:'hostnameLabel']

  raise 'You cannot provide both :hostnameLabel and :hostname_label' if attributes.key?(:'hostnameLabel') && attributes.key?(:'hostname_label')

  self.hostname_label = attributes[:'hostname_label'] if attributes[:'hostname_label']

  self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress']

  raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address')

  self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address']

  self.port = attributes[:'port'] if attributes[:'port']

  self.port_x = attributes[:'portX'] if attributes[:'portX']

  raise 'You cannot provide both :portX and :port_x' if attributes.key?(:'portX') && attributes.key?(:'port_x')

  self.port_x = attributes[:'port_x'] if attributes[:'port_x']

  self.is_highly_available = attributes[:'isHighlyAvailable'] unless attributes[:'isHighlyAvailable'].nil?
  self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHighlyAvailable and :is_highly_available' if attributes.key?(:'isHighlyAvailable') && attributes.key?(:'is_highly_available')

  self.is_highly_available = attributes[:'is_highly_available'] unless attributes[:'is_highly_available'].nil?
  self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') && !attributes.key?(:'is_highly_available') # rubocop:disable Style/StringLiterals

  self.endpoints = attributes[:'endpoints'] if attributes[:'endpoints']

  self.maintenance = attributes[:'maintenance'] if attributes[:'maintenance']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#admin_usernameString

The username for the administrative user.

Returns:

  • (String)


57
58
59
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 57

def admin_username
  @admin_username
end

#availability_domainString

The Availability Domain where the primary DB System should be located.

Returns:

  • (String)


35
36
37
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 35

def availability_domain
  @availability_domain
end

#backup_policyOCI::Mysql::Models::BackupPolicy



60
61
62
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 60

def backup_policy
  @backup_policy
end

#compartment_idString

[Required] The OCID of the compartment the DB System belongs in.

Returns:

  • (String)


25
26
27
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 25

def compartment_id
  @compartment_id
end

#configuration_idString

The OCID of the Configuration to be used for Instances in this DB System.

Returns:

  • (String)


64
65
66
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 64

def configuration_id
  @configuration_id
end

#data_storage_size_in_gbsInteger

[Required] Initial size of the data volume in GiBs that will be created and attached.

Returns:

  • (Integer)


69
70
71
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 69

def data_storage_size_in_gbs
  @data_storage_size_in_gbs
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


121
122
123
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 121

def defined_tags
  @defined_tags
end

#descriptionString

User-provided data about the DB System.

Returns:

  • (String)


21
22
23
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 21

def description
  @description
end

#display_nameString

[Required] The user-friendly name for the DB System. It does not have to be unique.

Returns:

  • (String)


17
18
19
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 17

def display_name
  @display_name
end

#endpointsArray<OCI::Mysql::Models::DbSystemEndpoint>

The network endpoints available for this DB System.



105
106
107
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 105

def endpoints
  @endpoints
end

#fault_domainString

The name of the Fault Domain the DB System is located in.

Returns:

  • (String)


40
41
42
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 40

def fault_domain
  @fault_domain
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


115
116
117
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 115

def freeform_tags
  @freeform_tags
end

#hostname_labelString

The hostname for the primary endpoint of the DB System. Used for DNS. The value is the hostname portion of the primary private IP’s fully qualified domain name (FQDN) (for example, "dbsystem-1" in FQDN "dbsystem-1.subnet123.vcn1.oraclevcn.com"). Must be unique across all VNICs in the subnet and comply with RFC 952 and RFC 1123.

Returns:

  • (String)


77
78
79
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 77

def hostname_label
  @hostname_label
end

#idString

[Required] The OCID of the DB System.

Returns:

  • (String)


13
14
15
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 13

def id
  @id
end

#ip_addressString

The IP address the DB System is configured to listen on. A private IP address of the primary endpoint of the DB System. Must be an available IP address within the subnet’s CIDR. This will be a "dotted-quad" style IPv4 address.

Returns:

  • (String)


85
86
87
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 85

def ip_address
  @ip_address
end

#is_highly_availableBOOLEAN

If the policy is to enable high availability of the instance, by maintaining secondary/failover capacity as necessary.

Returns:

  • (BOOLEAN)


100
101
102
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 100

def is_highly_available
  @is_highly_available
end

#maintenanceOCI::Mysql::Models::MaintenanceDetails

This attribute is required.



109
110
111
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 109

def maintenance
  @maintenance
end

#mysql_versionString

[Required] Name of the MySQL Version in use for the DB System.

Returns:

  • (String)


53
54
55
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 53

def mysql_version
  @mysql_version
end

#portInteger

The port for primary endpoint of the DB System to listen on.

Returns:

  • (Integer)


89
90
91
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 89

def port
  @port
end

#port_xInteger

The network port on which X Plugin listens for TCP/IP connections. This is the X Plugin equivalent of port.

Returns:

  • (Integer)


94
95
96
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 94

def port_x
  @port_x
end

#shape_nameString

The shape of the primary instances of the DB System. The shape determines resources allocated to a DB System - CPU cores and memory for VM shapes; CPU cores, memory and storage for non-VM (or bare metal) shapes. To get a list of shapes, use (the list_shapes operation.

Returns:

  • (String)


49
50
51
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 49

def shape_name
  @shape_name
end

#subnet_idString

[Required] The OCID of the subnet the DB System is associated with.

Returns:

  • (String)


30
31
32
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 30

def subnet_id
  @subnet_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 124

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'subnet_id': :'subnetId',
    'availability_domain': :'availabilityDomain',
    'fault_domain': :'faultDomain',
    'shape_name': :'shapeName',
    'mysql_version': :'mysqlVersion',
    'admin_username': :'adminUsername',
    'backup_policy': :'backupPolicy',
    'configuration_id': :'configurationId',
    'data_storage_size_in_gbs': :'dataStorageSizeInGBs',
    'hostname_label': :'hostnameLabel',
    'ip_address': :'ipAddress',
    'port': :'port',
    'port_x': :'portX',
    'is_highly_available': :'isHighlyAvailable',
    'endpoints': :'endpoints',
    'maintenance': :'maintenance',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 154

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'subnet_id': :'String',
    'availability_domain': :'String',
    'fault_domain': :'String',
    'shape_name': :'String',
    'mysql_version': :'String',
    'admin_username': :'String',
    'backup_policy': :'OCI::Mysql::Models::BackupPolicy',
    'configuration_id': :'String',
    'data_storage_size_in_gbs': :'Integer',
    'hostname_label': :'String',
    'ip_address': :'String',
    'port': :'Integer',
    'port_x': :'Integer',
    'is_highly_available': :'BOOLEAN',
    'endpoints': :'Array<OCI::Mysql::Models::DbSystemEndpoint>',
    'maintenance': :'OCI::Mysql::Models::MaintenanceDetails',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 339

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    subnet_id == other.subnet_id &&
    availability_domain == other.availability_domain &&
    fault_domain == other.fault_domain &&
    shape_name == other.shape_name &&
    mysql_version == other.mysql_version &&
    admin_username == other.admin_username &&
    backup_policy == other.backup_policy &&
    configuration_id == other.configuration_id &&
    data_storage_size_in_gbs == other.data_storage_size_in_gbs &&
    hostname_label == other.hostname_label &&
    ip_address == other.ip_address &&
    port == other.port &&
    port_x == other.port_x &&
    is_highly_available == other.is_highly_available &&
    endpoints == other.endpoints &&
    maintenance == other.maintenance &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 390

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


370
371
372
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 370

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



379
380
381
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 379

def hash
  [id, display_name, description, compartment_id, subnet_id, availability_domain, fault_domain, shape_name, mysql_version, admin_username, backup_policy, configuration_id, data_storage_size_in_gbs, hostname_label, ip_address, port, port_x, is_highly_available, endpoints, maintenance, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



423
424
425
426
427
428
429
430
431
432
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 423

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



417
418
419
# File 'lib/oci/mysql/models/db_system_snapshot.rb', line 417

def to_s
  to_hash.to_s
end