Class: OCI::Mysql::Models::DbSystemSummary
- Inherits:
-
Object
- Object
- OCI::Mysql::Models::DbSystemSummary
- Defined in:
- lib/oci/mysql/models/db_system_summary.rb
Overview
A summary of a DB System.
Constant Summary collapse
- CRASH_RECOVERY_ENUM =
[ CRASH_RECOVERY_ENABLED = 'ENABLED'.freeze, CRASH_RECOVERY_DISABLED = 'DISABLED'.freeze, CRASH_RECOVERY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #analytics_cluster ⇒ OCI::Mysql::Models::AnalyticsClusterSummary
-
#availability_domain ⇒ String
The availability domain on which to deploy the Read/Write endpoint.
- #backup_policy ⇒ OCI::Mysql::Models::BackupPolicy
-
#compartment_id ⇒ String
The OCID of the compartment the DB System belongs in.
-
#crash_recovery ⇒ String
Whether to run the DB System with InnoDB Redo Logs and the Double Write Buffer enabled or disabled, and whether to enable or disable syncing of the Binary Logs.
- #current_placement ⇒ OCI::Mysql::Models::DbSystemPlacement
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
- #deletion_policy ⇒ OCI::Mysql::Models::DeletionPolicyDetails
-
#description ⇒ String
User-provided data about the DB System.
-
#display_name ⇒ String
**[Required]** The user-friendly name for the DB System.
-
#endpoints ⇒ Array<OCI::Mysql::Models::DbSystemEndpoint>
The network endpoints available for this DB System.
-
#fault_domain ⇒ String
The fault domain on which to deploy the Read/Write endpoint.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #heat_wave_cluster ⇒ OCI::Mysql::Models::HeatWaveClusterSummary
-
#id ⇒ String
**[Required]** The OCID of the DB System.
-
#is_analytics_cluster_attached ⇒ BOOLEAN
DEPRECATED – please use `isHeatWaveClusterAttached` instead.
-
#is_heat_wave_cluster_attached ⇒ BOOLEAN
If the DB System has a HeatWave Cluster attached.
-
#is_highly_available ⇒ BOOLEAN
Specifies if the DB System is highly available.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the DB System.
-
#mysql_version ⇒ String
**[Required]** Name of the MySQL Version in use for the DB System.
-
#shape_name ⇒ String
The shape of the primary instances of the DB System.
-
#time_created ⇒ DateTime
**[Required]** The date and time the DB System was created.
-
#time_updated ⇒ DateTime
**[Required]** The time the DB System was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DbSystemSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DbSystemSummary
Initializes the object
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 226 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_highly_available = attributes[:'isHighlyAvailable'] unless attributes[:'isHighlyAvailable'].nil? self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHighlyAvailable and :is_highly_available' if attributes.key?(:'isHighlyAvailable') && attributes.key?(:'is_highly_available') self.is_highly_available = attributes[:'is_highly_available'] unless attributes[:'is_highly_available'].nil? self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') && !attributes.key?(:'is_highly_available') # rubocop:disable Style/StringLiterals self.current_placement = attributes[:'currentPlacement'] if attributes[:'currentPlacement'] raise 'You cannot provide both :currentPlacement and :current_placement' if attributes.key?(:'currentPlacement') && attributes.key?(:'current_placement') self.current_placement = attributes[:'current_placement'] if attributes[:'current_placement'] self.is_analytics_cluster_attached = attributes[:'isAnalyticsClusterAttached'] unless attributes[:'isAnalyticsClusterAttached'].nil? self.is_analytics_cluster_attached = false if is_analytics_cluster_attached.nil? && !attributes.key?(:'isAnalyticsClusterAttached') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isAnalyticsClusterAttached and :is_analytics_cluster_attached' if attributes.key?(:'isAnalyticsClusterAttached') && attributes.key?(:'is_analytics_cluster_attached') self.is_analytics_cluster_attached = attributes[:'is_analytics_cluster_attached'] unless attributes[:'is_analytics_cluster_attached'].nil? self.is_analytics_cluster_attached = false if is_analytics_cluster_attached.nil? && !attributes.key?(:'isAnalyticsClusterAttached') && !attributes.key?(:'is_analytics_cluster_attached') # rubocop:disable Style/StringLiterals self.analytics_cluster = attributes[:'analyticsCluster'] if attributes[:'analyticsCluster'] raise 'You cannot provide both :analyticsCluster and :analytics_cluster' if attributes.key?(:'analyticsCluster') && attributes.key?(:'analytics_cluster') self.analytics_cluster = attributes[:'analytics_cluster'] if attributes[:'analytics_cluster'] self.is_heat_wave_cluster_attached = attributes[:'isHeatWaveClusterAttached'] unless attributes[:'isHeatWaveClusterAttached'].nil? self.is_heat_wave_cluster_attached = false if is_heat_wave_cluster_attached.nil? && !attributes.key?(:'isHeatWaveClusterAttached') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHeatWaveClusterAttached and :is_heat_wave_cluster_attached' if attributes.key?(:'isHeatWaveClusterAttached') && attributes.key?(:'is_heat_wave_cluster_attached') self.is_heat_wave_cluster_attached = attributes[:'is_heat_wave_cluster_attached'] unless attributes[:'is_heat_wave_cluster_attached'].nil? self.is_heat_wave_cluster_attached = false if is_heat_wave_cluster_attached.nil? && !attributes.key?(:'isHeatWaveClusterAttached') && !attributes.key?(:'is_heat_wave_cluster_attached') # rubocop:disable Style/StringLiterals self.heat_wave_cluster = attributes[:'heatWaveCluster'] if attributes[:'heatWaveCluster'] raise 'You cannot provide both :heatWaveCluster and :heat_wave_cluster' if attributes.key?(:'heatWaveCluster') && attributes.key?(:'heat_wave_cluster') self.heat_wave_cluster = attributes[:'heat_wave_cluster'] if attributes[:'heat_wave_cluster'] self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain'] raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain') self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain'] self.endpoints = attributes[:'endpoints'] if attributes[:'endpoints'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.mysql_version = attributes[:'mysqlVersion'] if attributes[:'mysqlVersion'] raise 'You cannot provide both :mysqlVersion and :mysql_version' if attributes.key?(:'mysqlVersion') && attributes.key?(:'mysql_version') self.mysql_version = attributes[:'mysql_version'] if attributes[:'mysql_version'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.deletion_policy = attributes[:'deletionPolicy'] if attributes[:'deletionPolicy'] raise 'You cannot provide both :deletionPolicy and :deletion_policy' if attributes.key?(:'deletionPolicy') && attributes.key?(:'deletion_policy') self.deletion_policy = attributes[:'deletion_policy'] if attributes[:'deletion_policy'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.backup_policy = attributes[:'backupPolicy'] if attributes[:'backupPolicy'] raise 'You cannot provide both :backupPolicy and :backup_policy' if attributes.key?(:'backupPolicy') && attributes.key?(:'backup_policy') self.backup_policy = attributes[:'backup_policy'] if attributes[:'backup_policy'] self.shape_name = attributes[:'shapeName'] if attributes[:'shapeName'] raise 'You cannot provide both :shapeName and :shape_name' if attributes.key?(:'shapeName') && attributes.key?(:'shape_name') self.shape_name = attributes[:'shape_name'] if attributes[:'shape_name'] self.crash_recovery = attributes[:'crashRecovery'] if attributes[:'crashRecovery'] self.crash_recovery = "ENABLED" if crash_recovery.nil? && !attributes.key?(:'crashRecovery') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :crashRecovery and :crash_recovery' if attributes.key?(:'crashRecovery') && attributes.key?(:'crash_recovery') self.crash_recovery = attributes[:'crash_recovery'] if attributes[:'crash_recovery'] self.crash_recovery = "ENABLED" if crash_recovery.nil? && !attributes.key?(:'crashRecovery') && !attributes.key?(:'crash_recovery') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#analytics_cluster ⇒ OCI::Mysql::Models::AnalyticsClusterSummary
49 50 51 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 49 def analytics_cluster @analytics_cluster end |
#availability_domain ⇒ String
The availability domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.
In a failover scenario, the Read/Write endpoint is redirected to one of the other availability domains and the MySQL instance in that domain is promoted to the primary instance. This redirection does not affect the IP address of the DB System in any way.
For a standalone DB System, this defines the availability domain in which the DB System is placed.
68 69 70 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 68 def availability_domain @availability_domain end |
#backup_policy ⇒ OCI::Mysql::Models::BackupPolicy
118 119 120 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 118 def backup_policy @backup_policy end |
#compartment_id ⇒ String
The OCID of the compartment the DB System belongs in.
32 33 34 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 32 def compartment_id @compartment_id end |
#crash_recovery ⇒ String
Whether to run the DB System with InnoDB Redo Logs and the Double Write Buffer enabled or disabled, and whether to enable or disable syncing of the Binary Logs.
133 134 135 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 133 def crash_recovery @crash_recovery end |
#current_placement ⇒ OCI::Mysql::Models::DbSystemPlacement
40 41 42 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 40 def current_placement @current_placement end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
115 116 117 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 115 def @defined_tags end |
#deletion_policy ⇒ OCI::Mysql::Models::DeletionPolicyDetails
103 104 105 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 103 def deletion_policy @deletion_policy end |
#description ⇒ String
User-provided data about the DB System.
28 29 30 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 28 def description @description end |
#display_name ⇒ String
**[Required]** The user-friendly name for the DB System. It does not have to be unique.
24 25 26 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 24 def display_name @display_name end |
#endpoints ⇒ Array<OCI::Mysql::Models::DbSystemEndpoint>
The network endpoints available for this DB System.
84 85 86 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 84 def endpoints @endpoints end |
#fault_domain ⇒ String
The fault domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.
In a failover scenario, the Read/Write endpoint is redirected to one of the other fault domains and the MySQL instance in that domain is promoted to the primary instance. This redirection does not affect the IP address of the DB System in any way.
For a standalone DB System, this defines the fault domain in which the DB System is placed.
79 80 81 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 79 def fault_domain @fault_domain end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
109 110 111 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 109 def @freeform_tags end |
#heat_wave_cluster ⇒ OCI::Mysql::Models::HeatWaveClusterSummary
57 58 59 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 57 def heat_wave_cluster @heat_wave_cluster end |
#id ⇒ String
**[Required]** The OCID of the DB System.
20 21 22 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 20 def id @id end |
#is_analytics_cluster_attached ⇒ BOOLEAN
DEPRECATED – please use `isHeatWaveClusterAttached` instead. If the DB System has an Analytics Cluster attached.
46 47 48 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 46 def is_analytics_cluster_attached @is_analytics_cluster_attached end |
#is_heat_wave_cluster_attached ⇒ BOOLEAN
If the DB System has a HeatWave Cluster attached.
54 55 56 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 54 def is_heat_wave_cluster_attached @is_heat_wave_cluster_attached end |
#is_highly_available ⇒ BOOLEAN
Specifies if the DB System is highly available.
37 38 39 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 37 def is_highly_available @is_highly_available end |
#lifecycle_state ⇒ String
**[Required]** The current state of the DB System.
88 89 90 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 88 def lifecycle_state @lifecycle_state end |
#mysql_version ⇒ String
**[Required]** Name of the MySQL Version in use for the DB System.
92 93 94 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 92 def mysql_version @mysql_version end |
#shape_name ⇒ String
The shape of the primary instances of the DB System. The shape determines resources allocated to a DB System - CPU cores and memory for VM shapes; CPU cores, memory and storage for non-VM (or bare metal) shapes. To get a list of shapes, use (the list_shapes operation.
127 128 129 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 127 def shape_name @shape_name end |
#time_created ⇒ DateTime
**[Required]** The date and time the DB System was created.
96 97 98 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 96 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The time the DB System was last updated.
100 101 102 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 100 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 136 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'is_highly_available': :'isHighlyAvailable', 'current_placement': :'currentPlacement', 'is_analytics_cluster_attached': :'isAnalyticsClusterAttached', 'analytics_cluster': :'analyticsCluster', 'is_heat_wave_cluster_attached': :'isHeatWaveClusterAttached', 'heat_wave_cluster': :'heatWaveCluster', 'availability_domain': :'availabilityDomain', 'fault_domain': :'faultDomain', 'endpoints': :'endpoints', 'lifecycle_state': :'lifecycleState', 'mysql_version': :'mysqlVersion', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'deletion_policy': :'deletionPolicy', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'backup_policy': :'backupPolicy', 'shape_name': :'shapeName', 'crash_recovery': :'crashRecovery' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 167 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'is_highly_available': :'BOOLEAN', 'current_placement': :'OCI::Mysql::Models::DbSystemPlacement', 'is_analytics_cluster_attached': :'BOOLEAN', 'analytics_cluster': :'OCI::Mysql::Models::AnalyticsClusterSummary', 'is_heat_wave_cluster_attached': :'BOOLEAN', 'heat_wave_cluster': :'OCI::Mysql::Models::HeatWaveClusterSummary', 'availability_domain': :'String', 'fault_domain': :'String', 'endpoints': :'Array<OCI::Mysql::Models::DbSystemEndpoint>', 'lifecycle_state': :'String', 'mysql_version': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'deletion_policy': :'OCI::Mysql::Models::DeletionPolicyDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'backup_policy': :'OCI::Mysql::Models::BackupPolicy', 'shape_name': :'String', 'crash_recovery': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 387 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && is_highly_available == other.is_highly_available && current_placement == other.current_placement && is_analytics_cluster_attached == other.is_analytics_cluster_attached && analytics_cluster == other.analytics_cluster && is_heat_wave_cluster_attached == other.is_heat_wave_cluster_attached && heat_wave_cluster == other.heat_wave_cluster && availability_domain == other.availability_domain && fault_domain == other.fault_domain && endpoints == other.endpoints && lifecycle_state == other.lifecycle_state && mysql_version == other.mysql_version && time_created == other.time_created && time_updated == other.time_updated && deletion_policy == other.deletion_policy && == other. && == other. && backup_policy == other.backup_policy && shape_name == other.shape_name && crash_recovery == other.crash_recovery end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 439 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
419 420 421 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 419 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
428 429 430 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 428 def hash [id, display_name, description, compartment_id, is_highly_available, current_placement, is_analytics_cluster_attached, analytics_cluster, is_heat_wave_cluster_attached, heat_wave_cluster, availability_domain, fault_domain, endpoints, lifecycle_state, mysql_version, time_created, time_updated, deletion_policy, , , backup_policy, shape_name, crash_recovery].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
472 473 474 475 476 477 478 479 480 481 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 472 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
466 467 468 |
# File 'lib/oci/mysql/models/db_system_summary.rb', line 466 def to_s to_hash.to_s end |