Class: OCI::Mysql::Models::DbSystemSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/mysql/models/db_system_summary.rb

Overview

A summary of a DB System.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DbSystemSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/oci/mysql/models/db_system_summary.rb', line 188

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.is_highly_available = attributes[:'isHighlyAvailable'] unless attributes[:'isHighlyAvailable'].nil?
  self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHighlyAvailable and :is_highly_available' if attributes.key?(:'isHighlyAvailable') && attributes.key?(:'is_highly_available')

  self.is_highly_available = attributes[:'is_highly_available'] unless attributes[:'is_highly_available'].nil?
  self.is_highly_available = true if is_highly_available.nil? && !attributes.key?(:'isHighlyAvailable') && !attributes.key?(:'is_highly_available') # rubocop:disable Style/StringLiterals

  self.current_placement = attributes[:'currentPlacement'] if attributes[:'currentPlacement']

  raise 'You cannot provide both :currentPlacement and :current_placement' if attributes.key?(:'currentPlacement') && attributes.key?(:'current_placement')

  self.current_placement = attributes[:'current_placement'] if attributes[:'current_placement']

  self.is_analytics_cluster_attached = attributes[:'isAnalyticsClusterAttached'] unless attributes[:'isAnalyticsClusterAttached'].nil?
  self.is_analytics_cluster_attached = false if is_analytics_cluster_attached.nil? && !attributes.key?(:'isAnalyticsClusterAttached') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isAnalyticsClusterAttached and :is_analytics_cluster_attached' if attributes.key?(:'isAnalyticsClusterAttached') && attributes.key?(:'is_analytics_cluster_attached')

  self.is_analytics_cluster_attached = attributes[:'is_analytics_cluster_attached'] unless attributes[:'is_analytics_cluster_attached'].nil?
  self.is_analytics_cluster_attached = false if is_analytics_cluster_attached.nil? && !attributes.key?(:'isAnalyticsClusterAttached') && !attributes.key?(:'is_analytics_cluster_attached') # rubocop:disable Style/StringLiterals

  self.analytics_cluster = attributes[:'analyticsCluster'] if attributes[:'analyticsCluster']

  raise 'You cannot provide both :analyticsCluster and :analytics_cluster' if attributes.key?(:'analyticsCluster') && attributes.key?(:'analytics_cluster')

  self.analytics_cluster = attributes[:'analytics_cluster'] if attributes[:'analytics_cluster']

  self.is_heat_wave_cluster_attached = attributes[:'isHeatWaveClusterAttached'] unless attributes[:'isHeatWaveClusterAttached'].nil?
  self.is_heat_wave_cluster_attached = false if is_heat_wave_cluster_attached.nil? && !attributes.key?(:'isHeatWaveClusterAttached') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isHeatWaveClusterAttached and :is_heat_wave_cluster_attached' if attributes.key?(:'isHeatWaveClusterAttached') && attributes.key?(:'is_heat_wave_cluster_attached')

  self.is_heat_wave_cluster_attached = attributes[:'is_heat_wave_cluster_attached'] unless attributes[:'is_heat_wave_cluster_attached'].nil?
  self.is_heat_wave_cluster_attached = false if is_heat_wave_cluster_attached.nil? && !attributes.key?(:'isHeatWaveClusterAttached') && !attributes.key?(:'is_heat_wave_cluster_attached') # rubocop:disable Style/StringLiterals

  self.heat_wave_cluster = attributes[:'heatWaveCluster'] if attributes[:'heatWaveCluster']

  raise 'You cannot provide both :heatWaveCluster and :heat_wave_cluster' if attributes.key?(:'heatWaveCluster') && attributes.key?(:'heat_wave_cluster')

  self.heat_wave_cluster = attributes[:'heat_wave_cluster'] if attributes[:'heat_wave_cluster']

  self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

  raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

  self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

  self.fault_domain = attributes[:'faultDomain'] if attributes[:'faultDomain']

  raise 'You cannot provide both :faultDomain and :fault_domain' if attributes.key?(:'faultDomain') && attributes.key?(:'fault_domain')

  self.fault_domain = attributes[:'fault_domain'] if attributes[:'fault_domain']

  self.endpoints = attributes[:'endpoints'] if attributes[:'endpoints']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.mysql_version = attributes[:'mysqlVersion'] if attributes[:'mysqlVersion']

  raise 'You cannot provide both :mysqlVersion and :mysql_version' if attributes.key?(:'mysqlVersion') && attributes.key?(:'mysql_version')

  self.mysql_version = attributes[:'mysql_version'] if attributes[:'mysql_version']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#analytics_clusterOCI::Mysql::Models::AnalyticsClusterSummary



44
45
46
# File 'lib/oci/mysql/models/db_system_summary.rb', line 44

def analytics_cluster
  @analytics_cluster
end

#availability_domainString

The availability domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

In a failover scenario, the Read/Write endpoint is redirected to one of the other availability domains and the MySQL instance in that domain is promoted to the primary instance. This redirection does not affect the IP address of the DB System in any way.

For a standalone DB System, this defines the availability domain in which the DB System is placed.

Returns:

  • (String)


63
64
65
# File 'lib/oci/mysql/models/db_system_summary.rb', line 63

def availability_domain
  @availability_domain
end

#compartment_idString

The OCID of the compartment the DB System belongs in.

Returns:

  • (String)


26
27
28
# File 'lib/oci/mysql/models/db_system_summary.rb', line 26

def compartment_id
  @compartment_id
end

#current_placementOCI::Mysql::Models::DbSystemPlacement



35
36
37
# File 'lib/oci/mysql/models/db_system_summary.rb', line 35

def current_placement
  @current_placement
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


107
108
109
# File 'lib/oci/mysql/models/db_system_summary.rb', line 107

def defined_tags
  @defined_tags
end

#descriptionString

User-provided data about the DB System.

Returns:

  • (String)


22
23
24
# File 'lib/oci/mysql/models/db_system_summary.rb', line 22

def description
  @description
end

#display_nameString

[Required] The user-friendly name for the DB System. It does not have to be unique.

Returns:

  • (String)


18
19
20
# File 'lib/oci/mysql/models/db_system_summary.rb', line 18

def display_name
  @display_name
end

#endpointsArray<OCI::Mysql::Models::DbSystemEndpoint>

The network endpoints available for this DB System.



79
80
81
# File 'lib/oci/mysql/models/db_system_summary.rb', line 79

def endpoints
  @endpoints
end

#fault_domainString

The fault domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

In a failover scenario, the Read/Write endpoint is redirected to one of the other fault domains and the MySQL instance in that domain is promoted to the primary instance. This redirection does not affect the IP address of the DB System in any way.

For a standalone DB System, this defines the fault domain in which the DB System is placed.

Returns:

  • (String)


74
75
76
# File 'lib/oci/mysql/models/db_system_summary.rb', line 74

def fault_domain
  @fault_domain
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


101
102
103
# File 'lib/oci/mysql/models/db_system_summary.rb', line 101

def freeform_tags
  @freeform_tags
end

#heat_wave_clusterOCI::Mysql::Models::HeatWaveClusterSummary



52
53
54
# File 'lib/oci/mysql/models/db_system_summary.rb', line 52

def heat_wave_cluster
  @heat_wave_cluster
end

#idString

[Required] The OCID of the DB System.

Returns:

  • (String)


14
15
16
# File 'lib/oci/mysql/models/db_system_summary.rb', line 14

def id
  @id
end

#is_analytics_cluster_attachedBOOLEAN

DEPRECATED – please use isHeatWaveClusterAttached instead. If the DB System has an Analytics Cluster attached.

Returns:

  • (BOOLEAN)


41
42
43
# File 'lib/oci/mysql/models/db_system_summary.rb', line 41

def is_analytics_cluster_attached
  @is_analytics_cluster_attached
end

#is_heat_wave_cluster_attachedBOOLEAN

If the DB System has a HeatWave Cluster attached.

Returns:

  • (BOOLEAN)


49
50
51
# File 'lib/oci/mysql/models/db_system_summary.rb', line 49

def is_heat_wave_cluster_attached
  @is_heat_wave_cluster_attached
end

#is_highly_availableBOOLEAN

If the policy is to enable high availability of the instance, by maintaining secondary/failover capacity as necessary.

Returns:

  • (BOOLEAN)


32
33
34
# File 'lib/oci/mysql/models/db_system_summary.rb', line 32

def is_highly_available
  @is_highly_available
end

#lifecycle_stateString

[Required] The current state of the DB System.

Returns:

  • (String)


83
84
85
# File 'lib/oci/mysql/models/db_system_summary.rb', line 83

def lifecycle_state
  @lifecycle_state
end

#mysql_versionString

[Required] Name of the MySQL Version in use for the DB System.

Returns:

  • (String)


87
88
89
# File 'lib/oci/mysql/models/db_system_summary.rb', line 87

def mysql_version
  @mysql_version
end

#time_createdDateTime

[Required] The date and time the DB System was created.

Returns:

  • (DateTime)


91
92
93
# File 'lib/oci/mysql/models/db_system_summary.rb', line 91

def time_created
  @time_created
end

#time_updatedDateTime

[Required] The time the DB System was last updated.

Returns:

  • (DateTime)


95
96
97
# File 'lib/oci/mysql/models/db_system_summary.rb', line 95

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/oci/mysql/models/db_system_summary.rb', line 110

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'display_name': :'displayName',
    'description': :'description',
    'compartment_id': :'compartmentId',
    'is_highly_available': :'isHighlyAvailable',
    'current_placement': :'currentPlacement',
    'is_analytics_cluster_attached': :'isAnalyticsClusterAttached',
    'analytics_cluster': :'analyticsCluster',
    'is_heat_wave_cluster_attached': :'isHeatWaveClusterAttached',
    'heat_wave_cluster': :'heatWaveCluster',
    'availability_domain': :'availabilityDomain',
    'fault_domain': :'faultDomain',
    'endpoints': :'endpoints',
    'lifecycle_state': :'lifecycleState',
    'mysql_version': :'mysqlVersion',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/oci/mysql/models/db_system_summary.rb', line 137

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'display_name': :'String',
    'description': :'String',
    'compartment_id': :'String',
    'is_highly_available': :'BOOLEAN',
    'current_placement': :'OCI::Mysql::Models::DbSystemPlacement',
    'is_analytics_cluster_attached': :'BOOLEAN',
    'analytics_cluster': :'OCI::Mysql::Models::AnalyticsClusterSummary',
    'is_heat_wave_cluster_attached': :'BOOLEAN',
    'heat_wave_cluster': :'OCI::Mysql::Models::HeatWaveClusterSummary',
    'availability_domain': :'String',
    'fault_domain': :'String',
    'endpoints': :'Array<OCI::Mysql::Models::DbSystemEndpoint>',
    'lifecycle_state': :'String',
    'mysql_version': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/oci/mysql/models/db_system_summary.rb', line 310

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    display_name == other.display_name &&
    description == other.description &&
    compartment_id == other.compartment_id &&
    is_highly_available == other.is_highly_available &&
    current_placement == other.current_placement &&
    is_analytics_cluster_attached == other.is_analytics_cluster_attached &&
    analytics_cluster == other.analytics_cluster &&
    is_heat_wave_cluster_attached == other.is_heat_wave_cluster_attached &&
    heat_wave_cluster == other.heat_wave_cluster &&
    availability_domain == other.availability_domain &&
    fault_domain == other.fault_domain &&
    endpoints == other.endpoints &&
    lifecycle_state == other.lifecycle_state &&
    mysql_version == other.mysql_version &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/oci/mysql/models/db_system_summary.rb', line 358

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


338
339
340
# File 'lib/oci/mysql/models/db_system_summary.rb', line 338

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



347
348
349
# File 'lib/oci/mysql/models/db_system_summary.rb', line 347

def hash
  [id, display_name, description, compartment_id, is_highly_available, current_placement, is_analytics_cluster_attached, analytics_cluster, is_heat_wave_cluster_attached, heat_wave_cluster, availability_domain, fault_domain, endpoints, lifecycle_state, mysql_version, time_created, time_updated, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



391
392
393
394
395
396
397
398
399
400
# File 'lib/oci/mysql/models/db_system_summary.rb', line 391

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



385
386
387
# File 'lib/oci/mysql/models/db_system_summary.rb', line 385

def to_s
  to_hash.to_s
end