Class: OCI::NetworkFirewall::Models::NetworkFirewallPolicy
- Inherits:
-
Object
- Object
- OCI::NetworkFirewall::Models::NetworkFirewallPolicy
- Defined in:
- lib/oci/network_firewall/models/network_firewall_policy.rb
Overview
Description of NetworkFirewall Policy.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#application_lists ⇒ Hash<String, Array<OCI::NetworkFirewall::Models::Application>>
Map defining application lists of the policy.
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the NetworkFirewall Policy.
-
#decryption_profiles ⇒ Hash<String, OCI::NetworkFirewall::Models::DecryptionProfile>
Map defining decryption profiles of the policy.
-
#decryption_rules ⇒ Array<OCI::NetworkFirewall::Models::DecryptionRule>
List of Decryption Rules defining the behavior of the policy.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** A user-friendly optional name for the firewall policy.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource - Network Firewall Policy.
-
#ip_address_lists ⇒ Hash<String, Array<String>>
Map defining IP address lists of the policy.
-
#is_firewall_attached ⇒ BOOLEAN
**[Required]** To determine if any Network Firewall is associated with this Network Firewall Policy.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the Network Firewall Policy.
-
#mapped_secrets ⇒ Hash<String, OCI::NetworkFirewall::Models::MappedSecret>
Map defining secrets of the policy.
-
#security_rules ⇒ Array<OCI::NetworkFirewall::Models::SecurityRule>
List of Security Rules defining the behavior of the policy.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The time instant at which the Network Firewall Policy was created in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
**[Required]** The time instant at which the Network Firewall Policy was updated in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#url_lists ⇒ Hash<String, Array<OCI::NetworkFirewall::Models::UrlPattern>>
Map defining URL pattern lists of the policy.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkFirewallPolicy
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NetworkFirewallPolicy
Initializes the object
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 199 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.mapped_secrets = attributes[:'mappedSecrets'] if attributes[:'mappedSecrets'] raise 'You cannot provide both :mappedSecrets and :mapped_secrets' if attributes.key?(:'mappedSecrets') && attributes.key?(:'mapped_secrets') self.mapped_secrets = attributes[:'mapped_secrets'] if attributes[:'mapped_secrets'] self.application_lists = attributes[:'applicationLists'] if attributes[:'applicationLists'] raise 'You cannot provide both :applicationLists and :application_lists' if attributes.key?(:'applicationLists') && attributes.key?(:'application_lists') self.application_lists = attributes[:'application_lists'] if attributes[:'application_lists'] self.url_lists = attributes[:'urlLists'] if attributes[:'urlLists'] raise 'You cannot provide both :urlLists and :url_lists' if attributes.key?(:'urlLists') && attributes.key?(:'url_lists') self.url_lists = attributes[:'url_lists'] if attributes[:'url_lists'] self.ip_address_lists = attributes[:'ipAddressLists'] if attributes[:'ipAddressLists'] raise 'You cannot provide both :ipAddressLists and :ip_address_lists' if attributes.key?(:'ipAddressLists') && attributes.key?(:'ip_address_lists') self.ip_address_lists = attributes[:'ip_address_lists'] if attributes[:'ip_address_lists'] self.security_rules = attributes[:'securityRules'] if attributes[:'securityRules'] raise 'You cannot provide both :securityRules and :security_rules' if attributes.key?(:'securityRules') && attributes.key?(:'security_rules') self.security_rules = attributes[:'security_rules'] if attributes[:'security_rules'] self.decryption_rules = attributes[:'decryptionRules'] if attributes[:'decryptionRules'] raise 'You cannot provide both :decryptionRules and :decryption_rules' if attributes.key?(:'decryptionRules') && attributes.key?(:'decryption_rules') self.decryption_rules = attributes[:'decryption_rules'] if attributes[:'decryption_rules'] self.decryption_profiles = attributes[:'decryptionProfiles'] if attributes[:'decryptionProfiles'] raise 'You cannot provide both :decryptionProfiles and :decryption_profiles' if attributes.key?(:'decryptionProfiles') && attributes.key?(:'decryption_profiles') self.decryption_profiles = attributes[:'decryption_profiles'] if attributes[:'decryption_profiles'] self.is_firewall_attached = attributes[:'isFirewallAttached'] unless attributes[:'isFirewallAttached'].nil? raise 'You cannot provide both :isFirewallAttached and :is_firewall_attached' if attributes.key?(:'isFirewallAttached') && attributes.key?(:'is_firewall_attached') self.is_firewall_attached = attributes[:'is_firewall_attached'] unless attributes[:'is_firewall_attached'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#application_lists ⇒ Hash<String, Array<OCI::NetworkFirewall::Models::Application>>
Map defining application lists of the policy. The value of an entry is a list of "applications", each consisting of a protocol identifier (such as TCP, UDP, or ICMP) and protocol-specific parameters (such as a port range). The associated key is the identifier by which the application list is referenced.
65 66 67 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 65 def application_lists @application_lists end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the NetworkFirewall Policy.
27 28 29 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 27 def compartment_id @compartment_id end |
#decryption_profiles ⇒ Hash<String, OCI::NetworkFirewall::Models::DecryptionProfile>
Map defining decryption profiles of the policy. The value of an entry is a decryption profile. The associated key is the identifier by which the decryption profile is referenced.
98 99 100 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 98 def decryption_profiles @decryption_profiles end |
#decryption_rules ⇒ Array<OCI::NetworkFirewall::Models::DecryptionRule>
List of Decryption Rules defining the behavior of the policy. The first rule with a matching condition determines the action taken upon network traffic.
91 92 93 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 91 def decryption_rules @decryption_rules end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
115 116 117 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 115 def @defined_tags end |
#display_name ⇒ String
**[Required]** A user-friendly optional name for the firewall policy. Avoid entering confidential information.
31 32 33 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 31 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
109 110 111 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 109 def @freeform_tags end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the resource - Network Firewall Policy.
23 24 25 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 23 def id @id end |
#ip_address_lists ⇒ Hash<String, Array<String>>
Map defining IP address lists of the policy. The value of an entry is a list of IP addresses or prefixes in CIDR notation. The associated key is the identifier by which the IP address list is referenced.
79 80 81 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 79 def ip_address_lists @ip_address_lists end |
#is_firewall_attached ⇒ BOOLEAN
**[Required]** To determine if any Network Firewall is associated with this Network Firewall Policy.
103 104 105 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 103 def is_firewall_attached @is_firewall_attached end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
51 52 53 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 51 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the Network Firewall Policy.
47 48 49 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 47 def lifecycle_state @lifecycle_state end |
#mapped_secrets ⇒ Hash<String, OCI::NetworkFirewall::Models::MappedSecret>
Map defining secrets of the policy. The value of an entry is a "mapped secret" consisting of a purpose and source. The associated key is the identifier by which the mapped secret is referenced.
58 59 60 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 58 def mapped_secrets @mapped_secrets end |
#security_rules ⇒ Array<OCI::NetworkFirewall::Models::SecurityRule>
List of Security Rules defining the behavior of the policy. The first rule with a matching condition determines the action taken upon network traffic.
85 86 87 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 85 def security_rules @security_rules end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
121 122 123 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 121 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The time instant at which the Network Firewall Policy was created in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2016-08-25T21:10:29.600Z`
37 38 39 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 37 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The time instant at which the Network Firewall Policy was updated in the format defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: `2016-08-25T21:10:29.600Z`
43 44 45 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 43 def time_updated @time_updated end |
#url_lists ⇒ Hash<String, Array<OCI::NetworkFirewall::Models::UrlPattern>>
Map defining URL pattern lists of the policy. The value of an entry is a list of URL patterns. The associated key is the identifier by which the URL pattern list is referenced.
72 73 74 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 72 def url_lists @url_lists end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 124 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'mapped_secrets': :'mappedSecrets', 'application_lists': :'applicationLists', 'url_lists': :'urlLists', 'ip_address_lists': :'ipAddressLists', 'security_rules': :'securityRules', 'decryption_rules': :'decryptionRules', 'decryption_profiles': :'decryptionProfiles', 'is_firewall_attached': :'isFirewallAttached', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 150 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'mapped_secrets': :'Hash<String, OCI::NetworkFirewall::Models::MappedSecret>', 'application_lists': :'Hash<String, Array<OCI::NetworkFirewall::Models::Application>>', 'url_lists': :'Hash<String, Array<OCI::NetworkFirewall::Models::UrlPattern>>', 'ip_address_lists': :'Hash<String, Array<String>>', 'security_rules': :'Array<OCI::NetworkFirewall::Models::SecurityRule>', 'decryption_rules': :'Array<OCI::NetworkFirewall::Models::DecryptionRule>', 'decryption_profiles': :'Hash<String, OCI::NetworkFirewall::Models::DecryptionProfile>', 'is_firewall_attached': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 330 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && mapped_secrets == other.mapped_secrets && application_lists == other.application_lists && url_lists == other.url_lists && ip_address_lists == other.ip_address_lists && security_rules == other.security_rules && decryption_rules == other.decryption_rules && decryption_profiles == other.decryption_profiles && is_firewall_attached == other.is_firewall_attached && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 377 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
357 358 359 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 357 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
366 367 368 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 366 def hash [id, compartment_id, display_name, time_created, time_updated, lifecycle_state, lifecycle_details, mapped_secrets, application_lists, url_lists, ip_address_lists, security_rules, decryption_rules, decryption_profiles, is_firewall_attached, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
410 411 412 413 414 415 416 417 418 419 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 410 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
404 405 406 |
# File 'lib/oci/network_firewall/models/network_firewall_policy.rb', line 404 def to_s to_hash.to_s end |