Class: OCI::NetworkFirewall::Models::UpdateNetworkFirewallPolicyDetails
- Inherits:
-
Object
- Object
- OCI::NetworkFirewall::Models::UpdateNetworkFirewallPolicyDetails
- Defined in:
- lib/oci/network_firewall/models/update_network_firewall_policy_details.rb
Overview
The request details to be updated in the firewall policy.
Instance Attribute Summary collapse
-
#application_lists ⇒ Hash<String, Array<OCI::NetworkFirewall::Models::Application>>
Map defining application lists of the policy.
-
#decryption_profiles ⇒ Hash<String, OCI::NetworkFirewall::Models::DecryptionProfile>
Map defining decryption profiles of the policy.
-
#decryption_rules ⇒ Array<OCI::NetworkFirewall::Models::DecryptionRule>
List of Decryption Rules defining the behavior of the policy.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name for the firewall.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#ip_address_lists ⇒ Hash<String, Array<String>>
Map defining IP address lists of the policy.
-
#mapped_secrets ⇒ Hash<String, OCI::NetworkFirewall::Models::MappedSecret>
Map defining secrets of the policy.
-
#security_rules ⇒ Array<OCI::NetworkFirewall::Models::SecurityRule>
List of Security Rules defining the behavior of the policy.
-
#url_lists ⇒ Hash<String, Array<OCI::NetworkFirewall::Models::UrlPattern>>
Map defining URL pattern lists of the policy.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateNetworkFirewallPolicyDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateNetworkFirewallPolicyDetails
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 125 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.mapped_secrets = attributes[:'mappedSecrets'] if attributes[:'mappedSecrets'] raise 'You cannot provide both :mappedSecrets and :mapped_secrets' if attributes.key?(:'mappedSecrets') && attributes.key?(:'mapped_secrets') self.mapped_secrets = attributes[:'mapped_secrets'] if attributes[:'mapped_secrets'] self.application_lists = attributes[:'applicationLists'] if attributes[:'applicationLists'] raise 'You cannot provide both :applicationLists and :application_lists' if attributes.key?(:'applicationLists') && attributes.key?(:'application_lists') self.application_lists = attributes[:'application_lists'] if attributes[:'application_lists'] self.url_lists = attributes[:'urlLists'] if attributes[:'urlLists'] raise 'You cannot provide both :urlLists and :url_lists' if attributes.key?(:'urlLists') && attributes.key?(:'url_lists') self.url_lists = attributes[:'url_lists'] if attributes[:'url_lists'] self.ip_address_lists = attributes[:'ipAddressLists'] if attributes[:'ipAddressLists'] raise 'You cannot provide both :ipAddressLists and :ip_address_lists' if attributes.key?(:'ipAddressLists') && attributes.key?(:'ip_address_lists') self.ip_address_lists = attributes[:'ip_address_lists'] if attributes[:'ip_address_lists'] self.security_rules = attributes[:'securityRules'] if attributes[:'securityRules'] raise 'You cannot provide both :securityRules and :security_rules' if attributes.key?(:'securityRules') && attributes.key?(:'security_rules') self.security_rules = attributes[:'security_rules'] if attributes[:'security_rules'] self.decryption_rules = attributes[:'decryptionRules'] if attributes[:'decryptionRules'] raise 'You cannot provide both :decryptionRules and :decryption_rules' if attributes.key?(:'decryptionRules') && attributes.key?(:'decryption_rules') self.decryption_rules = attributes[:'decryption_rules'] if attributes[:'decryption_rules'] self.decryption_profiles = attributes[:'decryptionProfiles'] if attributes[:'decryptionProfiles'] raise 'You cannot provide both :decryptionProfiles and :decryption_profiles' if attributes.key?(:'decryptionProfiles') && attributes.key?(:'decryption_profiles') self.decryption_profiles = attributes[:'decryption_profiles'] if attributes[:'decryption_profiles'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#application_lists ⇒ Hash<String, Array<OCI::NetworkFirewall::Models::Application>>
Map defining application lists of the policy. The value of an entry is a list of "applications", each consisting of a protocol identifier (such as TCP, UDP, or ICMP) and protocol-specific parameters (such as a port range). The associated key is the identifier by which the application list is referenced.
26 27 28 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 26 def application_lists @application_lists end |
#decryption_profiles ⇒ Hash<String, OCI::NetworkFirewall::Models::DecryptionProfile>
Map defining decryption profiles of the policy. The value of an entry is a decryption profile. The associated key is the identifier by which the decryption profile is referenced.
59 60 61 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 59 def decryption_profiles @decryption_profiles end |
#decryption_rules ⇒ Array<OCI::NetworkFirewall::Models::DecryptionRule>
List of Decryption Rules defining the behavior of the policy. The first rule with a matching condition determines the action taken upon network traffic.
52 53 54 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 52 def decryption_rules @decryption_rules end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
71 72 73 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 71 def @defined_tags end |
#display_name ⇒ String
A user-friendly name for the firewall. Does not have to be unique, and it's changeable. Avoid entering confidential information.
12 13 14 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 12 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
65 66 67 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 65 def @freeform_tags end |
#ip_address_lists ⇒ Hash<String, Array<String>>
Map defining IP address lists of the policy. The value of an entry is a list of IP addresses or prefixes in CIDR notation. The associated key is the identifier by which the IP address list is referenced.
40 41 42 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 40 def ip_address_lists @ip_address_lists end |
#mapped_secrets ⇒ Hash<String, OCI::NetworkFirewall::Models::MappedSecret>
Map defining secrets of the policy. The value of an entry is a "mapped secret" consisting of a purpose and source. The associated key is the identifier by which the mapped secret is referenced.
19 20 21 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 19 def mapped_secrets @mapped_secrets end |
#security_rules ⇒ Array<OCI::NetworkFirewall::Models::SecurityRule>
List of Security Rules defining the behavior of the policy. The first rule with a matching condition determines the action taken upon network traffic.
46 47 48 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 46 def security_rules @security_rules end |
#url_lists ⇒ Hash<String, Array<OCI::NetworkFirewall::Models::UrlPattern>>
Map defining URL pattern lists of the policy. The value of an entry is a list of URL patterns. The associated key is the identifier by which the URL pattern list is referenced.
33 34 35 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 33 def url_lists @url_lists end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 74 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'mapped_secrets': :'mappedSecrets', 'application_lists': :'applicationLists', 'url_lists': :'urlLists', 'ip_address_lists': :'ipAddressLists', 'security_rules': :'securityRules', 'decryption_rules': :'decryptionRules', 'decryption_profiles': :'decryptionProfiles', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 92 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'mapped_secrets': :'Hash<String, OCI::NetworkFirewall::Models::MappedSecret>', 'application_lists': :'Hash<String, Array<OCI::NetworkFirewall::Models::Application>>', 'url_lists': :'Hash<String, Array<OCI::NetworkFirewall::Models::UrlPattern>>', 'ip_address_lists': :'Hash<String, Array<String>>', 'security_rules': :'Array<OCI::NetworkFirewall::Models::SecurityRule>', 'decryption_rules': :'Array<OCI::NetworkFirewall::Models::DecryptionRule>', 'decryption_profiles': :'Hash<String, OCI::NetworkFirewall::Models::DecryptionProfile>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 199 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && mapped_secrets == other.mapped_secrets && application_lists == other.application_lists && url_lists == other.url_lists && ip_address_lists == other.ip_address_lists && security_rules == other.security_rules && decryption_rules == other.decryption_rules && decryption_profiles == other.decryption_profiles && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 238 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
218 219 220 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 218 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
227 228 229 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 227 def hash [display_name, mapped_secrets, application_lists, url_lists, ip_address_lists, security_rules, decryption_rules, decryption_profiles, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
265 266 267 |
# File 'lib/oci/network_firewall/models/update_network_firewall_policy_details.rb', line 265 def to_s to_hash.to_s end |