Class: OCI::NetworkLoadBalancer::Models::BackendSetSummary
- Inherits:
-
Object
- Object
- OCI::NetworkLoadBalancer::Models::BackendSetSummary
- Defined in:
- lib/oci/network_load_balancer/models/backend_set_summary.rb
Overview
The configuration of a network load balancer backend set. For more information about backend set configuration, see [Managing Backend Sets](docs.cloud.oracle.com/Content/Balance/Tasks/managingbackendsets.htm).
Caution: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- POLICY_ENUM =
[ POLICY_TWO_TUPLE = 'TWO_TUPLE'.freeze, POLICY_THREE_TUPLE = 'THREE_TUPLE'.freeze, POLICY_FIVE_TUPLE = 'FIVE_TUPLE'.freeze, POLICY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#backends ⇒ Array<OCI::NetworkLoadBalancer::Models::Backend>
[Required] An array of backends.
-
#health_checker ⇒ OCI::NetworkLoadBalancer::Models::HealthChecker
This attribute is required.
-
#is_preserve_source ⇒ BOOLEAN
If this parameter is enabled, then the network load balancer preserves the source IP of the packet when it is forwarded to backends.
-
#name ⇒ String
[Required] A user-friendly name for the backend set that must be unique and cannot be changed.
-
#policy ⇒ String
[Required] The network load balancer policy for the backend set.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BackendSetSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BackendSetSummary
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 93 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.policy = attributes[:'policy'] if attributes[:'policy'] self.policy = "FIVE_TUPLE" if policy.nil? && !attributes.key?(:'policy') # rubocop:disable Style/StringLiterals self.is_preserve_source = attributes[:'isPreserveSource'] unless attributes[:'isPreserveSource'].nil? self.is_preserve_source = true if is_preserve_source.nil? && !attributes.key?(:'isPreserveSource') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPreserveSource and :is_preserve_source' if attributes.key?(:'isPreserveSource') && attributes.key?(:'is_preserve_source') self.is_preserve_source = attributes[:'is_preserve_source'] unless attributes[:'is_preserve_source'].nil? self.is_preserve_source = true if is_preserve_source.nil? && !attributes.key?(:'isPreserveSource') && !attributes.key?(:'is_preserve_source') # rubocop:disable Style/StringLiterals self.backends = attributes[:'backends'] if attributes[:'backends'] self.health_checker = attributes[:'healthChecker'] if attributes[:'healthChecker'] raise 'You cannot provide both :healthChecker and :health_checker' if attributes.key?(:'healthChecker') && attributes.key?(:'health_checker') self.health_checker = attributes[:'health_checker'] if attributes[:'health_checker'] end |
Instance Attribute Details
#backends ⇒ Array<OCI::NetworkLoadBalancer::Models::Backend>
[Required] An array of backends.
50 51 52 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 50 def backends @backends end |
#health_checker ⇒ OCI::NetworkLoadBalancer::Models::HealthChecker
This attribute is required.
54 55 56 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 54 def health_checker @health_checker end |
#is_preserve_source ⇒ BOOLEAN
If this parameter is enabled, then the network load balancer preserves the source IP of the packet when it is forwarded to backends. Backends see the original source IP. If the isPreserveSourceDestination parameter is enabled for the network load balancer resource, then this parameter cannot be disabled. The value is true by default.
45 46 47 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 45 def is_preserve_source @is_preserve_source end |
#name ⇒ String
[Required] A user-friendly name for the backend set that must be unique and cannot be changed.
Valid backend set names include only alphanumeric characters, dashes, and underscores. Backend set names cannot contain spaces. Avoid entering confidential information.
Example: example_backend_set
31 32 33 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 31 def name @name end |
#policy ⇒ String
[Required] The network load balancer policy for the backend set.
Example: FIVE_TUPLE
38 39 40 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 38 def policy @policy end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'policy': :'policy', 'is_preserve_source': :'isPreserveSource', 'backends': :'backends', 'health_checker': :'healthChecker' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 70 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'policy': :'String', 'is_preserve_source': :'BOOLEAN', 'backends': :'Array<OCI::NetworkLoadBalancer::Models::Backend>', 'health_checker': :'OCI::NetworkLoadBalancer::Models::HealthChecker' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 141 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && policy == other.policy && is_preserve_source == other.is_preserve_source && backends == other.backends && health_checker == other.health_checker end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 175 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
155 156 157 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 155 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 164 def hash [name, policy, is_preserve_source, backends, health_checker].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
202 203 204 |
# File 'lib/oci/network_load_balancer/models/backend_set_summary.rb', line 202 def to_s to_hash.to_s end |