Class: OCI::NetworkLoadBalancer::Models::CreateBackendSetDetails
- Inherits:
-
Object
- Object
- OCI::NetworkLoadBalancer::Models::CreateBackendSetDetails
- Defined in:
- lib/oci/network_load_balancer/models/create_backend_set_details.rb
Overview
The configuration details for creating a backend set in a network load balancer. For more information about backend set configuration, see [Managing Backend Sets](docs.cloud.oracle.com/Content/Balance/Tasks/managingbackendsets.htm).
Caution: Oracle recommends that you avoid using any confidential information when you supply string values using the API.
Constant Summary collapse
- POLICY_ENUM =
[ POLICY_TWO_TUPLE = 'TWO_TUPLE'.freeze, POLICY_THREE_TUPLE = 'THREE_TUPLE'.freeze, POLICY_FIVE_TUPLE = 'FIVE_TUPLE'.freeze ].freeze
Instance Attribute Summary collapse
-
#backends ⇒ Array<OCI::NetworkLoadBalancer::Models::BackendDetails>
An array of backends to be associated with the backend set.
-
#health_checker ⇒ OCI::NetworkLoadBalancer::Models::HealthCheckerDetails
This attribute is required.
-
#is_preserve_source ⇒ BOOLEAN
If this parameter is enabled, then the network load balancer preserves the source IP of the packet when it is forwarded to backends.
-
#name ⇒ String
[Required] A user-friendly name for the backend set that must be unique and cannot be changed.
-
#policy ⇒ String
[Required] The network load balancer policy for the backend set.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBackendSetDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateBackendSetDetails
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.policy = attributes[:'policy'] if attributes[:'policy'] self.policy = "FIVE_TUPLE" if policy.nil? && !attributes.key?(:'policy') # rubocop:disable Style/StringLiterals self.is_preserve_source = attributes[:'isPreserveSource'] unless attributes[:'isPreserveSource'].nil? self.is_preserve_source = true if is_preserve_source.nil? && !attributes.key?(:'isPreserveSource') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPreserveSource and :is_preserve_source' if attributes.key?(:'isPreserveSource') && attributes.key?(:'is_preserve_source') self.is_preserve_source = attributes[:'is_preserve_source'] unless attributes[:'is_preserve_source'].nil? self.is_preserve_source = true if is_preserve_source.nil? && !attributes.key?(:'isPreserveSource') && !attributes.key?(:'is_preserve_source') # rubocop:disable Style/StringLiterals self.backends = attributes[:'backends'] if attributes[:'backends'] self.health_checker = attributes[:'healthChecker'] if attributes[:'healthChecker'] raise 'You cannot provide both :healthChecker and :health_checker' if attributes.key?(:'healthChecker') && attributes.key?(:'health_checker') self.health_checker = attributes[:'health_checker'] if attributes[:'health_checker'] end |
Instance Attribute Details
#backends ⇒ Array<OCI::NetworkLoadBalancer::Models::BackendDetails>
An array of backends to be associated with the backend set.
47 48 49 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 47 def backends @backends end |
#health_checker ⇒ OCI::NetworkLoadBalancer::Models::HealthCheckerDetails
This attribute is required.
51 52 53 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 51 def health_checker @health_checker end |
#is_preserve_source ⇒ BOOLEAN
If this parameter is enabled, then the network load balancer preserves the source IP of the packet when it is forwarded to backends. Backends see the original source IP. If the isPreserveSourceDestination parameter is enabled for the network load balancer resource, then this parameter cannot be disabled. The value is true by default.
43 44 45 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 43 def is_preserve_source @is_preserve_source end |
#name ⇒ String
[Required] A user-friendly name for the backend set that must be unique and cannot be changed.
Valid backend set names include only alphanumeric characters, dashes, and underscores. Backend set names cannot contain spaces. Avoid entering confidential information.
Example: example_backend_set
29 30 31 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 29 def name @name end |
#policy ⇒ String
[Required] The network load balancer policy for the backend set.
Example: FIVE_TUPLE`
36 37 38 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 36 def policy @policy end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 54 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'policy': :'policy', 'is_preserve_source': :'isPreserveSource', 'backends': :'backends', 'health_checker': :'healthChecker' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 67 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'policy': :'String', 'is_preserve_source': :'BOOLEAN', 'backends': :'Array<OCI::NetworkLoadBalancer::Models::BackendDetails>', 'health_checker': :'OCI::NetworkLoadBalancer::Models::HealthCheckerDetails' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 133 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && policy == other.policy && is_preserve_source == other.is_preserve_source && backends == other.backends && health_checker == other.health_checker end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 167 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
147 148 149 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 147 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 156 def hash [name, policy, is_preserve_source, backends, health_checker].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
194 195 196 |
# File 'lib/oci/network_load_balancer/models/create_backend_set_details.rb', line 194 def to_s to_hash.to_s end |