Class: OCI::NetworkLoadBalancer::Models::CreateNetworkLoadBalancerDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb

Overview

The properties that define a network load balancer. For more information, see [Managing a network load balancer](docs.cloud.oracle.com/Content/Balance/Tasks/managingloadbalancer.htm).

To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, then contact an administrator. If you are an administrator who writes policies to give users access, then see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).

For information about endpoints and signing API requests, see [About the API](docs.cloud.oracle.com/Content/API/Concepts/usingapi.htm). For information about available SDKs and tools, see [SDKS and Other Tools](docs.cloud.oracle.com/Content/API/Concepts/sdks.htm).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateNetworkLoadBalancerDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 152

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.display_name = attributes[:'displayName'] if attributes[:'displayName']

  raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

  self.display_name = attributes[:'display_name'] if attributes[:'display_name']

  self.is_preserve_source_destination = attributes[:'isPreserveSourceDestination'] unless attributes[:'isPreserveSourceDestination'].nil?
  self.is_preserve_source_destination = false if is_preserve_source_destination.nil? && !attributes.key?(:'isPreserveSourceDestination') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isPreserveSourceDestination and :is_preserve_source_destination' if attributes.key?(:'isPreserveSourceDestination') && attributes.key?(:'is_preserve_source_destination')

  self.is_preserve_source_destination = attributes[:'is_preserve_source_destination'] unless attributes[:'is_preserve_source_destination'].nil?
  self.is_preserve_source_destination = false if is_preserve_source_destination.nil? && !attributes.key?(:'isPreserveSourceDestination') && !attributes.key?(:'is_preserve_source_destination') # rubocop:disable Style/StringLiterals

  self.reserved_ips = attributes[:'reservedIps'] if attributes[:'reservedIps']

  raise 'You cannot provide both :reservedIps and :reserved_ips' if attributes.key?(:'reservedIps') && attributes.key?(:'reserved_ips')

  self.reserved_ips = attributes[:'reserved_ips'] if attributes[:'reserved_ips']

  self.is_private = attributes[:'isPrivate'] unless attributes[:'isPrivate'].nil?
  self.is_private = true if is_private.nil? && !attributes.key?(:'isPrivate') # rubocop:disable Style/StringLiterals

  raise 'You cannot provide both :isPrivate and :is_private' if attributes.key?(:'isPrivate') && attributes.key?(:'is_private')

  self.is_private = attributes[:'is_private'] unless attributes[:'is_private'].nil?
  self.is_private = true if is_private.nil? && !attributes.key?(:'isPrivate') && !attributes.key?(:'is_private') # rubocop:disable Style/StringLiterals

  self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId']

  raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id')

  self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id']

  self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds']

  raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids')

  self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids']

  self.listeners = attributes[:'listeners'] if attributes[:'listeners']

  self.backend_sets = attributes[:'backendSets'] if attributes[:'backendSets']

  raise 'You cannot provide both :backendSets and :backend_sets' if attributes.key?(:'backendSets') && attributes.key?(:'backend_sets')

  self.backend_sets = attributes[:'backend_sets'] if attributes[:'backend_sets']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#backend_setsHash<String, OCI::NetworkLoadBalancer::Models::BackendSetDetails>

Backend sets associated with the network load balancer.



83
84
85
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 83

def backend_sets
  @backend_sets
end

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the network load balancer.

Returns:

  • (String)


22
23
24
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 22

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


95
96
97
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 95

def defined_tags
  @defined_tags
end

#display_nameString

[Required] Network load balancer identifier, which can be renamed.

Returns:

  • (String)


26
27
28
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 26

def display_name
  @display_name
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


89
90
91
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 89

def freeform_tags
  @freeform_tags
end

#is_preserve_source_destinationBOOLEAN

This parameter can be enabled only if backends are compute OCIDs. When enabled, the skipSourceDestinationCheck parameter is automatically enabled on the load balancer VNIC, and packets are sent to the backend with the entire IP header intact.

Returns:

  • (BOOLEAN)


32
33
34
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 32

def is_preserve_source_destination
  @is_preserve_source_destination
end

#is_privateBOOLEAN

Whether the network load balancer has a virtual cloud network-local (private) IP address.

If "true", then the service assigns a private IP address to the network load balancer.

If "false", then the service assigns a public IP address to the network load balancer.

A public network load balancer is accessible from the internet, depending on the [security list rules](docs.cloud.oracle.com/Content/network/Concepts/securitylists.htm) for your virtual cloud network. For more information about public and private network load balancers, see [How Network Load Balancing Works](docs.cloud.oracle.com/Content/Balance/Concepts/balanceoverview.htm#how-network-load-balancing-works). This value is true by default.

Example: true

Returns:

  • (BOOLEAN)


54
55
56
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 54

def is_private
  @is_private
end

#listenersHash<String, OCI::NetworkLoadBalancer::Models::ListenerDetails>

Listeners associated with the network load balancer.



79
80
81
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 79

def listeners
  @listeners
end

#network_security_group_idsArray<String>

An array of network security groups [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) associated with the network load balancer.

During the creation of the network load balancer, the service adds the new load balancer to the specified network security groups.

The benefits of associating the network load balancer with network security groups include:

  • Network security groups define network security rules to govern ingress and egress traffic for the network load balancer.

  • The network security rules of other resources can reference the network security groups associated with the network load balancer to ensure access.

Example: ["ocid1.nsg.oc1.phx.unique_ID"]

Returns:

  • (Array<String>)


75
76
77
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 75

def network_security_group_ids
  @network_security_group_ids
end

#reserved_ipsArray<OCI::NetworkLoadBalancer::Models::ReservedIP>

An array of reserved Ips.

Returns:

  • (Array<OCI::NetworkLoadBalancer::Models::ReservedIP>)


37
38
39
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 37

def reserved_ips
  @reserved_ips
end

#subnet_idString

[Required] The subnet in which the network load balancer is spawned [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).

Returns:

  • (String)


58
59
60
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 58

def subnet_id
  @subnet_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 98

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'compartmentId',
    'display_name': :'displayName',
    'is_preserve_source_destination': :'isPreserveSourceDestination',
    'reserved_ips': :'reservedIps',
    'is_private': :'isPrivate',
    'subnet_id': :'subnetId',
    'network_security_group_ids': :'networkSecurityGroupIds',
    'listeners': :'listeners',
    'backend_sets': :'backendSets',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 117

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'compartment_id': :'String',
    'display_name': :'String',
    'is_preserve_source_destination': :'BOOLEAN',
    'reserved_ips': :'Array<OCI::NetworkLoadBalancer::Models::ReservedIP>',
    'is_private': :'BOOLEAN',
    'subnet_id': :'String',
    'network_security_group_ids': :'Array<String>',
    'listeners': :'Hash<String, OCI::NetworkLoadBalancer::Models::ListenerDetails>',
    'backend_sets': :'Hash<String, OCI::NetworkLoadBalancer::Models::BackendSetDetails>',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 232

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    compartment_id == other.compartment_id &&
    display_name == other.display_name &&
    is_preserve_source_destination == other.is_preserve_source_destination &&
    reserved_ips == other.reserved_ips &&
    is_private == other.is_private &&
    subnet_id == other.subnet_id &&
    network_security_group_ids == other.network_security_group_ids &&
    listeners == other.listeners &&
    backend_sets == other.backend_sets &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 272

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


252
253
254
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 252

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



261
262
263
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 261

def hash
  [compartment_id, display_name, is_preserve_source_destination, reserved_ips, is_private, subnet_id, network_security_group_ids, listeners, backend_sets, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
314
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



299
300
301
# File 'lib/oci/network_load_balancer/models/create_network_load_balancer_details.rb', line 299

def to_s
  to_hash.to_s
end