Class: OCI::NetworkLoadBalancer::Models::NetworkLoadBalancerSummary
- Inherits:
-
Object
- Object
- OCI::NetworkLoadBalancer::Models::NetworkLoadBalancerSummary
- Defined in:
- lib/oci/network_load_balancer/models/network_load_balancer_summary.rb
Overview
Network load balancer object to be used for list operations.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#backend_sets ⇒ Hash<String, OCI::NetworkLoadBalancer::Models::BackendSet>
Backend sets associated with the network load balancer.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the network load balancer.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-friendly name, which does not have to be unique, and can be changed.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network load balancer.
-
#ip_addresses ⇒ Array<OCI::NetworkLoadBalancer::Models::IpAddress>
[Required] An array of IP addresses.
-
#is_preserve_source_destination ⇒ BOOLEAN
When enabled, the skipSourceDestinationCheck parameter is automatically enabled on the load balancer VNIC.
-
#is_private ⇒ BOOLEAN
Whether the network load balancer has a virtual cloud network-local (private) IP address.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
[Required] The current state of the network load balancer.
-
#listeners ⇒ Hash<String, OCI::NetworkLoadBalancer::Models::Listener>
Listeners associated with the network load balancer.
-
#network_security_group_ids ⇒ Array<String>
An array of network security groups [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) associated with the network load balancer.
-
#subnet_id ⇒ String
[Required] The subnet in which the network load balancer is spawned [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).".
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Key-value pair representing system tags’ keys and values scoped to a namespace.
-
#time_created ⇒ DateTime
[Required] The date and time the network load balancer was created, in the format defined by RFC3339.
-
#time_updated ⇒ DateTime
The time the network load balancer was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NetworkLoadBalancerSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ NetworkLoadBalancerSummary
Initializes the object
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 212 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.ip_addresses = attributes[:'ipAddresses'] if attributes[:'ipAddresses'] raise 'You cannot provide both :ipAddresses and :ip_addresses' if attributes.key?(:'ipAddresses') && attributes.key?(:'ip_addresses') self.ip_addresses = attributes[:'ip_addresses'] if attributes[:'ip_addresses'] self.is_private = attributes[:'isPrivate'] unless attributes[:'isPrivate'].nil? self.is_private = true if is_private.nil? && !attributes.key?(:'isPrivate') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPrivate and :is_private' if attributes.key?(:'isPrivate') && attributes.key?(:'is_private') self.is_private = attributes[:'is_private'] unless attributes[:'is_private'].nil? self.is_private = true if is_private.nil? && !attributes.key?(:'isPrivate') && !attributes.key?(:'is_private') # rubocop:disable Style/StringLiterals self.is_preserve_source_destination = attributes[:'isPreserveSourceDestination'] unless attributes[:'isPreserveSourceDestination'].nil? self.is_preserve_source_destination = false if is_preserve_source_destination.nil? && !attributes.key?(:'isPreserveSourceDestination') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPreserveSourceDestination and :is_preserve_source_destination' if attributes.key?(:'isPreserveSourceDestination') && attributes.key?(:'is_preserve_source_destination') self.is_preserve_source_destination = attributes[:'is_preserve_source_destination'] unless attributes[:'is_preserve_source_destination'].nil? self.is_preserve_source_destination = false if is_preserve_source_destination.nil? && !attributes.key?(:'isPreserveSourceDestination') && !attributes.key?(:'is_preserve_source_destination') # rubocop:disable Style/StringLiterals self.subnet_id = attributes[:'subnetId'] if attributes[:'subnetId'] raise 'You cannot provide both :subnetId and :subnet_id' if attributes.key?(:'subnetId') && attributes.key?(:'subnet_id') self.subnet_id = attributes[:'subnet_id'] if attributes[:'subnet_id'] self.network_security_group_ids = attributes[:'networkSecurityGroupIds'] if attributes[:'networkSecurityGroupIds'] raise 'You cannot provide both :networkSecurityGroupIds and :network_security_group_ids' if attributes.key?(:'networkSecurityGroupIds') && attributes.key?(:'network_security_group_ids') self.network_security_group_ids = attributes[:'network_security_group_ids'] if attributes[:'network_security_group_ids'] self.listeners = attributes[:'listeners'] if attributes[:'listeners'] self.backend_sets = attributes[:'backendSets'] if attributes[:'backendSets'] raise 'You cannot provide both :backendSets and :backend_sets' if attributes.key?(:'backendSets') && attributes.key?(:'backend_sets') self.backend_sets = attributes[:'backend_sets'] if attributes[:'backend_sets'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#backend_sets ⇒ Hash<String, OCI::NetworkLoadBalancer::Models::BackendSet>
Backend sets associated with the network load balancer.
115 116 117 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 115 def backend_sets @backend_sets end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment containing the network load balancer.
27 28 29 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 27 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘{"CostCenter": "42"}`
131 132 133 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 131 def end |
#display_name ⇒ String
[Required] A user-friendly name, which does not have to be unique, and can be changed.
Example: example_load_balancer
34 35 36 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 34 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: ‘"Finance"`
123 124 125 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 123 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the network load balancer.
23 24 25 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 23 def id @id end |
#ip_addresses ⇒ Array<OCI::NetworkLoadBalancer::Models::IpAddress>
[Required] An array of IP addresses.
63 64 65 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 63 def ip_addresses @ip_addresses end |
#is_preserve_source_destination ⇒ BOOLEAN
When enabled, the skipSourceDestinationCheck parameter is automatically enabled on the load balancer VNIC. Packets are sent to the backend set without any changes to the source and destination IP.
86 87 88 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 86 def is_preserve_source_destination @is_preserve_source_destination end |
#is_private ⇒ BOOLEAN
Whether the network load balancer has a virtual cloud network-local (private) IP address.
If "true", then the service assigns a private IP address to the network load balancer.
If "false", then the service assigns a public IP address to the network load balancer.
A public network load balancer is accessible from the internet, depending the [security list rules](docs.cloud.oracle.com/Content/network/Concepts/securitylists.htm) for your virtual cloudn network. For more information about public and private network load balancers, see [How Network Load Balancing Works](docs.cloud.oracle.com/Content/Balance/Concepts/balanceoverview.htm#how-network-load-balancing-works). This value is true by default.
Example: true
80 81 82 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 80 def is_private @is_private end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
44 45 46 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 44 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the network load balancer.
38 39 40 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 38 def lifecycle_state @lifecycle_state end |
#listeners ⇒ Hash<String, OCI::NetworkLoadBalancer::Models::Listener>
Listeners associated with the network load balancer.
111 112 113 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 111 def listeners @listeners end |
#network_security_group_ids ⇒ Array<String>
An array of network security groups [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) associated with the network load balancer.
During the creation of the network load balancer, the service adds the new load balancer to the specified network security groups.
The benefits of associating the network load balancer with network security groups include:
-
Network security groups define network security rules to govern ingress and egress traffic for the network load balancer.
-
The network security rules of other resources can reference the network security groups associated with the network load balancer to ensure access.
Example: ["ocid1.nsg.oc1.phx.unique_ID"]
107 108 109 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 107 def network_security_group_ids @network_security_group_ids end |
#subnet_id ⇒ String
[Required] The subnet in which the network load balancer is spawned [OCIDs](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)."
90 91 92 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 90 def subnet_id @subnet_id end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Key-value pair representing system tags’ keys and values scoped to a namespace. Example: ‘"value"`
137 138 139 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 137 def end |
#time_created ⇒ DateTime
[Required] The date and time the network load balancer was created, in the format defined by RFC3339.
Example: 2020-05-01T21:10:29.600Z
51 52 53 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 51 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the network load balancer was updated. An RFC3339 formatted date-time string.
Example: 2020-05-01T22:10:29.600Z
58 59 60 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 58 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 140 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'ip_addresses': :'ipAddresses', 'is_private': :'isPrivate', 'is_preserve_source_destination': :'isPreserveSourceDestination', 'subnet_id': :'subnetId', 'network_security_group_ids': :'networkSecurityGroupIds', 'listeners': :'listeners', 'backend_sets': :'backendSets', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 165 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'ip_addresses': :'Array<OCI::NetworkLoadBalancer::Models::IpAddress>', 'is_private': :'BOOLEAN', 'is_preserve_source_destination': :'BOOLEAN', 'subnet_id': :'String', 'network_security_group_ids': :'Array<String>', 'listeners': :'Hash<String, OCI::NetworkLoadBalancer::Models::Listener>', 'backend_sets': :'Hash<String, OCI::NetworkLoadBalancer::Models::BackendSet>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 337 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && time_created == other.time_created && time_updated == other.time_updated && ip_addresses == other.ip_addresses && is_private == other.is_private && is_preserve_source_destination == other.is_preserve_source_destination && subnet_id == other.subnet_id && network_security_group_ids == other.network_security_group_ids && listeners == other.listeners && backend_sets == other.backend_sets && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 383 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
363 364 365 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 363 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
372 373 374 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 372 def hash [id, compartment_id, display_name, lifecycle_state, lifecycle_details, time_created, time_updated, ip_addresses, is_private, is_preserve_source_destination, subnet_id, network_security_group_ids, listeners, backend_sets, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
416 417 418 419 420 421 422 423 424 425 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 416 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
410 411 412 |
# File 'lib/oci/network_load_balancer/models/network_load_balancer_summary.rb', line 410 def to_s to_hash.to_s end |