Class: OCI::Nosql::Models::Table
- Inherits:
-
Object
- Object
- OCI::Nosql::Models::Table
- Defined in:
- lib/oci/nosql/models/table.rb
Overview
Complete metadata about a table.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment Identifier.
-
#ddl_statement ⇒ String
A DDL statement representing the schema.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Unique identifier that is immutable.
-
#is_auto_reclaimable ⇒ BOOLEAN
True if this table can be reclaimed after an idle period.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The state of a table.
-
#name ⇒ String
Human-friendly table name, immutable.
- #schema ⇒ OCI::Nosql::Models::Schema
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Read-only system tag.
- #table_limits ⇒ OCI::Nosql::Models::TableLimits
-
#time_created ⇒ DateTime
The time the the table was created.
-
#time_of_expiration ⇒ DateTime
If lifecycleState is INACTIVE, indicates when this table will be automatically removed.
-
#time_updated ⇒ DateTime
The time the the table’s metadata was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Table
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Table
Initializes the object
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/oci/nosql/models/table.rb', line 166 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.table_limits = attributes[:'tableLimits'] if attributes[:'tableLimits'] raise 'You cannot provide both :tableLimits and :table_limits' if attributes.key?(:'tableLimits') && attributes.key?(:'table_limits') self.table_limits = attributes[:'table_limits'] if attributes[:'table_limits'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.is_auto_reclaimable = attributes[:'isAutoReclaimable'] unless attributes[:'isAutoReclaimable'].nil? raise 'You cannot provide both :isAutoReclaimable and :is_auto_reclaimable' if attributes.key?(:'isAutoReclaimable') && attributes.key?(:'is_auto_reclaimable') self.is_auto_reclaimable = attributes[:'is_auto_reclaimable'] unless attributes[:'is_auto_reclaimable'].nil? self.time_of_expiration = attributes[:'timeOfExpiration'] if attributes[:'timeOfExpiration'] raise 'You cannot provide both :timeOfExpiration and :time_of_expiration' if attributes.key?(:'timeOfExpiration') && attributes.key?(:'time_of_expiration') self.time_of_expiration = attributes[:'time_of_expiration'] if attributes[:'time_of_expiration'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self.schema = attributes[:'schema'] if attributes[:'schema'] self.ddl_statement = attributes[:'ddlStatement'] if attributes[:'ddlStatement'] raise 'You cannot provide both :ddlStatement and :ddl_statement' if attributes.key?(:'ddlStatement') && attributes.key?(:'ddl_statement') self.ddl_statement = attributes[:'ddl_statement'] if attributes[:'ddl_statement'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment Identifier.
32 33 34 |
# File 'lib/oci/nosql/models/table.rb', line 32 def compartment_id @compartment_id end |
#ddl_statement ⇒ String
A DDL statement representing the schema.
74 75 76 |
# File 'lib/oci/nosql/models/table.rb', line 74 def ddl_statement @ddl_statement end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
88 89 90 |
# File 'lib/oci/nosql/models/table.rb', line 88 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
81 82 83 |
# File 'lib/oci/nosql/models/table.rb', line 81 def end |
#id ⇒ String
[Required] Unique identifier that is immutable.
24 25 26 |
# File 'lib/oci/nosql/models/table.rb', line 24 def id @id end |
#is_auto_reclaimable ⇒ BOOLEAN
True if this table can be reclaimed after an idle period.
55 56 57 |
# File 'lib/oci/nosql/models/table.rb', line 55 def is_auto_reclaimable @is_auto_reclaimable end |
#lifecycle_details ⇒ String
A message describing the current state in more detail.
67 68 69 |
# File 'lib/oci/nosql/models/table.rb', line 67 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The state of a table.
51 52 53 |
# File 'lib/oci/nosql/models/table.rb', line 51 def lifecycle_state @lifecycle_state end |
#name ⇒ String
Human-friendly table name, immutable.
28 29 30 |
# File 'lib/oci/nosql/models/table.rb', line 28 def name @name end |
#schema ⇒ OCI::Nosql::Models::Schema
70 71 72 |
# File 'lib/oci/nosql/models/table.rb', line 70 def schema @schema end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Read-only system tag. These predefined keys are scoped to namespaces. At present the only supported namespace is ‘"orcl-cloud"`; and the only key in that namespace is `"free-tier-retained"`. Example: `{"free-tier-retained": "true"}`
97 98 99 |
# File 'lib/oci/nosql/models/table.rb', line 97 def end |
#table_limits ⇒ OCI::Nosql::Models::TableLimits
47 48 49 |
# File 'lib/oci/nosql/models/table.rb', line 47 def table_limits @table_limits end |
#time_created ⇒ DateTime
The time the the table was created. An RFC3339 formatted datetime string.
38 39 40 |
# File 'lib/oci/nosql/models/table.rb', line 38 def time_created @time_created end |
#time_of_expiration ⇒ DateTime
If lifecycleState is INACTIVE, indicates when this table will be automatically removed. An RFC3339 formatted datetime string.
62 63 64 |
# File 'lib/oci/nosql/models/table.rb', line 62 def time_of_expiration @time_of_expiration end |
#time_updated ⇒ DateTime
The time the the table’s metadata was last updated. An RFC3339 formatted datetime string.
44 45 46 |
# File 'lib/oci/nosql/models/table.rb', line 44 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/nosql/models/table.rb', line 100 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'table_limits': :'tableLimits', 'lifecycle_state': :'lifecycleState', 'is_auto_reclaimable': :'isAutoReclaimable', 'time_of_expiration': :'timeOfExpiration', 'lifecycle_details': :'lifecycleDetails', 'schema': :'schema', 'ddl_statement': :'ddlStatement', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/nosql/models/table.rb', line 123 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'table_limits': :'OCI::Nosql::Models::TableLimits', 'lifecycle_state': :'String', 'is_auto_reclaimable': :'BOOLEAN', 'time_of_expiration': :'DateTime', 'lifecycle_details': :'String', 'schema': :'OCI::Nosql::Models::Schema', 'ddl_statement': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/oci/nosql/models/table.rb', line 271 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && table_limits == other.table_limits && lifecycle_state == other.lifecycle_state && is_auto_reclaimable == other.is_auto_reclaimable && time_of_expiration == other.time_of_expiration && lifecycle_details == other.lifecycle_details && schema == other.schema && ddl_statement == other.ddl_statement && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/oci/nosql/models/table.rb', line 315 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
295 296 297 |
# File 'lib/oci/nosql/models/table.rb', line 295 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
304 305 306 |
# File 'lib/oci/nosql/models/table.rb', line 304 def hash [id, name, compartment_id, time_created, time_updated, table_limits, lifecycle_state, is_auto_reclaimable, time_of_expiration, lifecycle_details, schema, ddl_statement, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 357 |
# File 'lib/oci/nosql/models/table.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
342 343 344 |
# File 'lib/oci/nosql/models/table.rb', line 342 def to_s to_hash.to_s end |