Class: OCI::ObjectStorage::Models::CreateBucketDetails
- Inherits:
-
Object
- Object
- OCI::ObjectStorage::Models::CreateBucketDetails
- Defined in:
- lib/oci/object_storage/models/create_bucket_details.rb
Overview
To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Constant Summary collapse
- PUBLIC_ACCESS_TYPE_ENUM =
[ PUBLIC_ACCESS_TYPE_NO_PUBLIC_ACCESS = 'NoPublicAccess'.freeze, PUBLIC_ACCESS_TYPE_OBJECT_READ = 'ObjectRead'.freeze, PUBLIC_ACCESS_TYPE_OBJECT_READ_WITHOUT_LIST = 'ObjectReadWithoutList'.freeze ].freeze
- STORAGE_TIER_ENUM =
[ STORAGE_TIER_STANDARD = 'Standard'.freeze, STORAGE_TIER_ARCHIVE = 'Archive'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The ID of the compartment in which to create the bucket.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource.
-
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of a master encryption key used to call the Key Management service to generate a data encryption key or to encrypt or decrypt a data encryption key.
-
#metadata ⇒ Hash<String, String>
Arbitrary string, up to 4KB, of keys and values for user-defined metadata.
-
#name ⇒ String
[Required] The name of the bucket.
-
#object_events_enabled ⇒ BOOLEAN
Whether or not events are emitted for object state changes in this bucket.
-
#public_access_type ⇒ String
The type of public access enabled on this bucket.
-
#storage_tier ⇒ String
The type of storage tier of this bucket.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateBucketDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateBucketDetails
Initializes the object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 131 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'metadata'] if attributes[:'metadata'] self.public_access_type = attributes[:'publicAccessType'] if attributes[:'publicAccessType'] raise 'You cannot provide both :publicAccessType and :public_access_type' if attributes.key?(:'publicAccessType') && attributes.key?(:'public_access_type') self.public_access_type = attributes[:'public_access_type'] if attributes[:'public_access_type'] self.storage_tier = attributes[:'storageTier'] if attributes[:'storageTier'] raise 'You cannot provide both :storageTier and :storage_tier' if attributes.key?(:'storageTier') && attributes.key?(:'storage_tier') self.storage_tier = attributes[:'storage_tier'] if attributes[:'storage_tier'] self.object_events_enabled = attributes[:'objectEventsEnabled'] unless attributes[:'objectEventsEnabled'].nil? raise 'You cannot provide both :objectEventsEnabled and :object_events_enabled' if attributes.key?(:'objectEventsEnabled') && attributes.key?(:'object_events_enabled') self.object_events_enabled = attributes[:'object_events_enabled'] unless attributes[:'object_events_enabled'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId'] raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id') self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The ID of the compartment in which to create the bucket.
32 33 34 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 32 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
74 75 76 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 74 def end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
67 68 69 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 67 def end |
#kms_key_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of a master encryption key used to call the Key Management service to generate a data encryption key or to encrypt or decrypt a data encryption key.
80 81 82 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 80 def kms_key_id @kms_key_id end |
#metadata ⇒ Hash<String, String>
Arbitrary string, up to 4KB, of keys and values for user-defined metadata.
36 37 38 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 36 def end |
#name ⇒ String
[Required] The name of the bucket. Valid characters are uppercase or lowercase letters, numbers, hyphens, underscores, and periods. Bucket names must be unique within an Object Storage namespace. Avoid entering confidential information. example: Example: my-new-bucket1
28 29 30 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 28 def name @name end |
#object_events_enabled ⇒ BOOLEAN
Whether or not events are emitted for object state changes in this bucket. By default, objectEventsEnabled is set to false. Set objectEventsEnabled to true to emit events for object state changes. For more information about events, see [Overview of Events](docs.cloud.oracle.com/Content/Events/Concepts/eventsoverview.htm).
60 61 62 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 60 def object_events_enabled @object_events_enabled end |
#public_access_type ⇒ String
The type of public access enabled on this bucket. A bucket is set to NoPublicAccess by default, which only allows an authenticated caller to access the bucket and its contents. When ObjectRead is enabled on the bucket, public access is allowed for the GetObject, HeadObject, and ListObjects operations. When ObjectReadWithoutList is enabled on the bucket, public access is allowed for the GetObject and HeadObject operations.
45 46 47 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 45 def public_access_type @public_access_type end |
#storage_tier ⇒ String
The type of storage tier of this bucket. A bucket is set to ‘Standard’ tier by default, which means the bucket will be put in the standard storage tier. When ‘Archive’ tier type is set explicitly, the bucket is put in the Archive Storage tier. The ‘storageTier’ property is immutable after bucket is created.
53 54 55 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 53 def storage_tier @storage_tier end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 83 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'compartment_id': :'compartmentId', 'metadata': :'metadata', 'public_access_type': :'publicAccessType', 'storage_tier': :'storageTier', 'object_events_enabled': :'objectEventsEnabled', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'kms_key_id': :'kmsKeyId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 100 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'compartment_id': :'String', 'metadata': :'Hash<String, String>', 'public_access_type': :'String', 'storage_tier': :'String', 'object_events_enabled': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'kms_key_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 207 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && compartment_id == other.compartment_id && == other. && public_access_type == other.public_access_type && storage_tier == other.storage_tier && object_events_enabled == other.object_events_enabled && == other. && == other. && kms_key_id == other.kms_key_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 245 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
225 226 227 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 225 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
234 235 236 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 234 def hash [name, compartment_id, , public_access_type, storage_tier, object_events_enabled, , , kms_key_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
278 279 280 281 282 283 284 285 286 287 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 278 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
272 273 274 |
# File 'lib/oci/object_storage/models/create_bucket_details.rb', line 272 def to_s to_hash.to_s end |