Method: OCI::ObjectStorage::Models::CreateReplicationPolicyDetails#destination_bucket_name
- Defined in:
- lib/oci/object_storage/models/create_replication_policy_details.rb
#destination_bucket_name ⇒ String
[Required] The bucket to replicate to in the destination region. Replication policy creation does not automatically create a destination bucket. Create the destination bucket before creating the policy.
22 23 24 |
# File 'lib/oci/object_storage/models/create_replication_policy_details.rb', line 22 def destination_bucket_name @destination_bucket_name end |