Class: OCI::ObjectStorage::Models::ObjectSummary
- Inherits:
-
Object
- Object
- OCI::ObjectStorage::Models::ObjectSummary
- Defined in:
- lib/oci/object_storage/models/object_summary.rb
Overview
To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized, talk to an administrator. If you are an administrator who needs to write policies to give users access, see [Getting Started with Policies](docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
Instance Attribute Summary collapse
-
#etag ⇒ String
The current entity tag (ETag) for the object.
-
#md5 ⇒ String
Base64-encoded MD5 hash of the object data.
-
#name ⇒ String
[Required] The name of the object.
-
#size ⇒ Integer
Size of the object in bytes.
-
#time_created ⇒ DateTime
The date and time the object was created, as described in [RFC 2616](tools.ietf.org/html/rfc2616#section-14.29).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ObjectSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ObjectSummary
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 71 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.size = attributes[:'size'] if attributes[:'size'] self.md5 = attributes[:'md5'] if attributes[:'md5'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.etag = attributes[:'etag'] if attributes[:'etag'] end |
Instance Attribute Details
#etag ⇒ String
The current entity tag (ETag) for the object.
32 33 34 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 32 def etag @etag end |
#md5 ⇒ String
Base64-encoded MD5 hash of the object data.
24 25 26 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 24 def md5 @md5 end |
#name ⇒ String
[Required] The name of the object. Avoid entering confidential information. Example: test/object1.log
16 17 18 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 16 def name @name end |
#size ⇒ Integer
Size of the object in bytes.
20 21 22 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 20 def size @size end |
#time_created ⇒ DateTime
The date and time the object was created, as described in [RFC 2616](tools.ietf.org/html/rfc2616#section-14.29).
28 29 30 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 28 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 35 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'size': :'size', 'md5': :'md5', 'time_created': :'timeCreated', 'etag': :'etag' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 48 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'size': :'Integer', 'md5': :'String', 'time_created': :'DateTime', 'etag': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 99 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && size == other.size && md5 == other.md5 && time_created == other.time_created && etag == other.etag end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 133 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
113 114 115 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 113 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
122 123 124 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 122 def hash [name, size, md5, time_created, etag].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
166 167 168 169 170 171 172 173 174 175 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 166 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
160 161 162 |
# File 'lib/oci/object_storage/models/object_summary.rb', line 160 def to_s to_hash.to_s end |