Class: OCI::Oce::Models::OceInstanceSummary
- Inherits:
-
Object
- Object
- OCI::Oce::Models::OceInstanceSummary
- Defined in:
- lib/oci/oce/models/oce_instance_summary.rb
Overview
Summary of the OceInstance.
Constant Summary collapse
- INSTANCE_USAGE_TYPE_ENUM =
[ INSTANCE_USAGE_TYPE_PRIMARY = 'PRIMARY'.freeze, INSTANCE_USAGE_TYPE_NONPRIMARY = 'NONPRIMARY'.freeze, INSTANCE_USAGE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- INSTANCE_ACCESS_TYPE_ENUM =
[ INSTANCE_ACCESS_TYPE_PUBLIC = 'PUBLIC'.freeze, INSTANCE_ACCESS_TYPE_PRIVATE = 'PRIVATE'.freeze, INSTANCE_ACCESS_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- INSTANCE_LICENSE_TYPE_ENUM =
[ INSTANCE_LICENSE_TYPE_NEW = 'NEW'.freeze, INSTANCE_LICENSE_TYPE_BYOL = 'BYOL'.freeze, INSTANCE_LICENSE_TYPE_PREMIUM = 'PREMIUM'.freeze, INSTANCE_LICENSE_TYPE_STARTER = 'STARTER'.freeze, INSTANCE_LICENSE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_DETAILS_ENUM =
[ LIFECYCLE_DETAILS_STANDBY = 'STANDBY'.freeze, LIFECYCLE_DETAILS_FAILOVER = 'FAILOVER'.freeze, LIFECYCLE_DETAILS_DOWN = 'DOWN'.freeze, LIFECYCLE_DETAILS_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_DETAILS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#add_on_features ⇒ Array<String>
a list of add-on features for the ocm instance.
-
#admin_email ⇒ String
**[Required]** Admin Email for Notification.
-
#compartment_id ⇒ String
**[Required]** Compartment Identifier.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys.
-
#description ⇒ String
OceInstance description, can be updated.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#guid ⇒ String
**[Required]** Unique GUID identifier that is immutable on creation.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#idcs_tenancy ⇒ String
**[Required]** IDCS Tenancy Identifier.
-
#instance_access_type ⇒ String
Flag indicating whether the instance access is private or public.
-
#instance_license_type ⇒ String
Flag indicating whether the instance license is new cloud or bring your own license.
-
#instance_usage_type ⇒ String
Instance type based on its usage.
-
#lifecycle_details ⇒ String
Details of the current state of the instance lifecycle.
-
#lifecycle_state ⇒ String
The current state of the instance lifecycle.
-
#name ⇒ String
**[Required]** OceInstance Name.
-
#object_storage_namespace ⇒ String
**[Required]** Object Storage Namespace of tenancy.
-
#service ⇒ Hash<String, Object>
SERVICE data.
-
#state_message ⇒ String
An message describing the current state in more detail.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#tenancy_id ⇒ String
**[Required]** Tenancy Identifier.
-
#tenancy_name ⇒ String
**[Required]** Tenancy Name.
-
#time_created ⇒ DateTime
The time the the OceInstance was created.
-
#time_updated ⇒ DateTime
The time the OceInstance was updated.
-
#upgrade_schedule ⇒ String
Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version.
-
#waf_primary_domain ⇒ String
Web Application Firewall(WAF) primary domain.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OceInstanceSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OceInstanceSummary
Initializes the object
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 256 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.guid = attributes[:'guid'] if attributes[:'guid'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId'] raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id') self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id'] self.idcs_tenancy = attributes[:'idcsTenancy'] if attributes[:'idcsTenancy'] raise 'You cannot provide both :idcsTenancy and :idcs_tenancy' if attributes.key?(:'idcsTenancy') && attributes.key?(:'idcs_tenancy') self.idcs_tenancy = attributes[:'idcs_tenancy'] if attributes[:'idcs_tenancy'] self.tenancy_name = attributes[:'tenancyName'] if attributes[:'tenancyName'] raise 'You cannot provide both :tenancyName and :tenancy_name' if attributes.key?(:'tenancyName') && attributes.key?(:'tenancy_name') self.tenancy_name = attributes[:'tenancy_name'] if attributes[:'tenancy_name'] self.instance_usage_type = attributes[:'instanceUsageType'] if attributes[:'instanceUsageType'] raise 'You cannot provide both :instanceUsageType and :instance_usage_type' if attributes.key?(:'instanceUsageType') && attributes.key?(:'instance_usage_type') self.instance_usage_type = attributes[:'instance_usage_type'] if attributes[:'instance_usage_type'] self.add_on_features = attributes[:'addOnFeatures'] if attributes[:'addOnFeatures'] raise 'You cannot provide both :addOnFeatures and :add_on_features' if attributes.key?(:'addOnFeatures') && attributes.key?(:'add_on_features') self.add_on_features = attributes[:'add_on_features'] if attributes[:'add_on_features'] self.object_storage_namespace = attributes[:'objectStorageNamespace'] if attributes[:'objectStorageNamespace'] raise 'You cannot provide both :objectStorageNamespace and :object_storage_namespace' if attributes.key?(:'objectStorageNamespace') && attributes.key?(:'object_storage_namespace') self.object_storage_namespace = attributes[:'object_storage_namespace'] if attributes[:'object_storage_namespace'] self.admin_email = attributes[:'adminEmail'] if attributes[:'adminEmail'] raise 'You cannot provide both :adminEmail and :admin_email' if attributes.key?(:'adminEmail') && attributes.key?(:'admin_email') self.admin_email = attributes[:'admin_email'] if attributes[:'admin_email'] self.upgrade_schedule = attributes[:'upgradeSchedule'] if attributes[:'upgradeSchedule'] raise 'You cannot provide both :upgradeSchedule and :upgrade_schedule' if attributes.key?(:'upgradeSchedule') && attributes.key?(:'upgrade_schedule') self.upgrade_schedule = attributes[:'upgrade_schedule'] if attributes[:'upgrade_schedule'] self.waf_primary_domain = attributes[:'wafPrimaryDomain'] if attributes[:'wafPrimaryDomain'] raise 'You cannot provide both :wafPrimaryDomain and :waf_primary_domain' if attributes.key?(:'wafPrimaryDomain') && attributes.key?(:'waf_primary_domain') self.waf_primary_domain = attributes[:'waf_primary_domain'] if attributes[:'waf_primary_domain'] self.instance_access_type = attributes[:'instanceAccessType'] if attributes[:'instanceAccessType'] raise 'You cannot provide both :instanceAccessType and :instance_access_type' if attributes.key?(:'instanceAccessType') && attributes.key?(:'instance_access_type') self.instance_access_type = attributes[:'instance_access_type'] if attributes[:'instance_access_type'] self.instance_license_type = attributes[:'instanceLicenseType'] if attributes[:'instanceLicenseType'] raise 'You cannot provide both :instanceLicenseType and :instance_license_type' if attributes.key?(:'instanceLicenseType') && attributes.key?(:'instance_license_type') self.instance_license_type = attributes[:'instance_license_type'] if attributes[:'instance_license_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'stateMessage'] if attributes[:'stateMessage'] raise 'You cannot provide both :stateMessage and :state_message' if attributes.key?(:'stateMessage') && attributes.key?(:'state_message') self. = attributes[:'state_message'] if attributes[:'state_message'] self.service = attributes[:'service'] if attributes[:'service'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#add_on_features ⇒ Array<String>
a list of add-on features for the ocm instance
87 88 89 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 87 def add_on_features @add_on_features end |
#admin_email ⇒ String
**[Required]** Admin Email for Notification
95 96 97 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 95 def admin_email @admin_email end |
#compartment_id ⇒ String
**[Required]** Compartment Identifier
63 64 65 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 63 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Usage of predefined tag keys. These predefined keys are scoped to namespaces. Example: `{"bar-key": "value"}`
151 152 153 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 151 def @defined_tags end |
#description ⇒ String
OceInstance description, can be updated
59 60 61 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 59 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
145 146 147 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 145 def @freeform_tags end |
#guid ⇒ String
**[Required]** Unique GUID identifier that is immutable on creation
55 56 57 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 55 def guid @guid end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation
51 52 53 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 51 def id @id end |
#idcs_tenancy ⇒ String
**[Required]** IDCS Tenancy Identifier
75 76 77 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 75 def idcs_tenancy @idcs_tenancy end |
#instance_access_type ⇒ String
Flag indicating whether the instance access is private or public
109 110 111 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 109 def instance_access_type @instance_access_type end |
#instance_license_type ⇒ String
Flag indicating whether the instance license is new cloud or bring your own license
113 114 115 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 113 def instance_license_type @instance_license_type end |
#instance_usage_type ⇒ String
Instance type based on its usage
83 84 85 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 83 def instance_usage_type @instance_usage_type end |
#lifecycle_details ⇒ String
Details of the current state of the instance lifecycle
129 130 131 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 129 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the instance lifecycle.
125 126 127 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 125 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** OceInstance Name
67 68 69 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 67 def name @name end |
#object_storage_namespace ⇒ String
**[Required]** Object Storage Namespace of tenancy
91 92 93 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 91 def object_storage_namespace @object_storage_namespace end |
#service ⇒ Hash<String, Object>
SERVICE data. Example: `{"IDCS": "value"}`
139 140 141 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 139 def service @service end |
#state_message ⇒ String
An message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
133 134 135 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 133 def @state_message end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
157 158 159 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 157 def @system_tags end |
#tenancy_id ⇒ String
**[Required]** Tenancy Identifier
71 72 73 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 71 def tenancy_id @tenancy_id end |
#tenancy_name ⇒ String
**[Required]** Tenancy Name
79 80 81 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 79 def tenancy_name @tenancy_name end |
#time_created ⇒ DateTime
The time the the OceInstance was created. An RFC3339 formatted datetime string
117 118 119 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 117 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the OceInstance was updated. An RFC3339 formatted datetime string
121 122 123 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 121 def time_updated @time_updated end |
#upgrade_schedule ⇒ String
Upgrade schedule type representing service to be upgraded immediately whenever latest version is released or delay upgrade of the service to previous released version
101 102 103 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 101 def upgrade_schedule @upgrade_schedule end |
#waf_primary_domain ⇒ String
Web Application Firewall(WAF) primary domain
105 106 107 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 105 def waf_primary_domain @waf_primary_domain end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 160 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'guid': :'guid', 'description': :'description', 'compartment_id': :'compartmentId', 'name': :'name', 'tenancy_id': :'tenancyId', 'idcs_tenancy': :'idcsTenancy', 'tenancy_name': :'tenancyName', 'instance_usage_type': :'instanceUsageType', 'add_on_features': :'addOnFeatures', 'object_storage_namespace': :'objectStorageNamespace', 'admin_email': :'adminEmail', 'upgrade_schedule': :'upgradeSchedule', 'waf_primary_domain': :'wafPrimaryDomain', 'instance_access_type': :'instanceAccessType', 'instance_license_type': :'instanceLicenseType', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'state_message': :'stateMessage', 'service': :'service', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 193 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'guid': :'String', 'description': :'String', 'compartment_id': :'String', 'name': :'String', 'tenancy_id': :'String', 'idcs_tenancy': :'String', 'tenancy_name': :'String', 'instance_usage_type': :'String', 'add_on_features': :'Array<String>', 'object_storage_namespace': :'String', 'admin_email': :'String', 'upgrade_schedule': :'String', 'waf_primary_domain': :'String', 'instance_access_type': :'String', 'instance_license_type': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'state_message': :'String', 'service': :'Hash<String, Object>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 465 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && guid == other.guid && description == other.description && compartment_id == other.compartment_id && name == other.name && tenancy_id == other.tenancy_id && idcs_tenancy == other.idcs_tenancy && tenancy_name == other.tenancy_name && instance_usage_type == other.instance_usage_type && add_on_features == other.add_on_features && object_storage_namespace == other.object_storage_namespace && admin_email == other.admin_email && upgrade_schedule == other.upgrade_schedule && waf_primary_domain == other.waf_primary_domain && instance_access_type == other.instance_access_type && instance_license_type == other.instance_license_type && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && service == other.service && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 519 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
499 500 501 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 499 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
508 509 510 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 508 def hash [id, guid, description, compartment_id, name, tenancy_id, idcs_tenancy, tenancy_name, instance_usage_type, add_on_features, object_storage_namespace, admin_email, upgrade_schedule, waf_primary_domain, instance_access_type, instance_license_type, time_created, time_updated, lifecycle_state, lifecycle_details, , service, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
552 553 554 555 556 557 558 559 560 561 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 552 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
546 547 548 |
# File 'lib/oci/oce/models/oce_instance_summary.rb', line 546 def to_s to_hash.to_s end |