Class: OCI::Ocvp::EsxiHostClient
- Inherits:
-
Object
- Object
- OCI::Ocvp::EsxiHostClient
- Defined in:
- lib/oci/ocvp/esxi_host_client.rb
Overview
Use the Oracle Cloud VMware API to create SDDCs and manage ESXi hosts and software. For more information, see [Oracle Cloud VMware Solution](/iaas/Content/VMware/Concepts/ocvsoverview.htm).
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#create_esxi_host(create_esxi_host_details, opts = {}) ⇒ Response
Adds another ESXi host to an existing SDDC.
-
#delete_esxi_host(esxi_host_id, opts = {}) ⇒ Response
Deletes the specified ESXi host.
-
#get_esxi_host(esxi_host_id, opts = {}) ⇒ Response
Gets the specified ESXi host's information.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ EsxiHostClient
constructor
Creates a new EsxiHostClient.
-
#list_esxi_hosts(opts = {}) ⇒ Response
Lists the ESXi hosts in the specified SDDC.
-
#logger ⇒ Logger
The logger for this client.
-
#update_esxi_host(esxi_host_id, update_esxi_host_details, opts = {}) ⇒ Response
Updates the specified ESXi host.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ EsxiHostClient
Creates a new EsxiHostClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 54 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20200501' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "EsxiHostClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
14 15 16 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 14 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
18 19 20 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 18 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
28 29 30 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 28 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is `nil`, which means that an operation will not perform any retries
24 25 26 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 24 def retry_config @retry_config end |
Instance Method Details
#create_esxi_host(create_esxi_host_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ocvp/create_esxi_host.rb.html) to see an example of how to use create_esxi_host API.
Adds another ESXi host to an existing SDDC. The attributes of the specified `Sddc` determine the VMware software and other configuration settings used by the ESXi host.
Use the WorkRequest operations to track the creation of the ESXi host.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 124 def create_esxi_host(create_esxi_host_details, opts = {}) logger.debug 'Calling operation EsxiHostClient#create_esxi_host.' if logger raise "Missing the required parameter 'create_esxi_host_details' when calling create_esxi_host." if create_esxi_host_details.nil? path = '/esxiHosts' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_esxi_host_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EsxiHostClient#create_esxi_host') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_esxi_host(esxi_host_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ocvp/delete_esxi_host.rb.html) to see an example of how to use delete_esxi_host API.
Deletes the specified ESXi host. Before deleting the host, back up or migrate any VMware workloads running on it.
When you delete an ESXi host, Oracle does not remove the node configuration within the VMware environment itself. That is your responsibility.
*Note:* If you delete EXSi hosts from the SDDC to total less than 3, you are still billed for the 3 minimum recommended EXSi hosts. Also, you cannot add more VMware workloads to the SDDC until it again has at least 3 ESXi hosts.
Use the WorkRequest operations to track the deletion of the ESXi host.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 201 def delete_esxi_host(esxi_host_id, opts = {}) logger.debug 'Calling operation EsxiHostClient#delete_esxi_host.' if logger raise "Missing the required parameter 'esxi_host_id' when calling delete_esxi_host." if esxi_host_id.nil? raise "Parameter value for 'esxi_host_id' must not be blank" if OCI::Internal::Util.blank_string?(esxi_host_id) path = '/esxiHosts/{esxiHostId}'.sub('{esxiHostId}', esxi_host_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EsxiHostClient#delete_esxi_host') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_esxi_host(esxi_host_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ocvp/get_esxi_host.rb.html) to see an example of how to use get_esxi_host API.
Gets the specified ESXi host's information.
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 258 def get_esxi_host(esxi_host_id, opts = {}) logger.debug 'Calling operation EsxiHostClient#get_esxi_host.' if logger raise "Missing the required parameter 'esxi_host_id' when calling get_esxi_host." if esxi_host_id.nil? raise "Parameter value for 'esxi_host_id' must not be blank" if OCI::Internal::Util.blank_string?(esxi_host_id) path = '/esxiHosts/{esxiHostId}'.sub('{esxiHostId}', esxi_host_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EsxiHostClient#get_esxi_host') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Ocvp::Models::EsxiHost' ) end # rubocop:enable Metrics/BlockLength end |
#list_esxi_hosts(opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ocvp/list_esxi_hosts.rb.html) to see an example of how to use list_esxi_hosts API.
Lists the ESXi hosts in the specified SDDC. The list can be filtered by Compute instance OCID or ESXi display name.
Remember that in terms of implementation, an ESXi host is a Compute instance that is configured with the chosen bundle of VMware software. Each `EsxiHost` object has its own OCID (`id`), and a separate attribute for the OCID of the Compute instance (`computeInstanceId`). When filtering the list of ESXi hosts, you can specify the OCID of the Compute instance, not the ESXi host OCID.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 349 def list_esxi_hosts(opts = {}) logger.debug 'Calling operation EsxiHostClient#list_esxi_hosts.' if logger if opts[:sort_order] && !OCI::Ocvp::Models::SORT_ORDERS_ENUM.include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of the values in OCI::Ocvp::Models::SORT_ORDERS_ENUM.' end if opts[:sort_by] && !%w[timeCreated displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of timeCreated, displayName.' end if opts[:lifecycle_state] && !OCI::Ocvp::Models::LIFECYCLE_STATES_ENUM.include?(opts[:lifecycle_state]) raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::Ocvp::Models::LIFECYCLE_STATES_ENUM.' end path = '/esxiHosts' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:sddcId] = opts[:sddc_id] if opts[:sddc_id] query_params[:computeInstanceId] = opts[:compute_instance_id] if opts[:compute_instance_id] query_params[:displayName] = opts[:display_name] if opts[:display_name] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EsxiHostClient#list_esxi_hosts') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Ocvp::Models::EsxiHostCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
93 94 95 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 93 def logger @api_client.config.logger end |
#update_esxi_host(esxi_host_id, update_esxi_host_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/ocvp/update_esxi_host.rb.html) to see an example of how to use update_esxi_host API.
Updates the specified ESXi host.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/oci/ocvp/esxi_host_client.rb', line 431 def update_esxi_host(esxi_host_id, update_esxi_host_details, opts = {}) logger.debug 'Calling operation EsxiHostClient#update_esxi_host.' if logger raise "Missing the required parameter 'esxi_host_id' when calling update_esxi_host." if esxi_host_id.nil? raise "Missing the required parameter 'update_esxi_host_details' when calling update_esxi_host." if update_esxi_host_details.nil? raise "Parameter value for 'esxi_host_id' must not be blank" if OCI::Internal::Util.blank_string?(esxi_host_id) path = '/esxiHosts/{esxiHostId}'.sub('{esxiHostId}', esxi_host_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_esxi_host_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'EsxiHostClient#update_esxi_host') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Ocvp::Models::EsxiHost' ) end # rubocop:enable Metrics/BlockLength end |