Class: OCI::Ocvp::Models::EsxiHost
- Inherits:
-
Object
- Object
- OCI::Ocvp::Models::EsxiHost
- Defined in:
- lib/oci/ocvp/models/esxi_host.rb
Overview
An ESXi host is a node in an SDDC. At a minimum, each SDDC has 3 ESXi hosts that are used to implement a functioning VMware environment.
In terms of implementation, an ESXi host is a Compute instance that is configured with the chosen bundle of VMware software.
Notice that an `EsxiHost` object has its own OCID (`id`), and a separate attribute for the OCID of the Compute instance (`computeInstanceId`).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- CURRENT_SKU_ENUM =
[ CURRENT_SKU_HOUR = 'HOUR'.freeze, CURRENT_SKU_MONTH = 'MONTH'.freeze, CURRENT_SKU_ONE_YEAR = 'ONE_YEAR'.freeze, CURRENT_SKU_THREE_YEARS = 'THREE_YEARS'.freeze, CURRENT_SKU_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- NEXT_SKU_ENUM =
[ NEXT_SKU_HOUR = 'HOUR'.freeze, NEXT_SKU_MONTH = 'MONTH'.freeze, NEXT_SKU_ONE_YEAR = 'ONE_YEAR'.freeze, NEXT_SKU_THREE_YEARS = 'THREE_YEARS'.freeze, NEXT_SKU_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#billing_contract_end_date ⇒ DateTime
**[Required]** Current billing cycle end date.
-
#capacity_reservation_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Capacity Reservation.
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the SDDC.
-
#compute_availability_domain ⇒ String
**[Required]** The availability domain of the ESXi host.
-
#compute_instance_id ⇒ String
In terms of implementation, an ESXi host is a Compute instance that is configured with the chosen bundle of VMware software.
-
#current_sku ⇒ String
**[Required]** The billing option currently used by the ESXi host.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** A descriptive name for the ESXi host.
-
#failed_esxi_host_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the ESXi host that failed.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource.
-
#grace_period_end_date ⇒ DateTime
The date and time when the new esxi host should start billing cycle.
-
#host_ocpu_count ⇒ Float
The OCPU count of the ESXi host.
-
#host_shape_name ⇒ String
**[Required]** The compute shape name of the ESXi host.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the ESXi host.
-
#lifecycle_state ⇒ String
The current state of the ESXi host.
-
#next_sku ⇒ String
**[Required]** The billing option to switch to after the current billing cycle ends.
-
#replacement_esxi_host_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the ESXi host that is created to replace the failed host.
-
#sddc_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the SDDC that the ESXi host belongs to.
-
#time_created ⇒ DateTime
The date and time the ESXi host was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
The date and time the ESXi host was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EsxiHost
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ EsxiHost
Initializes the object
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 250 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.sddc_id = attributes[:'sddcId'] if attributes[:'sddcId'] raise 'You cannot provide both :sddcId and :sddc_id' if attributes.key?(:'sddcId') && attributes.key?(:'sddc_id') self.sddc_id = attributes[:'sddc_id'] if attributes[:'sddc_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.compute_instance_id = attributes[:'computeInstanceId'] if attributes[:'computeInstanceId'] raise 'You cannot provide both :computeInstanceId and :compute_instance_id' if attributes.key?(:'computeInstanceId') && attributes.key?(:'compute_instance_id') self.compute_instance_id = attributes[:'compute_instance_id'] if attributes[:'compute_instance_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.current_sku = attributes[:'currentSku'] if attributes[:'currentSku'] self.current_sku = "MONTH" if current_sku.nil? && !attributes.key?(:'currentSku') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :currentSku and :current_sku' if attributes.key?(:'currentSku') && attributes.key?(:'current_sku') self.current_sku = attributes[:'current_sku'] if attributes[:'current_sku'] self.current_sku = "MONTH" if current_sku.nil? && !attributes.key?(:'currentSku') && !attributes.key?(:'current_sku') # rubocop:disable Style/StringLiterals self.next_sku = attributes[:'nextSku'] if attributes[:'nextSku'] raise 'You cannot provide both :nextSku and :next_sku' if attributes.key?(:'nextSku') && attributes.key?(:'next_sku') self.next_sku = attributes[:'next_sku'] if attributes[:'next_sku'] self.billing_contract_end_date = attributes[:'billingContractEndDate'] if attributes[:'billingContractEndDate'] raise 'You cannot provide both :billingContractEndDate and :billing_contract_end_date' if attributes.key?(:'billingContractEndDate') && attributes.key?(:'billing_contract_end_date') self.billing_contract_end_date = attributes[:'billing_contract_end_date'] if attributes[:'billing_contract_end_date'] self.failed_esxi_host_id = attributes[:'failedEsxiHostId'] if attributes[:'failedEsxiHostId'] raise 'You cannot provide both :failedEsxiHostId and :failed_esxi_host_id' if attributes.key?(:'failedEsxiHostId') && attributes.key?(:'failed_esxi_host_id') self.failed_esxi_host_id = attributes[:'failed_esxi_host_id'] if attributes[:'failed_esxi_host_id'] self.replacement_esxi_host_id = attributes[:'replacementEsxiHostId'] if attributes[:'replacementEsxiHostId'] raise 'You cannot provide both :replacementEsxiHostId and :replacement_esxi_host_id' if attributes.key?(:'replacementEsxiHostId') && attributes.key?(:'replacement_esxi_host_id') self.replacement_esxi_host_id = attributes[:'replacement_esxi_host_id'] if attributes[:'replacement_esxi_host_id'] self.grace_period_end_date = attributes[:'gracePeriodEndDate'] if attributes[:'gracePeriodEndDate'] raise 'You cannot provide both :gracePeriodEndDate and :grace_period_end_date' if attributes.key?(:'gracePeriodEndDate') && attributes.key?(:'grace_period_end_date') self.grace_period_end_date = attributes[:'grace_period_end_date'] if attributes[:'grace_period_end_date'] self.compute_availability_domain = attributes[:'computeAvailabilityDomain'] if attributes[:'computeAvailabilityDomain'] raise 'You cannot provide both :computeAvailabilityDomain and :compute_availability_domain' if attributes.key?(:'computeAvailabilityDomain') && attributes.key?(:'compute_availability_domain') self.compute_availability_domain = attributes[:'compute_availability_domain'] if attributes[:'compute_availability_domain'] self.host_shape_name = attributes[:'hostShapeName'] if attributes[:'hostShapeName'] raise 'You cannot provide both :hostShapeName and :host_shape_name' if attributes.key?(:'hostShapeName') && attributes.key?(:'host_shape_name') self.host_shape_name = attributes[:'host_shape_name'] if attributes[:'host_shape_name'] self.host_ocpu_count = attributes[:'hostOcpuCount'] if attributes[:'hostOcpuCount'] raise 'You cannot provide both :hostOcpuCount and :host_ocpu_count' if attributes.key?(:'hostOcpuCount') && attributes.key?(:'host_ocpu_count') self.host_ocpu_count = attributes[:'host_ocpu_count'] if attributes[:'host_ocpu_count'] self.capacity_reservation_id = attributes[:'capacityReservationId'] if attributes[:'capacityReservationId'] raise 'You cannot provide both :capacityReservationId and :capacity_reservation_id' if attributes.key?(:'capacityReservationId') && attributes.key?(:'capacity_reservation_id') self.capacity_reservation_id = attributes[:'capacity_reservation_id'] if attributes[:'capacity_reservation_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#billing_contract_end_date ⇒ DateTime
**[Required]** Current billing cycle end date. If the value in `currentSku` and `nextSku` are different, the value specified in `nextSku` becomes the new `currentSKU` when the `contractEndDate` is reached. Example: `2016-08-25T21:10:29.600Z`
111 112 113 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 111 def billing_contract_end_date @billing_contract_end_date end |
#capacity_reservation_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Capacity Reservation.
150 151 152 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 150 def capacity_reservation_id @capacity_reservation_id end |
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the SDDC.
66 67 68 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 66 def compartment_id @compartment_id end |
#compute_availability_domain ⇒ String
**[Required]** The availability domain of the ESXi host.
134 135 136 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 134 def compute_availability_domain @compute_availability_domain end |
#compute_instance_id ⇒ String
In terms of implementation, an ESXi host is a Compute instance that is configured with the chosen bundle of VMware software. The `computeInstanceId` is the [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of that Compute instance.
73 74 75 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 73 def compute_instance_id @compute_instance_id end |
#current_sku ⇒ String
**[Required]** The billing option currently used by the ESXi host. list_supported_skus.
97 98 99 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 97 def current_sku @current_sku end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
166 167 168 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 166 def @defined_tags end |
#display_name ⇒ String
**[Required]** A descriptive name for the ESXi host. Does not have to be unique, and it's changeable. Avoid entering confidential information.
54 55 56 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 54 def display_name @display_name end |
#failed_esxi_host_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the ESXi host that failed.
116 117 118 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 116 def failed_esxi_host_id @failed_esxi_host_id end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
158 159 160 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 158 def @freeform_tags end |
#grace_period_end_date ⇒ DateTime
The date and time when the new esxi host should start billing cycle. [RFC3339](tools.ietf.org/html/rfc3339). Example: `2021-07-25T21:10:29.600Z`
129 130 131 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 129 def grace_period_end_date @grace_period_end_date end |
#host_ocpu_count ⇒ Float
The OCPU count of the ESXi host.
145 146 147 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 145 def host_ocpu_count @host_ocpu_count end |
#host_shape_name ⇒ String
**[Required]** The compute shape name of the ESXi host. list_supported_host_shapes.
140 141 142 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 140 def host_shape_name @host_shape_name end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the ESXi host.
48 49 50 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 48 def id @id end |
#lifecycle_state ⇒ String
The current state of the ESXi host.
91 92 93 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 91 def lifecycle_state @lifecycle_state end |
#next_sku ⇒ String
**[Required]** The billing option to switch to after the current billing cycle ends. If `nextSku` is null or empty, `currentSku` continues to the next billing cycle. list_supported_skus.
104 105 106 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 104 def next_sku @next_sku end |
#replacement_esxi_host_id ⇒ String
The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the ESXi host that is created to replace the failed host.
122 123 124 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 122 def replacement_esxi_host_id @replacement_esxi_host_id end |
#sddc_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the SDDC that the ESXi host belongs to.
60 61 62 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 60 def sddc_id @sddc_id end |
#time_created ⇒ DateTime
The date and time the ESXi host was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
81 82 83 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 81 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the ESXi host was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
87 88 89 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 87 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 169 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'sddc_id': :'sddcId', 'compartment_id': :'compartmentId', 'compute_instance_id': :'computeInstanceId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'current_sku': :'currentSku', 'next_sku': :'nextSku', 'billing_contract_end_date': :'billingContractEndDate', 'failed_esxi_host_id': :'failedEsxiHostId', 'replacement_esxi_host_id': :'replacementEsxiHostId', 'grace_period_end_date': :'gracePeriodEndDate', 'compute_availability_domain': :'computeAvailabilityDomain', 'host_shape_name': :'hostShapeName', 'host_ocpu_count': :'hostOcpuCount', 'capacity_reservation_id': :'capacityReservationId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 197 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'sddc_id': :'String', 'compartment_id': :'String', 'compute_instance_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'current_sku': :'String', 'next_sku': :'String', 'billing_contract_end_date': :'DateTime', 'failed_esxi_host_id': :'String', 'replacement_esxi_host_id': :'String', 'grace_period_end_date': :'DateTime', 'compute_availability_domain': :'String', 'host_shape_name': :'String', 'host_ocpu_count': :'Float', 'capacity_reservation_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 421 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && sddc_id == other.sddc_id && compartment_id == other.compartment_id && compute_instance_id == other.compute_instance_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && current_sku == other.current_sku && next_sku == other.next_sku && billing_contract_end_date == other.billing_contract_end_date && failed_esxi_host_id == other.failed_esxi_host_id && replacement_esxi_host_id == other.replacement_esxi_host_id && grace_period_end_date == other.grace_period_end_date && compute_availability_domain == other.compute_availability_domain && host_shape_name == other.host_shape_name && host_ocpu_count == other.host_ocpu_count && capacity_reservation_id == other.capacity_reservation_id && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 470 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
450 451 452 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 450 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
459 460 461 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 459 def hash [id, display_name, sddc_id, compartment_id, compute_instance_id, time_created, time_updated, lifecycle_state, current_sku, next_sku, billing_contract_end_date, failed_esxi_host_id, replacement_esxi_host_id, grace_period_end_date, compute_availability_domain, host_shape_name, host_ocpu_count, capacity_reservation_id, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
503 504 505 506 507 508 509 510 511 512 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 503 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
497 498 499 |
# File 'lib/oci/ocvp/models/esxi_host.rb', line 497 def to_s to_hash.to_s end |