Class: OCI::Ocvp::Models::SddcSummary
- Inherits:
-
Object
- Object
- OCI::Ocvp::Models::SddcSummary
- Defined in:
- lib/oci/ocvp/models/sddc_summary.rb
Overview
A summary of the SDDC.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the SDDC.
-
#compute_availability_domain ⇒ String
**[Required]** The availability domain that the SDDC's ESXi hosts are running in.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource.
-
#display_name ⇒ String
**[Required]** A descriptive name for the SDDC.
-
#esxi_hosts_count ⇒ Integer
**[Required]** The number of ESXi hosts in the SDDC.
-
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource.
-
#hcx_fqdn ⇒ String
HCX Fully Qualified Domain Name.
-
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the SDDC.
-
#initial_host_ocpu_count ⇒ Float
The initial OCPU count of the SDDC's ESXi hosts.
-
#initial_host_shape_name ⇒ String
**[Required]** The initial compute shape of the SDDC's ESXi hosts.
-
#is_hcx_enabled ⇒ BOOLEAN
Indicates whether HCX is enabled.
-
#is_shielded_instance_enabled ⇒ BOOLEAN
Indicates whether shielded instance is enabled at the SDDC level.
-
#lifecycle_state ⇒ String
The current state of the SDDC.
-
#nsx_manager_fqdn ⇒ String
FQDN for NSX Manager.
-
#time_created ⇒ DateTime
The date and time the SDDC was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#time_updated ⇒ DateTime
The date and time the SDDC was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
-
#vcenter_fqdn ⇒ String
FQDN for vCenter.
-
#vmware_software_version ⇒ String
**[Required]** In general, this is a specific version of bundled VMware software supported by Oracle Cloud VMware Solution (see list_supported_vmware_software_versions).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SddcSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SddcSummary
Initializes the object
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 215 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compute_availability_domain = attributes[:'computeAvailabilityDomain'] if attributes[:'computeAvailabilityDomain'] raise 'You cannot provide both :computeAvailabilityDomain and :compute_availability_domain' if attributes.key?(:'computeAvailabilityDomain') && attributes.key?(:'compute_availability_domain') self.compute_availability_domain = attributes[:'compute_availability_domain'] if attributes[:'compute_availability_domain'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.vmware_software_version = attributes[:'vmwareSoftwareVersion'] if attributes[:'vmwareSoftwareVersion'] raise 'You cannot provide both :vmwareSoftwareVersion and :vmware_software_version' if attributes.key?(:'vmwareSoftwareVersion') && attributes.key?(:'vmware_software_version') self.vmware_software_version = attributes[:'vmware_software_version'] if attributes[:'vmware_software_version'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.esxi_hosts_count = attributes[:'esxiHostsCount'] if attributes[:'esxiHostsCount'] raise 'You cannot provide both :esxiHostsCount and :esxi_hosts_count' if attributes.key?(:'esxiHostsCount') && attributes.key?(:'esxi_hosts_count') self.esxi_hosts_count = attributes[:'esxi_hosts_count'] if attributes[:'esxi_hosts_count'] self.hcx_fqdn = attributes[:'hcxFqdn'] if attributes[:'hcxFqdn'] raise 'You cannot provide both :hcxFqdn and :hcx_fqdn' if attributes.key?(:'hcxFqdn') && attributes.key?(:'hcx_fqdn') self.hcx_fqdn = attributes[:'hcx_fqdn'] if attributes[:'hcx_fqdn'] self.is_hcx_enabled = attributes[:'isHcxEnabled'] unless attributes[:'isHcxEnabled'].nil? raise 'You cannot provide both :isHcxEnabled and :is_hcx_enabled' if attributes.key?(:'isHcxEnabled') && attributes.key?(:'is_hcx_enabled') self.is_hcx_enabled = attributes[:'is_hcx_enabled'] unless attributes[:'is_hcx_enabled'].nil? self.vcenter_fqdn = attributes[:'vcenterFqdn'] if attributes[:'vcenterFqdn'] raise 'You cannot provide both :vcenterFqdn and :vcenter_fqdn' if attributes.key?(:'vcenterFqdn') && attributes.key?(:'vcenter_fqdn') self.vcenter_fqdn = attributes[:'vcenter_fqdn'] if attributes[:'vcenter_fqdn'] self.nsx_manager_fqdn = attributes[:'nsxManagerFqdn'] if attributes[:'nsxManagerFqdn'] raise 'You cannot provide both :nsxManagerFqdn and :nsx_manager_fqdn' if attributes.key?(:'nsxManagerFqdn') && attributes.key?(:'nsx_manager_fqdn') self.nsx_manager_fqdn = attributes[:'nsx_manager_fqdn'] if attributes[:'nsx_manager_fqdn'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.is_shielded_instance_enabled = attributes[:'isShieldedInstanceEnabled'] unless attributes[:'isShieldedInstanceEnabled'].nil? self.is_shielded_instance_enabled = false if is_shielded_instance_enabled.nil? && !attributes.key?(:'isShieldedInstanceEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isShieldedInstanceEnabled and :is_shielded_instance_enabled' if attributes.key?(:'isShieldedInstanceEnabled') && attributes.key?(:'is_shielded_instance_enabled') self.is_shielded_instance_enabled = attributes[:'is_shielded_instance_enabled'] unless attributes[:'is_shielded_instance_enabled'].nil? self.is_shielded_instance_enabled = false if is_shielded_instance_enabled.nil? && !attributes.key?(:'isShieldedInstanceEnabled') && !attributes.key?(:'is_shielded_instance_enabled') # rubocop:disable Style/StringLiterals self.initial_host_shape_name = attributes[:'initialHostShapeName'] if attributes[:'initialHostShapeName'] raise 'You cannot provide both :initialHostShapeName and :initial_host_shape_name' if attributes.key?(:'initialHostShapeName') && attributes.key?(:'initial_host_shape_name') self.initial_host_shape_name = attributes[:'initial_host_shape_name'] if attributes[:'initial_host_shape_name'] self.initial_host_ocpu_count = attributes[:'initialHostOcpuCount'] if attributes[:'initialHostOcpuCount'] raise 'You cannot provide both :initialHostOcpuCount and :initial_host_ocpu_count' if attributes.key?(:'initialHostOcpuCount') && attributes.key?(:'initial_host_ocpu_count') self.initial_host_ocpu_count = attributes[:'initial_host_ocpu_count'] if attributes[:'initial_host_ocpu_count'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the SDDC.
61 62 63 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 61 def compartment_id @compartment_id end |
#compute_availability_domain ⇒ String
**[Required]** The availability domain that the SDDC's ESXi hosts are running in. For Multi-AD SDDC, it is `multi-AD`.
30 31 32 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 30 def compute_availability_domain @compute_availability_domain end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
**[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `{"CostCenter": "42"}`
137 138 139 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 137 def @defined_tags end |
#display_name ⇒ String
**[Required]** A descriptive name for the SDDC. It must be unique, start with a letter, and contain only letters, digits, whitespaces, dashes and underscores. Avoid entering confidential information.
37 38 39 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 37 def display_name @display_name end |
#esxi_hosts_count ⇒ Integer
**[Required]** The number of ESXi hosts in the SDDC.
65 66 67 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 65 def esxi_hosts_count @esxi_hosts_count end |
#freeform_tags ⇒ Hash<String, String>
**[Required]** Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
Example: `"Finance"`
129 130 131 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 129 def @freeform_tags end |
#hcx_fqdn ⇒ String
HCX Fully Qualified Domain Name
69 70 71 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 69 def hcx_fqdn @hcx_fqdn end |
#id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the SDDC.
25 26 27 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 25 def id @id end |
#initial_host_ocpu_count ⇒ Float
The initial OCPU count of the SDDC's ESXi hosts.
121 122 123 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 121 def initial_host_ocpu_count @initial_host_ocpu_count end |
#initial_host_shape_name ⇒ String
**[Required]** The initial compute shape of the SDDC's ESXi hosts. list_supported_host_shapes.
116 117 118 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 116 def initial_host_shape_name @initial_host_shape_name end |
#is_hcx_enabled ⇒ BOOLEAN
Indicates whether HCX is enabled.
73 74 75 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 73 def is_hcx_enabled @is_hcx_enabled end |
#is_shielded_instance_enabled ⇒ BOOLEAN
Indicates whether shielded instance is enabled at the SDDC level.
110 111 112 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 110 def is_shielded_instance_enabled @is_shielded_instance_enabled end |
#lifecycle_state ⇒ String
The current state of the SDDC.
105 106 107 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 105 def lifecycle_state @lifecycle_state end |
#nsx_manager_fqdn ⇒ String
FQDN for NSX Manager
Example: `nsx-my-sddc.sddc.us-phoenix-1.oraclecloud.com`
87 88 89 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 87 def nsx_manager_fqdn @nsx_manager_fqdn end |
#time_created ⇒ DateTime
The date and time the SDDC was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
95 96 97 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 95 def time_created @time_created end |
#time_updated ⇒ DateTime
The date and time the SDDC was updated, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
101 102 103 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 101 def time_updated @time_updated end |
#vcenter_fqdn ⇒ String
FQDN for vCenter
Example: `vcenter-my-sddc.sddc.us-phoenix-1.oraclecloud.com`
80 81 82 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 80 def vcenter_fqdn @vcenter_fqdn end |
#vmware_software_version ⇒ String
**[Required]** In general, this is a specific version of bundled VMware software supported by Oracle Cloud VMware Solution (see list_supported_vmware_software_versions).
This attribute is not guaranteed to reflect the version of software currently installed on the ESXi hosts in the SDDC. The purpose of this attribute is to show the version of software that the Oracle Cloud VMware Solution will install on any new ESXi hosts that you *add to this SDDC in the future* with create_esxi_host.
Therefore, if you upgrade the existing ESXi hosts in the SDDC to use a newer version of bundled VMware software supported by the Oracle Cloud VMware Solution, you should use update_sddc to update the SDDC's `vmwareSoftwareVersion` with that new version.
55 56 57 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 55 def vmware_software_version @vmware_software_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 140 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compute_availability_domain': :'computeAvailabilityDomain', 'display_name': :'displayName', 'vmware_software_version': :'vmwareSoftwareVersion', 'compartment_id': :'compartmentId', 'esxi_hosts_count': :'esxiHostsCount', 'hcx_fqdn': :'hcxFqdn', 'is_hcx_enabled': :'isHcxEnabled', 'vcenter_fqdn': :'vcenterFqdn', 'nsx_manager_fqdn': :'nsxManagerFqdn', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'is_shielded_instance_enabled': :'isShieldedInstanceEnabled', 'initial_host_shape_name': :'initialHostShapeName', 'initial_host_ocpu_count': :'initialHostOcpuCount', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 166 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compute_availability_domain': :'String', 'display_name': :'String', 'vmware_software_version': :'String', 'compartment_id': :'String', 'esxi_hosts_count': :'Integer', 'hcx_fqdn': :'String', 'is_hcx_enabled': :'BOOLEAN', 'vcenter_fqdn': :'String', 'nsx_manager_fqdn': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'is_shielded_instance_enabled': :'BOOLEAN', 'initial_host_shape_name': :'String', 'initial_host_ocpu_count': :'Float', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 348 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compute_availability_domain == other.compute_availability_domain && display_name == other.display_name && vmware_software_version == other.vmware_software_version && compartment_id == other.compartment_id && esxi_hosts_count == other.esxi_hosts_count && hcx_fqdn == other.hcx_fqdn && is_hcx_enabled == other.is_hcx_enabled && vcenter_fqdn == other.vcenter_fqdn && nsx_manager_fqdn == other.nsx_manager_fqdn && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && is_shielded_instance_enabled == other.is_shielded_instance_enabled && initial_host_shape_name == other.initial_host_shape_name && initial_host_ocpu_count == other.initial_host_ocpu_count && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 395 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
375 376 377 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 375 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
384 385 386 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 384 def hash [id, compute_availability_domain, display_name, vmware_software_version, compartment_id, esxi_hosts_count, hcx_fqdn, is_hcx_enabled, vcenter_fqdn, nsx_manager_fqdn, time_created, time_updated, lifecycle_state, is_shielded_instance_enabled, initial_host_shape_name, initial_host_ocpu_count, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
428 429 430 431 432 433 434 435 436 437 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 428 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
422 423 424 |
# File 'lib/oci/ocvp/models/sddc_summary.rb', line 422 def to_s to_hash.to_s end |