Class: OCI::Onesubscription::Models::OrganizationSubscriptionSummary
- Inherits:
-
Object
- Object
- OCI::Onesubscription::Models::OrganizationSubscriptionSummary
- Defined in:
- lib/oci/onesubscription/models/organization_subscription_summary.rb
Overview
Subscription summary
Instance Attribute Summary collapse
- #currency ⇒ OCI::Onesubscription::Models::OrgnizationSubsCurrency
-
#id ⇒ String
**[Required]** SPM internal Subscription ID.
-
#service_name ⇒ String
Customer friendly service name provided by PRG.
-
#status ⇒ String
Status of the plan.
-
#time_end ⇒ DateTime
Represents the date when the last service of the subscription ends.
-
#time_start ⇒ DateTime
Represents the date when the first service of the subscription was activated.
-
#total_value ⇒ String
Total aggregate TCLV of all lines for the subscription including expired, active, and signed.
-
#type ⇒ String
Subscription Type i.e.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrganizationSubscriptionSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OrganizationSubscriptionSummary
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.service_name = attributes[:'serviceName'] if attributes[:'serviceName'] raise 'You cannot provide both :serviceName and :service_name' if attributes.key?(:'serviceName') && attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] if attributes[:'service_name'] self.type = attributes[:'type'] if attributes[:'type'] self.status = attributes[:'status'] if attributes[:'status'] self.time_start = attributes[:'timeStart'] if attributes[:'timeStart'] raise 'You cannot provide both :timeStart and :time_start' if attributes.key?(:'timeStart') && attributes.key?(:'time_start') self.time_start = attributes[:'time_start'] if attributes[:'time_start'] self.time_end = attributes[:'timeEnd'] if attributes[:'timeEnd'] raise 'You cannot provide both :timeEnd and :time_end' if attributes.key?(:'timeEnd') && attributes.key?(:'time_end') self.time_end = attributes[:'time_end'] if attributes[:'time_end'] self.currency = attributes[:'currency'] if attributes[:'currency'] self.total_value = attributes[:'totalValue'] if attributes[:'totalValue'] raise 'You cannot provide both :totalValue and :total_value' if attributes.key?(:'totalValue') && attributes.key?(:'total_value') self.total_value = attributes[:'total_value'] if attributes[:'total_value'] end |
Instance Attribute Details
#currency ⇒ OCI::Onesubscription::Models::OrgnizationSubsCurrency
42 43 44 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 42 def currency @currency end |
#id ⇒ String
**[Required]** SPM internal Subscription ID
14 15 16 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 14 def id @id end |
#service_name ⇒ String
Customer friendly service name provided by PRG
19 20 21 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 19 def service_name @service_name end |
#status ⇒ String
Status of the plan
29 30 31 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 29 def status @status end |
#time_end ⇒ DateTime
Represents the date when the last service of the subscription ends
39 40 41 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 39 def time_end @time_end end |
#time_start ⇒ DateTime
Represents the date when the first service of the subscription was activated
34 35 36 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 34 def time_start @time_start end |
#total_value ⇒ String
Total aggregate TCLV of all lines for the subscription including expired, active, and signed
47 48 49 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 47 def total_value @total_value end |
#type ⇒ String
Subscription Type i.e. IAAS,SAAS,PAAS
24 25 26 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 24 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'service_name': :'serviceName', 'type': :'type', 'status': :'status', 'time_start': :'timeStart', 'time_end': :'timeEnd', 'currency': :'currency', 'total_value': :'totalValue' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'service_name': :'String', 'type': :'String', 'status': :'String', 'time_start': :'DateTime', 'time_end': :'DateTime', 'currency': :'OCI::Onesubscription::Models::OrgnizationSubsCurrency', 'total_value': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 141 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && service_name == other.service_name && type == other.type && status == other.status && time_start == other.time_start && time_end == other.time_end && currency == other.currency && total_value == other.total_value end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 178 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
158 159 160 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 158 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 167 def hash [id, service_name, type, status, time_start, time_end, currency, total_value].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
211 212 213 214 215 216 217 218 219 220 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 211 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
205 206 207 |
# File 'lib/oci/onesubscription/models/organization_subscription_summary.rb', line 205 def to_s to_hash.to_s end |