Class: OCI::OperatorAccessControl::Models::AccessRequestHistorySummary
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::AccessRequestHistorySummary
- Defined in:
- lib/oci/operator_access_control/models/access_request_history_summary.rb
Overview
Summary of access request status.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATED = 'CREATED'.freeze, LIFECYCLE_STATE_APPROVALWAITING = 'APPROVALWAITING'.freeze, LIFECYCLE_STATE_PREAPPROVED = 'PREAPPROVED'.freeze, LIFECYCLE_STATE_APPROVED = 'APPROVED'.freeze, LIFECYCLE_STATE_REJECTED = 'REJECTED'.freeze, LIFECYCLE_STATE_DEPLOYED = 'DEPLOYED'.freeze, LIFECYCLE_STATE_DEPLOYFAILED = 'DEPLOYFAILED'.freeze, LIFECYCLE_STATE_UNDEPLOYED = 'UNDEPLOYED'.freeze, LIFECYCLE_STATE_UNDEPLOYFAILED = 'UNDEPLOYFAILED'.freeze, LIFECYCLE_STATE_CLOSEFAILED = 'CLOSEFAILED'.freeze, LIFECYCLE_STATE_REVOKEFAILED = 'REVOKEFAILED'.freeze, LIFECYCLE_STATE_EXPIRYFAILED = 'EXPIRYFAILED'.freeze, LIFECYCLE_STATE_REVOKING = 'REVOKING'.freeze, LIFECYCLE_STATE_REVOKED = 'REVOKED'.freeze, LIFECYCLE_STATE_EXTENDING = 'EXTENDING'.freeze, LIFECYCLE_STATE_EXTENDED = 'EXTENDED'.freeze, LIFECYCLE_STATE_EXTENSIONREJECTED = 'EXTENSIONREJECTED'.freeze, LIFECYCLE_STATE_COMPLETING = 'COMPLETING'.freeze, LIFECYCLE_STATE_COMPLETED = 'COMPLETED'.freeze, LIFECYCLE_STATE_EXPIRED = 'EXPIRED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#actions_list ⇒ Array<String>
List of operator actions for which approvals were requested by the operator.
-
#description ⇒ String
Reason or description about the cause of change.
-
#duration ⇒ Integer
Duration for approval of request or extension depending on the type of action.
-
#is_auto_approved ⇒ BOOLEAN
Whether the access request was automatically approved.
-
#lifecycle_state ⇒ String
The current state of the AccessRequest.
-
#time_of_action ⇒ DateTime
Time when the respective action happened in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.
-
#user_id ⇒ String
Approver who modified the access request.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccessRequestHistorySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AccessRequestHistorySummary
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 107 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.user_id = attributes[:'userId'] if attributes[:'userId'] raise 'You cannot provide both :userId and :user_id' if attributes.key?(:'userId') && attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] if attributes[:'user_id'] self.description = attributes[:'description'] if attributes[:'description'] self.duration = attributes[:'duration'] if attributes[:'duration'] self.is_auto_approved = attributes[:'isAutoApproved'] unless attributes[:'isAutoApproved'].nil? raise 'You cannot provide both :isAutoApproved and :is_auto_approved' if attributes.key?(:'isAutoApproved') && attributes.key?(:'is_auto_approved') self.is_auto_approved = attributes[:'is_auto_approved'] unless attributes[:'is_auto_approved'].nil? self.actions_list = attributes[:'actionsList'] if attributes[:'actionsList'] raise 'You cannot provide both :actionsList and :actions_list' if attributes.key?(:'actionsList') && attributes.key?(:'actions_list') self.actions_list = attributes[:'actions_list'] if attributes[:'actions_list'] self.time_of_action = attributes[:'timeOfAction'] if attributes[:'timeOfAction'] raise 'You cannot provide both :timeOfAction and :time_of_action' if attributes.key?(:'timeOfAction') && attributes.key?(:'time_of_action') self.time_of_action = attributes[:'time_of_action'] if attributes[:'time_of_action'] end |
Instance Attribute Details
#actions_list ⇒ Array<String>
List of operator actions for which approvals were requested by the operator.
57 58 59 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 57 def actions_list @actions_list end |
#description ⇒ String
Reason or description about the cause of change.
45 46 47 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 45 def description @description end |
#duration ⇒ Integer
Duration for approval of request or extension depending on the type of action.
49 50 51 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 49 def duration @duration end |
#is_auto_approved ⇒ BOOLEAN
Whether the access request was automatically approved.
53 54 55 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 53 def is_auto_approved @is_auto_approved end |
#lifecycle_state ⇒ String
The current state of the AccessRequest.
37 38 39 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 37 def lifecycle_state @lifecycle_state end |
#time_of_action ⇒ DateTime
Time when the respective action happened in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
62 63 64 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 62 def time_of_action @time_of_action end |
#user_id ⇒ String
Approver who modified the access request.
41 42 43 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 41 def user_id @user_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 65 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'lifecycle_state': :'lifecycleState', 'user_id': :'userId', 'description': :'description', 'duration': :'duration', 'is_auto_approved': :'isAutoApproved', 'actions_list': :'actionsList', 'time_of_action': :'timeOfAction' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 80 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'lifecycle_state': :'String', 'user_id': :'String', 'description': :'String', 'duration': :'Integer', 'is_auto_approved': :'BOOLEAN', 'actions_list': :'Array<String>', 'time_of_action': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 168 def ==(other) return true if equal?(other) self.class == other.class && lifecycle_state == other.lifecycle_state && user_id == other.user_id && description == other.description && duration == other.duration && is_auto_approved == other.is_auto_approved && actions_list == other.actions_list && time_of_action == other.time_of_action end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 204 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
184 185 186 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 184 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 193 def hash [lifecycle_state, user_id, description, duration, is_auto_approved, actions_list, time_of_action].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
237 238 239 240 241 242 243 244 245 246 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 237 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
231 232 233 |
# File 'lib/oci/operator_access_control/models/access_request_history_summary.rb', line 231 def to_s to_hash.to_s end |