Class: OCI::OperatorAccessControl::Models::AccessRequestSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/operator_access_control/models/access_request_summary.rb

Overview

Summary of access request.

Constant Summary collapse

RESOURCE_TYPE_ENUM =
[
  RESOURCE_TYPE_EXACC = 'EXACC'.freeze,
  RESOURCE_TYPE_EXADATAINFRASTRUCTURE = 'EXADATAINFRASTRUCTURE'.freeze,
  RESOURCE_TYPE_AUTONOMOUSVMCLUSTER = 'AUTONOMOUSVMCLUSTER'.freeze,
  RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATED = 'CREATED'.freeze,
  LIFECYCLE_STATE_APPROVALWAITING = 'APPROVALWAITING'.freeze,
  LIFECYCLE_STATE_PREAPPROVED = 'PREAPPROVED'.freeze,
  LIFECYCLE_STATE_APPROVED = 'APPROVED'.freeze,
  LIFECYCLE_STATE_REJECTED = 'REJECTED'.freeze,
  LIFECYCLE_STATE_DEPLOYED = 'DEPLOYED'.freeze,
  LIFECYCLE_STATE_DEPLOYFAILED = 'DEPLOYFAILED'.freeze,
  LIFECYCLE_STATE_UNDEPLOYED = 'UNDEPLOYED'.freeze,
  LIFECYCLE_STATE_UNDEPLOYFAILED = 'UNDEPLOYFAILED'.freeze,
  LIFECYCLE_STATE_CLOSEFAILED = 'CLOSEFAILED'.freeze,
  LIFECYCLE_STATE_REVOKEFAILED = 'REVOKEFAILED'.freeze,
  LIFECYCLE_STATE_EXPIRYFAILED = 'EXPIRYFAILED'.freeze,
  LIFECYCLE_STATE_REVOKING = 'REVOKING'.freeze,
  LIFECYCLE_STATE_REVOKED = 'REVOKED'.freeze,
  LIFECYCLE_STATE_EXTENDING = 'EXTENDING'.freeze,
  LIFECYCLE_STATE_EXTENDED = 'EXTENDED'.freeze,
  LIFECYCLE_STATE_EXTENSIONREJECTED = 'EXTENSIONREJECTED'.freeze,
  LIFECYCLE_STATE_COMPLETING = 'COMPLETING'.freeze,
  LIFECYCLE_STATE_COMPLETED = 'COMPLETED'.freeze,
  LIFECYCLE_STATE_EXPIRED = 'EXPIRED'.freeze,
  LIFECYCLE_STATE_APPROVEDFORFUTURE = 'APPROVEDFORFUTURE'.freeze,
  LIFECYCLE_STATE_INREVIEW = 'INREVIEW'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
SEVERITY_ENUM =
[
  SEVERITY_S1 = 'S1'.freeze,
  SEVERITY_S2 = 'S2'.freeze,
  SEVERITY_S3 = 'S3'.freeze,
  SEVERITY_S4 = 'S4'.freeze,
  SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AccessRequestSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :request_id (String)

    The value to assign to the #request_id property

  • :access_reason_summary (String)

    The value to assign to the #access_reason_summary property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :resource_id (String)

    The value to assign to the #resource_id property

  • :resource_name (String)

    The value to assign to the #resource_name property

  • :resource_type (String)

    The value to assign to the #resource_type property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :time_of_creation (DateTime)

    The value to assign to the #time_of_creation property

  • :time_of_modification (DateTime)

    The value to assign to the #time_of_modification property

  • :time_of_user_creation (DateTime)

    The value to assign to the #time_of_user_creation property

  • :duration (Integer)

    The value to assign to the #duration property

  • :extend_duration (Integer)

    The value to assign to the #extend_duration property

  • :severity (String)

    The value to assign to the #severity property

  • :is_auto_approved (BOOLEAN)

    The value to assign to the #is_auto_approved property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 200

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.request_id = attributes[:'requestId'] if attributes[:'requestId']

  raise 'You cannot provide both :requestId and :request_id' if attributes.key?(:'requestId') && attributes.key?(:'request_id')

  self.request_id = attributes[:'request_id'] if attributes[:'request_id']

  self.access_reason_summary = attributes[:'accessReasonSummary'] if attributes[:'accessReasonSummary']

  raise 'You cannot provide both :accessReasonSummary and :access_reason_summary' if attributes.key?(:'accessReasonSummary') && attributes.key?(:'access_reason_summary')

  self.access_reason_summary = attributes[:'access_reason_summary'] if attributes[:'access_reason_summary']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId']

  raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id')

  self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id']

  self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName']

  raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name')

  self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name']

  self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType']

  raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type')

  self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_of_creation = attributes[:'timeOfCreation'] if attributes[:'timeOfCreation']

  raise 'You cannot provide both :timeOfCreation and :time_of_creation' if attributes.key?(:'timeOfCreation') && attributes.key?(:'time_of_creation')

  self.time_of_creation = attributes[:'time_of_creation'] if attributes[:'time_of_creation']

  self.time_of_modification = attributes[:'timeOfModification'] if attributes[:'timeOfModification']

  raise 'You cannot provide both :timeOfModification and :time_of_modification' if attributes.key?(:'timeOfModification') && attributes.key?(:'time_of_modification')

  self.time_of_modification = attributes[:'time_of_modification'] if attributes[:'time_of_modification']

  self.time_of_user_creation = attributes[:'timeOfUserCreation'] if attributes[:'timeOfUserCreation']

  raise 'You cannot provide both :timeOfUserCreation and :time_of_user_creation' if attributes.key?(:'timeOfUserCreation') && attributes.key?(:'time_of_user_creation')

  self.time_of_user_creation = attributes[:'time_of_user_creation'] if attributes[:'time_of_user_creation']

  self.duration = attributes[:'duration'] if attributes[:'duration']

  self.extend_duration = attributes[:'extendDuration'] if attributes[:'extendDuration']

  raise 'You cannot provide both :extendDuration and :extend_duration' if attributes.key?(:'extendDuration') && attributes.key?(:'extend_duration')

  self.extend_duration = attributes[:'extend_duration'] if attributes[:'extend_duration']

  self.severity = attributes[:'severity'] if attributes[:'severity']

  self.is_auto_approved = attributes[:'isAutoApproved'] unless attributes[:'isAutoApproved'].nil?

  raise 'You cannot provide both :isAutoApproved and :is_auto_approved' if attributes.key?(:'isAutoApproved') && attributes.key?(:'is_auto_approved')

  self.is_auto_approved = attributes[:'is_auto_approved'] unless attributes[:'is_auto_approved'].nil?

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#access_reason_summaryString

[Required] Comment associated with the access request.

Returns:

  • (String)


62
63
64
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 62

def access_reason_summary
  @access_reason_summary
end

#compartment_idString

The OCID of the compartment that contains the access request.

Returns:

  • (String)


66
67
68
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 66

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace.

Returns:

  • (Hash<String, Hash<String, Object>>)


125
126
127
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 125

def defined_tags
  @defined_tags
end

#durationInteger

Duration in hours for which access is sought on the target resource.

Returns:

  • (Integer)


103
104
105
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 103

def duration
  @duration
end

#extend_durationInteger

Duration in hours for which extension access is sought on the target resource.

Returns:

  • (Integer)


107
108
109
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 107

def extend_duration
  @extend_duration
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.

Returns:

  • (Hash<String, String>)


120
121
122
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 120

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the access request.

Returns:

  • (String)


54
55
56
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 54

def id
  @id
end

#is_auto_approvedBOOLEAN

Whether the access request was automatically approved.

Returns:

  • (BOOLEAN)


115
116
117
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 115

def is_auto_approved
  @is_auto_approved
end

#lifecycle_stateString

The current state of the AccessRequest.

Returns:

  • (String)


84
85
86
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 84

def lifecycle_state
  @lifecycle_state
end

#request_idString

This is a system-generated identifier.

Returns:

  • (String)


58
59
60
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 58

def request_id
  @request_id
end

#resource_idString

[Required] The OCID of the target resource associated with the access request. The operator raises an access request to get approval to access the target resource.

Returns:

  • (String)


72
73
74
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 72

def resource_id
  @resource_id
end

#resource_nameString

The name of the target resource.

Returns:

  • (String)


76
77
78
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 76

def resource_name
  @resource_name
end

#resource_typeString

resourceType for which the AccessRequest is applicable

Returns:

  • (String)


80
81
82
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 80

def resource_type
  @resource_type
end

#severityString

Priority assigned to the access request by the operator

Returns:

  • (String)


111
112
113
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 111

def severity
  @severity
end

#time_of_creationDateTime

Time when the access request was created by the operator user in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.Example: ‘2020-05-22T21:10:29.600Z’

Returns:

  • (DateTime)


89
90
91
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 89

def time_of_creation
  @time_of_creation
end

#time_of_modificationDateTime

Time when the access request was last modified in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.Example: ‘2020-05-22T21:10:29.600Z’

Returns:

  • (DateTime)


94
95
96
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 94

def time_of_modification
  @time_of_modification
end

#time_of_user_creationDateTime

The time when access request is scheduled to be approved in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.Example: ‘2020-05-22T21:10:29.600Z’

Returns:

  • (DateTime)


99
100
101
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 99

def time_of_user_creation
  @time_of_user_creation
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 128

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'request_id': :'requestId',
    'access_reason_summary': :'accessReasonSummary',
    'compartment_id': :'compartmentId',
    'resource_id': :'resourceId',
    'resource_name': :'resourceName',
    'resource_type': :'resourceType',
    'lifecycle_state': :'lifecycleState',
    'time_of_creation': :'timeOfCreation',
    'time_of_modification': :'timeOfModification',
    'time_of_user_creation': :'timeOfUserCreation',
    'duration': :'duration',
    'extend_duration': :'extendDuration',
    'severity': :'severity',
    'is_auto_approved': :'isAutoApproved',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 153

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'request_id': :'String',
    'access_reason_summary': :'String',
    'compartment_id': :'String',
    'resource_id': :'String',
    'resource_name': :'String',
    'resource_type': :'String',
    'lifecycle_state': :'String',
    'time_of_creation': :'DateTime',
    'time_of_modification': :'DateTime',
    'time_of_user_creation': :'DateTime',
    'duration': :'Integer',
    'extend_duration': :'Integer',
    'severity': :'String',
    'is_auto_approved': :'BOOLEAN',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 343

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    request_id == other.request_id &&
    access_reason_summary == other.access_reason_summary &&
    compartment_id == other.compartment_id &&
    resource_id == other.resource_id &&
    resource_name == other.resource_name &&
    resource_type == other.resource_type &&
    lifecycle_state == other.lifecycle_state &&
    time_of_creation == other.time_of_creation &&
    time_of_modification == other.time_of_modification &&
    time_of_user_creation == other.time_of_user_creation &&
    duration == other.duration &&
    extend_duration == other.extend_duration &&
    severity == other.severity &&
    is_auto_approved == other.is_auto_approved &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 389

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


369
370
371
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 369

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



378
379
380
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 378

def hash
  [id, request_id, access_reason_summary, compartment_id, resource_id, resource_name, resource_type, lifecycle_state, time_of_creation, time_of_modification, time_of_user_creation, duration, extend_duration, severity, is_auto_approved, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



422
423
424
425
426
427
428
429
430
431
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 422

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



416
417
418
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 416

def to_s
  to_hash.to_s
end