Class: OCI::OperatorAccessControl::Models::AccessRequestSummary
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::AccessRequestSummary
- Defined in:
- lib/oci/operator_access_control/models/access_request_summary.rb
Overview
Summary of access request.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATED = 'CREATED'.freeze, LIFECYCLE_STATE_APPROVALWAITING = 'APPROVALWAITING'.freeze, LIFECYCLE_STATE_PREAPPROVED = 'PREAPPROVED'.freeze, LIFECYCLE_STATE_APPROVED = 'APPROVED'.freeze, LIFECYCLE_STATE_REJECTED = 'REJECTED'.freeze, LIFECYCLE_STATE_DEPLOYED = 'DEPLOYED'.freeze, LIFECYCLE_STATE_DEPLOYFAILED = 'DEPLOYFAILED'.freeze, LIFECYCLE_STATE_UNDEPLOYED = 'UNDEPLOYED'.freeze, LIFECYCLE_STATE_UNDEPLOYFAILED = 'UNDEPLOYFAILED'.freeze, LIFECYCLE_STATE_CLOSEFAILED = 'CLOSEFAILED'.freeze, LIFECYCLE_STATE_REVOKEFAILED = 'REVOKEFAILED'.freeze, LIFECYCLE_STATE_EXPIRYFAILED = 'EXPIRYFAILED'.freeze, LIFECYCLE_STATE_REVOKING = 'REVOKING'.freeze, LIFECYCLE_STATE_REVOKED = 'REVOKED'.freeze, LIFECYCLE_STATE_EXTENDING = 'EXTENDING'.freeze, LIFECYCLE_STATE_EXTENDED = 'EXTENDED'.freeze, LIFECYCLE_STATE_EXTENSIONREJECTED = 'EXTENSIONREJECTED'.freeze, LIFECYCLE_STATE_COMPLETING = 'COMPLETING'.freeze, LIFECYCLE_STATE_COMPLETED = 'COMPLETED'.freeze, LIFECYCLE_STATE_EXPIRED = 'EXPIRED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SEVERITY_ENUM =
[ SEVERITY_S1 = 'S1'.freeze, SEVERITY_S2 = 'S2'.freeze, SEVERITY_S3 = 'S3'.freeze, SEVERITY_S4 = 'S4'.freeze, SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#access_reason_summary ⇒ String
[Required] Comment associated with the access request.
-
#compartment_id ⇒ String
The OCID of the compartment that contains the access request.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#duration ⇒ Integer
Duration in hours for which access is sought on the target resource.
-
#extend_duration ⇒ Integer
Duration in hours for which extension access is sought on the target resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The OCID of the access request.
-
#is_auto_approved ⇒ BOOLEAN
Whether the access request was automatically approved.
-
#lifecycle_state ⇒ String
The current state of the AccessRequest.
-
#request_id ⇒ String
This is a system-generated identifier.
-
#resource_id ⇒ String
[Required] The OCID of the target resource associated with the access request.
-
#resource_name ⇒ String
The name of the target resource.
-
#severity ⇒ String
Priority assigned to the access request by the operator.
-
#time_of_creation ⇒ DateTime
Time when the access request was created by the operator user in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.Example: ‘2020-05-22T21:10:29.600Z’.
-
#time_of_modification ⇒ DateTime
Time when the access request was last modified in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.Example: ‘2020-05-22T21:10:29.600Z’.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccessRequestSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AccessRequestSummary
Initializes the object
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 176 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.request_id = attributes[:'requestId'] if attributes[:'requestId'] raise 'You cannot provide both :requestId and :request_id' if attributes.key?(:'requestId') && attributes.key?(:'request_id') self.request_id = attributes[:'request_id'] if attributes[:'request_id'] self.access_reason_summary = attributes[:'accessReasonSummary'] if attributes[:'accessReasonSummary'] raise 'You cannot provide both :accessReasonSummary and :access_reason_summary' if attributes.key?(:'accessReasonSummary') && attributes.key?(:'access_reason_summary') self.access_reason_summary = attributes[:'access_reason_summary'] if attributes[:'access_reason_summary'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_of_creation = attributes[:'timeOfCreation'] if attributes[:'timeOfCreation'] raise 'You cannot provide both :timeOfCreation and :time_of_creation' if attributes.key?(:'timeOfCreation') && attributes.key?(:'time_of_creation') self.time_of_creation = attributes[:'time_of_creation'] if attributes[:'time_of_creation'] self.time_of_modification = attributes[:'timeOfModification'] if attributes[:'timeOfModification'] raise 'You cannot provide both :timeOfModification and :time_of_modification' if attributes.key?(:'timeOfModification') && attributes.key?(:'time_of_modification') self.time_of_modification = attributes[:'time_of_modification'] if attributes[:'time_of_modification'] self.duration = attributes[:'duration'] if attributes[:'duration'] self.extend_duration = attributes[:'extendDuration'] if attributes[:'extendDuration'] raise 'You cannot provide both :extendDuration and :extend_duration' if attributes.key?(:'extendDuration') && attributes.key?(:'extend_duration') self.extend_duration = attributes[:'extend_duration'] if attributes[:'extend_duration'] self.severity = attributes[:'severity'] if attributes[:'severity'] self.is_auto_approved = attributes[:'isAutoApproved'] unless attributes[:'isAutoApproved'].nil? raise 'You cannot provide both :isAutoApproved and :is_auto_approved' if attributes.key?(:'isAutoApproved') && attributes.key?(:'is_auto_approved') self.is_auto_approved = attributes[:'is_auto_approved'] unless attributes[:'is_auto_approved'].nil? self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#access_reason_summary ⇒ String
[Required] Comment associated with the access request.
53 54 55 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 53 def access_reason_summary @access_reason_summary end |
#compartment_id ⇒ String
The OCID of the compartment that contains the access request.
57 58 59 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 57 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
107 108 109 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 107 def end |
#duration ⇒ Integer
Duration in hours for which access is sought on the target resource.
85 86 87 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 85 def duration @duration end |
#extend_duration ⇒ Integer
Duration in hours for which extension access is sought on the target resource.
89 90 91 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 89 def extend_duration @extend_duration end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
102 103 104 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 102 def end |
#id ⇒ String
[Required] The OCID of the access request.
45 46 47 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 45 def id @id end |
#is_auto_approved ⇒ BOOLEAN
Whether the access request was automatically approved.
97 98 99 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 97 def is_auto_approved @is_auto_approved end |
#lifecycle_state ⇒ String
The current state of the AccessRequest.
71 72 73 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 71 def lifecycle_state @lifecycle_state end |
#request_id ⇒ String
This is a system-generated identifier.
49 50 51 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 49 def request_id @request_id end |
#resource_id ⇒ String
[Required] The OCID of the target resource associated with the access request. The operator raises an access request to get approval to access the target resource.
63 64 65 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 63 def resource_id @resource_id end |
#resource_name ⇒ String
The name of the target resource.
67 68 69 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 67 def resource_name @resource_name end |
#severity ⇒ String
Priority assigned to the access request by the operator
93 94 95 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 93 def severity @severity end |
#time_of_creation ⇒ DateTime
Time when the access request was created by the operator user in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.Example: ‘2020-05-22T21:10:29.600Z’
76 77 78 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 76 def time_of_creation @time_of_creation end |
#time_of_modification ⇒ DateTime
Time when the access request was last modified in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.Example: ‘2020-05-22T21:10:29.600Z’
81 82 83 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 81 def time_of_modification @time_of_modification end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 110 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'request_id': :'requestId', 'access_reason_summary': :'accessReasonSummary', 'compartment_id': :'compartmentId', 'resource_id': :'resourceId', 'resource_name': :'resourceName', 'lifecycle_state': :'lifecycleState', 'time_of_creation': :'timeOfCreation', 'time_of_modification': :'timeOfModification', 'duration': :'duration', 'extend_duration': :'extendDuration', 'severity': :'severity', 'is_auto_approved': :'isAutoApproved', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 133 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'request_id': :'String', 'access_reason_summary': :'String', 'compartment_id': :'String', 'resource_id': :'String', 'resource_name': :'String', 'lifecycle_state': :'String', 'time_of_creation': :'DateTime', 'time_of_modification': :'DateTime', 'duration': :'Integer', 'extend_duration': :'Integer', 'severity': :'String', 'is_auto_approved': :'BOOLEAN', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 294 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && request_id == other.request_id && access_reason_summary == other.access_reason_summary && compartment_id == other.compartment_id && resource_id == other.resource_id && resource_name == other.resource_name && lifecycle_state == other.lifecycle_state && time_of_creation == other.time_of_creation && time_of_modification == other.time_of_modification && duration == other.duration && extend_duration == other.extend_duration && severity == other.severity && is_auto_approved == other.is_auto_approved && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 338 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
318 319 320 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 318 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
327 328 329 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 327 def hash [id, request_id, access_reason_summary, compartment_id, resource_id, resource_name, lifecycle_state, time_of_creation, time_of_modification, duration, extend_duration, severity, is_auto_approved, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
371 372 373 374 375 376 377 378 379 380 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 371 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
365 366 367 |
# File 'lib/oci/operator_access_control/models/access_request_summary.rb', line 365 def to_s to_hash.to_s end |