Class: OCI::OperatorAccessControl::Models::CreateOperatorControlAssignmentDetails
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::CreateOperatorControlAssignmentDetails
- Defined in:
- lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb
Overview
Details of the Operator Control assignment. An Operator Control Assignment identifies the target resource that is placed under the governance of an Operator Control. Creating an Operator Control Assignment Assignment with a time duration ensures that human accesses to the target resource will be governed by Operator Control for the duration specified.
Constant Summary collapse
- RESOURCE_TYPE_ENUM =
[ RESOURCE_TYPE_EXACC = 'EXACC'.freeze ].freeze
Instance Attribute Summary collapse
-
#comment ⇒ String
Comment about the assignment of the operator control to this target resource.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the operator control assignment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_enforced_always ⇒ BOOLEAN
If set, then the target resource is always governed by the operator control.
-
#operator_control_id ⇒ String
[Required] The OCID of the operator control that is being assigned to a target resource.
-
#resource_compartment_id ⇒ String
[Required] The OCID of the compartment that contains the target resource.
-
#resource_id ⇒ String
[Required] The OCID of the target resource being brought under the governance of the operator control.
-
#resource_name ⇒ String
[Required] Name of the target resource.
-
#resource_type ⇒ String
Type of the target resource.
-
#time_assignment_from ⇒ DateTime
The time at which the target resource will be brought under the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_assignment_to ⇒ DateTime
The time at which the target resource will leave the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateOperatorControlAssignmentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateOperatorControlAssignmentDetails
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 126 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operator_control_id = attributes[:'operatorControlId'] if attributes[:'operatorControlId'] raise 'You cannot provide both :operatorControlId and :operator_control_id' if attributes.key?(:'operatorControlId') && attributes.key?(:'operator_control_id') self.operator_control_id = attributes[:'operator_control_id'] if attributes[:'operator_control_id'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.resource_compartment_id = attributes[:'resourceCompartmentId'] if attributes[:'resourceCompartmentId'] raise 'You cannot provide both :resourceCompartmentId and :resource_compartment_id' if attributes.key?(:'resourceCompartmentId') && attributes.key?(:'resource_compartment_id') self.resource_compartment_id = attributes[:'resource_compartment_id'] if attributes[:'resource_compartment_id'] self.time_assignment_from = attributes[:'timeAssignmentFrom'] if attributes[:'timeAssignmentFrom'] raise 'You cannot provide both :timeAssignmentFrom and :time_assignment_from' if attributes.key?(:'timeAssignmentFrom') && attributes.key?(:'time_assignment_from') self.time_assignment_from = attributes[:'time_assignment_from'] if attributes[:'time_assignment_from'] self.time_assignment_to = attributes[:'timeAssignmentTo'] if attributes[:'timeAssignmentTo'] raise 'You cannot provide both :timeAssignmentTo and :time_assignment_to' if attributes.key?(:'timeAssignmentTo') && attributes.key?(:'time_assignment_to') self.time_assignment_to = attributes[:'time_assignment_to'] if attributes[:'time_assignment_to'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.is_enforced_always = attributes[:'isEnforcedAlways'] unless attributes[:'isEnforcedAlways'].nil? raise 'You cannot provide both :isEnforcedAlways and :is_enforced_always' if attributes.key?(:'isEnforcedAlways') && attributes.key?(:'is_enforced_always') self.is_enforced_always = attributes[:'is_enforced_always'] unless attributes[:'is_enforced_always'].nil? self.comment = attributes[:'comment'] if attributes[:'comment'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#comment ⇒ String
Comment about the assignment of the operator control to this target resource.
56 57 58 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 56 def comment @comment end |
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the operator control assignment.
48 49 50 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 48 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
66 67 68 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 66 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
61 62 63 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 61 def end |
#is_enforced_always ⇒ BOOLEAN
If set, then the target resource is always governed by the operator control.
52 53 54 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 52 def is_enforced_always @is_enforced_always end |
#operator_control_id ⇒ String
[Required] The OCID of the operator control that is being assigned to a target resource.
18 19 20 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 18 def operator_control_id @operator_control_id end |
#resource_compartment_id ⇒ String
[Required] The OCID of the compartment that contains the target resource.
34 35 36 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 34 def resource_compartment_id @resource_compartment_id end |
#resource_id ⇒ String
[Required] The OCID of the target resource being brought under the governance of the operator control.
22 23 24 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 22 def resource_id @resource_id end |
#resource_name ⇒ String
[Required] Name of the target resource.
26 27 28 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 26 def resource_name @resource_name end |
#resource_type ⇒ String
Type of the target resource.
30 31 32 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 30 def resource_type @resource_type end |
#time_assignment_from ⇒ DateTime
The time at which the target resource will be brought under the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
39 40 41 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 39 def time_assignment_from @time_assignment_from end |
#time_assignment_to ⇒ DateTime
The time at which the target resource will leave the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’
44 45 46 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 44 def time_assignment_to @time_assignment_to end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 69 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operator_control_id': :'operatorControlId', 'resource_id': :'resourceId', 'resource_name': :'resourceName', 'resource_type': :'resourceType', 'resource_compartment_id': :'resourceCompartmentId', 'time_assignment_from': :'timeAssignmentFrom', 'time_assignment_to': :'timeAssignmentTo', 'compartment_id': :'compartmentId', 'is_enforced_always': :'isEnforcedAlways', 'comment': :'comment', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 89 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operator_control_id': :'String', 'resource_id': :'String', 'resource_name': :'String', 'resource_type': :'String', 'resource_compartment_id': :'String', 'time_assignment_from': :'DateTime', 'time_assignment_to': :'DateTime', 'compartment_id': :'String', 'is_enforced_always': :'BOOLEAN', 'comment': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 216 def ==(other) return true if equal?(other) self.class == other.class && operator_control_id == other.operator_control_id && resource_id == other.resource_id && resource_name == other.resource_name && resource_type == other.resource_type && resource_compartment_id == other.resource_compartment_id && time_assignment_from == other.time_assignment_from && time_assignment_to == other.time_assignment_to && compartment_id == other.compartment_id && is_enforced_always == other.is_enforced_always && comment == other.comment && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 257 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
237 238 239 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 237 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 246 def hash [operator_control_id, resource_id, resource_name, resource_type, resource_compartment_id, time_assignment_from, time_assignment_to, compartment_id, is_enforced_always, comment, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
284 285 286 |
# File 'lib/oci/operator_access_control/models/create_operator_control_assignment_details.rb', line 284 def to_s to_hash.to_s end |