Class: OperatorAccessControl::Models::OperatorAction
- Inherits:
-
Object
- Object
- OperatorAccessControl::Models::OperatorAction
- Defined in:
- lib/oci/operator_access_control/models/operator_action.rb
Overview
Details of the operator action. Operator actions are a pre-defined set of commands available to the operator on different layers of the infrastructure. Although the groupings may differ depending on the infrastructure layers, the groups are designed to enable the operator access to commands to resolve a specific set of issues. The infrastructure layers controlled by the Operator Control include Dom0, CellServer, and Control Plane Server (CPS).
There are five groups available to the operator. x-obmcs-top-level-enum: '#/definitions/OperatorActionCategories' enum: *OPERATORACTIONCATEGORIES
The following infrastructure layers are controlled by the operator actions x-obmcs-top-level-enum: '#/definitions/InfrastructureLayers' enum: *INFRASTRUCTURELAYERS
Constant Summary collapse
- RESOURCE_TYPE_ENUM =
[ RESOURCE_TYPE_EXACC = 'EXACC'.freeze, RESOURCE_TYPE_EXADATAINFRASTRUCTURE = 'EXADATAINFRASTRUCTURE'.freeze, RESOURCE_TYPE_AUTONOMOUSVMCLUSTER = 'AUTONOMOUSVMCLUSTER'.freeze, RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#component ⇒ String
Name of the infrastructure layer associated with the operator action.
-
#customer_display_name ⇒ String
Display Name of the operator action.
-
#description ⇒ String
Description of the operator action in terms of associated risk profile, and characteristics of the operating system commands made available to the operator under this operator action.
-
#id ⇒ String
**[Required]** Unique Oracle assigned identifier for the operator action.
-
#name ⇒ String
**[Required]** Unique name of the operator action.
-
#properties ⇒ Array<OCI::OperatorAccessControl::Models::OperatorActionProperties>
Fine grained properties associated with the operator control.
-
#resource_type ⇒ String
resourceType for which the OperatorAction is applicable.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperatorAction
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OperatorAction
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 97 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.customer_display_name = attributes[:'customerDisplayName'] if attributes[:'customerDisplayName'] raise 'You cannot provide both :customerDisplayName and :customer_display_name' if attributes.key?(:'customerDisplayName') && attributes.key?(:'customer_display_name') self.customer_display_name = attributes[:'customer_display_name'] if attributes[:'customer_display_name'] self.component = attributes[:'component'] if attributes[:'component'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.description = attributes[:'description'] if attributes[:'description'] self.properties = attributes[:'properties'] if attributes[:'properties'] end |
Instance Attribute Details
#component ⇒ String
Name of the infrastructure layer associated with the operator action.
38 39 40 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 38 def component @component end |
#customer_display_name ⇒ String
Display Name of the operator action.
34 35 36 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 34 def customer_display_name @customer_display_name end |
#description ⇒ String
Description of the operator action in terms of associated risk profile, and characteristics of the operating system commands made available to the operator under this operator action.
48 49 50 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 48 def description @description end |
#id ⇒ String
**[Required]** Unique Oracle assigned identifier for the operator action.
26 27 28 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 26 def id @id end |
#name ⇒ String
**[Required]** Unique name of the operator action.
30 31 32 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 30 def name @name end |
#properties ⇒ Array<OCI::OperatorAccessControl::Models::OperatorActionProperties>
Fine grained properties associated with the operator control.
52 53 54 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 52 def properties @properties end |
#resource_type ⇒ String
resourceType for which the OperatorAction is applicable
42 43 44 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 42 def resource_type @resource_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 55 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'customer_display_name': :'customerDisplayName', 'component': :'component', 'resource_type': :'resourceType', 'description': :'description', 'properties': :'properties' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 70 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'customer_display_name': :'String', 'component': :'String', 'resource_type': :'String', 'description': :'String', 'properties': :'Array<OCI::OperatorAccessControl::Models::OperatorActionProperties>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 146 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && customer_display_name == other.customer_display_name && component == other.component && resource_type == other.resource_type && description == other.description && properties == other.properties end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 182 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
162 163 164 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 162 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 171 def hash [id, name, customer_display_name, component, resource_type, description, properties].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
209 210 211 |
# File 'lib/oci/operator_access_control/models/operator_action.rb', line 209 def to_s to_hash.to_s end |