Class: OCI::OperatorAccessControl::Models::OperatorActionSummary
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::OperatorActionSummary
- Defined in:
- lib/oci/operator_access_control/models/operator_action_summary.rb
Overview
Details of the operator action. Operator actions are pre-defined set of commands available to the operator on different layers of the infrastructure.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
compartmentId for which the OperatorAction is applicable.
-
#component ⇒ String
Name of the component for which the operator action is applicable.
-
#description ⇒ String
Description of the operator action in terms of associated risk profile, and characteristics of the operating system commands made available to the operator under this operator action.
-
#id ⇒ String
[Required] Unique identifier assigned by Oracle to an operator action.
-
#lifecycle_state ⇒ String
The current lifecycle state of the operator action.
-
#name ⇒ String
[Required] Name of the operator action.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperatorActionSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OperatorActionSummary
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 83 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.component = attributes[:'component'] if attributes[:'component'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.description = attributes[:'description'] if attributes[:'description'] end |
Instance Attribute Details
#compartment_id ⇒ String
compartmentId for which the OperatorAction is applicable
31 32 33 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 31 def compartment_id @compartment_id end |
#component ⇒ String
Name of the component for which the operator action is applicable.
27 28 29 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 27 def component @component end |
#description ⇒ String
Description of the operator action in terms of associated risk profile, and characteristics of the operating system commands made available to the operator under this operator action.
41 42 43 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 41 def description @description end |
#id ⇒ String
[Required] Unique identifier assigned by Oracle to an operator action.
19 20 21 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 19 def id @id end |
#lifecycle_state ⇒ String
The current lifecycle state of the operator action.
35 36 37 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 35 def lifecycle_state @lifecycle_state end |
#name ⇒ String
[Required] Name of the operator action.
23 24 25 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 23 def name @name end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 44 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'component': :'component', 'compartment_id': :'compartmentId', 'lifecycle_state': :'lifecycleState', 'description': :'description' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'component': :'String', 'compartment_id': :'String', 'lifecycle_state': :'String', 'description': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 130 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && component == other.component && compartment_id == other.compartment_id && lifecycle_state == other.lifecycle_state && description == other.description end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 165 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
145 146 147 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 145 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
154 155 156 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 154 def hash [id, name, component, compartment_id, lifecycle_state, description].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
198 199 200 201 202 203 204 205 206 207 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 198 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
192 193 194 |
# File 'lib/oci/operator_access_control/models/operator_action_summary.rb', line 192 def to_s to_hash.to_s end |