Class: OCI::OperatorAccessControl::Models::OperatorControlAssignment

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/operator_access_control/models/operator_control_assignment.rb

Overview

An Operator Control Assignment identifies the target resource that is placed under the governance of an Operator Control. Creating an Operator Control Assignment Assignment with a time duration ensures that human accesses to the target resource will be governed by Operator Control for the duration specified.

Constant Summary collapse

RESOURCE_TYPE_ENUM =
[
  RESOURCE_TYPE_EXACC = 'EXACC'.freeze,
  RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATED = 'CREATED'.freeze,
  LIFECYCLE_STATE_APPLIED = 'APPLIED'.freeze,
  LIFECYCLE_STATE_APPLYFAILED = 'APPLYFAILED'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OperatorControlAssignment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :operator_control_id (String)

    The value to assign to the #operator_control_id property

  • :resource_id (String)

    The value to assign to the #resource_id property

  • :resource_name (String)

    The value to assign to the #resource_name property

  • :resource_type (String)

    The value to assign to the #resource_type property

  • :resource_compartment_id (String)

    The value to assign to the #resource_compartment_id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :time_assignment_from (DateTime)

    The value to assign to the #time_assignment_from property

  • :time_assignment_to (DateTime)

    The value to assign to the #time_assignment_to property

  • :is_enforced_always (BOOLEAN)

    The value to assign to the #is_enforced_always property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :assigner_id (String)

    The value to assign to the #assigner_id property

  • :time_of_assignment (DateTime)

    The value to assign to the #time_of_assignment property

  • :comment (String)

    The value to assign to the #comment property

  • :unassigner_id (String)

    The value to assign to the #unassigner_id property

  • :time_of_deletion (DateTime)

    The value to assign to the #time_of_deletion property

  • :detachment_description (String)

    The value to assign to the #detachment_description property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 189

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.operator_control_id = attributes[:'operatorControlId'] if attributes[:'operatorControlId']

  raise 'You cannot provide both :operatorControlId and :operator_control_id' if attributes.key?(:'operatorControlId') && attributes.key?(:'operator_control_id')

  self.operator_control_id = attributes[:'operator_control_id'] if attributes[:'operator_control_id']

  self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId']

  raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id')

  self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id']

  self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName']

  raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name')

  self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name']

  self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType']

  raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type')

  self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type']

  self.resource_compartment_id = attributes[:'resourceCompartmentId'] if attributes[:'resourceCompartmentId']

  raise 'You cannot provide both :resourceCompartmentId and :resource_compartment_id' if attributes.key?(:'resourceCompartmentId') && attributes.key?(:'resource_compartment_id')

  self.resource_compartment_id = attributes[:'resource_compartment_id'] if attributes[:'resource_compartment_id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.time_assignment_from = attributes[:'timeAssignmentFrom'] if attributes[:'timeAssignmentFrom']

  raise 'You cannot provide both :timeAssignmentFrom and :time_assignment_from' if attributes.key?(:'timeAssignmentFrom') && attributes.key?(:'time_assignment_from')

  self.time_assignment_from = attributes[:'time_assignment_from'] if attributes[:'time_assignment_from']

  self.time_assignment_to = attributes[:'timeAssignmentTo'] if attributes[:'timeAssignmentTo']

  raise 'You cannot provide both :timeAssignmentTo and :time_assignment_to' if attributes.key?(:'timeAssignmentTo') && attributes.key?(:'time_assignment_to')

  self.time_assignment_to = attributes[:'time_assignment_to'] if attributes[:'time_assignment_to']

  self.is_enforced_always = attributes[:'isEnforcedAlways'] unless attributes[:'isEnforcedAlways'].nil?

  raise 'You cannot provide both :isEnforcedAlways and :is_enforced_always' if attributes.key?(:'isEnforcedAlways') && attributes.key?(:'is_enforced_always')

  self.is_enforced_always = attributes[:'is_enforced_always'] unless attributes[:'is_enforced_always'].nil?

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.assigner_id = attributes[:'assignerId'] if attributes[:'assignerId']

  raise 'You cannot provide both :assignerId and :assigner_id' if attributes.key?(:'assignerId') && attributes.key?(:'assigner_id')

  self.assigner_id = attributes[:'assigner_id'] if attributes[:'assigner_id']

  self.time_of_assignment = attributes[:'timeOfAssignment'] if attributes[:'timeOfAssignment']

  raise 'You cannot provide both :timeOfAssignment and :time_of_assignment' if attributes.key?(:'timeOfAssignment') && attributes.key?(:'time_of_assignment')

  self.time_of_assignment = attributes[:'time_of_assignment'] if attributes[:'time_of_assignment']

  self.comment = attributes[:'comment'] if attributes[:'comment']

  self.unassigner_id = attributes[:'unassignerId'] if attributes[:'unassignerId']

  raise 'You cannot provide both :unassignerId and :unassigner_id' if attributes.key?(:'unassignerId') && attributes.key?(:'unassigner_id')

  self.unassigner_id = attributes[:'unassigner_id'] if attributes[:'unassigner_id']

  self.time_of_deletion = attributes[:'timeOfDeletion'] if attributes[:'timeOfDeletion']

  raise 'You cannot provide both :timeOfDeletion and :time_of_deletion' if attributes.key?(:'timeOfDeletion') && attributes.key?(:'time_of_deletion')

  self.time_of_deletion = attributes[:'time_of_deletion'] if attributes[:'time_of_deletion']

  self.detachment_description = attributes[:'detachmentDescription'] if attributes[:'detachmentDescription']

  raise 'You cannot provide both :detachmentDescription and :detachment_description' if attributes.key?(:'detachmentDescription') && attributes.key?(:'detachment_description')

  self.detachment_description = attributes[:'detachment_description'] if attributes[:'detachment_description']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#assigner_idString

The OCID of the user who created this operator control assignment.

Returns:

  • (String)


76
77
78
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 76

def assigner_id
  @assigner_id
end

#commentString

Comment about the assignment of the operator control to this target resource.

Returns:

  • (String)


85
86
87
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 85

def comment
  @comment
end

#compartment_idString

The OCID of the comparment that contains the operator control assignment.

Returns:

  • (String)


52
53
54
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 52

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace.

Returns:

  • (Hash<String, Hash<String, Object>>)


108
109
110
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 108

def defined_tags
  @defined_tags
end

#detachment_descriptionString

description containing reason for releasing of OperatorControl.

Returns:

  • (String)


98
99
100
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 98

def detachment_description
  @detachment_description
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.

Returns:

  • (Hash<String, String>)


103
104
105
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 103

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the operator control assignment.

Returns:

  • (String)


28
29
30
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 28

def id
  @id
end

#is_enforced_alwaysBOOLEAN

If set, then the target resource is always governed by the operator control.

Returns:

  • (BOOLEAN)


68
69
70
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 68

def is_enforced_always
  @is_enforced_always
end

#lifecycle_stateString

The current lifcycle state of the OperatorControl.

Returns:

  • (String)


72
73
74
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 72

def lifecycle_state
  @lifecycle_state
end

#operator_control_idString

[Required] The OCID of the operator control.

Returns:

  • (String)


32
33
34
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 32

def operator_control_id
  @operator_control_id
end

#resource_compartment_idString

The OCID of the compartment that contains the target resource.

Returns:

  • (String)


48
49
50
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 48

def resource_compartment_id
  @resource_compartment_id
end

#resource_idString

[Required] The OCID of the target resource.

Returns:

  • (String)


36
37
38
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 36

def resource_id
  @resource_id
end

#resource_nameString

[Required] Name of the target resource.

Returns:

  • (String)


40
41
42
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 40

def resource_name
  @resource_name
end

#resource_typeString

Type of the target resource.

Returns:

  • (String)


44
45
46
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 44

def resource_type
  @resource_type
end

#time_assignment_fromDateTime

The time at which the target resource will be brought under the governance of the operator control expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’

Returns:

  • (DateTime)


58
59
60
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 58

def time_assignment_from
  @time_assignment_from
end

#time_assignment_toDateTime

The time at which the target resource will leave the governance of the operator control expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’

Returns:

  • (DateTime)


64
65
66
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 64

def time_assignment_to
  @time_assignment_to
end

#time_of_assignmentDateTime

Time when the operator control assignment is created in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’

Returns:

  • (DateTime)


81
82
83
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 81

def time_of_assignment
  @time_of_assignment
end

#time_of_deletionDateTime

Time on which the operator control assignment was deleted in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’

Returns:

  • (DateTime)


94
95
96
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 94

def time_of_deletion
  @time_of_deletion
end

#unassigner_idString

User id who released the operatorControl.

Returns:

  • (String)


89
90
91
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 89

def unassigner_id
  @unassigner_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 111

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'operator_control_id': :'operatorControlId',
    'resource_id': :'resourceId',
    'resource_name': :'resourceName',
    'resource_type': :'resourceType',
    'resource_compartment_id': :'resourceCompartmentId',
    'compartment_id': :'compartmentId',
    'time_assignment_from': :'timeAssignmentFrom',
    'time_assignment_to': :'timeAssignmentTo',
    'is_enforced_always': :'isEnforcedAlways',
    'lifecycle_state': :'lifecycleState',
    'assigner_id': :'assignerId',
    'time_of_assignment': :'timeOfAssignment',
    'comment': :'comment',
    'unassigner_id': :'unassignerId',
    'time_of_deletion': :'timeOfDeletion',
    'detachment_description': :'detachmentDescription',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 138

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'operator_control_id': :'String',
    'resource_id': :'String',
    'resource_name': :'String',
    'resource_type': :'String',
    'resource_compartment_id': :'String',
    'compartment_id': :'String',
    'time_assignment_from': :'DateTime',
    'time_assignment_to': :'DateTime',
    'is_enforced_always': :'BOOLEAN',
    'lifecycle_state': :'String',
    'assigner_id': :'String',
    'time_of_assignment': :'DateTime',
    'comment': :'String',
    'unassigner_id': :'String',
    'time_of_deletion': :'DateTime',
    'detachment_description': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 335

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    operator_control_id == other.operator_control_id &&
    resource_id == other.resource_id &&
    resource_name == other.resource_name &&
    resource_type == other.resource_type &&
    resource_compartment_id == other.resource_compartment_id &&
    compartment_id == other.compartment_id &&
    time_assignment_from == other.time_assignment_from &&
    time_assignment_to == other.time_assignment_to &&
    is_enforced_always == other.is_enforced_always &&
    lifecycle_state == other.lifecycle_state &&
    assigner_id == other.assigner_id &&
    time_of_assignment == other.time_of_assignment &&
    comment == other.comment &&
    unassigner_id == other.unassigner_id &&
    time_of_deletion == other.time_of_deletion &&
    detachment_description == other.detachment_description &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 383

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


363
364
365
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 363

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



372
373
374
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 372

def hash
  [id, operator_control_id, resource_id, resource_name, resource_type, resource_compartment_id, compartment_id, time_assignment_from, time_assignment_to, is_enforced_always, lifecycle_state, assigner_id, time_of_assignment, comment, unassigner_id, time_of_deletion, detachment_description, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



416
417
418
419
420
421
422
423
424
425
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 416

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



410
411
412
# File 'lib/oci/operator_access_control/models/operator_control_assignment.rb', line 410

def to_s
  to_hash.to_s
end