Class: OCI::OperatorAccessControl::Models::OperatorControlAssignmentSummary
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::OperatorControlAssignmentSummary
- Defined in:
- lib/oci/operator_access_control/models/operator_control_assignment_summary.rb
Overview
Details of the operator control assignment.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATED = 'CREATED'.freeze, LIFECYCLE_STATE_APPLIED = 'APPLIED'.freeze, LIFECYCLE_STATE_APPLYFAILED = 'APPLYFAILED'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the operator control assignment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The OCID of the operator control assignment.
-
#is_enforced_always ⇒ BOOLEAN
If true, then the target resource is always governed by the operator control.
-
#lifecycle_state ⇒ String
The current lifcycle state of the OperatorControl.
-
#operator_control_id ⇒ String
[Required] The OCID of the operator control.
-
#resource_id ⇒ String
[Required] The OCID of the target resource being governed by the operator control.
-
#resource_type ⇒ String
Type of the target resource being governed by the operator control.
-
#time_assignment_from ⇒ DateTime
The time at which the target resource will be brought under the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_assignment_to ⇒ DateTime
The time at which the target resource will leave the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’.
-
#time_of_assignment ⇒ DateTime
Time when the operator control assignment is created in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OperatorControlAssignmentSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OperatorControlAssignmentSummary
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 130 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.operator_control_id = attributes[:'operatorControlId'] if attributes[:'operatorControlId'] raise 'You cannot provide both :operatorControlId and :operator_control_id' if attributes.key?(:'operatorControlId') && attributes.key?(:'operator_control_id') self.operator_control_id = attributes[:'operator_control_id'] if attributes[:'operator_control_id'] self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId'] raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_assignment_from = attributes[:'timeAssignmentFrom'] if attributes[:'timeAssignmentFrom'] raise 'You cannot provide both :timeAssignmentFrom and :time_assignment_from' if attributes.key?(:'timeAssignmentFrom') && attributes.key?(:'time_assignment_from') self.time_assignment_from = attributes[:'time_assignment_from'] if attributes[:'time_assignment_from'] self.time_assignment_to = attributes[:'timeAssignmentTo'] if attributes[:'timeAssignmentTo'] raise 'You cannot provide both :timeAssignmentTo and :time_assignment_to' if attributes.key?(:'timeAssignmentTo') && attributes.key?(:'time_assignment_to') self.time_assignment_to = attributes[:'time_assignment_to'] if attributes[:'time_assignment_to'] self.is_enforced_always = attributes[:'isEnforcedAlways'] unless attributes[:'isEnforcedAlways'].nil? raise 'You cannot provide both :isEnforcedAlways and :is_enforced_always' if attributes.key?(:'isEnforcedAlways') && attributes.key?(:'is_enforced_always') self.is_enforced_always = attributes[:'is_enforced_always'] unless attributes[:'is_enforced_always'].nil? self.time_of_assignment = attributes[:'timeOfAssignment'] if attributes[:'timeOfAssignment'] raise 'You cannot provide both :timeOfAssignment and :time_of_assignment' if attributes.key?(:'timeOfAssignment') && attributes.key?(:'time_of_assignment') self.time_of_assignment = attributes[:'time_of_assignment'] if attributes[:'time_of_assignment'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The OCID of the compartment that contains the operator control assignment.
37 38 39 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 37 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
70 71 72 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 70 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
65 66 67 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 65 def end |
#id ⇒ String
[Required] The OCID of the operator control assignment.
21 22 23 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 21 def id @id end |
#is_enforced_always ⇒ BOOLEAN
If true, then the target resource is always governed by the operator control. Otherwise governance is time-based as specified by timeAssignmentTo and timeAssignmentFrom.
51 52 53 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 51 def is_enforced_always @is_enforced_always end |
#lifecycle_state ⇒ String
The current lifcycle state of the OperatorControl.
60 61 62 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 60 def lifecycle_state @lifecycle_state end |
#operator_control_id ⇒ String
[Required] The OCID of the operator control.
25 26 27 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 25 def operator_control_id @operator_control_id end |
#resource_id ⇒ String
[Required] The OCID of the target resource being governed by the operator control.
29 30 31 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 29 def resource_id @resource_id end |
#resource_type ⇒ String
Type of the target resource being governed by the operator control.
33 34 35 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 33 def resource_type @resource_type end |
#time_assignment_from ⇒ DateTime
The time at which the target resource will be brought under the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
42 43 44 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 42 def time_assignment_from @time_assignment_from end |
#time_assignment_to ⇒ DateTime
The time at which the target resource will leave the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’
47 48 49 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 47 def time_assignment_to @time_assignment_to end |
#time_of_assignment ⇒ DateTime
Time when the operator control assignment is created in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
56 57 58 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 56 def time_of_assignment @time_of_assignment end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 73 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'operator_control_id': :'operatorControlId', 'resource_id': :'resourceId', 'resource_type': :'resourceType', 'compartment_id': :'compartmentId', 'time_assignment_from': :'timeAssignmentFrom', 'time_assignment_to': :'timeAssignmentTo', 'is_enforced_always': :'isEnforcedAlways', 'time_of_assignment': :'timeOfAssignment', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 93 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'operator_control_id': :'String', 'resource_id': :'String', 'resource_type': :'String', 'compartment_id': :'String', 'time_assignment_from': :'DateTime', 'time_assignment_to': :'DateTime', 'is_enforced_always': :'BOOLEAN', 'time_of_assignment': :'DateTime', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 225 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && operator_control_id == other.operator_control_id && resource_id == other.resource_id && resource_type == other.resource_type && compartment_id == other.compartment_id && time_assignment_from == other.time_assignment_from && time_assignment_to == other.time_assignment_to && is_enforced_always == other.is_enforced_always && time_of_assignment == other.time_of_assignment && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 266 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
246 247 248 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 246 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 255 def hash [id, operator_control_id, resource_id, resource_type, compartment_id, time_assignment_from, time_assignment_to, is_enforced_always, time_of_assignment, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
293 294 295 |
# File 'lib/oci/operator_access_control/models/operator_control_assignment_summary.rb', line 293 def to_s to_hash.to_s end |