Class: OCI::OperatorAccessControl::Models::OperatorControlSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/operator_access_control/models/operator_control_summary.rb

Overview

Summary of the OperatorControl.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATED = 'CREATED'.freeze,
  LIFECYCLE_STATE_ASSIGNED = 'ASSIGNED'.freeze,
  LIFECYCLE_STATE_UNASSIGNED = 'UNASSIGNED'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OperatorControlSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :operator_control_name (String)

    The value to assign to the #operator_control_name property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :is_fully_pre_approved (BOOLEAN)

    The value to assign to the #is_fully_pre_approved property

  • :time_of_creation (DateTime)

    The value to assign to the #time_of_creation property

  • :time_of_modification (DateTime)

    The value to assign to the #time_of_modification property

  • :time_of_deletion (DateTime)

    The value to assign to the #time_of_deletion property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 116

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.operator_control_name = attributes[:'operatorControlName'] if attributes[:'operatorControlName']

  raise 'You cannot provide both :operatorControlName and :operator_control_name' if attributes.key?(:'operatorControlName') && attributes.key?(:'operator_control_name')

  self.operator_control_name = attributes[:'operator_control_name'] if attributes[:'operator_control_name']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.is_fully_pre_approved = attributes[:'isFullyPreApproved'] unless attributes[:'isFullyPreApproved'].nil?

  raise 'You cannot provide both :isFullyPreApproved and :is_fully_pre_approved' if attributes.key?(:'isFullyPreApproved') && attributes.key?(:'is_fully_pre_approved')

  self.is_fully_pre_approved = attributes[:'is_fully_pre_approved'] unless attributes[:'is_fully_pre_approved'].nil?

  self.time_of_creation = attributes[:'timeOfCreation'] if attributes[:'timeOfCreation']

  raise 'You cannot provide both :timeOfCreation and :time_of_creation' if attributes.key?(:'timeOfCreation') && attributes.key?(:'time_of_creation')

  self.time_of_creation = attributes[:'time_of_creation'] if attributes[:'time_of_creation']

  self.time_of_modification = attributes[:'timeOfModification'] if attributes[:'timeOfModification']

  raise 'You cannot provide both :timeOfModification and :time_of_modification' if attributes.key?(:'timeOfModification') && attributes.key?(:'time_of_modification')

  self.time_of_modification = attributes[:'time_of_modification'] if attributes[:'time_of_modification']

  self.time_of_deletion = attributes[:'timeOfDeletion'] if attributes[:'timeOfDeletion']

  raise 'You cannot provide both :timeOfDeletion and :time_of_deletion' if attributes.key?(:'timeOfDeletion') && attributes.key?(:'time_of_deletion')

  self.time_of_deletion = attributes[:'time_of_deletion'] if attributes[:'time_of_deletion']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
end

Instance Attribute Details

#compartment_idString

The OCID of the compartment that contains the operator control.

Returns:

  • (String)


29
30
31
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 29

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace.

Returns:

  • (Hash<String, Hash<String, Object>>)


62
63
64
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 62

def defined_tags
  @defined_tags
end

#freeform_tagsHash<String, String>

Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.

Returns:

  • (Hash<String, String>)


57
58
59
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 57

def freeform_tags
  @freeform_tags
end

#idString

[Required] The OCID of the operator control.

Returns:

  • (String)


21
22
23
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 21

def id
  @id
end

#is_fully_pre_approvedBOOLEAN

Whether all operator actions are pre-approved. If yes, an access request associated with a resource governed by the operator control will be automatically approved by the system.

Returns:

  • (BOOLEAN)


33
34
35
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 33

def is_fully_pre_approved
  @is_fully_pre_approved
end

#lifecycle_stateString

The current lifecycle state of the operator control.

Returns:

  • (String)


52
53
54
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 52

def lifecycle_state
  @lifecycle_state
end

#operator_control_nameString

[Required] Name of the operator control.

Returns:

  • (String)


25
26
27
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 25

def operator_control_name
  @operator_control_name
end

#time_of_creationDateTime

Time when the operator control was created, expressed in [RFC 3339] (tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’

Returns:

  • (DateTime)


38
39
40
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 38

def time_of_creation
  @time_of_creation
end

#time_of_deletionDateTime

Time when the operator control was deleted, expressed in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’

Returns:

  • (DateTime)


48
49
50
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 48

def time_of_deletion
  @time_of_deletion
end

#time_of_modificationDateTime

Time when the operator control was last modified, expressed in [RFC 3339] (tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’

Returns:

  • (DateTime)


43
44
45
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 43

def time_of_modification
  @time_of_modification
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 65

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'operator_control_name': :'operatorControlName',
    'compartment_id': :'compartmentId',
    'is_fully_pre_approved': :'isFullyPreApproved',
    'time_of_creation': :'timeOfCreation',
    'time_of_modification': :'timeOfModification',
    'time_of_deletion': :'timeOfDeletion',
    'lifecycle_state': :'lifecycleState',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 83

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'operator_control_name': :'String',
    'compartment_id': :'String',
    'is_fully_pre_approved': :'BOOLEAN',
    'time_of_creation': :'DateTime',
    'time_of_modification': :'DateTime',
    'time_of_deletion': :'DateTime',
    'lifecycle_state': :'String',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 199

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    operator_control_name == other.operator_control_name &&
    compartment_id == other.compartment_id &&
    is_fully_pre_approved == other.is_fully_pre_approved &&
    time_of_creation == other.time_of_creation &&
    time_of_modification == other.time_of_modification &&
    time_of_deletion == other.time_of_deletion &&
    lifecycle_state == other.lifecycle_state &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 238

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 218

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



227
228
229
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 227

def hash
  [id, operator_control_name, compartment_id, is_fully_pre_approved, time_of_creation, time_of_modification, time_of_deletion, lifecycle_state, freeform_tags, defined_tags].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



265
266
267
# File 'lib/oci/operator_access_control/models/operator_control_summary.rb', line 265

def to_s
  to_hash.to_s
end