Class: OCI::OperatorAccessControl::Models::UpdateOperatorControlAssignmentDetails
- Inherits:
-
Object
- Object
- OCI::OperatorAccessControl::Models::UpdateOperatorControlAssignmentDetails
- Defined in:
- lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb
Overview
Details for modifying the Operator Control assignment.
Instance Attribute Summary collapse
-
#comment ⇒ String
Comment about the modification of the operator control assignment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#is_enforced_always ⇒ BOOLEAN
If true, then the target resource is always governed by the operator control.
-
#time_assignment_from ⇒ DateTime
The time at which the target resource will be brought under the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format.
-
#time_assignment_to ⇒ DateTime
The time at which the target resource will leave the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOperatorControlAssignmentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOperatorControlAssignmentDetails
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 78 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_assignment_from = attributes[:'timeAssignmentFrom'] if attributes[:'timeAssignmentFrom'] raise 'You cannot provide both :timeAssignmentFrom and :time_assignment_from' if attributes.key?(:'timeAssignmentFrom') && attributes.key?(:'time_assignment_from') self.time_assignment_from = attributes[:'time_assignment_from'] if attributes[:'time_assignment_from'] self.time_assignment_to = attributes[:'timeAssignmentTo'] if attributes[:'timeAssignmentTo'] raise 'You cannot provide both :timeAssignmentTo and :time_assignment_to' if attributes.key?(:'timeAssignmentTo') && attributes.key?(:'time_assignment_to') self.time_assignment_to = attributes[:'time_assignment_to'] if attributes[:'time_assignment_to'] self.is_enforced_always = attributes[:'isEnforcedAlways'] unless attributes[:'isEnforcedAlways'].nil? raise 'You cannot provide both :isEnforcedAlways and :is_enforced_always' if attributes.key?(:'isEnforcedAlways') && attributes.key?(:'is_enforced_always') self.is_enforced_always = attributes[:'is_enforced_always'] unless attributes[:'is_enforced_always'].nil? self.comment = attributes[:'comment'] if attributes[:'comment'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#comment ⇒ String
Comment about the modification of the operator control assignment.
26 27 28 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 26 def comment @comment end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace.
36 37 38 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 36 def end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
31 32 33 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 31 def end |
#is_enforced_always ⇒ BOOLEAN
If true, then the target resource is always governed by the operator control. Otherwise governance is time-based as specified by timeAssignmentTo and timeAssignmentFrom.
22 23 24 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 22 def is_enforced_always @is_enforced_always end |
#time_assignment_from ⇒ DateTime
The time at which the target resource will be brought under the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339) timestamp format. Example: ‘2020-05-22T21:10:29.600Z’
13 14 15 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 13 def time_assignment_from @time_assignment_from end |
#time_assignment_to ⇒ DateTime
The time at which the target resource will leave the governance of the operator control in [RFC 3339](tools.ietf.org/html/rfc3339)timestamp format.Example: ‘2020-05-22T21:10:29.600Z’
18 19 20 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 18 def time_assignment_to @time_assignment_to end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_assignment_from': :'timeAssignmentFrom', 'time_assignment_to': :'timeAssignmentTo', 'is_enforced_always': :'isEnforcedAlways', 'comment': :'comment', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 53 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_assignment_from': :'DateTime', 'time_assignment_to': :'DateTime', 'is_enforced_always': :'BOOLEAN', 'comment': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 124 def ==(other) return true if equal?(other) self.class == other.class && time_assignment_from == other.time_assignment_from && time_assignment_to == other.time_assignment_to && is_enforced_always == other.is_enforced_always && comment == other.comment && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 159 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
139 140 141 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 139 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 148 def hash [time_assignment_from, time_assignment_to, is_enforced_always, comment, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
186 187 188 |
# File 'lib/oci/operator_access_control/models/update_operator_control_assignment_details.rb', line 186 def to_s to_hash.to_s end |