Class: OCI::Opsi::Models::AutonomousDatabaseInsight

Inherits:
DatabaseInsight show all
Defined in:
lib/oci/opsi/models/autonomous_database_insight.rb

Overview

Database insight resource.

Constant Summary

Constants inherited from DatabaseInsight

DatabaseInsight::ENTITY_SOURCE_ENUM, DatabaseInsight::LIFECYCLE_STATE_ENUM, DatabaseInsight::STATUS_ENUM

Instance Attribute Summary collapse

Attributes inherited from DatabaseInsight

#compartment_id, #database_type, #database_version, #defined_tags, #entity_source, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #processor_count, #status, #system_tags, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from DatabaseInsight

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ AutonomousDatabaseInsight

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id proprety

  • :compartment_id (String)

    The value to assign to the #compartment_id proprety

  • :status (String)

    The value to assign to the #status proprety

  • :database_type (String)

    The value to assign to the #database_type proprety

  • :database_version (String)

    The value to assign to the #database_version proprety

  • :processor_count (Integer)

    The value to assign to the #processor_count proprety

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags proprety

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags proprety

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags proprety

  • :time_created (DateTime)

    The value to assign to the #time_created proprety

  • :time_updated (DateTime)

    The value to assign to the #time_updated proprety

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state proprety

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details proprety

  • :database_id (String)

    The value to assign to the #database_id property

  • :database_name (String)

    The value to assign to the #database_name property

  • :database_display_name (String)

    The value to assign to the #database_display_name property

  • :database_resource_type (String)

    The value to assign to the #database_resource_type property

  • :db_additional_details (Object)

    The value to assign to the #db_additional_details property



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 110

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['entitySource'] = 'AUTONOMOUS_DATABASE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.database_name = attributes[:'databaseName'] if attributes[:'databaseName']

  raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name')

  self.database_name = attributes[:'database_name'] if attributes[:'database_name']

  self.database_display_name = attributes[:'databaseDisplayName'] if attributes[:'databaseDisplayName']

  raise 'You cannot provide both :databaseDisplayName and :database_display_name' if attributes.key?(:'databaseDisplayName') && attributes.key?(:'database_display_name')

  self.database_display_name = attributes[:'database_display_name'] if attributes[:'database_display_name']

  self.database_resource_type = attributes[:'databaseResourceType'] if attributes[:'databaseResourceType']

  raise 'You cannot provide both :databaseResourceType and :database_resource_type' if attributes.key?(:'databaseResourceType') && attributes.key?(:'database_resource_type')

  self.database_resource_type = attributes[:'database_resource_type'] if attributes[:'database_resource_type']

  self.db_additional_details = attributes[:'dbAdditionalDetails'] if attributes[:'dbAdditionalDetails']

  raise 'You cannot provide both :dbAdditionalDetails and :db_additional_details' if attributes.key?(:'dbAdditionalDetails') && attributes.key?(:'db_additional_details')

  self.db_additional_details = attributes[:'db_additional_details'] if attributes[:'db_additional_details']
end

Instance Attribute Details

#database_display_nameString

Display name of database

Returns:

  • (String)


21
22
23
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 21

def database_display_name
  @database_display_name
end

#database_idString

Returns:

  • (String)


13
14
15
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 13

def database_id
  @database_id
end

#database_nameString

[Required] Name of database

Returns:

  • (String)


17
18
19
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 17

def database_name
  @database_name
end

#database_resource_typeString

[Required] OCI database resource type

Returns:

  • (String)


25
26
27
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 25

def database_resource_type
  @database_resource_type
end

#db_additional_detailsObject

Additional details of a database in JSON format. For autonomous databases, this is the AutonomousDatabase object serialized as a JSON string as defined in docs.cloud.oracle.com/en-us/iaas/api/#/en/database/20160918/AutonomousDatabase/. For EM, pass in null or an empty string. Note that this string needs to be escaped when specified in the curl command.

Returns:

  • (Object)


30
31
32
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 30

def db_additional_details
  @db_additional_details
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 33

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'entitySource',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'status': :'status',
    'database_type': :'databaseType',
    'database_version': :'databaseVersion',
    'processor_count': :'processorCount',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'database_id': :'databaseId',
    'database_name': :'databaseName',
    'database_display_name': :'databaseDisplayName',
    'database_resource_type': :'databaseResourceType',
    'db_additional_details': :'dbAdditionalDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 60

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'String',
    'id': :'String',
    'compartment_id': :'String',
    'status': :'String',
    'database_type': :'String',
    'database_version': :'String',
    'processor_count': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'database_id': :'String',
    'database_name': :'String',
    'database_display_name': :'String',
    'database_resource_type': :'String',
    'db_additional_details': :'Object'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 158

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    entity_source == other.entity_source &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    status == other.status &&
    database_type == other.database_type &&
    database_version == other.database_version &&
    processor_count == other.processor_count &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    database_id == other.database_id &&
    database_name == other.database_name &&
    database_display_name == other.database_display_name &&
    database_resource_type == other.database_resource_type &&
    db_additional_details == other.db_additional_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 206

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


186
187
188
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 186

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



195
196
197
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 195

def hash
  [entity_source, id, compartment_id, status, database_type, database_version, processor_count, freeform_tags, defined_tags, system_tags, time_created, time_updated, lifecycle_state, lifecycle_details, database_id, database_name, database_display_name, database_resource_type, db_additional_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



233
234
235
# File 'lib/oci/opsi/models/autonomous_database_insight.rb', line 233

def to_s
  to_hash.to_s
end