Class: OCI::Opsi::Models::DBOSConfigInstance
- Inherits:
-
DatabaseConfigurationMetricGroup
- Object
- DatabaseConfigurationMetricGroup
- OCI::Opsi::Models::DBOSConfigInstance
- Defined in:
- lib/oci/opsi/models/dbos_config_instance.rb
Overview
Configuration parameters defined for external databases instance level.
Constant Summary
Constants inherited from DatabaseConfigurationMetricGroup
OCI::Opsi::Models::DatabaseConfigurationMetricGroup::METRIC_NAME_ENUM
Instance Attribute Summary collapse
-
#host_name ⇒ String
[Required] Host name of the database instance.
-
#instance_name ⇒ String
[Required] Name of the database instance.
-
#num_cp_us ⇒ Integer
Total number of CPUs available.
-
#num_cpu_cores ⇒ Integer
Number of CPU cores available (includes subcores of multicore CPUs as well as single-core CPUs).
-
#num_cpu_sockets ⇒ Integer
Number of CPU Sockets available.
-
#physical_memory_bytes ⇒ Float
Total number of bytes of physical memory.
Attributes inherited from DatabaseConfigurationMetricGroup
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DBOSConfigInstance
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DatabaseConfigurationMetricGroup
Constructor Details
#initialize(attributes = {}) ⇒ DBOSConfigInstance
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 80 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['metricName'] = 'DB_OS_CONFIG_INSTANCE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.instance_name = attributes[:'instanceName'] if attributes[:'instanceName'] raise 'You cannot provide both :instanceName and :instance_name' if attributes.key?(:'instanceName') && attributes.key?(:'instance_name') self.instance_name = attributes[:'instance_name'] if attributes[:'instance_name'] self.host_name = attributes[:'hostName'] if attributes[:'hostName'] raise 'You cannot provide both :hostName and :host_name' if attributes.key?(:'hostName') && attributes.key?(:'host_name') self.host_name = attributes[:'host_name'] if attributes[:'host_name'] self.num_cp_us = attributes[:'numCPUs'] if attributes[:'numCPUs'] raise 'You cannot provide both :numCPUs and :num_cp_us' if attributes.key?(:'numCPUs') && attributes.key?(:'num_cp_us') self.num_cp_us = attributes[:'num_cp_us'] if attributes[:'num_cp_us'] self.num_cpu_cores = attributes[:'numCPUCores'] if attributes[:'numCPUCores'] raise 'You cannot provide both :numCPUCores and :num_cpu_cores' if attributes.key?(:'numCPUCores') && attributes.key?(:'num_cpu_cores') self.num_cpu_cores = attributes[:'num_cpu_cores'] if attributes[:'num_cpu_cores'] self.num_cpu_sockets = attributes[:'numCPUSockets'] if attributes[:'numCPUSockets'] raise 'You cannot provide both :numCPUSockets and :num_cpu_sockets' if attributes.key?(:'numCPUSockets') && attributes.key?(:'num_cpu_sockets') self.num_cpu_sockets = attributes[:'num_cpu_sockets'] if attributes[:'num_cpu_sockets'] self.physical_memory_bytes = attributes[:'physicalMemoryBytes'] if attributes[:'physicalMemoryBytes'] raise 'You cannot provide both :physicalMemoryBytes and :physical_memory_bytes' if attributes.key?(:'physicalMemoryBytes') && attributes.key?(:'physical_memory_bytes') self.physical_memory_bytes = attributes[:'physical_memory_bytes'] if attributes[:'physical_memory_bytes'] end |
Instance Attribute Details
#host_name ⇒ String
[Required] Host name of the database instance.
17 18 19 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 17 def host_name @host_name end |
#instance_name ⇒ String
[Required] Name of the database instance.
13 14 15 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 13 def instance_name @instance_name end |
#num_cp_us ⇒ Integer
Total number of CPUs available.
21 22 23 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 21 def num_cp_us @num_cp_us end |
#num_cpu_cores ⇒ Integer
Number of CPU cores available (includes subcores of multicore CPUs as well as single-core CPUs).
25 26 27 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 25 def num_cpu_cores @num_cpu_cores end |
#num_cpu_sockets ⇒ Integer
Number of CPU Sockets available.
29 30 31 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 29 def num_cpu_sockets @num_cpu_sockets end |
#physical_memory_bytes ⇒ Float
Total number of bytes of physical memory.
33 34 35 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 33 def physical_memory_bytes @physical_memory_bytes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 36 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'metric_name': :'metricName', 'time_collected': :'timeCollected', 'instance_name': :'instanceName', 'host_name': :'hostName', 'num_cp_us': :'numCPUs', 'num_cpu_cores': :'numCPUCores', 'num_cpu_sockets': :'numCPUSockets', 'physical_memory_bytes': :'physicalMemoryBytes' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 52 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'metric_name': :'String', 'time_collected': :'DateTime', 'instance_name': :'String', 'host_name': :'String', 'num_cp_us': :'Integer', 'num_cpu_cores': :'Integer', 'num_cpu_sockets': :'Integer', 'physical_memory_bytes': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 134 def ==(other) return true if equal?(other) self.class == other.class && metric_name == other.metric_name && time_collected == other.time_collected && instance_name == other.instance_name && host_name == other.host_name && num_cp_us == other.num_cp_us && num_cpu_cores == other.num_cpu_cores && num_cpu_sockets == other.num_cpu_sockets && physical_memory_bytes == other.physical_memory_bytes end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 171 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
151 152 153 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 151 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 160 def hash [metric_name, time_collected, instance_name, host_name, num_cp_us, num_cpu_cores, num_cpu_sockets, physical_memory_bytes].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
198 199 200 |
# File 'lib/oci/opsi/models/dbos_config_instance.rb', line 198 def to_s to_hash.to_s end |