Class: OCI::Opsi::Models::DatabaseConfigurationSummary
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::DatabaseConfigurationSummary
- Defined in:
- lib/oci/opsi/models/database_configuration_summary.rb
Overview
Summary of a database configuration for a resource. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
AutonomousDatabaseConfigurationSummary, EmManagedExternalDatabaseConfigurationSummary, MacsManagedExternalDatabaseConfigurationSummary
Constant Summary collapse
- ENTITY_SOURCE_ENUM =
[ ENTITY_SOURCE_AUTONOMOUS_DATABASE = 'AUTONOMOUS_DATABASE'.freeze, ENTITY_SOURCE_EM_MANAGED_EXTERNAL_DATABASE = 'EM_MANAGED_EXTERNAL_DATABASE'.freeze, ENTITY_SOURCE_MACS_MANAGED_EXTERNAL_DATABASE = 'MACS_MANAGED_EXTERNAL_DATABASE'.freeze, ENTITY_SOURCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cdb_name ⇒ String
[Required] Name of the CDB.Only applies to PDB.
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
-
#database_display_name ⇒ String
[Required] The user-friendly name for the database.
-
#database_insight_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.
-
#database_name ⇒ String
[Required] The database name.
-
#database_type ⇒ String
[Required] Operations Insights internal representation of the database type.
-
#database_version ⇒ String
[Required] The version of the database.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Defined tags for this resource.
-
#entity_source ⇒ String
[Required] Source of the database entity.
-
#freeform_tags ⇒ Hash<String, String>
[Required] Simple key-value pair that is applied without any predefined name, type or scope.
-
#processor_count ⇒ Integer
Processor count.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseConfigurationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseConfigurationSummary
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 139 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.database_insight_id = attributes[:'databaseInsightId'] if attributes[:'databaseInsightId'] raise 'You cannot provide both :databaseInsightId and :database_insight_id' if attributes.key?(:'databaseInsightId') && attributes.key?(:'database_insight_id') self.database_insight_id = attributes[:'database_insight_id'] if attributes[:'database_insight_id'] self.entity_source = attributes[:'entitySource'] if attributes[:'entitySource'] raise 'You cannot provide both :entitySource and :entity_source' if attributes.key?(:'entitySource') && attributes.key?(:'entity_source') self.entity_source = attributes[:'entity_source'] if attributes[:'entity_source'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.database_name = attributes[:'databaseName'] if attributes[:'databaseName'] raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name') self.database_name = attributes[:'database_name'] if attributes[:'database_name'] self.database_display_name = attributes[:'databaseDisplayName'] if attributes[:'databaseDisplayName'] raise 'You cannot provide both :databaseDisplayName and :database_display_name' if attributes.key?(:'databaseDisplayName') && attributes.key?(:'database_display_name') self.database_display_name = attributes[:'database_display_name'] if attributes[:'database_display_name'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion'] raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version') self.database_version = attributes[:'database_version'] if attributes[:'database_version'] self.cdb_name = attributes[:'cdbName'] if attributes[:'cdbName'] raise 'You cannot provide both :cdbName and :cdb_name' if attributes.key?(:'cdbName') && attributes.key?(:'cdb_name') self.cdb_name = attributes[:'cdb_name'] if attributes[:'cdb_name'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.processor_count = attributes[:'processorCount'] if attributes[:'processorCount'] raise 'You cannot provide both :processorCount and :processor_count' if attributes.key?(:'processorCount') && attributes.key?(:'processor_count') self.processor_count = attributes[:'processor_count'] if attributes[:'processor_count'] end |
Instance Attribute Details
#cdb_name ⇒ String
[Required] Name of the CDB.Only applies to PDB.
49 50 51 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 49 def cdb_name @cdb_name end |
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
29 30 31 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 29 def compartment_id @compartment_id end |
#database_display_name ⇒ String
[Required] The user-friendly name for the database. The name does not have to be unique.
37 38 39 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 37 def database_display_name @database_display_name end |
#database_insight_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.
21 22 23 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 21 def database_insight_id @database_insight_id end |
#database_name ⇒ String
[Required] The database name. The database name is unique within the tenancy.
33 34 35 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 33 def database_name @database_name end |
#database_type ⇒ String
[Required] Operations Insights internal representation of the database type.
41 42 43 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 41 def database_type @database_type end |
#database_version ⇒ String
[Required] The version of the database.
45 46 47 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 45 def database_version @database_version end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
55 56 57 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 55 def @defined_tags end |
#entity_source ⇒ String
[Required] Source of the database entity.
25 26 27 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 25 def entity_source @entity_source end |
#freeform_tags ⇒ Hash<String, String>
[Required] Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
61 62 63 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 61 def @freeform_tags end |
#processor_count ⇒ Integer
Processor count. This is the OCPU count for Autonomous Database and CPU core count for other database types.
65 66 67 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 65 def processor_count @processor_count end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 68 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'database_insight_id': :'databaseInsightId', 'entity_source': :'entitySource', 'compartment_id': :'compartmentId', 'database_name': :'databaseName', 'database_display_name': :'databaseDisplayName', 'database_type': :'databaseType', 'database_version': :'databaseVersion', 'cdb_name': :'cdbName', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'processor_count': :'processorCount' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 110 def self.get_subtype(object_hash) type = object_hash[:'entitySource'] # rubocop:disable Style/SymbolLiteral return 'OCI::Opsi::Models::EmManagedExternalDatabaseConfigurationSummary' if type == 'EM_MANAGED_EXTERNAL_DATABASE' return 'OCI::Opsi::Models::AutonomousDatabaseConfigurationSummary' if type == 'AUTONOMOUS_DATABASE' return 'OCI::Opsi::Models::MacsManagedExternalDatabaseConfigurationSummary' if type == 'MACS_MANAGED_EXTERNAL_DATABASE' # TODO: Log a warning when the subtype is not found. 'OCI::Opsi::Models::DatabaseConfigurationSummary' end |
.swagger_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 87 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'database_insight_id': :'String', 'entity_source': :'String', 'compartment_id': :'String', 'database_name': :'String', 'database_display_name': :'String', 'database_type': :'String', 'database_version': :'String', 'cdb_name': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'processor_count': :'Integer' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 232 def ==(other) return true if equal?(other) self.class == other.class && database_insight_id == other.database_insight_id && entity_source == other.entity_source && compartment_id == other.compartment_id && database_name == other.database_name && database_display_name == other.database_display_name && database_type == other.database_type && database_version == other.database_version && cdb_name == other.cdb_name && == other. && == other. && processor_count == other.processor_count end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 272 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
252 253 254 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 252 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 261 def hash [database_insight_id, entity_source, compartment_id, database_name, database_display_name, database_type, database_version, cdb_name, , , processor_count].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
299 300 301 |
# File 'lib/oci/opsi/models/database_configuration_summary.rb', line 299 def to_s to_hash.to_s end |