Class: OCI::Opsi::Models::DatabaseDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/database_details.rb

Overview

Partial information about the database which includes id, name, type.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DatabaseDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/opsi/models/database_details.rb', line 82

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.database_id = attributes[:'databaseId'] if attributes[:'databaseId']

  raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id')

  self.database_id = attributes[:'database_id'] if attributes[:'database_id']

  self.database_name = attributes[:'databaseName'] if attributes[:'databaseName']

  raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name')

  self.database_name = attributes[:'database_name'] if attributes[:'database_name']

  self.database_display_name = attributes[:'databaseDisplayName'] if attributes[:'databaseDisplayName']

  raise 'You cannot provide both :databaseDisplayName and :database_display_name' if attributes.key?(:'databaseDisplayName') && attributes.key?(:'database_display_name')

  self.database_display_name = attributes[:'database_display_name'] if attributes[:'database_display_name']

  self.database_type = attributes[:'databaseType'] if attributes[:'databaseType']

  raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type')

  self.database_type = attributes[:'database_type'] if attributes[:'database_type']

  self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion']

  raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version')

  self.database_version = attributes[:'database_version'] if attributes[:'database_version']

  self.instances = attributes[:'instances'] if attributes[:'instances']
end

Instance Attribute Details

#database_display_nameString

The user-friendly name for the database. The name does not have to be unique.

Returns:

  • (String)


25
26
27
# File 'lib/oci/opsi/models/database_details.rb', line 25

def database_display_name
  @database_display_name
end

#database_idString

Returns:

  • (String)


17
18
19
# File 'lib/oci/opsi/models/database_details.rb', line 17

def database_id
  @database_id
end

#database_nameString

[Required] The database name. The database name is unique within the tenancy.

Returns:

  • (String)


21
22
23
# File 'lib/oci/opsi/models/database_details.rb', line 21

def database_name
  @database_name
end

#database_typeString

[Required] Operations Insights internal representation of the database type.

Returns:

  • (String)


29
30
31
# File 'lib/oci/opsi/models/database_details.rb', line 29

def database_type
  @database_type
end

#database_versionString

The version of the database.

Returns:

  • (String)


33
34
35
# File 'lib/oci/opsi/models/database_details.rb', line 33

def database_version
  @database_version
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.

Returns:

  • (String)


13
14
15
# File 'lib/oci/opsi/models/database_details.rb', line 13

def id
  @id
end

#instancesArray<OCI::Opsi::Models::HostInstanceMap>

Array of hostname and instance name.



37
38
39
# File 'lib/oci/opsi/models/database_details.rb', line 37

def instances
  @instances
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/oci/opsi/models/database_details.rb', line 40

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'database_id': :'databaseId',
    'database_name': :'databaseName',
    'database_display_name': :'databaseDisplayName',
    'database_type': :'databaseType',
    'database_version': :'databaseVersion',
    'instances': :'instances'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/opsi/models/database_details.rb', line 55

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'database_id': :'String',
    'database_name': :'String',
    'database_display_name': :'String',
    'database_type': :'String',
    'database_version': :'String',
    'instances': :'Array<OCI::Opsi::Models::HostInstanceMap>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/oci/opsi/models/database_details.rb', line 130

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    database_id == other.database_id &&
    database_name == other.database_name &&
    database_display_name == other.database_display_name &&
    database_type == other.database_type &&
    database_version == other.database_version &&
    instances == other.instances
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/oci/opsi/models/database_details.rb', line 166

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


146
147
148
# File 'lib/oci/opsi/models/database_details.rb', line 146

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



155
156
157
# File 'lib/oci/opsi/models/database_details.rb', line 155

def hash
  [id, database_id, database_name, database_display_name, database_type, database_version, instances].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
# File 'lib/oci/opsi/models/database_details.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



193
194
195
# File 'lib/oci/opsi/models/database_details.rb', line 193

def to_s
  to_hash.to_s
end