Class: OCI::Opsi::Models::DatabaseInsight
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::DatabaseInsight
- Defined in:
- lib/oci/opsi/models/database_insight.rb
Overview
Database insight resource. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
AutonomousDatabaseInsight, EmManagedExternalDatabaseInsight, MacsManagedExternalDatabaseInsight
Constant Summary collapse
- ENTITY_SOURCE_ENUM =
[ ENTITY_SOURCE_AUTONOMOUS_DATABASE = 'AUTONOMOUS_DATABASE'.freeze, ENTITY_SOURCE_EM_MANAGED_EXTERNAL_DATABASE = 'EM_MANAGED_EXTERNAL_DATABASE'.freeze, ENTITY_SOURCE_MACS_MANAGED_EXTERNAL_DATABASE = 'MACS_MANAGED_EXTERNAL_DATABASE'.freeze, ENTITY_SOURCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_DISABLED = 'DISABLED'.freeze, STATUS_ENABLED = 'ENABLED'.freeze, STATUS_TERMINATED = 'TERMINATED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Compartment identifier of the database.
-
#database_type ⇒ String
Operations Insights internal representation of the database type.
-
#database_version ⇒ String
The version of the database.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Defined tags for this resource.
-
#entity_source ⇒ String
[Required] Source of the database entity.
-
#freeform_tags ⇒ Hash<String, String>
[Required] Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] Database insight identifier.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
[Required] The current state of the database.
-
#processor_count ⇒ Integer
Processor count.
-
#status ⇒ String
[Required] Indicates the status of a database insight in Operations Insights.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
[Required] The time the the database insight was first enabled.
-
#time_updated ⇒ DateTime
The time the database insight was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseInsight
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseInsight
Initializes the object
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/opsi/models/database_insight.rb', line 180 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.entity_source = attributes[:'entitySource'] if attributes[:'entitySource'] raise 'You cannot provide both :entitySource and :entity_source' if attributes.key?(:'entitySource') && attributes.key?(:'entity_source') self.entity_source = attributes[:'entity_source'] if attributes[:'entity_source'] self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.status = attributes[:'status'] if attributes[:'status'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion'] raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version') self.database_version = attributes[:'database_version'] if attributes[:'database_version'] self.processor_count = attributes[:'processorCount'] if attributes[:'processorCount'] raise 'You cannot provide both :processorCount and :processor_count' if attributes.key?(:'processorCount') && attributes.key?(:'processor_count') self.processor_count = attributes[:'processor_count'] if attributes[:'processor_count'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Compartment identifier of the database
47 48 49 |
# File 'lib/oci/opsi/models/database_insight.rb', line 47 def compartment_id @compartment_id end |
#database_type ⇒ String
Operations Insights internal representation of the database type.
55 56 57 |
# File 'lib/oci/opsi/models/database_insight.rb', line 55 def database_type @database_type end |
#database_version ⇒ String
The version of the database.
59 60 61 |
# File 'lib/oci/opsi/models/database_insight.rb', line 59 def database_version @database_version end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
[Required] Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
75 76 77 |
# File 'lib/oci/opsi/models/database_insight.rb', line 75 def end |
#entity_source ⇒ String
[Required] Source of the database entity.
39 40 41 |
# File 'lib/oci/opsi/models/database_insight.rb', line 39 def entity_source @entity_source end |
#freeform_tags ⇒ Hash<String, String>
[Required] Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
69 70 71 |
# File 'lib/oci/opsi/models/database_insight.rb', line 69 def end |
#id ⇒ String
[Required] Database insight identifier
43 44 45 |
# File 'lib/oci/opsi/models/database_insight.rb', line 43 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
97 98 99 |
# File 'lib/oci/opsi/models/database_insight.rb', line 97 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
[Required] The current state of the database.
93 94 95 |
# File 'lib/oci/opsi/models/database_insight.rb', line 93 def lifecycle_state @lifecycle_state end |
#processor_count ⇒ Integer
Processor count. This is the OCPU count for Autonomous Database and CPU core count for other database types.
63 64 65 |
# File 'lib/oci/opsi/models/database_insight.rb', line 63 def processor_count @processor_count end |
#status ⇒ String
[Required] Indicates the status of a database insight in Operations Insights
51 52 53 |
# File 'lib/oci/opsi/models/database_insight.rb', line 51 def status @status end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"free-tier-retained": "true"}`
81 82 83 |
# File 'lib/oci/opsi/models/database_insight.rb', line 81 def end |
#time_created ⇒ DateTime
[Required] The time the the database insight was first enabled. An RFC3339 formatted datetime string
85 86 87 |
# File 'lib/oci/opsi/models/database_insight.rb', line 85 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the database insight was updated. An RFC3339 formatted datetime string
89 90 91 |
# File 'lib/oci/opsi/models/database_insight.rb', line 89 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/oci/opsi/models/database_insight.rb', line 100 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_source': :'entitySource', 'id': :'id', 'compartment_id': :'compartmentId', 'status': :'status', 'database_type': :'databaseType', 'database_version': :'databaseVersion', 'processor_count': :'processorCount', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
148 149 150 151 152 153 154 155 156 157 |
# File 'lib/oci/opsi/models/database_insight.rb', line 148 def self.get_subtype(object_hash) type = object_hash[:'entitySource'] # rubocop:disable Style/SymbolLiteral return 'OCI::Opsi::Models::EmManagedExternalDatabaseInsight' if type == 'EM_MANAGED_EXTERNAL_DATABASE' return 'OCI::Opsi::Models::MacsManagedExternalDatabaseInsight' if type == 'MACS_MANAGED_EXTERNAL_DATABASE' return 'OCI::Opsi::Models::AutonomousDatabaseInsight' if type == 'AUTONOMOUS_DATABASE' # TODO: Log a warning when the subtype is not found. 'OCI::Opsi::Models::DatabaseInsight' end |
.swagger_types ⇒ Object
Attribute type mapping.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/oci/opsi/models/database_insight.rb', line 122 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_source': :'String', 'id': :'String', 'compartment_id': :'String', 'status': :'String', 'database_type': :'String', 'database_version': :'String', 'processor_count': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/oci/opsi/models/database_insight.rb', line 309 def ==(other) return true if equal?(other) self.class == other.class && entity_source == other.entity_source && id == other.id && compartment_id == other.compartment_id && status == other.status && database_type == other.database_type && database_version == other.database_version && processor_count == other.processor_count && == other. && == other. && == other. && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/oci/opsi/models/database_insight.rb', line 352 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
332 333 334 |
# File 'lib/oci/opsi/models/database_insight.rb', line 332 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
341 342 343 |
# File 'lib/oci/opsi/models/database_insight.rb', line 341 def hash [entity_source, id, compartment_id, status, database_type, database_version, processor_count, , , , time_created, time_updated, lifecycle_state, lifecycle_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
385 386 387 388 389 390 391 392 393 394 |
# File 'lib/oci/opsi/models/database_insight.rb', line 385 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
379 380 381 |
# File 'lib/oci/opsi/models/database_insight.rb', line 379 def to_s to_hash.to_s end |