Class: OCI::Opsi::Models::DatabaseInsightSummary
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::DatabaseInsightSummary
- Defined in:
- lib/oci/opsi/models/database_insight_summary.rb
Overview
Summary of a database insight resource. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
AutonomousDatabaseInsightSummary, EmManagedExternalDatabaseInsightSummary, MacsManagedExternalDatabaseInsightSummary
Constant Summary collapse
- ENTITY_SOURCE_ENUM =
[ ENTITY_SOURCE_AUTONOMOUS_DATABASE = 'AUTONOMOUS_DATABASE'.freeze, ENTITY_SOURCE_EM_MANAGED_EXTERNAL_DATABASE = 'EM_MANAGED_EXTERNAL_DATABASE'.freeze, ENTITY_SOURCE_MACS_MANAGED_EXTERNAL_DATABASE = 'MACS_MANAGED_EXTERNAL_DATABASE'.freeze, ENTITY_SOURCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_DISABLED = 'DISABLED'.freeze, STATUS_ENABLED = 'ENABLED'.freeze, STATUS_TERMINATED = 'TERMINATED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
-
#database_display_name ⇒ String
The user-friendly name for the database.
-
#database_host_names ⇒ Array<String>
The hostnames for the database.
-
#database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
-
#database_name ⇒ String
The database name.
-
#database_type ⇒ String
Operations Insights internal representation of the database type.
-
#database_version ⇒ String
The version of the database.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#entity_source ⇒ String
[Required] Source of the database entity.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
The current state of the database.
-
#processor_count ⇒ Integer
Processor count.
-
#status ⇒ String
Indicates the status of a database insight in Operations Insights.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource.
-
#time_created ⇒ DateTime
The time the the database insight was first enabled.
-
#time_updated ⇒ DateTime
The time the database insight was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DatabaseInsightSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DatabaseInsightSummary
Initializes the object
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 207 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.database_id = attributes[:'databaseId'] if attributes[:'databaseId'] raise 'You cannot provide both :databaseId and :database_id' if attributes.key?(:'databaseId') && attributes.key?(:'database_id') self.database_id = attributes[:'database_id'] if attributes[:'database_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.database_name = attributes[:'databaseName'] if attributes[:'databaseName'] raise 'You cannot provide both :databaseName and :database_name' if attributes.key?(:'databaseName') && attributes.key?(:'database_name') self.database_name = attributes[:'database_name'] if attributes[:'database_name'] self.database_display_name = attributes[:'databaseDisplayName'] if attributes[:'databaseDisplayName'] raise 'You cannot provide both :databaseDisplayName and :database_display_name' if attributes.key?(:'databaseDisplayName') && attributes.key?(:'database_display_name') self.database_display_name = attributes[:'database_display_name'] if attributes[:'database_display_name'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.database_version = attributes[:'databaseVersion'] if attributes[:'databaseVersion'] raise 'You cannot provide both :databaseVersion and :database_version' if attributes.key?(:'databaseVersion') && attributes.key?(:'database_version') self.database_version = attributes[:'database_version'] if attributes[:'database_version'] self.database_host_names = attributes[:'databaseHostNames'] if attributes[:'databaseHostNames'] raise 'You cannot provide both :databaseHostNames and :database_host_names' if attributes.key?(:'databaseHostNames') && attributes.key?(:'database_host_names') self.database_host_names = attributes[:'database_host_names'] if attributes[:'database_host_names'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] self.entity_source = attributes[:'entitySource'] if attributes[:'entitySource'] raise 'You cannot provide both :entitySource and :entity_source' if attributes.key?(:'entitySource') && attributes.key?(:'entity_source') self.entity_source = attributes[:'entity_source'] if attributes[:'entity_source'] self.processor_count = attributes[:'processorCount'] if attributes[:'processorCount'] raise 'You cannot provide both :processorCount and :processor_count' if attributes.key?(:'processorCount') && attributes.key?(:'processor_count') self.processor_count = attributes[:'processor_count'] if attributes[:'processor_count'] self.status = attributes[:'status'] if attributes[:'status'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] end |
Instance Attribute Details
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
46 47 48 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 46 def compartment_id @compartment_id end |
#database_display_name ⇒ String
The user-friendly name for the database. The name does not have to be unique.
54 55 56 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 54 def database_display_name @database_display_name end |
#database_host_names ⇒ Array<String>
The hostnames for the database.
66 67 68 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 66 def database_host_names @database_host_names end |
#database_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database.
42 43 44 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 42 def database_id @database_id end |
#database_name ⇒ String
The database name. The database name is unique within the tenancy.
50 51 52 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 50 def database_name @database_name end |
#database_type ⇒ String
Operations Insights internal representation of the database type.
58 59 60 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 58 def database_type @database_type end |
#database_version ⇒ String
The version of the database.
62 63 64 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 62 def database_version @database_version end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
78 79 80 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 78 def end |
#entity_source ⇒ String
[Required] Source of the database entity.
88 89 90 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 88 def entity_source @entity_source end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
72 73 74 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 72 def end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database insight resource.
38 39 40 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 38 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
112 113 114 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 112 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
The current state of the database.
108 109 110 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 108 def lifecycle_state @lifecycle_state end |
#processor_count ⇒ Integer
Processor count. This is the OCPU count for Autonomous Database and CPU core count for other database types.
92 93 94 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 92 def processor_count @processor_count end |
#status ⇒ String
Indicates the status of a database insight in Operations Insights
96 97 98 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 96 def status @status end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
System tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"free-tier-retained": "true"}`
84 85 86 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 84 def end |
#time_created ⇒ DateTime
The time the the database insight was first enabled. An RFC3339 formatted datetime string
100 101 102 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 100 def time_created @time_created end |
#time_updated ⇒ DateTime
The time the database insight was updated. An RFC3339 formatted datetime string
104 105 106 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 104 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 115 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'database_id': :'databaseId', 'compartment_id': :'compartmentId', 'database_name': :'databaseName', 'database_display_name': :'databaseDisplayName', 'database_type': :'databaseType', 'database_version': :'databaseVersion', 'database_host_names': :'databaseHostNames', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'entity_source': :'entitySource', 'processor_count': :'processorCount', 'status': :'status', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 171 def self.get_subtype(object_hash) type = object_hash[:'entitySource'] # rubocop:disable Style/SymbolLiteral return 'OCI::Opsi::Models::MacsManagedExternalDatabaseInsightSummary' if type == 'MACS_MANAGED_EXTERNAL_DATABASE' return 'OCI::Opsi::Models::AutonomousDatabaseInsightSummary' if type == 'AUTONOMOUS_DATABASE' return 'OCI::Opsi::Models::EmManagedExternalDatabaseInsightSummary' if type == 'EM_MANAGED_EXTERNAL_DATABASE' # TODO: Log a warning when the subtype is not found. 'OCI::Opsi::Models::DatabaseInsightSummary' end |
.swagger_types ⇒ Object
Attribute type mapping.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 141 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'database_id': :'String', 'compartment_id': :'String', 'database_name': :'String', 'database_display_name': :'String', 'database_type': :'String', 'database_version': :'String', 'database_host_names': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'entity_source': :'String', 'processor_count': :'Integer', 'status': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 360 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && database_id == other.database_id && compartment_id == other.compartment_id && database_name == other.database_name && database_display_name == other.database_display_name && database_type == other.database_type && database_version == other.database_version && database_host_names == other.database_host_names && == other. && == other. && == other. && entity_source == other.entity_source && processor_count == other.processor_count && status == other.status && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 407 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
387 388 389 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 387 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
396 397 398 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 396 def hash [id, database_id, compartment_id, database_name, database_display_name, database_type, database_version, database_host_names, , , , entity_source, processor_count, status, time_created, time_updated, lifecycle_state, lifecycle_details].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
440 441 442 443 444 445 446 447 448 449 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 440 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
434 435 436 |
# File 'lib/oci/opsi/models/database_insight_summary.rb', line 434 def to_s to_hash.to_s end |