Class: OCI::Opsi::Models::EmManagedExternalDatabaseInsightSummary
- Inherits:
-
DatabaseInsightSummary
- Object
- DatabaseInsightSummary
- OCI::Opsi::Models::EmManagedExternalDatabaseInsightSummary
- Defined in:
- lib/oci/opsi/models/em_managed_external_database_insight_summary.rb
Overview
Summary of a database insight resource.
Constant Summary
Constants inherited from DatabaseInsightSummary
DatabaseInsightSummary::ENTITY_SOURCE_ENUM, DatabaseInsightSummary::LIFECYCLE_STATE_ENUM, DatabaseInsightSummary::STATUS_ENUM
Instance Attribute Summary collapse
-
#enterprise_manager_bridge_id ⇒ String
[Required] OPSI Enterprise Manager Bridge OCID.
-
#enterprise_manager_entity_display_name ⇒ String
Enterprise Manager Entity Display Name.
-
#enterprise_manager_entity_identifier ⇒ String
[Required] Enterprise Manager Entity Unique Identifier.
-
#enterprise_manager_entity_name ⇒ String
[Required] Enterprise Manager Entity Name.
-
#enterprise_manager_entity_type ⇒ String
[Required] Enterprise Manager Entity Type.
-
#enterprise_manager_identifier ⇒ String
[Required] Enterprise Manager Unique Identifier.
-
#exadata_insight_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
Attributes inherited from DatabaseInsightSummary
#compartment_id, #database_display_name, #database_host_names, #database_id, #database_name, #database_type, #database_version, #defined_tags, #entity_source, #freeform_tags, #id, #lifecycle_details, #lifecycle_state, #processor_count, #status, #system_tags, #time_created, #time_updated
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmManagedExternalDatabaseInsightSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from DatabaseInsightSummary
Constructor Details
#initialize(attributes = {}) ⇒ EmManagedExternalDatabaseInsightSummary
Initializes the object
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 135 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['entitySource'] = 'EM_MANAGED_EXTERNAL_DATABASE' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.enterprise_manager_identifier = attributes[:'enterpriseManagerIdentifier'] if attributes[:'enterpriseManagerIdentifier'] raise 'You cannot provide both :enterpriseManagerIdentifier and :enterprise_manager_identifier' if attributes.key?(:'enterpriseManagerIdentifier') && attributes.key?(:'enterprise_manager_identifier') self.enterprise_manager_identifier = attributes[:'enterprise_manager_identifier'] if attributes[:'enterprise_manager_identifier'] self.enterprise_manager_entity_name = attributes[:'enterpriseManagerEntityName'] if attributes[:'enterpriseManagerEntityName'] raise 'You cannot provide both :enterpriseManagerEntityName and :enterprise_manager_entity_name' if attributes.key?(:'enterpriseManagerEntityName') && attributes.key?(:'enterprise_manager_entity_name') self.enterprise_manager_entity_name = attributes[:'enterprise_manager_entity_name'] if attributes[:'enterprise_manager_entity_name'] self.enterprise_manager_entity_type = attributes[:'enterpriseManagerEntityType'] if attributes[:'enterpriseManagerEntityType'] raise 'You cannot provide both :enterpriseManagerEntityType and :enterprise_manager_entity_type' if attributes.key?(:'enterpriseManagerEntityType') && attributes.key?(:'enterprise_manager_entity_type') self.enterprise_manager_entity_type = attributes[:'enterprise_manager_entity_type'] if attributes[:'enterprise_manager_entity_type'] self.enterprise_manager_entity_identifier = attributes[:'enterpriseManagerEntityIdentifier'] if attributes[:'enterpriseManagerEntityIdentifier'] raise 'You cannot provide both :enterpriseManagerEntityIdentifier and :enterprise_manager_entity_identifier' if attributes.key?(:'enterpriseManagerEntityIdentifier') && attributes.key?(:'enterprise_manager_entity_identifier') self.enterprise_manager_entity_identifier = attributes[:'enterprise_manager_entity_identifier'] if attributes[:'enterprise_manager_entity_identifier'] self.enterprise_manager_entity_display_name = attributes[:'enterpriseManagerEntityDisplayName'] if attributes[:'enterpriseManagerEntityDisplayName'] raise 'You cannot provide both :enterpriseManagerEntityDisplayName and :enterprise_manager_entity_display_name' if attributes.key?(:'enterpriseManagerEntityDisplayName') && attributes.key?(:'enterprise_manager_entity_display_name') self.enterprise_manager_entity_display_name = attributes[:'enterprise_manager_entity_display_name'] if attributes[:'enterprise_manager_entity_display_name'] self.enterprise_manager_bridge_id = attributes[:'enterpriseManagerBridgeId'] if attributes[:'enterpriseManagerBridgeId'] raise 'You cannot provide both :enterpriseManagerBridgeId and :enterprise_manager_bridge_id' if attributes.key?(:'enterpriseManagerBridgeId') && attributes.key?(:'enterprise_manager_bridge_id') self.enterprise_manager_bridge_id = attributes[:'enterprise_manager_bridge_id'] if attributes[:'enterprise_manager_bridge_id'] self.exadata_insight_id = attributes[:'exadataInsightId'] if attributes[:'exadataInsightId'] raise 'You cannot provide both :exadataInsightId and :exadata_insight_id' if attributes.key?(:'exadataInsightId') && attributes.key?(:'exadata_insight_id') self.exadata_insight_id = attributes[:'exadata_insight_id'] if attributes[:'exadata_insight_id'] end |
Instance Attribute Details
#enterprise_manager_bridge_id ⇒ String
[Required] OPSI Enterprise Manager Bridge OCID
33 34 35 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 33 def enterprise_manager_bridge_id @enterprise_manager_bridge_id end |
#enterprise_manager_entity_display_name ⇒ String
Enterprise Manager Entity Display Name
29 30 31 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 29 def enterprise_manager_entity_display_name @enterprise_manager_entity_display_name end |
#enterprise_manager_entity_identifier ⇒ String
[Required] Enterprise Manager Entity Unique Identifier
25 26 27 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 25 def enterprise_manager_entity_identifier @enterprise_manager_entity_identifier end |
#enterprise_manager_entity_name ⇒ String
[Required] Enterprise Manager Entity Name
17 18 19 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 17 def enterprise_manager_entity_name @enterprise_manager_entity_name end |
#enterprise_manager_entity_type ⇒ String
[Required] Enterprise Manager Entity Type
21 22 23 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 21 def enterprise_manager_entity_type @enterprise_manager_entity_type end |
#enterprise_manager_identifier ⇒ String
[Required] Enterprise Manager Unique Identifier
13 14 15 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 13 def enterprise_manager_identifier @enterprise_manager_identifier end |
#exadata_insight_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
37 38 39 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 37 def exadata_insight_id @exadata_insight_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 40 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'database_id': :'databaseId', 'compartment_id': :'compartmentId', 'database_name': :'databaseName', 'database_display_name': :'databaseDisplayName', 'database_type': :'databaseType', 'database_version': :'databaseVersion', 'database_host_names': :'databaseHostNames', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'entity_source': :'entitySource', 'processor_count': :'processorCount', 'status': :'status', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'enterprise_manager_identifier': :'enterpriseManagerIdentifier', 'enterprise_manager_entity_name': :'enterpriseManagerEntityName', 'enterprise_manager_entity_type': :'enterpriseManagerEntityType', 'enterprise_manager_entity_identifier': :'enterpriseManagerEntityIdentifier', 'enterprise_manager_entity_display_name': :'enterpriseManagerEntityDisplayName', 'enterprise_manager_bridge_id': :'enterpriseManagerBridgeId', 'exadata_insight_id': :'exadataInsightId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 73 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'database_id': :'String', 'compartment_id': :'String', 'database_name': :'String', 'database_display_name': :'String', 'database_type': :'String', 'database_version': :'String', 'database_host_names': :'Array<String>', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'entity_source': :'String', 'processor_count': :'Integer', 'status': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'enterprise_manager_identifier': :'String', 'enterprise_manager_entity_name': :'String', 'enterprise_manager_entity_type': :'String', 'enterprise_manager_entity_identifier': :'String', 'enterprise_manager_entity_display_name': :'String', 'enterprise_manager_bridge_id': :'String', 'exadata_insight_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 195 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && database_id == other.database_id && compartment_id == other.compartment_id && database_name == other.database_name && database_display_name == other.database_display_name && database_type == other.database_type && database_version == other.database_version && database_host_names == other.database_host_names && == other. && == other. && == other. && entity_source == other.entity_source && processor_count == other.processor_count && status == other.status && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && enterprise_manager_identifier == other.enterprise_manager_identifier && enterprise_manager_entity_name == other.enterprise_manager_entity_name && enterprise_manager_entity_type == other.enterprise_manager_entity_type && enterprise_manager_entity_identifier == other.enterprise_manager_entity_identifier && enterprise_manager_entity_display_name == other.enterprise_manager_entity_display_name && enterprise_manager_bridge_id == other.enterprise_manager_bridge_id && exadata_insight_id == other.exadata_insight_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 249 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
229 230 231 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 229 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
238 239 240 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 238 def hash [id, database_id, compartment_id, database_name, database_display_name, database_type, database_version, database_host_names, , , , entity_source, processor_count, status, time_created, time_updated, lifecycle_state, lifecycle_details, enterprise_manager_identifier, enterprise_manager_entity_name, enterprise_manager_entity_type, enterprise_manager_entity_identifier, enterprise_manager_entity_display_name, enterprise_manager_bridge_id, exadata_insight_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
282 283 284 285 286 287 288 289 290 291 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 282 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
276 277 278 |
# File 'lib/oci/opsi/models/em_managed_external_database_insight_summary.rb', line 276 def to_s to_hash.to_s end |