Class: OCI::Opsi::Models::EmManagedExternalHostInsightSummary

Inherits:
HostInsightSummary show all
Defined in:
lib/oci/opsi/models/em_managed_external_host_insight_summary.rb

Overview

Summary of an EM-managed external host insight resource.

Constant Summary collapse

PLATFORM_TYPE_ENUM =
[
  PLATFORM_TYPE_LINUX = 'LINUX'.freeze,
  PLATFORM_TYPE_SOLARIS = 'SOLARIS'.freeze,
  PLATFORM_TYPE_SUNOS = 'SUNOS'.freeze,
  PLATFORM_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Constants inherited from HostInsightSummary

HostInsightSummary::ENTITY_SOURCE_ENUM, HostInsightSummary::LIFECYCLE_STATE_ENUM, HostInsightSummary::STATUS_ENUM

Instance Attribute Summary collapse

Attributes inherited from HostInsightSummary

#compartment_id, #defined_tags, #entity_source, #freeform_tags, #host_display_name, #host_name, #host_type, #id, #lifecycle_details, #lifecycle_state, #processor_count, #status, #system_tags, #time_created, #time_updated

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from HostInsightSummary

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ EmManagedExternalHostInsightSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 144

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['entitySource'] = 'EM_MANAGED_EXTERNAL_HOST'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.enterprise_manager_identifier = attributes[:'enterpriseManagerIdentifier'] if attributes[:'enterpriseManagerIdentifier']

  raise 'You cannot provide both :enterpriseManagerIdentifier and :enterprise_manager_identifier' if attributes.key?(:'enterpriseManagerIdentifier') && attributes.key?(:'enterprise_manager_identifier')

  self.enterprise_manager_identifier = attributes[:'enterprise_manager_identifier'] if attributes[:'enterprise_manager_identifier']

  self.enterprise_manager_entity_name = attributes[:'enterpriseManagerEntityName'] if attributes[:'enterpriseManagerEntityName']

  raise 'You cannot provide both :enterpriseManagerEntityName and :enterprise_manager_entity_name' if attributes.key?(:'enterpriseManagerEntityName') && attributes.key?(:'enterprise_manager_entity_name')

  self.enterprise_manager_entity_name = attributes[:'enterprise_manager_entity_name'] if attributes[:'enterprise_manager_entity_name']

  self.enterprise_manager_entity_type = attributes[:'enterpriseManagerEntityType'] if attributes[:'enterpriseManagerEntityType']

  raise 'You cannot provide both :enterpriseManagerEntityType and :enterprise_manager_entity_type' if attributes.key?(:'enterpriseManagerEntityType') && attributes.key?(:'enterprise_manager_entity_type')

  self.enterprise_manager_entity_type = attributes[:'enterprise_manager_entity_type'] if attributes[:'enterprise_manager_entity_type']

  self.enterprise_manager_entity_identifier = attributes[:'enterpriseManagerEntityIdentifier'] if attributes[:'enterpriseManagerEntityIdentifier']

  raise 'You cannot provide both :enterpriseManagerEntityIdentifier and :enterprise_manager_entity_identifier' if attributes.key?(:'enterpriseManagerEntityIdentifier') && attributes.key?(:'enterprise_manager_entity_identifier')

  self.enterprise_manager_entity_identifier = attributes[:'enterprise_manager_entity_identifier'] if attributes[:'enterprise_manager_entity_identifier']

  self.enterprise_manager_entity_display_name = attributes[:'enterpriseManagerEntityDisplayName'] if attributes[:'enterpriseManagerEntityDisplayName']

  raise 'You cannot provide both :enterpriseManagerEntityDisplayName and :enterprise_manager_entity_display_name' if attributes.key?(:'enterpriseManagerEntityDisplayName') && attributes.key?(:'enterprise_manager_entity_display_name')

  self.enterprise_manager_entity_display_name = attributes[:'enterprise_manager_entity_display_name'] if attributes[:'enterprise_manager_entity_display_name']

  self.enterprise_manager_bridge_id = attributes[:'enterpriseManagerBridgeId'] if attributes[:'enterpriseManagerBridgeId']

  raise 'You cannot provide both :enterpriseManagerBridgeId and :enterprise_manager_bridge_id' if attributes.key?(:'enterpriseManagerBridgeId') && attributes.key?(:'enterprise_manager_bridge_id')

  self.enterprise_manager_bridge_id = attributes[:'enterprise_manager_bridge_id'] if attributes[:'enterprise_manager_bridge_id']

  self.platform_type = attributes[:'platformType'] if attributes[:'platformType']

  raise 'You cannot provide both :platformType and :platform_type' if attributes.key?(:'platformType') && attributes.key?(:'platform_type')

  self.platform_type = attributes[:'platform_type'] if attributes[:'platform_type']

  self.exadata_insight_id = attributes[:'exadataInsightId'] if attributes[:'exadataInsightId']

  raise 'You cannot provide both :exadataInsightId and :exadata_insight_id' if attributes.key?(:'exadataInsightId') && attributes.key?(:'exadata_insight_id')

  self.exadata_insight_id = attributes[:'exadata_insight_id'] if attributes[:'exadata_insight_id']
end

Instance Attribute Details

#enterprise_manager_bridge_idString

[Required] OPSI Enterprise Manager Bridge OCID

Returns:

  • (String)


41
42
43
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 41

def enterprise_manager_bridge_id
  @enterprise_manager_bridge_id
end

#enterprise_manager_entity_display_nameString

Enterprise Manager Entity Display Name

Returns:

  • (String)


37
38
39
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 37

def enterprise_manager_entity_display_name
  @enterprise_manager_entity_display_name
end

#enterprise_manager_entity_identifierString

[Required] Enterprise Manager Entity Unique Identifier

Returns:

  • (String)


33
34
35
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 33

def enterprise_manager_entity_identifier
  @enterprise_manager_entity_identifier
end

#enterprise_manager_entity_nameString

[Required] Enterprise Manager Entity Name

Returns:

  • (String)


25
26
27
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 25

def enterprise_manager_entity_name
  @enterprise_manager_entity_name
end

#enterprise_manager_entity_typeString

[Required] Enterprise Manager Entity Type

Returns:

  • (String)


29
30
31
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 29

def enterprise_manager_entity_type
  @enterprise_manager_entity_type
end

#enterprise_manager_identifierString

[Required] Enterprise Manager Unique Identifier

Returns:

  • (String)


21
22
23
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 21

def enterprise_manager_identifier
  @enterprise_manager_identifier
end

#exadata_insight_idString

Returns:

  • (String)


52
53
54
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 52

def exadata_insight_id
  @exadata_insight_id
end

#platform_typeString

Platform type. Supported platformType(s) for MACS-managed external host insight: [LINUX]. Supported platformType(s) for EM-managed external host insight: [LINUX, SOLARIS, SUNOS].

Returns:

  • (String)


48
49
50
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 48

def platform_type
  @platform_type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 55

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'entitySource',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'host_name': :'hostName',
    'host_display_name': :'hostDisplayName',
    'host_type': :'hostType',
    'processor_count': :'processorCount',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'status': :'status',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails',
    'enterprise_manager_identifier': :'enterpriseManagerIdentifier',
    'enterprise_manager_entity_name': :'enterpriseManagerEntityName',
    'enterprise_manager_entity_type': :'enterpriseManagerEntityType',
    'enterprise_manager_entity_identifier': :'enterpriseManagerEntityIdentifier',
    'enterprise_manager_entity_display_name': :'enterpriseManagerEntityDisplayName',
    'enterprise_manager_bridge_id': :'enterpriseManagerBridgeId',
    'platform_type': :'platformType',
    'exadata_insight_id': :'exadataInsightId'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 86

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'String',
    'id': :'String',
    'compartment_id': :'String',
    'host_name': :'String',
    'host_display_name': :'String',
    'host_type': :'String',
    'processor_count': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'status': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String',
    'enterprise_manager_identifier': :'String',
    'enterprise_manager_entity_name': :'String',
    'enterprise_manager_entity_type': :'String',
    'enterprise_manager_entity_identifier': :'String',
    'enterprise_manager_entity_display_name': :'String',
    'enterprise_manager_bridge_id': :'String',
    'platform_type': :'String',
    'exadata_insight_id': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 223

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    entity_source == other.entity_source &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    host_name == other.host_name &&
    host_display_name == other.host_display_name &&
    host_type == other.host_type &&
    processor_count == other.processor_count &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    status == other.status &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details &&
    enterprise_manager_identifier == other.enterprise_manager_identifier &&
    enterprise_manager_entity_name == other.enterprise_manager_entity_name &&
    enterprise_manager_entity_type == other.enterprise_manager_entity_type &&
    enterprise_manager_entity_identifier == other.enterprise_manager_entity_identifier &&
    enterprise_manager_entity_display_name == other.enterprise_manager_entity_display_name &&
    enterprise_manager_bridge_id == other.enterprise_manager_bridge_id &&
    platform_type == other.platform_type &&
    exadata_insight_id == other.exadata_insight_id
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 275

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


255
256
257
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 255

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



264
265
266
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 264

def hash
  [entity_source, id, compartment_id, host_name, host_display_name, host_type, processor_count, freeform_tags, defined_tags, system_tags, status, time_created, time_updated, lifecycle_state, lifecycle_details, enterprise_manager_identifier, enterprise_manager_entity_name, enterprise_manager_entity_type, enterprise_manager_entity_identifier, enterprise_manager_entity_display_name, enterprise_manager_bridge_id, platform_type, exadata_insight_id].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
311
312
313
314
315
316
317
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 308

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



302
303
304
# File 'lib/oci/opsi/models/em_managed_external_host_insight_summary.rb', line 302

def to_s
  to_hash.to_s
end