Class: OCI::Opsi::Models::ExadataInsightResourceInsightUtilizationItem

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb

Overview

Object containing current utilization, projected utilization, id and daysToReach high and low utilization value.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExadataInsightResourceInsightUtilizationItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 67

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.exadata_insight_id = attributes[:'exadataInsightId'] if attributes[:'exadataInsightId']

  raise 'You cannot provide both :exadataInsightId and :exadata_insight_id' if attributes.key?(:'exadataInsightId') && attributes.key?(:'exadata_insight_id')

  self.exadata_insight_id = attributes[:'exadata_insight_id'] if attributes[:'exadata_insight_id']

  self.current_utilization = attributes[:'currentUtilization'] if attributes[:'currentUtilization']

  raise 'You cannot provide both :currentUtilization and :current_utilization' if attributes.key?(:'currentUtilization') && attributes.key?(:'current_utilization')

  self.current_utilization = attributes[:'current_utilization'] if attributes[:'current_utilization']

  self.projected_utilization = attributes[:'projectedUtilization'] if attributes[:'projectedUtilization']

  raise 'You cannot provide both :projectedUtilization and :projected_utilization' if attributes.key?(:'projectedUtilization') && attributes.key?(:'projected_utilization')

  self.projected_utilization = attributes[:'projected_utilization'] if attributes[:'projected_utilization']

  self.days_to_reach_high_utilization = attributes[:'daysToReachHighUtilization'] if attributes[:'daysToReachHighUtilization']

  raise 'You cannot provide both :daysToReachHighUtilization and :days_to_reach_high_utilization' if attributes.key?(:'daysToReachHighUtilization') && attributes.key?(:'days_to_reach_high_utilization')

  self.days_to_reach_high_utilization = attributes[:'days_to_reach_high_utilization'] if attributes[:'days_to_reach_high_utilization']

  self.days_to_reach_low_utilization = attributes[:'daysToReachLowUtilization'] if attributes[:'daysToReachLowUtilization']

  raise 'You cannot provide both :daysToReachLowUtilization and :days_to_reach_low_utilization' if attributes.key?(:'daysToReachLowUtilization') && attributes.key?(:'days_to_reach_low_utilization')

  self.days_to_reach_low_utilization = attributes[:'days_to_reach_low_utilization'] if attributes[:'days_to_reach_low_utilization']
end

Instance Attribute Details

#current_utilizationFloat

[Required] Current utilization

Returns:

  • (Float)


16
17
18
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 16

def current_utilization
  @current_utilization
end

#days_to_reach_high_utilizationInteger

[Required] Days to reach projected high utilization

Returns:

  • (Integer)


24
25
26
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 24

def days_to_reach_high_utilization
  @days_to_reach_high_utilization
end

#days_to_reach_low_utilizationInteger

[Required] Days to reach projected low utilization

Returns:

  • (Integer)


28
29
30
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 28

def days_to_reach_low_utilization
  @days_to_reach_low_utilization
end

#exadata_insight_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.

Returns:

  • (String)


12
13
14
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 12

def exadata_insight_id
  @exadata_insight_id
end

#projected_utilizationFloat

[Required] Projected utilization

Returns:

  • (Float)


20
21
22
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 20

def projected_utilization
  @projected_utilization
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 31

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'exadata_insight_id': :'exadataInsightId',
    'current_utilization': :'currentUtilization',
    'projected_utilization': :'projectedUtilization',
    'days_to_reach_high_utilization': :'daysToReachHighUtilization',
    'days_to_reach_low_utilization': :'daysToReachLowUtilization'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 44

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'exadata_insight_id': :'String',
    'current_utilization': :'Float',
    'projected_utilization': :'Float',
    'days_to_reach_high_utilization': :'Integer',
    'days_to_reach_low_utilization': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



111
112
113
114
115
116
117
118
119
120
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 111

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    exadata_insight_id == other.exadata_insight_id &&
    current_utilization == other.current_utilization &&
    projected_utilization == other.projected_utilization &&
    days_to_reach_high_utilization == other.days_to_reach_high_utilization &&
    days_to_reach_low_utilization == other.days_to_reach_low_utilization
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 145

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


125
126
127
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 125

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



134
135
136
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 134

def hash
  [exadata_insight_id, current_utilization, projected_utilization, days_to_reach_high_utilization, days_to_reach_low_utilization].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



172
173
174
# File 'lib/oci/opsi/models/exadata_insight_resource_insight_utilization_item.rb', line 172

def to_s
  to_hash.to_s
end