Class: OCI::Opsi::Models::HostInsight

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/host_insight.rb

Overview

Host insight resource. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class

Direct Known Subclasses

MacsManagedExternalHostInsight

Constant Summary collapse

ENTITY_SOURCE_ENUM =
[
  ENTITY_SOURCE_MACS_MANAGED_EXTERNAL_HOST = 'MACS_MANAGED_EXTERNAL_HOST'.freeze,
  ENTITY_SOURCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
STATUS_ENUM =
[
  STATUS_DISABLED = 'DISABLED'.freeze,
  STATUS_ENABLED = 'ENABLED'.freeze,
  STATUS_TERMINATED = 'TERMINATED'.freeze,
  STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HostInsight

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :entity_source (String)

    The value to assign to the #entity_source property

  • :id (String)

    The value to assign to the #id property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :host_name (String)

    The value to assign to the #host_name property

  • :host_display_name (String)

    The value to assign to the #host_display_name property

  • :host_type (String)

    The value to assign to the #host_type property

  • :processor_count (Integer)

    The value to assign to the #processor_count property

  • :freeform_tags (Hash<String, String>)

    The value to assign to the #freeform_tags property

  • :defined_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #defined_tags property

  • :system_tags (Hash<String, Hash<String, Object>>)

    The value to assign to the #system_tags property

  • :status (String)

    The value to assign to the #status property

  • :time_created (DateTime)

    The value to assign to the #time_created property

  • :time_updated (DateTime)

    The value to assign to the #time_updated property

  • :lifecycle_state (String)

    The value to assign to the #lifecycle_state property

  • :lifecycle_details (String)

    The value to assign to the #lifecycle_details property



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/oci/opsi/models/host_insight.rb', line 182

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.entity_source = attributes[:'entitySource'] if attributes[:'entitySource']

  raise 'You cannot provide both :entitySource and :entity_source' if attributes.key?(:'entitySource') && attributes.key?(:'entity_source')

  self.entity_source = attributes[:'entity_source'] if attributes[:'entity_source']

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.host_name = attributes[:'hostName'] if attributes[:'hostName']

  raise 'You cannot provide both :hostName and :host_name' if attributes.key?(:'hostName') && attributes.key?(:'host_name')

  self.host_name = attributes[:'host_name'] if attributes[:'host_name']

  self.host_display_name = attributes[:'hostDisplayName'] if attributes[:'hostDisplayName']

  raise 'You cannot provide both :hostDisplayName and :host_display_name' if attributes.key?(:'hostDisplayName') && attributes.key?(:'host_display_name')

  self.host_display_name = attributes[:'host_display_name'] if attributes[:'host_display_name']

  self.host_type = attributes[:'hostType'] if attributes[:'hostType']

  raise 'You cannot provide both :hostType and :host_type' if attributes.key?(:'hostType') && attributes.key?(:'host_type')

  self.host_type = attributes[:'host_type'] if attributes[:'host_type']

  self.processor_count = attributes[:'processorCount'] if attributes[:'processorCount']

  raise 'You cannot provide both :processorCount and :processor_count' if attributes.key?(:'processorCount') && attributes.key?(:'processor_count')

  self.processor_count = attributes[:'processor_count'] if attributes[:'processor_count']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

  raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

  self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

  self.status = attributes[:'status'] if attributes[:'status']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

  raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

  self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.

Returns:

  • (String)


44
45
46
# File 'lib/oci/opsi/models/host_insight.rb', line 44

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

[Required] Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


72
73
74
# File 'lib/oci/opsi/models/host_insight.rb', line 72

def defined_tags
  @defined_tags
end

#entity_sourceString

[Required] Source of the host entity.

Returns:

  • (String)


36
37
38
# File 'lib/oci/opsi/models/host_insight.rb', line 36

def entity_source
  @entity_source
end

#freeform_tagsHash<String, String>

[Required] Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`

Returns:

  • (Hash<String, String>)


66
67
68
# File 'lib/oci/opsi/models/host_insight.rb', line 66

def freeform_tags
  @freeform_tags
end

#host_display_nameString

The user-friendly name for the host. The name does not have to be unique.

Returns:

  • (String)


52
53
54
# File 'lib/oci/opsi/models/host_insight.rb', line 52

def host_display_name
  @host_display_name
end

#host_nameString

[Required] The host name. The host name is unique amongst the hosts managed by the same management agent.

Returns:

  • (String)


48
49
50
# File 'lib/oci/opsi/models/host_insight.rb', line 48

def host_name
  @host_name
end

#host_typeString

Operations Insights internal representation of the host type. Possible value is EXTERNAL-HOST.

Returns:

  • (String)


56
57
58
# File 'lib/oci/opsi/models/host_insight.rb', line 56

def host_type
  @host_type
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the host insight resource.

Returns:

  • (String)


40
41
42
# File 'lib/oci/opsi/models/host_insight.rb', line 40

def id
  @id
end

#lifecycle_detailsString

A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.

Returns:

  • (String)


98
99
100
# File 'lib/oci/opsi/models/host_insight.rb', line 98

def lifecycle_details
  @lifecycle_details
end

#lifecycle_stateString

[Required] The current state of the host.

Returns:

  • (String)


94
95
96
# File 'lib/oci/opsi/models/host_insight.rb', line 94

def lifecycle_state
  @lifecycle_state
end

#processor_countInteger

Processor count. This is the OCPU count for Autonomous Database and CPU core count for other database types.

Returns:

  • (Integer)


60
61
62
# File 'lib/oci/opsi/models/host_insight.rb', line 60

def processor_count
  @processor_count
end

#statusString

[Required] Indicates the status of a host insight in Operations Insights

Returns:

  • (String)


82
83
84
# File 'lib/oci/opsi/models/host_insight.rb', line 82

def status
  @status
end

#system_tagsHash<String, Hash<String, Object>>

System tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"free-tier-retained": "true"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


78
79
80
# File 'lib/oci/opsi/models/host_insight.rb', line 78

def system_tags
  @system_tags
end

#time_createdDateTime

[Required] The time the the host insight was first enabled. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


86
87
88
# File 'lib/oci/opsi/models/host_insight.rb', line 86

def time_created
  @time_created
end

#time_updatedDateTime

The time the host insight was updated. An RFC3339 formatted datetime string

Returns:

  • (DateTime)


90
91
92
# File 'lib/oci/opsi/models/host_insight.rb', line 90

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/oci/opsi/models/host_insight.rb', line 101

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'entitySource',
    'id': :'id',
    'compartment_id': :'compartmentId',
    'host_name': :'hostName',
    'host_display_name': :'hostDisplayName',
    'host_type': :'hostType',
    'processor_count': :'processorCount',
    'freeform_tags': :'freeformTags',
    'defined_tags': :'definedTags',
    'system_tags': :'systemTags',
    'status': :'status',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated',
    'lifecycle_state': :'lifecycleState',
    'lifecycle_details': :'lifecycleDetails'
    # rubocop:enable Style/SymbolLiteral
  }
end

.get_subtype(object_hash) ⇒ Object

Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.



151
152
153
154
155
156
157
158
# File 'lib/oci/opsi/models/host_insight.rb', line 151

def self.get_subtype(object_hash)
  type = object_hash[:'entitySource'] # rubocop:disable Style/SymbolLiteral

  return 'OCI::Opsi::Models::MacsManagedExternalHostInsight' if type == 'MACS_MANAGED_EXTERNAL_HOST'

  # TODO: Log a warning when the subtype is not found.
  'OCI::Opsi::Models::HostInsight'
end

.swagger_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/oci/opsi/models/host_insight.rb', line 124

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'entity_source': :'String',
    'id': :'String',
    'compartment_id': :'String',
    'host_name': :'String',
    'host_display_name': :'String',
    'host_type': :'String',
    'processor_count': :'Integer',
    'freeform_tags': :'Hash<String, String>',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'system_tags': :'Hash<String, Hash<String, Object>>',
    'status': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime',
    'lifecycle_state': :'String',
    'lifecycle_details': :'String'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/oci/opsi/models/host_insight.rb', line 317

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    entity_source == other.entity_source &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    host_name == other.host_name &&
    host_display_name == other.host_display_name &&
    host_type == other.host_type &&
    processor_count == other.processor_count &&
    freeform_tags == other.freeform_tags &&
    defined_tags == other.defined_tags &&
    system_tags == other.system_tags &&
    status == other.status &&
    time_created == other.time_created &&
    time_updated == other.time_updated &&
    lifecycle_state == other.lifecycle_state &&
    lifecycle_details == other.lifecycle_details
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/oci/opsi/models/host_insight.rb', line 361

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


341
342
343
# File 'lib/oci/opsi/models/host_insight.rb', line 341

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



350
351
352
# File 'lib/oci/opsi/models/host_insight.rb', line 350

def hash
  [entity_source, id, compartment_id, host_name, host_display_name, host_type, processor_count, freeform_tags, defined_tags, system_tags, status, time_created, time_updated, lifecycle_state, lifecycle_details].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



394
395
396
397
398
399
400
401
402
403
# File 'lib/oci/opsi/models/host_insight.rb', line 394

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



388
389
390
# File 'lib/oci/opsi/models/host_insight.rb', line 388

def to_s
  to_hash.to_s
end