Class: OCI::Opsi::Models::MacsManagedExternalHostInsight
- Inherits:
-
HostInsight
- Object
- HostInsight
- OCI::Opsi::Models::MacsManagedExternalHostInsight
- Defined in:
- lib/oci/opsi/models/macs_managed_external_host_insight.rb
Overview
Host insight resource.
Constant Summary collapse
- PLATFORM_TYPE_ENUM =
[ PLATFORM_TYPE_LINUX = 'LINUX'.freeze, PLATFORM_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from HostInsight
HostInsight::ENTITY_SOURCE_ENUM, HostInsight::LIFECYCLE_STATE_ENUM, HostInsight::STATUS_ENUM
Instance Attribute Summary collapse
-
#management_agent_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Management Agent.
-
#platform_name ⇒ String
Platform name.
-
#platform_type ⇒ String
Platform type.
-
#platform_version ⇒ String
Platform version.
Attributes inherited from HostInsight
#compartment_id, #defined_tags, #entity_source, #freeform_tags, #host_display_name, #host_name, #host_type, #id, #lifecycle_details, #lifecycle_state, #processor_count, #status, #system_tags, #time_created, #time_updated
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MacsManagedExternalHostInsight
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from HostInsight
Constructor Details
#initialize(attributes = {}) ⇒ MacsManagedExternalHostInsight
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 111 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['entitySource'] = 'MACS_MANAGED_EXTERNAL_HOST' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.management_agent_id = attributes[:'managementAgentId'] if attributes[:'managementAgentId'] raise 'You cannot provide both :managementAgentId and :management_agent_id' if attributes.key?(:'managementAgentId') && attributes.key?(:'management_agent_id') self.management_agent_id = attributes[:'management_agent_id'] if attributes[:'management_agent_id'] self.platform_name = attributes[:'platformName'] if attributes[:'platformName'] raise 'You cannot provide both :platformName and :platform_name' if attributes.key?(:'platformName') && attributes.key?(:'platform_name') self.platform_name = attributes[:'platform_name'] if attributes[:'platform_name'] self.platform_type = attributes[:'platformType'] if attributes[:'platformType'] raise 'You cannot provide both :platformType and :platform_type' if attributes.key?(:'platformType') && attributes.key?(:'platform_type') self.platform_type = attributes[:'platform_type'] if attributes[:'platform_type'] self.platform_version = attributes[:'platformVersion'] if attributes[:'platformVersion'] raise 'You cannot provide both :platformVersion and :platform_version' if attributes.key?(:'platformVersion') && attributes.key?(:'platform_version') self.platform_version = attributes[:'platform_version'] if attributes[:'platform_version'] end |
Instance Attribute Details
#management_agent_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Management Agent
19 20 21 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 19 def management_agent_id @management_agent_id end |
#platform_name ⇒ String
Platform name.
23 24 25 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 23 def platform_name @platform_name end |
#platform_type ⇒ String
Platform type.
27 28 29 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 27 def platform_type @platform_type end |
#platform_version ⇒ String
Platform version.
31 32 33 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 31 def platform_version @platform_version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 34 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'entity_source': :'entitySource', 'id': :'id', 'compartment_id': :'compartmentId', 'host_name': :'hostName', 'host_display_name': :'hostDisplayName', 'host_type': :'hostType', 'processor_count': :'processorCount', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags', 'status': :'status', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'management_agent_id': :'managementAgentId', 'platform_name': :'platformName', 'platform_type': :'platformType', 'platform_version': :'platformVersion' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'entity_source': :'String', 'id': :'String', 'compartment_id': :'String', 'host_name': :'String', 'host_display_name': :'String', 'host_type': :'String', 'processor_count': :'Integer', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>', 'status': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'management_agent_id': :'String', 'platform_name': :'String', 'platform_type': :'String', 'platform_version': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 166 def ==(other) return true if equal?(other) self.class == other.class && entity_source == other.entity_source && id == other.id && compartment_id == other.compartment_id && host_name == other.host_name && host_display_name == other.host_display_name && host_type == other.host_type && processor_count == other.processor_count && == other. && == other. && == other. && status == other.status && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && management_agent_id == other.management_agent_id && platform_name == other.platform_name && platform_type == other.platform_type && platform_version == other.platform_version end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 214 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
194 195 196 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 194 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 203 def hash [entity_source, id, compartment_id, host_name, host_display_name, host_type, processor_count, , , , status, time_created, time_updated, lifecycle_state, lifecycle_details, management_agent_id, platform_name, platform_type, platform_version].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
241 242 243 |
# File 'lib/oci/opsi/models/macs_managed_external_host_insight.rb', line 241 def to_s to_hash.to_s end |