Class: OCI::Opsi::Models::ResourceStatistics
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::ResourceStatistics
- Defined in:
- lib/oci/opsi/models/resource_statistics.rb
Overview
Contains resource statistics with usage unit
Instance Attribute Summary collapse
-
#base_capacity ⇒ Float
The base allocated amount of the resource metric type (CPU, STORAGE).
-
#capacity ⇒ Float
[Required] The maximum allocated amount of the resource metric type (CPU, STORAGE).
-
#is_auto_scaling_enabled ⇒ BOOLEAN
Indicates if auto scaling feature is enabled or disabled on a database.
-
#usage ⇒ Float
[Required] Total amount used of the resource metric type (CPU, STORAGE).
-
#usage_change_percent ⇒ Float
[Required] Change in resource utilization in percentage.
-
#utilization_percent ⇒ Float
[Required] Resource utilization in percentage.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourceStatistics
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ResourceStatistics
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 77 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.usage = attributes[:'usage'] if attributes[:'usage'] self.capacity = attributes[:'capacity'] if attributes[:'capacity'] self.base_capacity = attributes[:'baseCapacity'] if attributes[:'baseCapacity'] raise 'You cannot provide both :baseCapacity and :base_capacity' if attributes.key?(:'baseCapacity') && attributes.key?(:'base_capacity') self.base_capacity = attributes[:'base_capacity'] if attributes[:'base_capacity'] self.is_auto_scaling_enabled = attributes[:'isAutoScalingEnabled'] unless attributes[:'isAutoScalingEnabled'].nil? raise 'You cannot provide both :isAutoScalingEnabled and :is_auto_scaling_enabled' if attributes.key?(:'isAutoScalingEnabled') && attributes.key?(:'is_auto_scaling_enabled') self.is_auto_scaling_enabled = attributes[:'is_auto_scaling_enabled'] unless attributes[:'is_auto_scaling_enabled'].nil? self.utilization_percent = attributes[:'utilizationPercent'] if attributes[:'utilizationPercent'] raise 'You cannot provide both :utilizationPercent and :utilization_percent' if attributes.key?(:'utilizationPercent') && attributes.key?(:'utilization_percent') self.utilization_percent = attributes[:'utilization_percent'] if attributes[:'utilization_percent'] self.usage_change_percent = attributes[:'usageChangePercent'] if attributes[:'usageChangePercent'] raise 'You cannot provide both :usageChangePercent and :usage_change_percent' if attributes.key?(:'usageChangePercent') && attributes.key?(:'usage_change_percent') self.usage_change_percent = attributes[:'usage_change_percent'] if attributes[:'usage_change_percent'] end |
Instance Attribute Details
#base_capacity ⇒ Float
The base allocated amount of the resource metric type (CPU, STORAGE).
23 24 25 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 23 def base_capacity @base_capacity end |
#capacity ⇒ Float
[Required] The maximum allocated amount of the resource metric type (CPU, STORAGE).
18 19 20 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 18 def capacity @capacity end |
#is_auto_scaling_enabled ⇒ BOOLEAN
Indicates if auto scaling feature is enabled or disabled on a database. It will be false for all metrics other than CPU.
27 28 29 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 27 def is_auto_scaling_enabled @is_auto_scaling_enabled end |
#usage ⇒ Float
[Required] Total amount used of the resource metric type (CPU, STORAGE).
13 14 15 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 13 def usage @usage end |
#usage_change_percent ⇒ Float
[Required] Change in resource utilization in percentage
35 36 37 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 35 def usage_change_percent @usage_change_percent end |
#utilization_percent ⇒ Float
[Required] Resource utilization in percentage
31 32 33 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 31 def utilization_percent @utilization_percent end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 38 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'usage': :'usage', 'capacity': :'capacity', 'base_capacity': :'baseCapacity', 'is_auto_scaling_enabled': :'isAutoScalingEnabled', 'utilization_percent': :'utilizationPercent', 'usage_change_percent': :'usageChangePercent' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 52 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'usage': :'Float', 'capacity': :'Float', 'base_capacity': :'Float', 'is_auto_scaling_enabled': :'BOOLEAN', 'utilization_percent': :'Float', 'usage_change_percent': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 119 def ==(other) return true if equal?(other) self.class == other.class && usage == other.usage && capacity == other.capacity && base_capacity == other.base_capacity && is_auto_scaling_enabled == other.is_auto_scaling_enabled && utilization_percent == other.utilization_percent && usage_change_percent == other.usage_change_percent end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 154 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
134 135 136 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 134 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 143 def hash [usage, capacity, base_capacity, is_auto_scaling_enabled, utilization_percent, usage_change_percent].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
181 182 183 |
# File 'lib/oci/opsi/models/resource_statistics.rb', line 181 def to_s to_hash.to_s end |