Class: OCI::Opsi::Models::ResourceUsageSummary
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::ResourceUsageSummary
- Defined in:
- lib/oci/opsi/models/resource_usage_summary.rb
Overview
Contains resource usage summary
Instance Attribute Summary collapse
-
#capacity ⇒ Float
[Required] The maximum allocated amount of the resource metric type (CPU, STORAGE).
-
#exadata_insight_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
-
#usage ⇒ Float
[Required] Total amount used of the resource metric type (CPU, STORAGE).
-
#usage_change_percent ⇒ Float
[Required] Change in resource utilization in percentage.
-
#utilization_percent ⇒ Float
[Required] Resource utilization in percentage.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourceUsageSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ResourceUsageSummary
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 69 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.exadata_insight_id = attributes[:'exadataInsightId'] if attributes[:'exadataInsightId'] raise 'You cannot provide both :exadataInsightId and :exadata_insight_id' if attributes.key?(:'exadataInsightId') && attributes.key?(:'exadata_insight_id') self.exadata_insight_id = attributes[:'exadata_insight_id'] if attributes[:'exadata_insight_id'] self.usage = attributes[:'usage'] if attributes[:'usage'] self.capacity = attributes[:'capacity'] if attributes[:'capacity'] self.utilization_percent = attributes[:'utilizationPercent'] if attributes[:'utilizationPercent'] raise 'You cannot provide both :utilizationPercent and :utilization_percent' if attributes.key?(:'utilizationPercent') && attributes.key?(:'utilization_percent') self.utilization_percent = attributes[:'utilization_percent'] if attributes[:'utilization_percent'] self.usage_change_percent = attributes[:'usageChangePercent'] if attributes[:'usageChangePercent'] raise 'You cannot provide both :usageChangePercent and :usage_change_percent' if attributes.key?(:'usageChangePercent') && attributes.key?(:'usage_change_percent') self.usage_change_percent = attributes[:'usage_change_percent'] if attributes[:'usage_change_percent'] end |
Instance Attribute Details
#capacity ⇒ Float
[Required] The maximum allocated amount of the resource metric type (CPU, STORAGE).
22 23 24 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 22 def capacity @capacity end |
#exadata_insight_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Exadata insight.
12 13 14 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 12 def exadata_insight_id @exadata_insight_id end |
#usage ⇒ Float
[Required] Total amount used of the resource metric type (CPU, STORAGE).
17 18 19 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 17 def usage @usage end |
#usage_change_percent ⇒ Float
[Required] Change in resource utilization in percentage
30 31 32 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 30 def usage_change_percent @usage_change_percent end |
#utilization_percent ⇒ Float
[Required] Resource utilization in percentage
26 27 28 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 26 def utilization_percent @utilization_percent end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 33 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'exadata_insight_id': :'exadataInsightId', 'usage': :'usage', 'capacity': :'capacity', 'utilization_percent': :'utilizationPercent', 'usage_change_percent': :'usageChangePercent' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 46 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'exadata_insight_id': :'String', 'usage': :'Float', 'capacity': :'Float', 'utilization_percent': :'Float', 'usage_change_percent': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 105 def ==(other) return true if equal?(other) self.class == other.class && exadata_insight_id == other.exadata_insight_id && usage == other.usage && capacity == other.capacity && utilization_percent == other.utilization_percent && usage_change_percent == other.usage_change_percent end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 139 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
119 120 121 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 119 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
128 129 130 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 128 def hash [exadata_insight_id, usage, capacity, utilization_percent, usage_change_percent].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
166 167 168 |
# File 'lib/oci/opsi/models/resource_usage_summary.rb', line 166 def to_s to_hash.to_s end |