Class: OCI::Opsi::Models::SqlBucket
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SqlBucket
- Defined in:
- lib/oci/opsi/models/sql_bucket.rb
Overview
Sql bucket type object.
Instance Attribute Summary collapse
-
#bucket_id ⇒ String
[Required] SQL Bucket ID, examples <= 3 secs, 3-10 secs, 10-60 secs, 1-5 min, > 5 min Example: ‘"<= 3 secs"`.
-
#cpu_time_in_sec ⇒ Float
Total CPU time Example:
1046. -
#database_type ⇒ String
Operations Insights internal representation of the database type.
-
#executions_count ⇒ Integer
Total number of executions Example:
60. -
#io_time_in_sec ⇒ Float
Total IO time Example:
5810. -
#other_wait_time_in_sec ⇒ Float
Total other wait time Example:
24061. -
#plan_hash ⇒ Integer
[Required] Plan hash value for the SQL Execution Plan.
-
#sql_identifier ⇒ String
[Required] Unique SQL_ID for a SQL Statement.
-
#time_collected ⇒ DateTime
[Required] Collection timestamp Example: ‘"2020-03-31T00:00:00.000Z"`.
-
#total_time_in_sec ⇒ Float
Total time Example:
30917. -
#version ⇒ Float
Version Example:
1.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlBucket
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlBucket
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 126 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.version = attributes[:'version'] if attributes[:'version'] self.database_type = attributes[:'databaseType'] if attributes[:'databaseType'] raise 'You cannot provide both :databaseType and :database_type' if attributes.key?(:'databaseType') && attributes.key?(:'database_type') self.database_type = attributes[:'database_type'] if attributes[:'database_type'] self.time_collected = attributes[:'timeCollected'] if attributes[:'timeCollected'] raise 'You cannot provide both :timeCollected and :time_collected' if attributes.key?(:'timeCollected') && attributes.key?(:'time_collected') self.time_collected = attributes[:'time_collected'] if attributes[:'time_collected'] self.sql_identifier = attributes[:'sqlIdentifier'] if attributes[:'sqlIdentifier'] raise 'You cannot provide both :sqlIdentifier and :sql_identifier' if attributes.key?(:'sqlIdentifier') && attributes.key?(:'sql_identifier') self.sql_identifier = attributes[:'sql_identifier'] if attributes[:'sql_identifier'] self.plan_hash = attributes[:'planHash'] if attributes[:'planHash'] raise 'You cannot provide both :planHash and :plan_hash' if attributes.key?(:'planHash') && attributes.key?(:'plan_hash') self.plan_hash = attributes[:'plan_hash'] if attributes[:'plan_hash'] self.bucket_id = attributes[:'bucketId'] if attributes[:'bucketId'] raise 'You cannot provide both :bucketId and :bucket_id' if attributes.key?(:'bucketId') && attributes.key?(:'bucket_id') self.bucket_id = attributes[:'bucket_id'] if attributes[:'bucket_id'] self.executions_count = attributes[:'executionsCount'] if attributes[:'executionsCount'] raise 'You cannot provide both :executionsCount and :executions_count' if attributes.key?(:'executionsCount') && attributes.key?(:'executions_count') self.executions_count = attributes[:'executions_count'] if attributes[:'executions_count'] self.cpu_time_in_sec = attributes[:'cpuTimeInSec'] if attributes[:'cpuTimeInSec'] raise 'You cannot provide both :cpuTimeInSec and :cpu_time_in_sec' if attributes.key?(:'cpuTimeInSec') && attributes.key?(:'cpu_time_in_sec') self.cpu_time_in_sec = attributes[:'cpu_time_in_sec'] if attributes[:'cpu_time_in_sec'] self.io_time_in_sec = attributes[:'ioTimeInSec'] if attributes[:'ioTimeInSec'] raise 'You cannot provide both :ioTimeInSec and :io_time_in_sec' if attributes.key?(:'ioTimeInSec') && attributes.key?(:'io_time_in_sec') self.io_time_in_sec = attributes[:'io_time_in_sec'] if attributes[:'io_time_in_sec'] self.other_wait_time_in_sec = attributes[:'otherWaitTimeInSec'] if attributes[:'otherWaitTimeInSec'] raise 'You cannot provide both :otherWaitTimeInSec and :other_wait_time_in_sec' if attributes.key?(:'otherWaitTimeInSec') && attributes.key?(:'other_wait_time_in_sec') self.other_wait_time_in_sec = attributes[:'other_wait_time_in_sec'] if attributes[:'other_wait_time_in_sec'] self.total_time_in_sec = attributes[:'totalTimeInSec'] if attributes[:'totalTimeInSec'] raise 'You cannot provide both :totalTimeInSec and :total_time_in_sec' if attributes.key?(:'totalTimeInSec') && attributes.key?(:'total_time_in_sec') self.total_time_in_sec = attributes[:'total_time_in_sec'] if attributes[:'total_time_in_sec'] end |
Instance Attribute Details
#bucket_id ⇒ String
[Required] SQL Bucket ID, examples <= 3 secs, 3-10 secs, 10-60 secs, 1-5 min, > 5 min Example: ‘"<= 3 secs"`
39 40 41 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 39 def bucket_id @bucket_id end |
#cpu_time_in_sec ⇒ Float
Total CPU time Example: 1046
51 52 53 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 51 def cpu_time_in_sec @cpu_time_in_sec end |
#database_type ⇒ String
Operations Insights internal representation of the database type.
18 19 20 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 18 def database_type @database_type end |
#executions_count ⇒ Integer
Total number of executions Example: 60
45 46 47 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 45 def executions_count @executions_count end |
#io_time_in_sec ⇒ Float
Total IO time Example: 5810
57 58 59 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 57 def io_time_in_sec @io_time_in_sec end |
#other_wait_time_in_sec ⇒ Float
Total other wait time Example: 24061
63 64 65 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 63 def other_wait_time_in_sec @other_wait_time_in_sec end |
#plan_hash ⇒ Integer
[Required] Plan hash value for the SQL Execution Plan
33 34 35 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 33 def plan_hash @plan_hash end |
#sql_identifier ⇒ String
[Required] Unique SQL_ID for a SQL Statement.
29 30 31 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 29 def sql_identifier @sql_identifier end |
#time_collected ⇒ DateTime
[Required] Collection timestamp Example: ‘"2020-03-31T00:00:00.000Z"`
24 25 26 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 24 def time_collected @time_collected end |
#total_time_in_sec ⇒ Float
Total time Example: 30917
69 70 71 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 69 def total_time_in_sec @total_time_in_sec end |
#version ⇒ Float
Version Example: 1
14 15 16 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 14 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 72 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'version': :'version', 'database_type': :'databaseType', 'time_collected': :'timeCollected', 'sql_identifier': :'sqlIdentifier', 'plan_hash': :'planHash', 'bucket_id': :'bucketId', 'executions_count': :'executionsCount', 'cpu_time_in_sec': :'cpuTimeInSec', 'io_time_in_sec': :'ioTimeInSec', 'other_wait_time_in_sec': :'otherWaitTimeInSec', 'total_time_in_sec': :'totalTimeInSec' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 91 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'version': :'Float', 'database_type': :'String', 'time_collected': :'DateTime', 'sql_identifier': :'String', 'plan_hash': :'Integer', 'bucket_id': :'String', 'executions_count': :'Integer', 'cpu_time_in_sec': :'Float', 'io_time_in_sec': :'Float', 'other_wait_time_in_sec': :'Float', 'total_time_in_sec': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 202 def ==(other) return true if equal?(other) self.class == other.class && version == other.version && database_type == other.database_type && time_collected == other.time_collected && sql_identifier == other.sql_identifier && plan_hash == other.plan_hash && bucket_id == other.bucket_id && executions_count == other.executions_count && cpu_time_in_sec == other.cpu_time_in_sec && io_time_in_sec == other.io_time_in_sec && other_wait_time_in_sec == other.other_wait_time_in_sec && total_time_in_sec == other.total_time_in_sec end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 242 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
222 223 224 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 222 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 231 def hash [version, database_type, time_collected, sql_identifier, plan_hash, bucket_id, executions_count, cpu_time_in_sec, io_time_in_sec, other_wait_time_in_sec, total_time_in_sec].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
275 276 277 278 279 280 281 282 283 284 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 275 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
269 270 271 |
# File 'lib/oci/opsi/models/sql_bucket.rb', line 269 def to_s to_hash.to_s end |