Class: OCI::Opsi::Models::SqlText
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SqlText
- Defined in:
- lib/oci/opsi/models/sql_text.rb
Overview
SQL Text type object.
Instance Attribute Summary collapse
-
#exact_matching_signature ⇒ String
Exact matching signature Example: ‘"18067345456756876713"`.
-
#force_matching_signature ⇒ String
Force matching signature Example: ‘"18067345456756876713"`.
-
#sql_command ⇒ String
[Required] SQL command Example: ‘"SELECT"`.
-
#sql_full_text ⇒ String
[Required] Full SQL Text Example: ‘"SELECT username,profile,default_tablespace,temporary_tablespace FROM dba_users"` Disclaimer: SQL text being uploaded explicitly via APIs is not masked.
-
#sql_identifier ⇒ String
[Required] Unique SQL_ID for a SQL Statement.
-
#time_collected ⇒ DateTime
[Required] Collection timestamp Example: ‘"2020-05-06T00:00:00.000Z"`.
-
#version ⇒ Float
Version Example:
1.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SqlText
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SqlText
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/opsi/models/sql_text.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.version = attributes[:'version'] if attributes[:'version'] self.sql_identifier = attributes[:'sqlIdentifier'] if attributes[:'sqlIdentifier'] raise 'You cannot provide both :sqlIdentifier and :sql_identifier' if attributes.key?(:'sqlIdentifier') && attributes.key?(:'sql_identifier') self.sql_identifier = attributes[:'sql_identifier'] if attributes[:'sql_identifier'] self.time_collected = attributes[:'timeCollected'] if attributes[:'timeCollected'] raise 'You cannot provide both :timeCollected and :time_collected' if attributes.key?(:'timeCollected') && attributes.key?(:'time_collected') self.time_collected = attributes[:'time_collected'] if attributes[:'time_collected'] self.sql_command = attributes[:'sqlCommand'] if attributes[:'sqlCommand'] raise 'You cannot provide both :sqlCommand and :sql_command' if attributes.key?(:'sqlCommand') && attributes.key?(:'sql_command') self.sql_command = attributes[:'sql_command'] if attributes[:'sql_command'] self.exact_matching_signature = attributes[:'exactMatchingSignature'] if attributes[:'exactMatchingSignature'] raise 'You cannot provide both :exactMatchingSignature and :exact_matching_signature' if attributes.key?(:'exactMatchingSignature') && attributes.key?(:'exact_matching_signature') self.exact_matching_signature = attributes[:'exact_matching_signature'] if attributes[:'exact_matching_signature'] self.force_matching_signature = attributes[:'forceMatchingSignature'] if attributes[:'forceMatchingSignature'] raise 'You cannot provide both :forceMatchingSignature and :force_matching_signature' if attributes.key?(:'forceMatchingSignature') && attributes.key?(:'force_matching_signature') self.force_matching_signature = attributes[:'force_matching_signature'] if attributes[:'force_matching_signature'] self.sql_full_text = attributes[:'sqlFullText'] if attributes[:'sqlFullText'] raise 'You cannot provide both :sqlFullText and :sql_full_text' if attributes.key?(:'sqlFullText') && attributes.key?(:'sql_full_text') self.sql_full_text = attributes[:'sql_full_text'] if attributes[:'sql_full_text'] end |
Instance Attribute Details
#exact_matching_signature ⇒ String
Exact matching signature Example: ‘"18067345456756876713"`
37 38 39 |
# File 'lib/oci/opsi/models/sql_text.rb', line 37 def exact_matching_signature @exact_matching_signature end |
#force_matching_signature ⇒ String
Force matching signature Example: ‘"18067345456756876713"`
43 44 45 |
# File 'lib/oci/opsi/models/sql_text.rb', line 43 def force_matching_signature @force_matching_signature end |
#sql_command ⇒ String
[Required] SQL command Example: ‘"SELECT"`
31 32 33 |
# File 'lib/oci/opsi/models/sql_text.rb', line 31 def sql_command @sql_command end |
#sql_full_text ⇒ String
[Required] Full SQL Text Example: ‘"SELECT username,profile,default_tablespace,temporary_tablespace FROM dba_users"` Disclaimer: SQL text being uploaded explicitly via APIs is not masked. Any sensitive literals contained in the sqlFullText column should be masked prior to ingestion.
50 51 52 |
# File 'lib/oci/opsi/models/sql_text.rb', line 50 def sql_full_text @sql_full_text end |
#sql_identifier ⇒ String
[Required] Unique SQL_ID for a SQL Statement.
19 20 21 |
# File 'lib/oci/opsi/models/sql_text.rb', line 19 def sql_identifier @sql_identifier end |
#time_collected ⇒ DateTime
[Required] Collection timestamp Example: ‘"2020-05-06T00:00:00.000Z"`
25 26 27 |
# File 'lib/oci/opsi/models/sql_text.rb', line 25 def time_collected @time_collected end |
#version ⇒ Float
Version Example: 1
14 15 16 |
# File 'lib/oci/opsi/models/sql_text.rb', line 14 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/oci/opsi/models/sql_text.rb', line 53 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'version': :'version', 'sql_identifier': :'sqlIdentifier', 'time_collected': :'timeCollected', 'sql_command': :'sqlCommand', 'exact_matching_signature': :'exactMatchingSignature', 'force_matching_signature': :'forceMatchingSignature', 'sql_full_text': :'sqlFullText' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/opsi/models/sql_text.rb', line 68 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'version': :'Float', 'sql_identifier': :'String', 'time_collected': :'DateTime', 'sql_command': :'String', 'exact_matching_signature': :'String', 'force_matching_signature': :'String', 'sql_full_text': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/opsi/models/sql_text.rb', line 147 def ==(other) return true if equal?(other) self.class == other.class && version == other.version && sql_identifier == other.sql_identifier && time_collected == other.time_collected && sql_command == other.sql_command && exact_matching_signature == other.exact_matching_signature && force_matching_signature == other.force_matching_signature && sql_full_text == other.sql_full_text end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/opsi/models/sql_text.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/opsi/models/sql_text.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/opsi/models/sql_text.rb', line 172 def hash [version, sql_identifier, time_collected, sql_command, exact_matching_signature, force_matching_signature, sql_full_text].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/opsi/models/sql_text.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/opsi/models/sql_text.rb', line 210 def to_s to_hash.to_s end |