Class: OCI::Opsi::Models::SummarizeDatabaseInsightResourceForecastTrendAggregation

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb

Overview

Forecast results from the selected time period.

Constant Summary collapse

RESOURCE_METRIC_ENUM =
[
  RESOURCE_METRIC_CPU = 'CPU'.freeze,
  RESOURCE_METRIC_STORAGE = 'STORAGE'.freeze,
  RESOURCE_METRIC_IO = 'IO'.freeze,
  RESOURCE_METRIC_MEMORY = 'MEMORY'.freeze,
  RESOURCE_METRIC_MEMORY_PGA = 'MEMORY_PGA'.freeze,
  RESOURCE_METRIC_MEMORY_SGA = 'MEMORY_SGA'.freeze,
  RESOURCE_METRIC_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
USAGE_UNIT_ENUM =
[
  USAGE_UNIT_CORES = 'CORES'.freeze,
  USAGE_UNIT_GB = 'GB'.freeze,
  USAGE_UNIT_MBPS = 'MBPS'.freeze,
  USAGE_UNIT_PERCENT = 'PERCENT'.freeze,
  USAGE_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze
PATTERN_ENUM =
[
  PATTERN_LINEAR = 'LINEAR'.freeze,
  PATTERN_MONTHLY_SEASONS = 'MONTHLY_SEASONS'.freeze,
  PATTERN_MONTHLY_AND_YEARLY_SEASONS = 'MONTHLY_AND_YEARLY_SEASONS'.freeze,
  PATTERN_WEEKLY_SEASONS = 'WEEKLY_SEASONS'.freeze,
  PATTERN_WEEKLY_AND_MONTHLY_SEASONS = 'WEEKLY_AND_MONTHLY_SEASONS'.freeze,
  PATTERN_WEEKLY_MONTHLY_AND_YEARLY_SEASONS = 'WEEKLY_MONTHLY_AND_YEARLY_SEASONS'.freeze,
  PATTERN_WEEKLY_AND_YEARLY_SEASONS = 'WEEKLY_AND_YEARLY_SEASONS'.freeze,
  PATTERN_YEARLY_SEASONS = 'YEARLY_SEASONS'.freeze,
  PATTERN_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SummarizeDatabaseInsightResourceForecastTrendAggregation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 114

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart']

  raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start')

  self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start']

  self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd']

  raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end')

  self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end']

  self.resource_metric = attributes[:'resourceMetric'] if attributes[:'resourceMetric']

  raise 'You cannot provide both :resourceMetric and :resource_metric' if attributes.key?(:'resourceMetric') && attributes.key?(:'resource_metric')

  self.resource_metric = attributes[:'resource_metric'] if attributes[:'resource_metric']

  self.usage_unit = attributes[:'usageUnit'] if attributes[:'usageUnit']

  raise 'You cannot provide both :usageUnit and :usage_unit' if attributes.key?(:'usageUnit') && attributes.key?(:'usage_unit')

  self.usage_unit = attributes[:'usage_unit'] if attributes[:'usage_unit']

  self.pattern = attributes[:'pattern'] if attributes[:'pattern']

  self.historical_data = attributes[:'historicalData'] if attributes[:'historicalData']

  raise 'You cannot provide both :historicalData and :historical_data' if attributes.key?(:'historicalData') && attributes.key?(:'historical_data')

  self.historical_data = attributes[:'historical_data'] if attributes[:'historical_data']

  self.projected_data = attributes[:'projectedData'] if attributes[:'projectedData']

  raise 'You cannot provide both :projectedData and :projected_data' if attributes.key?(:'projectedData') && attributes.key?(:'projected_data')

  self.projected_data = attributes[:'projected_data'] if attributes[:'projected_data']
end

Instance Attribute Details

#historical_dataArray<OCI::Opsi::Models::HistoricalDataItem>

[Required] Time series data used for the forecast analysis.



65
66
67
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 65

def historical_data
  @historical_data
end

#patternString

[Required] Time series patterns used in the forecasting.

Returns:

  • (String)


61
62
63
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 61

def pattern
  @pattern
end

#projected_dataArray<OCI::Opsi::Models::ProjectedDataItem>

[Required] Time series data result of the forecasting analysis.



69
70
71
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 69

def projected_data
  @projected_data
end

#resource_metricString

[Required] Defines the type of resource metric (example: CPU, STORAGE)

Returns:

  • (String)


52
53
54
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 52

def resource_metric
  @resource_metric
end

#time_interval_endDateTime

[Required] The end timestamp that was passed into the request.

Returns:

  • (DateTime)


47
48
49
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 47

def time_interval_end
  @time_interval_end
end

#time_interval_startDateTime

[Required] The start timestamp that was passed into the request.

Returns:

  • (DateTime)


43
44
45
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 43

def time_interval_start
  @time_interval_start
end

#usage_unitString

[Required] Displays usage unit ( CORES, GB)

Returns:

  • (String)


57
58
59
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 57

def usage_unit
  @usage_unit
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 72

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'time_interval_start': :'timeIntervalStart',
    'time_interval_end': :'timeIntervalEnd',
    'resource_metric': :'resourceMetric',
    'usage_unit': :'usageUnit',
    'pattern': :'pattern',
    'historical_data': :'historicalData',
    'projected_data': :'projectedData'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 87

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'time_interval_start': :'DateTime',
    'time_interval_end': :'DateTime',
    'resource_metric': :'String',
    'usage_unit': :'String',
    'pattern': :'String',
    'historical_data': :'Array<OCI::Opsi::Models::HistoricalDataItem>',
    'projected_data': :'Array<OCI::Opsi::Models::ProjectedDataItem>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 205

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    time_interval_start == other.time_interval_start &&
    time_interval_end == other.time_interval_end &&
    resource_metric == other.resource_metric &&
    usage_unit == other.usage_unit &&
    pattern == other.pattern &&
    historical_data == other.historical_data &&
    projected_data == other.projected_data
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 221

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



230
231
232
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 230

def hash
  [time_interval_start, time_interval_end, resource_metric, usage_unit, pattern, historical_data, projected_data].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



274
275
276
277
278
279
280
281
282
283
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 274

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



268
269
270
# File 'lib/oci/opsi/models/summarize_database_insight_resource_forecast_trend_aggregation.rb', line 268

def to_s
  to_hash.to_s
end