Class: OCI::Opsi::Models::SummarizeDatabaseInsightResourceUtilizationInsightAggregation

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb

Overview

Insights response containing current/projected groups for storage or CPU.

Constant Summary collapse

RESOURCE_METRIC_ENUM =
[
  RESOURCE_METRIC_CPU = 'CPU'.freeze,
  RESOURCE_METRIC_STORAGE = 'STORAGE'.freeze,
  RESOURCE_METRIC_IO = 'IO'.freeze,
  RESOURCE_METRIC_MEMORY = 'MEMORY'.freeze,
  RESOURCE_METRIC_MEMORY_PGA = 'MEMORY_PGA'.freeze,
  RESOURCE_METRIC_MEMORY_SGA = 'MEMORY_SGA'.freeze,
  RESOURCE_METRIC_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SummarizeDatabaseInsightResourceUtilizationInsightAggregation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 80

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart']

  raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start')

  self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start']

  self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd']

  raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end')

  self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end']

  self.resource_metric = attributes[:'resourceMetric'] if attributes[:'resourceMetric']

  raise 'You cannot provide both :resourceMetric and :resource_metric' if attributes.key?(:'resourceMetric') && attributes.key?(:'resource_metric')

  self.resource_metric = attributes[:'resource_metric'] if attributes[:'resource_metric']

  self.projected_utilization = attributes[:'projectedUtilization'] if attributes[:'projectedUtilization']

  raise 'You cannot provide both :projectedUtilization and :projected_utilization' if attributes.key?(:'projectedUtilization') && attributes.key?(:'projected_utilization')

  self.projected_utilization = attributes[:'projected_utilization'] if attributes[:'projected_utilization']

  self.current_utilization = attributes[:'currentUtilization'] if attributes[:'currentUtilization']

  raise 'You cannot provide both :currentUtilization and :current_utilization' if attributes.key?(:'currentUtilization') && attributes.key?(:'current_utilization')

  self.current_utilization = attributes[:'current_utilization'] if attributes[:'current_utilization']
end

Instance Attribute Details

#current_utilizationOCI::Opsi::Models::ResourceInsightCurrentUtilization

This attribute is required.



41
42
43
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 41

def current_utilization
  @current_utilization
end

#projected_utilizationOCI::Opsi::Models::ResourceInsightProjectedUtilization

This attribute is required.



37
38
39
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 37

def projected_utilization
  @projected_utilization
end

#resource_metricString

[Required] Defines the type of resource metric (example: CPU, STORAGE)

Returns:

  • (String)


33
34
35
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 33

def resource_metric
  @resource_metric
end

#time_interval_endDateTime

[Required] The end timestamp that was passed into the request.

Returns:

  • (DateTime)


28
29
30
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 28

def time_interval_end
  @time_interval_end
end

#time_interval_startDateTime

[Required] The start timestamp that was passed into the request.

Returns:

  • (DateTime)


24
25
26
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 24

def time_interval_start
  @time_interval_start
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 44

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'time_interval_start': :'timeIntervalStart',
    'time_interval_end': :'timeIntervalEnd',
    'resource_metric': :'resourceMetric',
    'projected_utilization': :'projectedUtilization',
    'current_utilization': :'currentUtilization'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 57

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'time_interval_start': :'DateTime',
    'time_interval_end': :'DateTime',
    'resource_metric': :'String',
    'projected_utilization': :'OCI::Opsi::Models::ResourceInsightProjectedUtilization',
    'current_utilization': :'OCI::Opsi::Models::ResourceInsightCurrentUtilization'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



137
138
139
140
141
142
143
144
145
146
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 137

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    time_interval_start == other.time_interval_start &&
    time_interval_end == other.time_interval_end &&
    resource_metric == other.resource_metric &&
    projected_utilization == other.projected_utilization &&
    current_utilization == other.current_utilization
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 171

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


151
152
153
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 151

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



160
161
162
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 160

def hash
  [time_interval_start, time_interval_end, resource_metric, projected_utilization, current_utilization].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



204
205
206
207
208
209
210
211
212
213
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 204

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



198
199
200
# File 'lib/oci/opsi/models/summarize_database_insight_resource_utilization_insight_aggregation.rb', line 198

def to_s
  to_hash.to_s
end