Class: OCI::Opsi::Models::SummarizeExadataInsightResourceUsageAggregation
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::SummarizeExadataInsightResourceUsageAggregation
- Defined in:
- lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb
Overview
Resource usage summation for the current time period
Constant Summary collapse
- EXADATA_RESOURCE_METRIC_ENUM =
[ EXADATA_RESOURCE_METRIC_CPU = 'CPU'.freeze, EXADATA_RESOURCE_METRIC_STORAGE = 'STORAGE'.freeze, EXADATA_RESOURCE_METRIC_IO = 'IO'.freeze, EXADATA_RESOURCE_METRIC_MEMORY = 'MEMORY'.freeze, EXADATA_RESOURCE_METRIC_IOPS = 'IOPS'.freeze, EXADATA_RESOURCE_METRIC_THROUGHPUT = 'THROUGHPUT'.freeze, EXADATA_RESOURCE_METRIC_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- EXADATA_RESOURCE_TYPE_ENUM =
[ EXADATA_RESOURCE_TYPE_DATABASE = 'DATABASE'.freeze, EXADATA_RESOURCE_TYPE_HOST = 'HOST'.freeze, EXADATA_RESOURCE_TYPE_STORAGE_SERVER = 'STORAGE_SERVER'.freeze, EXADATA_RESOURCE_TYPE_DISKGROUP = 'DISKGROUP'.freeze, EXADATA_RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- USAGE_UNIT_ENUM =
[ USAGE_UNIT_CORES = 'CORES'.freeze, USAGE_UNIT_GB = 'GB'.freeze, USAGE_UNIT_MBPS = 'MBPS'.freeze, USAGE_UNIT_IOPS = 'IOPS'.freeze, USAGE_UNIT_PERCENT = 'PERCENT'.freeze, USAGE_UNIT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#capacity ⇒ Float
[Required] The maximum allocated amount of the resource metric type (CPU, STORAGE).
-
#exadata_resource_metric ⇒ String
[Required] Defines the type of exadata resource metric (example: CPU, STORAGE).
-
#exadata_resource_type ⇒ String
[Required] Defines the resource type for an exadata (example: DATABASE, STORAGE_SERVER, HOST, DISKGROUP).
-
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
-
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
-
#usage ⇒ Float
[Required] Total amount used of the resource metric type (CPU, STORAGE).
-
#usage_change_percent ⇒ Float
[Required] Percentage change in resource usage during the current period calculated using linear regression functions.
-
#usage_unit ⇒ String
[Required] Displays usage unit (CORES, GB).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SummarizeExadataInsightResourceUsageAggregation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SummarizeExadataInsightResourceUsageAggregation
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 121 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.time_interval_start = attributes[:'timeIntervalStart'] if attributes[:'timeIntervalStart'] raise 'You cannot provide both :timeIntervalStart and :time_interval_start' if attributes.key?(:'timeIntervalStart') && attributes.key?(:'time_interval_start') self.time_interval_start = attributes[:'time_interval_start'] if attributes[:'time_interval_start'] self.time_interval_end = attributes[:'timeIntervalEnd'] if attributes[:'timeIntervalEnd'] raise 'You cannot provide both :timeIntervalEnd and :time_interval_end' if attributes.key?(:'timeIntervalEnd') && attributes.key?(:'time_interval_end') self.time_interval_end = attributes[:'time_interval_end'] if attributes[:'time_interval_end'] self.exadata_resource_metric = attributes[:'exadataResourceMetric'] if attributes[:'exadataResourceMetric'] raise 'You cannot provide both :exadataResourceMetric and :exadata_resource_metric' if attributes.key?(:'exadataResourceMetric') && attributes.key?(:'exadata_resource_metric') self.exadata_resource_metric = attributes[:'exadata_resource_metric'] if attributes[:'exadata_resource_metric'] self.exadata_resource_type = attributes[:'exadataResourceType'] if attributes[:'exadataResourceType'] raise 'You cannot provide both :exadataResourceType and :exadata_resource_type' if attributes.key?(:'exadataResourceType') && attributes.key?(:'exadata_resource_type') self.exadata_resource_type = attributes[:'exadata_resource_type'] if attributes[:'exadata_resource_type'] self.usage_unit = attributes[:'usageUnit'] if attributes[:'usageUnit'] raise 'You cannot provide both :usageUnit and :usage_unit' if attributes.key?(:'usageUnit') && attributes.key?(:'usage_unit') self.usage_unit = attributes[:'usage_unit'] if attributes[:'usage_unit'] self.usage = attributes[:'usage'] if attributes[:'usage'] self.capacity = attributes[:'capacity'] if attributes[:'capacity'] self.usage_change_percent = attributes[:'usageChangePercent'] if attributes[:'usageChangePercent'] raise 'You cannot provide both :usageChangePercent and :usage_change_percent' if attributes.key?(:'usageChangePercent') && attributes.key?(:'usage_change_percent') self.usage_change_percent = attributes[:'usage_change_percent'] if attributes[:'usage_change_percent'] end |
Instance Attribute Details
#capacity ⇒ Float
[Required] The maximum allocated amount of the resource metric type (CPU, STORAGE).
69 70 71 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 69 def capacity @capacity end |
#exadata_resource_metric ⇒ String
[Required] Defines the type of exadata resource metric (example: CPU, STORAGE)
49 50 51 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 49 def exadata_resource_metric @exadata_resource_metric end |
#exadata_resource_type ⇒ String
[Required] Defines the resource type for an exadata (example: DATABASE, STORAGE_SERVER, HOST, DISKGROUP)
54 55 56 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 54 def exadata_resource_type @exadata_resource_type end |
#time_interval_end ⇒ DateTime
[Required] The end timestamp that was passed into the request.
44 45 46 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 44 def time_interval_end @time_interval_end end |
#time_interval_start ⇒ DateTime
[Required] The start timestamp that was passed into the request.
40 41 42 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 40 def time_interval_start @time_interval_start end |
#usage ⇒ Float
[Required] Total amount used of the resource metric type (CPU, STORAGE).
64 65 66 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 64 def usage @usage end |
#usage_change_percent ⇒ Float
[Required] Percentage change in resource usage during the current period calculated using linear regression functions
73 74 75 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 73 def usage_change_percent @usage_change_percent end |
#usage_unit ⇒ String
[Required] Displays usage unit (CORES, GB)
59 60 61 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 59 def usage_unit @usage_unit end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 76 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'timeIntervalStart', 'time_interval_end': :'timeIntervalEnd', 'exadata_resource_metric': :'exadataResourceMetric', 'exadata_resource_type': :'exadataResourceType', 'usage_unit': :'usageUnit', 'usage': :'usage', 'capacity': :'capacity', 'usage_change_percent': :'usageChangePercent' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 92 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'time_interval_start': :'DateTime', 'time_interval_end': :'DateTime', 'exadata_resource_metric': :'String', 'exadata_resource_type': :'String', 'usage_unit': :'String', 'usage': :'Float', 'capacity': :'Float', 'usage_change_percent': :'Float' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 214 def ==(other) return true if equal?(other) self.class == other.class && time_interval_start == other.time_interval_start && time_interval_end == other.time_interval_end && exadata_resource_metric == other.exadata_resource_metric && exadata_resource_type == other.exadata_resource_type && usage_unit == other.usage_unit && usage == other.usage && capacity == other.capacity && usage_change_percent == other.usage_change_percent end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 251 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
231 232 233 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 231 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 240 def hash [time_interval_start, time_interval_end, exadata_resource_metric, exadata_resource_type, usage_unit, usage, capacity, usage_change_percent].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
284 285 286 287 288 289 290 291 292 293 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 284 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
278 279 280 |
# File 'lib/oci/opsi/models/summarize_exadata_insight_resource_usage_aggregation.rb', line 278 def to_s to_hash.to_s end |