Class: OCI::Opsi::Models::WorkRequest
- Inherits:
-
Object
- Object
- OCI::Opsi::Models::WorkRequest
- Defined in:
- lib/oci/opsi/models/work_request.rb
Overview
A description of workrequest status
Constant Summary collapse
- OPERATION_TYPE_ENUM =
[ OPERATION_TYPE_ENABLE_DATABASE_INSIGHT = 'ENABLE_DATABASE_INSIGHT'.freeze, OPERATION_TYPE_DISABLE_DATABASE_INSIGHT = 'DISABLE_DATABASE_INSIGHT'.freeze, OPERATION_TYPE_UPDATE_DATABASE_INSIGHT = 'UPDATE_DATABASE_INSIGHT'.freeze, OPERATION_TYPE_CREATE_DATABASE_INSIGHT = 'CREATE_DATABASE_INSIGHT'.freeze, OPERATION_TYPE_MOVE_DATABASE_INSIGHT = 'MOVE_DATABASE_INSIGHT'.freeze, OPERATION_TYPE_DELETE_DATABASE_INSIGHT = 'DELETE_DATABASE_INSIGHT'.freeze, OPERATION_TYPE_CREATE_ENTERPRISE_MANAGER_BRIDGE = 'CREATE_ENTERPRISE_MANAGER_BRIDGE'.freeze, OPERATION_TYPE_UDPATE_ENTERPRISE_MANAGER_BRIDGE = 'UDPATE_ENTERPRISE_MANAGER_BRIDGE'.freeze, OPERATION_TYPE_MOVE_ENTERPRISE_MANAGER_BRIDGE = 'MOVE_ENTERPRISE_MANAGER_BRIDGE'.freeze, OPERATION_TYPE_DELETE_ENTERPRISE_MANAGER_BRIDGE = 'DELETE_ENTERPRISE_MANAGER_BRIDGE'.freeze, OPERATION_TYPE_ENABLE_HOST_INSIGHT = 'ENABLE_HOST_INSIGHT'.freeze, OPERATION_TYPE_DISABLE_HOST_INSIGHT = 'DISABLE_HOST_INSIGHT'.freeze, OPERATION_TYPE_UPDATE_HOST_INSIGHT = 'UPDATE_HOST_INSIGHT'.freeze, OPERATION_TYPE_CREATE_HOST_INSIGHT = 'CREATE_HOST_INSIGHT'.freeze, OPERATION_TYPE_MOVE_HOST_INSIGHT = 'MOVE_HOST_INSIGHT'.freeze, OPERATION_TYPE_DELETE_HOST_INSIGHT = 'DELETE_HOST_INSIGHT'.freeze, OPERATION_TYPE_CREATE_EXADATA_INSIGHT = 'CREATE_EXADATA_INSIGHT'.freeze, OPERATION_TYPE_ENABLE_EXADATA_INSIGHT = 'ENABLE_EXADATA_INSIGHT'.freeze, OPERATION_TYPE_DISABLE_EXADATA_INSIGHT = 'DISABLE_EXADATA_INSIGHT'.freeze, OPERATION_TYPE_UPDATE_EXADATA_INSIGHT = 'UPDATE_EXADATA_INSIGHT'.freeze, OPERATION_TYPE_MOVE_EXADATA_INSIGHT = 'MOVE_EXADATA_INSIGHT'.freeze, OPERATION_TYPE_DELETE_EXADATA_INSIGHT = 'DELETE_EXADATA_INSIGHT'.freeze, OPERATION_TYPE_ADD_EXADATA_INSIGHT_MEMBERS = 'ADD_EXADATA_INSIGHT_MEMBERS'.freeze, OPERATION_TYPE_EXADATA_AUTO_SYNC = 'EXADATA_AUTO_SYNC'.freeze, OPERATION_TYPE_UPDATE_OPSI_WAREHOUSE = 'UPDATE_OPSI_WAREHOUSE'.freeze, OPERATION_TYPE_CREATE_OPSI_WAREHOUSE = 'CREATE_OPSI_WAREHOUSE'.freeze, OPERATION_TYPE_MOVE_OPSI_WAREHOUSE = 'MOVE_OPSI_WAREHOUSE'.freeze, OPERATION_TYPE_DELETE_OPSI_WAREHOUSE = 'DELETE_OPSI_WAREHOUSE'.freeze, OPERATION_TYPE_ROTATE_OPSI_WAREHOUSE_WALLET = 'ROTATE_OPSI_WAREHOUSE_WALLET'.freeze, OPERATION_TYPE_UPDATE_OPSI_WAREHOUSE_USER = 'UPDATE_OPSI_WAREHOUSE_USER'.freeze, OPERATION_TYPE_CREATE_OPSI_WAREHOUSE_USER = 'CREATE_OPSI_WAREHOUSE_USER'.freeze, OPERATION_TYPE_MOVE_OPSI_WAREHOUSE_USER = 'MOVE_OPSI_WAREHOUSE_USER'.freeze, OPERATION_TYPE_DELETE_OPSI_WAREHOUSE_USER = 'DELETE_OPSI_WAREHOUSE_USER'.freeze, OPERATION_TYPE_UPDATE_AWRHUB = 'UPDATE_AWRHUB'.freeze, OPERATION_TYPE_CREATE_AWRHUB = 'CREATE_AWRHUB'.freeze, OPERATION_TYPE_MOVE_AWRHUB = 'MOVE_AWRHUB'.freeze, OPERATION_TYPE_DELETE_AWRHUB = 'DELETE_AWRHUB'.freeze, OPERATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_ACCEPTED = 'ACCEPTED'.freeze, STATUS_IN_PROGRESS = 'IN_PROGRESS'.freeze, STATUS_WAITING = 'WAITING'.freeze, STATUS_FAILED = 'FAILED'.freeze, STATUS_SUCCEEDED = 'SUCCEEDED'.freeze, STATUS_CANCELING = 'CANCELING'.freeze, STATUS_CANCELED = 'CANCELED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The ocid of the compartment that contains the work request.
-
#id ⇒ String
[Required] The id of the work request.
-
#operation_type ⇒ String
[Required] Type of the work request.
-
#percent_complete ⇒ Float
[Required] Percentage of the request completed.
-
#resources ⇒ Array<OCI::Opsi::Models::WorkRequestResource>
[Required] The resources affected by this work request.
-
#status ⇒ String
[Required] Status of current work request.
-
#time_accepted ⇒ DateTime
[Required] The date and time the request was created, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
-
#time_finished ⇒ DateTime
The date and time the object was finished, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
-
#time_started ⇒ DateTime
The date and time the request was started, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequest
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequest
Initializes the object
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/oci/opsi/models/work_request.rb', line 157 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operation_type = attributes[:'operationType'] if attributes[:'operationType'] raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type'] self.status = attributes[:'status'] if attributes[:'status'] self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.resources = attributes[:'resources'] if attributes[:'resources'] self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete'] raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The ocid of the compartment that contains the work request. Work requests should be scoped to the same compartment as the resource the work request affects. If the work request affects multiple resources, and those resources are not in the same compartment, it is up to the service team to pick the primary resource whose compartment should be used
81 82 83 |
# File 'lib/oci/opsi/models/work_request.rb', line 81 def compartment_id @compartment_id end |
#id ⇒ String
[Required] The id of the work request.
73 74 75 |
# File 'lib/oci/opsi/models/work_request.rb', line 73 def id @id end |
#operation_type ⇒ String
[Required] Type of the work request
65 66 67 |
# File 'lib/oci/opsi/models/work_request.rb', line 65 def operation_type @operation_type end |
#percent_complete ⇒ Float
[Required] Percentage of the request completed.
89 90 91 |
# File 'lib/oci/opsi/models/work_request.rb', line 89 def percent_complete @percent_complete end |
#resources ⇒ Array<OCI::Opsi::Models::WorkRequestResource>
[Required] The resources affected by this work request.
85 86 87 |
# File 'lib/oci/opsi/models/work_request.rb', line 85 def resources @resources end |
#status ⇒ String
[Required] Status of current work request.
69 70 71 |
# File 'lib/oci/opsi/models/work_request.rb', line 69 def status @status end |
#time_accepted ⇒ DateTime
[Required] The date and time the request was created, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
95 96 97 |
# File 'lib/oci/opsi/models/work_request.rb', line 95 def time_accepted @time_accepted end |
#time_finished ⇒ DateTime
The date and time the object was finished, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339).
106 107 108 |
# File 'lib/oci/opsi/models/work_request.rb', line 106 def time_finished @time_finished end |
#time_started ⇒ DateTime
The date and time the request was started, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339), section 14.29.
101 102 103 |
# File 'lib/oci/opsi/models/work_request.rb', line 101 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/opsi/models/work_request.rb', line 109 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operation_type': :'operationType', 'status': :'status', 'id': :'id', 'compartment_id': :'compartmentId', 'resources': :'resources', 'percent_complete': :'percentComplete', 'time_accepted': :'timeAccepted', 'time_started': :'timeStarted', 'time_finished': :'timeFinished' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/oci/opsi/models/work_request.rb', line 126 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operation_type': :'String', 'status': :'String', 'id': :'String', 'compartment_id': :'String', 'resources': :'Array<OCI::Opsi::Models::WorkRequestResource>', 'percent_complete': :'Float', 'time_accepted': :'DateTime', 'time_started': :'DateTime', 'time_finished': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/oci/opsi/models/work_request.rb', line 239 def ==(other) return true if equal?(other) self.class == other.class && operation_type == other.operation_type && status == other.status && id == other.id && compartment_id == other.compartment_id && resources == other.resources && percent_complete == other.percent_complete && time_accepted == other.time_accepted && time_started == other.time_started && time_finished == other.time_finished end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/oci/opsi/models/work_request.rb', line 277 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
257 258 259 |
# File 'lib/oci/opsi/models/work_request.rb', line 257 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
266 267 268 |
# File 'lib/oci/opsi/models/work_request.rb', line 266 def hash [operation_type, status, id, compartment_id, resources, percent_complete, time_accepted, time_started, time_finished].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 |
# File 'lib/oci/opsi/models/work_request.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
304 305 306 |
# File 'lib/oci/opsi/models/work_request.rb', line 304 def to_s to_hash.to_s end |