Class: OCI::Optimizer::Models::CategorySummary
- Inherits:
-
Object
- Object
- OCI::Optimizer::Models::CategorySummary
- Defined in:
- lib/oci/optimizer/models/category_summary.rb
Overview
The metadata associated with the category summary.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_ATTACHING = 'ATTACHING'.freeze, LIFECYCLE_STATE_DETACHING = 'DETACHING'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the tenancy.
-
#description ⇒ String
**[Required]** Text describing the category.
-
#estimated_cost_saving ⇒ Float
**[Required]** The estimated cost savings, in dollars, for the category.
-
#extended_metadata ⇒ Hash<String, String>
Additional metadata key/value pairs for the category summary.
-
#id ⇒ String
**[Required]** The unique OCID of the category.
-
#lifecycle_state ⇒ String
**[Required]** The category's current state.
-
#name ⇒ String
**[Required]** The name assigned to the category.
-
#recommendation_counts ⇒ Array<OCI::Optimizer::Models::RecommendationCount>
**[Required]** An array of `RecommendationCount` objects grouped by the level of importance assigned to each recommendation.
-
#resource_counts ⇒ Array<OCI::Optimizer::Models::ResourceCount>
**[Required]** An array of `ResourceCount` objects grouped by the status of each recommendation.
-
#time_created ⇒ DateTime
**[Required]** The date and time the category details were created, in the format defined by RFC3339.
-
#time_updated ⇒ DateTime
**[Required]** The date and time the category details were last updated, in the format defined by RFC3339.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CategorySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CategorySummary
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 129 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.recommendation_counts = attributes[:'recommendationCounts'] if attributes[:'recommendationCounts'] raise 'You cannot provide both :recommendationCounts and :recommendation_counts' if attributes.key?(:'recommendationCounts') && attributes.key?(:'recommendation_counts') self.recommendation_counts = attributes[:'recommendation_counts'] if attributes[:'recommendation_counts'] self.resource_counts = attributes[:'resourceCounts'] if attributes[:'resourceCounts'] raise 'You cannot provide both :resourceCounts and :resource_counts' if attributes.key?(:'resourceCounts') && attributes.key?(:'resource_counts') self.resource_counts = attributes[:'resource_counts'] if attributes[:'resource_counts'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.estimated_cost_saving = attributes[:'estimatedCostSaving'] if attributes[:'estimatedCostSaving'] raise 'You cannot provide both :estimatedCostSaving and :estimated_cost_saving' if attributes.key?(:'estimatedCostSaving') && attributes.key?(:'estimated_cost_saving') self.estimated_cost_saving = attributes[:'estimated_cost_saving'] if attributes[:'estimated_cost_saving'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self. = attributes[:'extendedMetadata'] if attributes[:'extendedMetadata'] raise 'You cannot provide both :extendedMetadata and :extended_metadata' if attributes.key?(:'extendedMetadata') && attributes.key?(:'extended_metadata') self. = attributes[:'extended_metadata'] if attributes[:'extended_metadata'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the tenancy. The tenancy is the root compartment.
31 32 33 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 31 def compartment_id @compartment_id end |
#description ⇒ String
**[Required]** Text describing the category.
39 40 41 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 39 def description @description end |
#estimated_cost_saving ⇒ Float
**[Required]** The estimated cost savings, in dollars, for the category.
55 56 57 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 55 def estimated_cost_saving @estimated_cost_saving end |
#extended_metadata ⇒ Hash<String, String>
Additional metadata key/value pairs for the category summary.
For example:
`"200"`
72 73 74 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 72 def @extended_metadata end |
#id ⇒ String
**[Required]** The unique OCID of the category.
27 28 29 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 27 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The category's current state.
51 52 53 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 51 def lifecycle_state @lifecycle_state end |
#name ⇒ String
**[Required]** The name assigned to the category.
35 36 37 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 35 def name @name end |
#recommendation_counts ⇒ Array<OCI::Optimizer::Models::RecommendationCount>
**[Required]** An array of `RecommendationCount` objects grouped by the level of importance assigned to each recommendation.
43 44 45 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 43 def recommendation_counts @recommendation_counts end |
#resource_counts ⇒ Array<OCI::Optimizer::Models::ResourceCount>
**[Required]** An array of `ResourceCount` objects grouped by the status of each recommendation.
47 48 49 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 47 def resource_counts @resource_counts end |
#time_created ⇒ DateTime
**[Required]** The date and time the category details were created, in the format defined by RFC3339.
59 60 61 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 59 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The date and time the category details were last updated, in the format defined by RFC3339.
63 64 65 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 63 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 75 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'name': :'name', 'description': :'description', 'recommendation_counts': :'recommendationCounts', 'resource_counts': :'resourceCounts', 'lifecycle_state': :'lifecycleState', 'estimated_cost_saving': :'estimatedCostSaving', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'extended_metadata': :'extendedMetadata' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 94 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'name': :'String', 'description': :'String', 'recommendation_counts': :'Array<OCI::Optimizer::Models::RecommendationCount>', 'resource_counts': :'Array<OCI::Optimizer::Models::ResourceCount>', 'lifecycle_state': :'String', 'estimated_cost_saving': :'Float', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'extended_metadata': :'Hash<String, String>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 210 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && name == other.name && description == other.description && recommendation_counts == other.recommendation_counts && resource_counts == other.resource_counts && lifecycle_state == other.lifecycle_state && estimated_cost_saving == other.estimated_cost_saving && time_created == other.time_created && time_updated == other.time_updated && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 250 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
230 231 232 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 230 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 239 def hash [id, compartment_id, name, description, recommendation_counts, resource_counts, lifecycle_state, estimated_cost_saving, time_created, time_updated, ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 292 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
277 278 279 |
# File 'lib/oci/optimizer/models/category_summary.rb', line 277 def to_s to_hash.to_s end |