Class: OCI::Optimizer::Models::Profile

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/optimizer/models/profile.rb

Overview

The metadata associated with the profile.

Constant Summary collapse

LIFECYCLE_STATE_ENUM =
[
  LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
  LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
  LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
  LIFECYCLE_STATE_ATTACHING = 'ATTACHING'.freeze,
  LIFECYCLE_STATE_DETACHING = 'DETACHING'.freeze,
  LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
  LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
  LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
  LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
  LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Profile

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/oci/optimizer/models/profile.rb', line 136

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.name = attributes[:'name'] if attributes[:'name']

  self.description = attributes[:'description'] if attributes[:'description']

  self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

  raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

  self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

  self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

  raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

  self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

  self.levels_configuration = attributes[:'levelsConfiguration'] if attributes[:'levelsConfiguration']

  raise 'You cannot provide both :levelsConfiguration and :levels_configuration' if attributes.key?(:'levelsConfiguration') && attributes.key?(:'levels_configuration')

  self.levels_configuration = attributes[:'levels_configuration'] if attributes[:'levels_configuration']

  self.target_compartments = attributes[:'targetCompartments'] if attributes[:'targetCompartments']

  raise 'You cannot provide both :targetCompartments and :target_compartments' if attributes.key?(:'targetCompartments') && attributes.key?(:'target_compartments')

  self.target_compartments = attributes[:'target_compartments'] if attributes[:'target_compartments']

  self.target_tags = attributes[:'targetTags'] if attributes[:'targetTags']

  raise 'You cannot provide both :targetTags and :target_tags' if attributes.key?(:'targetTags') && attributes.key?(:'target_tags')

  self.target_tags = attributes[:'target_tags'] if attributes[:'target_tags']

  self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

  raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

  self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

  self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

  raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

  self.time_created = attributes[:'time_created'] if attributes[:'time_created']

  self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

  raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

  self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']
end

Instance Attribute Details

#compartment_idString

[Required] The OCID of the tenancy. The tenancy is the root compartment.

Returns:

  • (String)


31
32
33
# File 'lib/oci/optimizer/models/profile.rb', line 31

def compartment_id
  @compartment_id
end

#defined_tagsHash<String, Hash<String, Object>>

Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).

Example: ‘{"bar-key": "value"}`

Returns:

  • (Hash<String, Hash<String, Object>>)


47
48
49
# File 'lib/oci/optimizer/models/profile.rb', line 47

def defined_tags
  @defined_tags
end

#descriptionString

[Required] Text describing the profile. Avoid entering confidential information.

Returns:

  • (String)


39
40
41
# File 'lib/oci/optimizer/models/profile.rb', line 39

def description
  @description
end

#freeform_tagsHash<String, String>

Simple key-value pair applied without any predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm). Exists for cross-compatibility only.

Example: ‘"value"`

Returns:

  • (Hash<String, String>)


55
56
57
# File 'lib/oci/optimizer/models/profile.rb', line 55

def freeform_tags
  @freeform_tags
end

#idString

[Required] The unique OCID of the profile.

Returns:

  • (String)


27
28
29
# File 'lib/oci/optimizer/models/profile.rb', line 27

def id
  @id
end

#levels_configurationOCI::Optimizer::Models::LevelsConfiguration



58
59
60
# File 'lib/oci/optimizer/models/profile.rb', line 58

def levels_configuration
  @levels_configuration
end

#lifecycle_stateString

[Required] The profile’s current state.

Returns:

  • (String)


68
69
70
# File 'lib/oci/optimizer/models/profile.rb', line 68

def lifecycle_state
  @lifecycle_state
end

#nameString

[Required] The name assigned to the profile. Avoid entering confidential information.

Returns:

  • (String)


35
36
37
# File 'lib/oci/optimizer/models/profile.rb', line 35

def name
  @name
end

#target_compartmentsOCI::Optimizer::Models::TargetCompartments



61
62
63
# File 'lib/oci/optimizer/models/profile.rb', line 61

def target_compartments
  @target_compartments
end

#target_tagsOCI::Optimizer::Models::TargetTags



64
65
66
# File 'lib/oci/optimizer/models/profile.rb', line 64

def target_tags
  @target_tags
end

#time_createdDateTime

[Required] The date and time the profile was created, in the format defined by RFC3339.

Returns:

  • (DateTime)


72
73
74
# File 'lib/oci/optimizer/models/profile.rb', line 72

def time_created
  @time_created
end

#time_updatedDateTime

[Required] The date and time the profile was last updated, in the format defined by RFC3339.

Returns:

  • (DateTime)


76
77
78
# File 'lib/oci/optimizer/models/profile.rb', line 76

def time_updated
  @time_updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/oci/optimizer/models/profile.rb', line 79

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'compartment_id': :'compartmentId',
    'name': :'name',
    'description': :'description',
    'defined_tags': :'definedTags',
    'freeform_tags': :'freeformTags',
    'levels_configuration': :'levelsConfiguration',
    'target_compartments': :'targetCompartments',
    'target_tags': :'targetTags',
    'lifecycle_state': :'lifecycleState',
    'time_created': :'timeCreated',
    'time_updated': :'timeUpdated'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/oci/optimizer/models/profile.rb', line 99

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'compartment_id': :'String',
    'name': :'String',
    'description': :'String',
    'defined_tags': :'Hash<String, Hash<String, Object>>',
    'freeform_tags': :'Hash<String, String>',
    'levels_configuration': :'OCI::Optimizer::Models::LevelsConfiguration',
    'target_compartments': :'OCI::Optimizer::Models::TargetCompartments',
    'target_tags': :'OCI::Optimizer::Models::TargetTags',
    'lifecycle_state': :'String',
    'time_created': :'DateTime',
    'time_updated': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/oci/optimizer/models/profile.rb', line 223

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    compartment_id == other.compartment_id &&
    name == other.name &&
    description == other.description &&
    defined_tags == other.defined_tags &&
    freeform_tags == other.freeform_tags &&
    levels_configuration == other.levels_configuration &&
    target_compartments == other.target_compartments &&
    target_tags == other.target_tags &&
    lifecycle_state == other.lifecycle_state &&
    time_created == other.time_created &&
    time_updated == other.time_updated
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/oci/optimizer/models/profile.rb', line 264

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


244
245
246
# File 'lib/oci/optimizer/models/profile.rb', line 244

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



253
254
255
# File 'lib/oci/optimizer/models/profile.rb', line 253

def hash
  [id, compartment_id, name, description, defined_tags, freeform_tags, levels_configuration, target_compartments, target_tags, lifecycle_state, time_created, time_updated].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
306
# File 'lib/oci/optimizer/models/profile.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



291
292
293
# File 'lib/oci/optimizer/models/profile.rb', line 291

def to_s
  to_hash.to_s
end