Class: OCI::Optimizer::Models::ProfileLevelSummary
- Inherits:
-
Object
- Object
- OCI::Optimizer::Models::ProfileLevelSummary
- Defined in:
- lib/oci/optimizer/models/profile_level_summary.rb
Overview
The metadata associated with the profile level summary.
Instance Attribute Summary collapse
-
#default_interval ⇒ Integer
[Required] The default aggregation interval (in days) for profiles using this profile level.
-
#metrics ⇒ Array<OCI::Optimizer::Models::EvaluatedMetric>
[Required] The metrics that will be evaluated by profiles using this profile level.
-
#name ⇒ String
[Required] A unique name for the profile level.
-
#recommendation_name ⇒ String
[Required] The name of the recommendation this profile level applies to.
-
#time_created ⇒ DateTime
[Required] The date and time the category details were created, in the format defined by RFC3339.
-
#time_updated ⇒ DateTime
[Required] The date and time the category details were last updated, in the format defined by RFC3339.
-
#valid_intervals ⇒ Array<Integer>
[Required] An array of aggregation intervals (in days) allowed for profiles using this profile level.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProfileLevelSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ProfileLevelSummary
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.recommendation_name = attributes[:'recommendationName'] if attributes[:'recommendationName'] raise 'You cannot provide both :recommendationName and :recommendation_name' if attributes.key?(:'recommendationName') && attributes.key?(:'recommendation_name') self.recommendation_name = attributes[:'recommendation_name'] if attributes[:'recommendation_name'] self.metrics = attributes[:'metrics'] if attributes[:'metrics'] self.default_interval = attributes[:'defaultInterval'] if attributes[:'defaultInterval'] raise 'You cannot provide both :defaultInterval and :default_interval' if attributes.key?(:'defaultInterval') && attributes.key?(:'default_interval') self.default_interval = attributes[:'default_interval'] if attributes[:'default_interval'] self.valid_intervals = attributes[:'validIntervals'] if attributes[:'validIntervals'] raise 'You cannot provide both :validIntervals and :valid_intervals' if attributes.key?(:'validIntervals') && attributes.key?(:'valid_intervals') self.valid_intervals = attributes[:'valid_intervals'] if attributes[:'valid_intervals'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#default_interval ⇒ Integer
[Required] The default aggregation interval (in days) for profiles using this profile level.
26 27 28 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 26 def default_interval @default_interval end |
#metrics ⇒ Array<OCI::Optimizer::Models::EvaluatedMetric>
[Required] The metrics that will be evaluated by profiles using this profile level.
21 22 23 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 21 def metrics @metrics end |
#name ⇒ String
[Required] A unique name for the profile level.
13 14 15 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 13 def name @name end |
#recommendation_name ⇒ String
[Required] The name of the recommendation this profile level applies to.
17 18 19 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 17 def recommendation_name @recommendation_name end |
#time_created ⇒ DateTime
[Required] The date and time the category details were created, in the format defined by RFC3339.
35 36 37 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 35 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time the category details were last updated, in the format defined by RFC3339.
39 40 41 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 39 def time_updated @time_updated end |
#valid_intervals ⇒ Array<Integer>
[Required] An array of aggregation intervals (in days) allowed for profiles using this profile level.
31 32 33 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 31 def valid_intervals @valid_intervals end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'recommendation_name': :'recommendationName', 'metrics': :'metrics', 'default_interval': :'defaultInterval', 'valid_intervals': :'validIntervals', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 57 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'recommendation_name': :'String', 'metrics': :'Array<OCI::Optimizer::Models::EvaluatedMetric>', 'default_interval': :'Integer', 'valid_intervals': :'Array<Integer>', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 132 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && recommendation_name == other.recommendation_name && metrics == other.metrics && default_interval == other.default_interval && valid_intervals == other.valid_intervals && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 168 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
148 149 150 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 148 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 157 def hash [name, recommendation_name, metrics, default_interval, valid_intervals, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
195 196 197 |
# File 'lib/oci/optimizer/models/profile_level_summary.rb', line 195 def to_s to_hash.to_s end |