Class: OCI::Optimizer::Models::StrategyParameter
- Inherits:
-
Object
- Object
- OCI::Optimizer::Models::StrategyParameter
- Defined in:
- lib/oci/optimizer/models/strategy_parameter.rb
Overview
The metadata associated with the strategy parameter.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_STRING = 'STRING'.freeze, TYPE_BOOLEAN = 'BOOLEAN'.freeze, TYPE_NUMBER = 'NUMBER'.freeze, TYPE_DATETIME = 'DATETIME'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#default_value ⇒ Object
A default value used for the strategy parameter.
-
#description ⇒ String
[Required] Text describing the strategy parameter.
-
#is_required ⇒ BOOLEAN
[Required] Whether this parameter is required.
-
#name ⇒ String
[Required] The name of the strategy parameter.
-
#possible_values ⇒ Array<Object>
The list of possible values used for these strategy parameters.
-
#type ⇒ String
[Required] The type of strategy parameter.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StrategyParameter
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ StrategyParameter
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.type = attributes[:'type'] if attributes[:'type'] self.description = attributes[:'description'] if attributes[:'description'] self.is_required = attributes[:'isRequired'] unless attributes[:'isRequired'].nil? raise 'You cannot provide both :isRequired and :is_required' if attributes.key?(:'isRequired') && attributes.key?(:'is_required') self.is_required = attributes[:'is_required'] unless attributes[:'is_required'].nil? self.default_value = attributes[:'defaultValue'] if attributes[:'defaultValue'] raise 'You cannot provide both :defaultValue and :default_value' if attributes.key?(:'defaultValue') && attributes.key?(:'default_value') self.default_value = attributes[:'default_value'] if attributes[:'default_value'] self.possible_values = attributes[:'possibleValues'] if attributes[:'possibleValues'] raise 'You cannot provide both :possibleValues and :possible_values' if attributes.key?(:'possibleValues') && attributes.key?(:'possible_values') self.possible_values = attributes[:'possible_values'] if attributes[:'possible_values'] end |
Instance Attribute Details
#default_value ⇒ Object
A default value used for the strategy parameter.
38 39 40 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 38 def default_value @default_value end |
#description ⇒ String
[Required] Text describing the strategy parameter.
30 31 32 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 30 def description @description end |
#is_required ⇒ BOOLEAN
[Required] Whether this parameter is required.
34 35 36 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 34 def is_required @is_required end |
#name ⇒ String
[Required] The name of the strategy parameter.
22 23 24 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 22 def name @name end |
#possible_values ⇒ Array<Object>
The list of possible values used for these strategy parameters.
42 43 44 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 42 def possible_values @possible_values end |
#type ⇒ String
[Required] The type of strategy parameter.
26 27 28 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 26 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 45 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'type': :'type', 'description': :'description', 'is_required': :'isRequired', 'default_value': :'defaultValue', 'possible_values': :'possibleValues' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 59 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'type': :'String', 'description': :'String', 'is_required': :'BOOLEAN', 'default_value': :'Object', 'possible_values': :'Array<Object>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 135 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && type == other.type && description == other.description && is_required == other.is_required && default_value == other.default_value && possible_values == other.possible_values end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 170 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
150 151 152 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 150 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 159 def hash [name, type, description, is_required, default_value, possible_values].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
197 198 199 |
# File 'lib/oci/optimizer/models/strategy_parameter.rb', line 197 def to_s to_hash.to_s end |