Class: OsManagement::Models::Event
- Inherits:
-
Object
- Object
- OsManagement::Models::Event
- Defined in:
- lib/oci/os_management/models/event.rb
Overview
Description of Event. This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
OCI::OsManagement::Models::KernelCrashEvent, OCI::OsManagement::Models::KernelOopsEvent
Constant Summary collapse
- EVENT_TYPE_ENUM =
[ EVENT_TYPE_KERNEL_OOPS = 'KERNEL_OOPS'.freeze, EVENT_TYPE_KERNEL_CRASH = 'KERNEL_CRASH'.freeze, EVENT_TYPE_CRASH = 'CRASH'.freeze, EVENT_TYPE_EXPLOIT_ATTEMPT = 'EXPLOIT_ATTEMPT'.freeze, EVENT_TYPE_COMPLIANCE = 'COMPLIANCE'.freeze, EVENT_TYPE_TUNING_SUGGESTION = 'TUNING_SUGGESTION'.freeze, EVENT_TYPE_TUNING_APPLIED = 'TUNING_APPLIED'.freeze, EVENT_TYPE_SECURITY = 'SECURITY'.freeze, EVENT_TYPE_ERROR = 'ERROR'.freeze, EVENT_TYPE_WARNING = 'WARNING'.freeze, EVENT_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
OCI identifier of the compartement where the instance is.
-
#count ⇒ Integer
Event occurrence count.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#event_fingerprint ⇒ String
Unique ID used to group event with the same characteristics together.
-
#event_type ⇒ String
**[Required]** Type of the Event.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** OCID identifier of the event.
-
#instance_id ⇒ String
OCI identifier of the instance where the event occurred.
-
#summary ⇒ String
human readable description of the event.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#tenancy_id ⇒ String
OCID identifier of the instance tenancy.
-
#timestamp ⇒ DateTime
Time of the occurrence of the event.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Event
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Event
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/oci/os_management/models/event.rb', line 156 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.instance_id = attributes[:'instanceId'] if attributes[:'instanceId'] raise 'You cannot provide both :instanceId and :instance_id' if attributes.key?(:'instanceId') && attributes.key?(:'instance_id') self.instance_id = attributes[:'instance_id'] if attributes[:'instance_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId'] raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id') self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id'] self.summary = attributes[:'summary'] if attributes[:'summary'] self. = attributes[:'timestamp'] if attributes[:'timestamp'] self.event_fingerprint = attributes[:'eventFingerprint'] if attributes[:'eventFingerprint'] raise 'You cannot provide both :eventFingerprint and :event_fingerprint' if attributes.key?(:'eventFingerprint') && attributes.key?(:'event_fingerprint') self.event_fingerprint = attributes[:'event_fingerprint'] if attributes[:'event_fingerprint'] self.count = attributes[:'count'] if attributes[:'count'] self.event_type = attributes[:'eventType'] if attributes[:'eventType'] raise 'You cannot provide both :eventType and :event_type' if attributes.key?(:'eventType') && attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] if attributes[:'event_type'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
OCI identifier of the compartement where the instance is
36 37 38 |
# File 'lib/oci/os_management/models/event.rb', line 36 def compartment_id @compartment_id end |
#count ⇒ Integer
Event occurrence count. Number of time the event has happen on the system.
58 59 60 |
# File 'lib/oci/os_management/models/event.rb', line 58 def count @count end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
74 75 76 |
# File 'lib/oci/os_management/models/event.rb', line 74 def @defined_tags end |
#event_fingerprint ⇒ String
Unique ID used to group event with the same characteristics together. The list of such groups of event can be retrieved via /recurringEvents/EventFingerprint
54 55 56 |
# File 'lib/oci/os_management/models/event.rb', line 54 def event_fingerprint @event_fingerprint end |
#event_type ⇒ String
**[Required]** Type of the Event.
62 63 64 |
# File 'lib/oci/os_management/models/event.rb', line 62 def event_type @event_type end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
68 69 70 |
# File 'lib/oci/os_management/models/event.rb', line 68 def @freeform_tags end |
#id ⇒ String
**[Required]** OCID identifier of the event
28 29 30 |
# File 'lib/oci/os_management/models/event.rb', line 28 def id @id end |
#instance_id ⇒ String
OCI identifier of the instance where the event occurred
32 33 34 |
# File 'lib/oci/os_management/models/event.rb', line 32 def instance_id @instance_id end |
#summary ⇒ String
human readable description of the event
44 45 46 |
# File 'lib/oci/os_management/models/event.rb', line 44 def summary @summary end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
80 81 82 |
# File 'lib/oci/os_management/models/event.rb', line 80 def @system_tags end |
#tenancy_id ⇒ String
OCID identifier of the instance tenancy.
40 41 42 |
# File 'lib/oci/os_management/models/event.rb', line 40 def tenancy_id @tenancy_id end |
#timestamp ⇒ DateTime
Time of the occurrence of the event
48 49 50 |
# File 'lib/oci/os_management/models/event.rb', line 48 def @timestamp end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/oci/os_management/models/event.rb', line 83 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'instance_id': :'instanceId', 'compartment_id': :'compartmentId', 'tenancy_id': :'tenancyId', 'summary': :'summary', 'timestamp': :'timestamp', 'event_fingerprint': :'eventFingerprint', 'count': :'count', 'event_type': :'eventType', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
127 128 129 130 131 132 133 134 135 |
# File 'lib/oci/os_management/models/event.rb', line 127 def self.get_subtype(object_hash) type = object_hash[:'eventType'] # rubocop:disable Style/SymbolLiteral return 'OCI::OsManagement::Models::KernelOopsEvent' if type == 'KERNEL_OOPS' return 'OCI::OsManagement::Models::KernelCrashEvent' if type == 'KERNEL_CRASH' # TODO: Log a warning when the subtype is not found. 'OCI::OsManagement::Models::Event' end |
.swagger_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/oci/os_management/models/event.rb', line 103 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'instance_id': :'String', 'compartment_id': :'String', 'tenancy_id': :'String', 'summary': :'String', 'timestamp': :'DateTime', 'event_fingerprint': :'String', 'count': :'Integer', 'event_type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/os_management/models/event.rb', line 239 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && instance_id == other.instance_id && compartment_id == other.compartment_id && tenancy_id == other.tenancy_id && summary == other.summary && == other. && event_fingerprint == other.event_fingerprint && count == other.count && event_type == other.event_type && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/oci/os_management/models/event.rb', line 280 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
260 261 262 |
# File 'lib/oci/os_management/models/event.rb', line 260 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
269 270 271 |
# File 'lib/oci/os_management/models/event.rb', line 269 def hash [id, instance_id, compartment_id, tenancy_id, summary, , event_fingerprint, count, event_type, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
313 314 315 316 317 318 319 320 321 322 |
# File 'lib/oci/os_management/models/event.rb', line 313 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
307 308 309 |
# File 'lib/oci/os_management/models/event.rb', line 307 def to_s to_hash.to_s end |