Class: OCI::ResourceManager::Models::ConfigurationSourceProviderSummary
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::ConfigurationSourceProviderSummary
- Defined in:
- lib/oci/resource_manager/models/configuration_source_provider_summary.rb
Overview
Summary information for a configuration source provider.
This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
Direct Known Subclasses
GithubAccessTokenConfigurationSourceProviderSummary, GitlabAccessTokenConfigurationSourceProviderSummary
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where the configuration source provider is located.
-
#config_source_provider_type ⇒ String
[Required] The type of configuration source provider.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
General description of the configuration source provider.
-
#display_name ⇒ String
Human-readable display name for the configuration source provider.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with this resource.
-
#id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the configuration source provider.
-
#lifecycle_state ⇒ String
Current state of the specified configuration source provider.
-
#time_created ⇒ DateTime
The date and time when the configuration source provider was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConfigurationSourceProviderSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConfigurationSourceProviderSummary
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 130 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.config_source_provider_type = attributes[:'configSourceProviderType'] if attributes[:'configSourceProviderType'] raise 'You cannot provide both :configSourceProviderType and :config_source_provider_type' if attributes.key?(:'configSourceProviderType') && attributes.key?(:'config_source_provider_type') self.config_source_provider_type = attributes[:'config_source_provider_type'] if attributes[:'config_source_provider_type'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where the configuration source provider is located.
18 19 20 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 18 def compartment_id @compartment_id end |
#config_source_provider_type ⇒ String
[Required] The type of configuration source provider. The GITLAB_ACCESS_TOKEN type corresponds to GitLab. The GITHUB_ACCESS_TOKEN type corresponds to GitHub.
49 50 51 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 49 def config_source_provider_type @config_source_provider_type end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
63 64 65 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 63 def end |
#description ⇒ String
General description of the configuration source provider.
26 27 28 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 26 def description @description end |
#display_name ⇒ String
Human-readable display name for the configuration source provider.
22 23 24 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 22 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with this resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
56 57 58 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 56 def end |
#id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the configuration source provider.
14 15 16 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 14 def id @id end |
#lifecycle_state ⇒ String
Current state of the specified configuration source provider. For more information about configuration source provider lifecycle states in Resource Manager, see [Key Concepts](docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/resourcemanager.htm#concepts__CSPStates).
Allowable values:
-
ACTIVE
43 44 45 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 43 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The date and time when the configuration source provider was created. Format is defined by RFC3339. Example: 2020-01-25T21:10:29.600Z
33 34 35 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 33 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 66 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'config_source_provider_type': :'configSourceProviderType', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.get_subtype(object_hash) ⇒ Object
Given the hash representation of a subtype of this class, use the info in the hash to return the class of the subtype.
104 105 106 107 108 109 110 111 112 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 104 def self.get_subtype(object_hash) type = object_hash[:'configSourceProviderType'] # rubocop:disable Style/SymbolLiteral return 'OCI::ResourceManager::Models::GitlabAccessTokenConfigurationSourceProviderSummary' if type == 'GITLAB_ACCESS_TOKEN' return 'OCI::ResourceManager::Models::GithubAccessTokenConfigurationSourceProviderSummary' if type == 'GITHUB_ACCESS_TOKEN' # TODO: Log a warning when the subtype is not found. 'OCI::ResourceManager::Models::ConfigurationSourceProviderSummary' end |
.swagger_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 83 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'config_source_provider_type': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 190 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && time_created == other.time_created && lifecycle_state == other.lifecycle_state && config_source_provider_type == other.config_source_provider_type && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 228 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
208 209 210 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 208 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 217 def hash [id, compartment_id, display_name, description, time_created, lifecycle_state, config_source_provider_type, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 270 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
255 256 257 |
# File 'lib/oci/resource_manager/models/configuration_source_provider_summary.rb', line 255 def to_s to_hash.to_s end |