Class: OCI::ResourceManager::Models::CreateCompartmentConfigSourceDetails

Inherits:
CreateConfigSourceDetails show all
Defined in:
lib/oci/resource_manager/models/create_compartment_config_source_details.rb

Overview

Property details for uploading the specified compartment as the configuration source.

Instance Attribute Summary collapse

Attributes inherited from CreateConfigSourceDetails

#config_source_type, #working_directory

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from CreateConfigSourceDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ CreateCompartmentConfigSourceDetails

Initializes the object

Options Hash (attributes):

  • :working_directory (String)

    The value to assign to the #working_directory proprety

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :region (String)

    The value to assign to the #region property

  • :services_to_discover (Array<String>)

    The value to assign to the #services_to_discover property



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 68

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['configSourceType'] = 'COMPARTMENT_CONFIG_SOURCE'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.region = attributes[:'region'] if attributes[:'region']

  self.services_to_discover = attributes[:'servicesToDiscover'] if attributes[:'servicesToDiscover']

  raise 'You cannot provide both :servicesToDiscover and :services_to_discover' if attributes.key?(:'servicesToDiscover') && attributes.key?(:'services_to_discover')

  self.services_to_discover = attributes[:'services_to_discover'] if attributes[:'services_to_discover']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to use for creating the stack. The new stack will include definitions for supported resource types in scope of the specified compartment OCID (tenancy level for root compartment, compartment level otherwise).



16
17
18
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 16

def compartment_id
  @compartment_id
end

#regionString

[Required] The region to use for creating the stack. The new stack will include definitions for supported resource types in this region.



22
23
24
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 22

def region
  @region
end

#services_to_discoverArray<String>

Filter for [services to use with Resource Discovery](www.terraform.io/docs/providers/oci/guides/resource_discovery.html#services). For example, "database" limits resource discovery to resource types within the Database service. The specified services must be in scope of the given compartment OCID (tenancy level for root compartment, compartment level otherwise). If not specified, then all services at the scope of the given compartment OCID are used.



30
31
32
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 30

def services_to_discover
  @services_to_discover
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 33

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'config_source_type': :'configSourceType',
    'working_directory': :'workingDirectory',
    'compartment_id': :'compartmentId',
    'region': :'region',
    'services_to_discover': :'servicesToDiscover'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
53
54
55
56
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 46

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'config_source_type': :'String',
    'working_directory': :'String',
    'compartment_id': :'String',
    'region': :'String',
    'services_to_discover': :'Array<String>'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



100
101
102
103
104
105
106
107
108
109
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 100

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    config_source_type == other.config_source_type &&
    working_directory == other.working_directory &&
    compartment_id == other.compartment_id &&
    region == other.region &&
    services_to_discover == other.services_to_discover
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 134

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


114
115
116
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 114

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.



123
124
125
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 123

def hash
  [config_source_type, working_directory, compartment_id, region, services_to_discover].hash
end

#to_hashHash

Returns the object in the form of hash



167
168
169
170
171
172
173
174
175
176
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 167

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



161
162
163
# File 'lib/oci/resource_manager/models/create_compartment_config_source_details.rb', line 161

def to_s
  to_hash.to_s
end