Class: OCI::ResourceManager::Models::CreateTemplateDetails
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::CreateTemplateDetails
- Defined in:
- lib/oci/resource_manager/models/create_template_details.rb
Overview
The configuration details for creating a template.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing this template.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
[Required] Description of the template.
-
#display_name ⇒ String
[Required] The template’s display name.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with the resource.
-
#logo_file_base64_encoded ⇒ String
Base64-encoded logo for the template.
-
#long_description ⇒ String
Detailed description of the template.
-
#template_config_source ⇒ OCI::ResourceManager::Models::CreateTemplateConfigSourceDetails
This attribute is required.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateTemplateDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateTemplateDetails
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 95 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.long_description = attributes[:'longDescription'] if attributes[:'longDescription'] raise 'You cannot provide both :longDescription and :long_description' if attributes.key?(:'longDescription') && attributes.key?(:'long_description') self.long_description = attributes[:'long_description'] if attributes[:'long_description'] self.logo_file_base64_encoded = attributes[:'logoFileBase64Encoded'] if attributes[:'logoFileBase64Encoded'] raise 'You cannot provide both :logoFileBase64Encoded and :logo_file_base64_encoded' if attributes.key?(:'logoFileBase64Encoded') && attributes.key?(:'logo_file_base64_encoded') self.logo_file_base64_encoded = attributes[:'logo_file_base64_encoded'] if attributes[:'logo_file_base64_encoded'] self.template_config_source = attributes[:'templateConfigSource'] if attributes[:'templateConfigSource'] raise 'You cannot provide both :templateConfigSource and :template_config_source' if attributes.key?(:'templateConfigSource') && attributes.key?(:'template_config_source') self.template_config_source = attributes[:'template_config_source'] if attributes[:'template_config_source'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing this template.
13 14 15 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 13 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
47 48 49 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 47 def @defined_tags end |
#description ⇒ String
[Required] Description of the template. Avoid entering confidential information.
21 22 23 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 21 def description @description end |
#display_name ⇒ String
[Required] The template’s display name. Avoid entering confidential information.
17 18 19 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 17 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
40 41 42 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 40 def @freeform_tags end |
#logo_file_base64_encoded ⇒ String
Base64-encoded logo for the template.
29 30 31 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 29 def logo_file_base64_encoded @logo_file_base64_encoded end |
#long_description ⇒ String
Detailed description of the template. This description is displayed in the Console page listing templates when the template is expanded. Avoid entering confidential information.
25 26 27 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 25 def long_description @long_description end |
#template_config_source ⇒ OCI::ResourceManager::Models::CreateTemplateConfigSourceDetails
This attribute is required.
33 34 35 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 33 def template_config_source @template_config_source end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 50 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'long_description': :'longDescription', 'logo_file_base64_encoded': :'logoFileBase64Encoded', 'template_config_source': :'templateConfigSource', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 66 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'long_description': :'String', 'logo_file_base64_encoded': :'String', 'template_config_source': :'OCI::ResourceManager::Models::CreateTemplateConfigSourceDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 153 def ==(other) return true if equal?(other) self.class == other.class && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && long_description == other.long_description && logo_file_base64_encoded == other.logo_file_base64_encoded && template_config_source == other.template_config_source && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 190 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
170 171 172 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 170 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 179 def hash [compartment_id, display_name, description, long_description, logo_file_base64_encoded, template_config_source, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
217 218 219 |
# File 'lib/oci/resource_manager/models/create_template_details.rb', line 217 def to_s to_hash.to_s end |