Class: ResourceManager::Models::Job
- Inherits:
-
Object
- Object
- ResourceManager::Models::Job
- Defined in:
- lib/oci/resource_manager/models/job.rb
Overview
The properties that define a job. Jobs perform the actions that are defined in your configuration.
-
**Plan job**. A plan job takes your Terraform configuration, parses it, and creates an execution plan.
-
**Apply job**. The apply job takes your execution plan, applies it to the associated stack, then executes
the configuration's instructions.
-
**Destroy job**. To clean up the infrastructure controlled by the stack, you run a destroy job.
A destroy job does not delete the stack or associated job resources, but instead releases the resources managed by the stack.
-
**Import_TF_State job**. An import Terraform state job takes a Terraform state file and sets it as the current
state of the stack. This is used to migrate local Terraform environments to Resource Manager.
Constant Summary collapse
- OPERATION_ENUM =
[ OPERATION_PLAN = 'PLAN'.freeze, OPERATION_APPLY = 'APPLY'.freeze, OPERATION_DESTROY = 'DESTROY'.freeze, OPERATION_IMPORT_TF_STATE = 'IMPORT_TF_STATE'.freeze, OPERATION_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACCEPTED = 'ACCEPTED'.freeze, LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze, LIFECYCLE_STATE_CANCELING = 'CANCELING'.freeze, LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #apply_job_plan_resolution ⇒ OCI::ResourceManager::Models::ApplyJobPlanResolution
- #cancellation_details ⇒ OCI::ResourceManager::Models::CancellationDetails
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the job's associated stack resides.
- #config_source ⇒ OCI::ResourceManager::Models::ConfigSourceRecord
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
The job's display name.
- #failure_details ⇒ OCI::ResourceManager::Models::FailureDetails
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with this resource.
-
#id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the job.
- #job_operation_details ⇒ OCI::ResourceManager::Models::JobOperationDetails
-
#lifecycle_state ⇒ String
Current state of the specified job.
-
#operation ⇒ String
The type of job executing.
-
#resolved_plan_job_id ⇒ String
Deprecated.
-
#stack_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the stack that is associated with the job.
-
#time_created ⇒ DateTime
The date and time when the job was created.
-
#time_finished ⇒ DateTime
The date and time when the job stopped running, irrespective of whether the job ran successfully.
-
#variables ⇒ Hash<String, String>
Terraform variables associated with this resource.
-
#working_directory ⇒ String
File path to the directory to use for running Terraform.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Job
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Job
Initializes the object
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/oci/resource_manager/models/job.rb', line 208 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.stack_id = attributes[:'stackId'] if attributes[:'stackId'] raise 'You cannot provide both :stackId and :stack_id' if attributes.key?(:'stackId') && attributes.key?(:'stack_id') self.stack_id = attributes[:'stack_id'] if attributes[:'stack_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.operation = attributes[:'operation'] if attributes[:'operation'] self.job_operation_details = attributes[:'jobOperationDetails'] if attributes[:'jobOperationDetails'] raise 'You cannot provide both :jobOperationDetails and :job_operation_details' if attributes.key?(:'jobOperationDetails') && attributes.key?(:'job_operation_details') self.job_operation_details = attributes[:'job_operation_details'] if attributes[:'job_operation_details'] self.apply_job_plan_resolution = attributes[:'applyJobPlanResolution'] if attributes[:'applyJobPlanResolution'] raise 'You cannot provide both :applyJobPlanResolution and :apply_job_plan_resolution' if attributes.key?(:'applyJobPlanResolution') && attributes.key?(:'apply_job_plan_resolution') self.apply_job_plan_resolution = attributes[:'apply_job_plan_resolution'] if attributes[:'apply_job_plan_resolution'] self.resolved_plan_job_id = attributes[:'resolvedPlanJobId'] if attributes[:'resolvedPlanJobId'] raise 'You cannot provide both :resolvedPlanJobId and :resolved_plan_job_id' if attributes.key?(:'resolvedPlanJobId') && attributes.key?(:'resolved_plan_job_id') self.resolved_plan_job_id = attributes[:'resolved_plan_job_id'] if attributes[:'resolved_plan_job_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.failure_details = attributes[:'failureDetails'] if attributes[:'failureDetails'] raise 'You cannot provide both :failureDetails and :failure_details' if attributes.key?(:'failureDetails') && attributes.key?(:'failure_details') self.failure_details = attributes[:'failure_details'] if attributes[:'failure_details'] self.cancellation_details = attributes[:'cancellationDetails'] if attributes[:'cancellationDetails'] raise 'You cannot provide both :cancellationDetails and :cancellation_details' if attributes.key?(:'cancellationDetails') && attributes.key?(:'cancellation_details') self.cancellation_details = attributes[:'cancellation_details'] if attributes[:'cancellation_details'] self.working_directory = attributes[:'workingDirectory'] if attributes[:'workingDirectory'] raise 'You cannot provide both :workingDirectory and :working_directory' if attributes.key?(:'workingDirectory') && attributes.key?(:'working_directory') self.working_directory = attributes[:'working_directory'] if attributes[:'working_directory'] self.variables = attributes[:'variables'] if attributes[:'variables'] self.config_source = attributes[:'configSource'] if attributes[:'configSource'] raise 'You cannot provide both :configSource and :config_source' if attributes.key?(:'configSource') && attributes.key?(:'config_source') self.config_source = attributes[:'config_source'] if attributes[:'config_source'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#apply_job_plan_resolution ⇒ OCI::ResourceManager::Models::ApplyJobPlanResolution
62 63 64 |
# File 'lib/oci/resource_manager/models/job.rb', line 62 def apply_job_plan_resolution @apply_job_plan_resolution end |
#cancellation_details ⇒ OCI::ResourceManager::Models::CancellationDetails
95 96 97 |
# File 'lib/oci/resource_manager/models/job.rb', line 95 def cancellation_details @cancellation_details end |
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which the job's associated stack resides.
48 49 50 |
# File 'lib/oci/resource_manager/models/job.rb', line 48 def compartment_id @compartment_id end |
#config_source ⇒ OCI::ResourceManager::Models::ConfigSourceRecord
116 117 118 |
# File 'lib/oci/resource_manager/models/job.rb', line 116 def config_source @config_source end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
130 131 132 |
# File 'lib/oci/resource_manager/models/job.rb', line 130 def @defined_tags end |
#display_name ⇒ String
The job's display name.
52 53 54 |
# File 'lib/oci/resource_manager/models/job.rb', line 52 def display_name @display_name end |
#failure_details ⇒ OCI::ResourceManager::Models::FailureDetails
92 93 94 |
# File 'lib/oci/resource_manager/models/job.rb', line 92 def failure_details @failure_details end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with this resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
123 124 125 |
# File 'lib/oci/resource_manager/models/job.rb', line 123 def @freeform_tags end |
#id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the job.
40 41 42 |
# File 'lib/oci/resource_manager/models/job.rb', line 40 def id @id end |
#job_operation_details ⇒ OCI::ResourceManager::Models::JobOperationDetails
59 60 61 |
# File 'lib/oci/resource_manager/models/job.rb', line 59 def job_operation_details @job_operation_details end |
#lifecycle_state ⇒ String
Current state of the specified job. For more information about job lifecycle states in Resource Manager, see [Key Concepts](docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/resourcemanager.htm#concepts__JobStates).
89 90 91 |
# File 'lib/oci/resource_manager/models/job.rb', line 89 def lifecycle_state @lifecycle_state end |
#operation ⇒ String
The type of job executing.
56 57 58 |
# File 'lib/oci/resource_manager/models/job.rb', line 56 def operation @operation end |
#resolved_plan_job_id ⇒ String
Deprecated. Use the property `executionPlanJobId` in `jobOperationDetails` instead. The plan job [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) that was used (if this was an apply job and was not auto-approved).
68 69 70 |
# File 'lib/oci/resource_manager/models/job.rb', line 68 def resolved_plan_job_id @resolved_plan_job_id end |
#stack_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the stack that is associated with the job.
44 45 46 |
# File 'lib/oci/resource_manager/models/job.rb', line 44 def stack_id @stack_id end |
#time_created ⇒ DateTime
The date and time when the job was created. Format is defined by RFC3339. Example: `2020-01-25T21:10:29.600Z`
75 76 77 |
# File 'lib/oci/resource_manager/models/job.rb', line 75 def time_created @time_created end |
#time_finished ⇒ DateTime
The date and time when the job stopped running, irrespective of whether the job ran successfully. Format is defined by RFC3339. Example: `2020-01-25T21:10:29.600Z`
82 83 84 |
# File 'lib/oci/resource_manager/models/job.rb', line 82 def time_finished @time_finished end |
#variables ⇒ Hash<String, String>
Terraform variables associated with this resource. Maximum number of variables supported is 250. The maximum size of each variable, including both name and value, is 8192 bytes. Example: `"compartment-id-value"`
113 114 115 |
# File 'lib/oci/resource_manager/models/job.rb', line 113 def variables @variables end |
#working_directory ⇒ String
File path to the directory to use for running Terraform. If not specified, the root directory is used. Required when using a zip Terraform configuration (`configSourceType` value of `ZIP_UPLOAD`) that contains folders. Ignored for the `configSourceType` value of `COMPARTMENT_CONFIG_SOURCE`. For more information about required and recommended file structure, see [File Structure (Terraform Configurations for Resource Manager)](docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/terraformconfigresourcemanager.htm#filestructure).
105 106 107 |
# File 'lib/oci/resource_manager/models/job.rb', line 105 def working_directory @working_directory end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/oci/resource_manager/models/job.rb', line 133 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'stack_id': :'stackId', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'operation': :'operation', 'job_operation_details': :'jobOperationDetails', 'apply_job_plan_resolution': :'applyJobPlanResolution', 'resolved_plan_job_id': :'resolvedPlanJobId', 'time_created': :'timeCreated', 'time_finished': :'timeFinished', 'lifecycle_state': :'lifecycleState', 'failure_details': :'failureDetails', 'cancellation_details': :'cancellationDetails', 'working_directory': :'workingDirectory', 'variables': :'variables', 'config_source': :'configSource', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/oci/resource_manager/models/job.rb', line 159 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'stack_id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'operation': :'String', 'job_operation_details': :'OCI::ResourceManager::Models::JobOperationDetails', 'apply_job_plan_resolution': :'OCI::ResourceManager::Models::ApplyJobPlanResolution', 'resolved_plan_job_id': :'String', 'time_created': :'DateTime', 'time_finished': :'DateTime', 'lifecycle_state': :'String', 'failure_details': :'OCI::ResourceManager::Models::FailureDetails', 'cancellation_details': :'OCI::ResourceManager::Models::CancellationDetails', 'working_directory': :'String', 'variables': :'Hash<String, String>', 'config_source': :'OCI::ResourceManager::Models::ConfigSourceRecord', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/oci/resource_manager/models/job.rb', line 344 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && stack_id == other.stack_id && compartment_id == other.compartment_id && display_name == other.display_name && operation == other.operation && job_operation_details == other.job_operation_details && apply_job_plan_resolution == other.apply_job_plan_resolution && resolved_plan_job_id == other.resolved_plan_job_id && time_created == other.time_created && time_finished == other.time_finished && lifecycle_state == other.lifecycle_state && failure_details == other.failure_details && cancellation_details == other.cancellation_details && working_directory == other.working_directory && variables == other.variables && config_source == other.config_source && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/oci/resource_manager/models/job.rb', line 391 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
371 372 373 |
# File 'lib/oci/resource_manager/models/job.rb', line 371 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
380 381 382 |
# File 'lib/oci/resource_manager/models/job.rb', line 380 def hash [id, stack_id, compartment_id, display_name, operation, job_operation_details, apply_job_plan_resolution, resolved_plan_job_id, time_created, time_finished, lifecycle_state, failure_details, cancellation_details, working_directory, variables, config_source, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
424 425 426 427 428 429 430 431 432 433 |
# File 'lib/oci/resource_manager/models/job.rb', line 424 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
418 419 420 |
# File 'lib/oci/resource_manager/models/job.rb', line 418 def to_s to_hash.to_s end |