Class: OCI::ResourceManager::Models::PrivateEndpointSummary
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::PrivateEndpointSummary
- Defined in:
- lib/oci/resource_manager/models/private_endpoint_summary.rb
Overview
The summary metadata associated with the private endpoint.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing this private endpoint details.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
General description of the private endpoint.
-
#display_name ⇒ String
**[Required]** A user-friendly name.
-
#dns_zones ⇒ Array<String>
DNS Proxy forwards any DNS FQDN queries over into the consumer DNS resolver if the DNS FQDN is included in the dns zones list otherwise it goes to service provider VCN resolver.
-
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with the resource.
-
#id ⇒ String
**[Required]** Unique identifier ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the private endpoint.
-
#is_used_with_configuration_source_provider ⇒ BOOLEAN
When `true`, allows the private endpoint to be used with a configuration source provider.
-
#lifecycle_state ⇒ String
The current lifecycle state of the private endpoint.
-
#time_created ⇒ DateTime
The date and time when the private endpoint was created.
-
#vcn_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN for the private endpoint.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PrivateEndpointSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PrivateEndpointSummary
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 127 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] self.is_used_with_configuration_source_provider = attributes[:'isUsedWithConfigurationSourceProvider'] unless attributes[:'isUsedWithConfigurationSourceProvider'].nil? raise 'You cannot provide both :isUsedWithConfigurationSourceProvider and :is_used_with_configuration_source_provider' if attributes.key?(:'isUsedWithConfigurationSourceProvider') && attributes.key?(:'is_used_with_configuration_source_provider') self.is_used_with_configuration_source_provider = attributes[:'is_used_with_configuration_source_provider'] unless attributes[:'is_used_with_configuration_source_provider'].nil? self.dns_zones = attributes[:'dnsZones'] if attributes[:'dnsZones'] raise 'You cannot provide both :dnsZones and :dns_zones' if attributes.key?(:'dnsZones') && attributes.key?(:'dns_zones') self.dns_zones = attributes[:'dns_zones'] if attributes[:'dns_zones'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing this private endpoint details.
17 18 19 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 17 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
70 71 72 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 70 def @defined_tags end |
#description ⇒ String
General description of the private endpoint.
25 26 27 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 25 def description @description end |
#display_name ⇒ String
**[Required]** A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
21 22 23 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 21 def display_name @display_name end |
#dns_zones ⇒ Array<String>
DNS Proxy forwards any DNS FQDN queries over into the consumer DNS resolver if the DNS FQDN is included in the dns zones list otherwise it goes to service provider VCN resolver.
38 39 40 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 38 def dns_zones @dns_zones end |
#freeform_tags ⇒ Hash<String, String>
Free-form tags associated with the resource. Each tag is a key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
63 64 65 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 63 def @freeform_tags end |
#id ⇒ String
**[Required]** Unique identifier ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the private endpoint.
13 14 15 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 13 def id @id end |
#is_used_with_configuration_source_provider ⇒ BOOLEAN
When `true`, allows the private endpoint to be used with a configuration source provider.
33 34 35 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 33 def is_used_with_configuration_source_provider @is_used_with_configuration_source_provider end |
#lifecycle_state ⇒ String
The current lifecycle state of the private endpoint. Allowable values:
-
ACTIVE
-
CREATING
-
DELETING
-
DELETED
-
FAILED
56 57 58 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 56 def lifecycle_state @lifecycle_state end |
#time_created ⇒ DateTime
The date and time when the private endpoint was created. Format is defined by RFC3339. Example: `2020-01-25T21:10:29.600Z`
45 46 47 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 45 def time_created @time_created end |
#vcn_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN for the private endpoint.
29 30 31 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 29 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 73 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'description': :'description', 'vcn_id': :'vcnId', 'is_used_with_configuration_source_provider': :'isUsedWithConfigurationSourceProvider', 'dns_zones': :'dnsZones', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 92 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'description': :'String', 'vcn_id': :'String', 'is_used_with_configuration_source_provider': :'BOOLEAN', 'dns_zones': :'Array<String>', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 199 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && description == other.description && vcn_id == other.vcn_id && is_used_with_configuration_source_provider == other.is_used_with_configuration_source_provider && dns_zones == other.dns_zones && time_created == other.time_created && lifecycle_state == other.lifecycle_state && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 239 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
219 220 221 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 219 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
228 229 230 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 228 def hash [id, compartment_id, display_name, description, vcn_id, is_used_with_configuration_source_provider, dns_zones, time_created, lifecycle_state, , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
272 273 274 275 276 277 278 279 280 281 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 272 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
266 267 268 |
# File 'lib/oci/resource_manager/models/private_endpoint_summary.rb', line 266 def to_s to_hash.to_s end |