Class: OCI::ResourceManager::Models::WorkRequestSummary
- Inherits:
-
Object
- Object
- OCI::ResourceManager::Models::WorkRequestSummary
- Defined in:
- lib/oci/resource_manager/models/work_request_summary.rb
Overview
A summary of the status of a work request.
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] Unique identifier ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment that contains the work request.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) identifying this work request.
-
#operation_type ⇒ String
[Required] The asynchronous operation tracked by this work request.
-
#percent_complete ⇒ Float
[Required] Percentage of the work request completed.
-
#resources ⇒ Array<OCI::ResourceManager::Models::WorkRequestResource>
[Required] The resources affected by this work request.
-
#status ⇒ String
[Required] The status of the specified work request.
-
#time_accepted ⇒ DateTime
[Required] The date and time when the work request was created.
-
#time_finished ⇒ DateTime
The date and time when the work request reached a terminal state (FAILED or SUCCEEDED).
-
#time_started ⇒ DateTime
The date and time when the work request transitioned from ACCEPTED to IN_PROGRESS.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WorkRequestSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ WorkRequestSummary
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 105 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.operation_type = attributes[:'operationType'] if attributes[:'operationType'] raise 'You cannot provide both :operationType and :operation_type' if attributes.key?(:'operationType') && attributes.key?(:'operation_type') self.operation_type = attributes[:'operation_type'] if attributes[:'operation_type'] self.status = attributes[:'status'] if attributes[:'status'] self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.resources = attributes[:'resources'] if attributes[:'resources'] self.percent_complete = attributes[:'percentComplete'] if attributes[:'percentComplete'] raise 'You cannot provide both :percentComplete and :percent_complete' if attributes.key?(:'percentComplete') && attributes.key?(:'percent_complete') self.percent_complete = attributes[:'percent_complete'] if attributes[:'percent_complete'] self.time_accepted = attributes[:'timeAccepted'] if attributes[:'timeAccepted'] raise 'You cannot provide both :timeAccepted and :time_accepted' if attributes.key?(:'timeAccepted') && attributes.key?(:'time_accepted') self.time_accepted = attributes[:'time_accepted'] if attributes[:'time_accepted'] self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted'] raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started') self.time_started = attributes[:'time_started'] if attributes[:'time_started'] self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished'] raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished') self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] Unique identifier ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment that contains the work request.
25 26 27 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 25 def compartment_id @compartment_id end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) identifying this work request.
21 22 23 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 21 def id @id end |
#operation_type ⇒ String
[Required] The asynchronous operation tracked by this work request.
13 14 15 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 13 def operation_type @operation_type end |
#percent_complete ⇒ Float
[Required] Percentage of the work request completed.
33 34 35 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 33 def percent_complete @percent_complete end |
#resources ⇒ Array<OCI::ResourceManager::Models::WorkRequestResource>
[Required] The resources affected by this work request.
29 30 31 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 29 def resources @resources end |
#status ⇒ String
[Required] The status of the specified work request.
17 18 19 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 17 def status @status end |
#time_accepted ⇒ DateTime
[Required] The date and time when the work request was created. Format is defined by RFC3339. Example: 2020-01-25T21:10:29.600Z
40 41 42 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 40 def time_accepted @time_accepted end |
#time_finished ⇒ DateTime
The date and time when the work request reached a terminal state (FAILED or SUCCEEDED). Format is defined by RFC3339. Example: 2020-01-25T21:10:29.600Z
54 55 56 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 54 def time_finished @time_finished end |
#time_started ⇒ DateTime
The date and time when the work request transitioned from ACCEPTED to IN_PROGRESS. Format is defined by RFC3339. Example: 2020-01-25T21:10:29.600Z
47 48 49 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 47 def time_started @time_started end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'operation_type': :'operationType', 'status': :'status', 'id': :'id', 'compartment_id': :'compartmentId', 'resources': :'resources', 'percent_complete': :'percentComplete', 'time_accepted': :'timeAccepted', 'time_started': :'timeStarted', 'time_finished': :'timeFinished' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 74 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'operation_type': :'String', 'status': :'String', 'id': :'String', 'compartment_id': :'String', 'resources': :'Array<OCI::ResourceManager::Models::WorkRequestResource>', 'percent_complete': :'Float', 'time_accepted': :'DateTime', 'time_started': :'DateTime', 'time_finished': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 161 def ==(other) return true if equal?(other) self.class == other.class && operation_type == other.operation_type && status == other.status && id == other.id && compartment_id == other.compartment_id && resources == other.resources && percent_complete == other.percent_complete && time_accepted == other.time_accepted && time_started == other.time_started && time_finished == other.time_finished end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 199 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
179 180 181 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 179 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
188 189 190 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 188 def hash [operation_type, status, id, compartment_id, resources, percent_complete, time_accepted, time_started, time_finished].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
232 233 234 235 236 237 238 239 240 241 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 232 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
226 227 228 |
# File 'lib/oci/resource_manager/models/work_request_summary.rb', line 226 def to_s to_hash.to_s end |