Class: OCI::Rover::Models::CreateRoverNodeDetails
- Inherits:
-
Object
- Object
- OCI::Rover::Models::CreateRoverNodeDetails
- Defined in:
- lib/oci/rover/models/create_rover_node_details.rb
Overview
The information required to create a RoverNode.
Constant Summary collapse
- SHIPPING_PREFERENCE_ENUM =
[ SHIPPING_PREFERENCE_ORACLE_SHIPPED = 'ORACLE_SHIPPED'.freeze, SHIPPING_PREFERENCE_CUSTOMER_PICKUP = 'CUSTOMER_PICKUP'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze ].freeze
- ENCLOSURE_TYPE_ENUM =
[ ENCLOSURE_TYPE_RUGGADIZED = 'RUGGADIZED'.freeze, ENCLOSURE_TYPE_NON_RUGGADIZED = 'NON_RUGGADIZED'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the RoverNode.
- #customer_shipping_address ⇒ OCI::Rover::Models::ShippingAddress
-
#data_validation_code ⇒ String
Validation code returned by data validation tool.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any.
-
#display_name ⇒ String
**[Required]** A user-friendly name.
-
#enclosure_type ⇒ String
The type of enclosure rover nodes in this cluster are shipped in.
-
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any.
-
#import_compartment_id ⇒ String
An OCID of a compartment where data will be imported to upon Rover node return.
-
#import_file_bucket ⇒ String
Name of a bucket where files from NFS share will be imported to upon Rover node return.
-
#is_import_requested ⇒ BOOLEAN
The flag indicating that customer requests data to be imported to OCI upon Rover node return.
-
#lifecycle_state ⇒ String
The current state of the RoverNode.
-
#lifecycle_state_details ⇒ String
A property that can contain details on the lifecycle.
-
#master_key_id ⇒ String
Customer provided master key ID to encrypt secret information.
-
#node_workloads ⇒ Array<OCI::Rover::Models::RoverWorkload>
List of existing workloads that should be provisioned on the node.
-
#oracle_shipping_tracking_url ⇒ String
Tracking Url for the shipped FmsRoverNode.
-
#point_of_contact ⇒ String
Name of point of contact for this order if customer is picking up.
-
#point_of_contact_phone_number ⇒ String
Phone number of point of contact for this order if customer is picking up.
-
#public_key ⇒ String
The public key of the resource principal.
-
#serial_number ⇒ String
Serial number of the node.
-
#shape ⇒ String
The shape of the node.
-
#shipping_preference ⇒ String
Preference for device delivery.
-
#shipping_vendor ⇒ String
Shipping vendor of choice for orace to customer shipping.
-
#super_user_password ⇒ String
Root password for the rover node.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
-
#time_pickup_expected ⇒ DateTime
Expected date when customer wants to pickup the device if they chose customer pickup.
-
#time_return_window_ends ⇒ DateTime
End time for the window to pickup the device from customer.
-
#time_return_window_starts ⇒ DateTime
Start time for the window to pickup the device from customer.
-
#unlock_passphrase ⇒ String
Passphrase to unlock the rover node.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateRoverNodeDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateRoverNodeDetails
Initializes the object
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 255 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.customer_shipping_address = attributes[:'customerShippingAddress'] if attributes[:'customerShippingAddress'] raise 'You cannot provide both :customerShippingAddress and :customer_shipping_address' if attributes.key?(:'customerShippingAddress') && attributes.key?(:'customer_shipping_address') self.customer_shipping_address = attributes[:'customer_shipping_address'] if attributes[:'customer_shipping_address'] self.node_workloads = attributes[:'nodeWorkloads'] if attributes[:'nodeWorkloads'] raise 'You cannot provide both :nodeWorkloads and :node_workloads' if attributes.key?(:'nodeWorkloads') && attributes.key?(:'node_workloads') self.node_workloads = attributes[:'node_workloads'] if attributes[:'node_workloads'] self.super_user_password = attributes[:'superUserPassword'] if attributes[:'superUserPassword'] raise 'You cannot provide both :superUserPassword and :super_user_password' if attributes.key?(:'superUserPassword') && attributes.key?(:'super_user_password') self.super_user_password = attributes[:'super_user_password'] if attributes[:'super_user_password'] self.unlock_passphrase = attributes[:'unlockPassphrase'] if attributes[:'unlockPassphrase'] raise 'You cannot provide both :unlockPassphrase and :unlock_passphrase' if attributes.key?(:'unlockPassphrase') && attributes.key?(:'unlock_passphrase') self.unlock_passphrase = attributes[:'unlock_passphrase'] if attributes[:'unlock_passphrase'] self.point_of_contact = attributes[:'pointOfContact'] if attributes[:'pointOfContact'] raise 'You cannot provide both :pointOfContact and :point_of_contact' if attributes.key?(:'pointOfContact') && attributes.key?(:'point_of_contact') self.point_of_contact = attributes[:'point_of_contact'] if attributes[:'point_of_contact'] self.point_of_contact_phone_number = attributes[:'pointOfContactPhoneNumber'] if attributes[:'pointOfContactPhoneNumber'] raise 'You cannot provide both :pointOfContactPhoneNumber and :point_of_contact_phone_number' if attributes.key?(:'pointOfContactPhoneNumber') && attributes.key?(:'point_of_contact_phone_number') self.point_of_contact_phone_number = attributes[:'point_of_contact_phone_number'] if attributes[:'point_of_contact_phone_number'] self.shipping_preference = attributes[:'shippingPreference'] if attributes[:'shippingPreference'] self.shipping_preference = "ORACLE_SHIPPED" if shipping_preference.nil? && !attributes.key?(:'shippingPreference') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :shippingPreference and :shipping_preference' if attributes.key?(:'shippingPreference') && attributes.key?(:'shipping_preference') self.shipping_preference = attributes[:'shipping_preference'] if attributes[:'shipping_preference'] self.shipping_preference = "ORACLE_SHIPPED" if shipping_preference.nil? && !attributes.key?(:'shippingPreference') && !attributes.key?(:'shipping_preference') # rubocop:disable Style/StringLiterals self.shipping_vendor = attributes[:'shippingVendor'] if attributes[:'shippingVendor'] raise 'You cannot provide both :shippingVendor and :shipping_vendor' if attributes.key?(:'shippingVendor') && attributes.key?(:'shipping_vendor') self.shipping_vendor = attributes[:'shipping_vendor'] if attributes[:'shipping_vendor'] self.time_pickup_expected = attributes[:'timePickupExpected'] if attributes[:'timePickupExpected'] raise 'You cannot provide both :timePickupExpected and :time_pickup_expected' if attributes.key?(:'timePickupExpected') && attributes.key?(:'time_pickup_expected') self.time_pickup_expected = attributes[:'time_pickup_expected'] if attributes[:'time_pickup_expected'] self.public_key = attributes[:'publicKey'] if attributes[:'publicKey'] raise 'You cannot provide both :publicKey and :public_key' if attributes.key?(:'publicKey') && attributes.key?(:'public_key') self.public_key = attributes[:'public_key'] if attributes[:'public_key'] self.time_return_window_starts = attributes[:'timeReturnWindowStarts'] if attributes[:'timeReturnWindowStarts'] raise 'You cannot provide both :timeReturnWindowStarts and :time_return_window_starts' if attributes.key?(:'timeReturnWindowStarts') && attributes.key?(:'time_return_window_starts') self.time_return_window_starts = attributes[:'time_return_window_starts'] if attributes[:'time_return_window_starts'] self.time_return_window_ends = attributes[:'timeReturnWindowEnds'] if attributes[:'timeReturnWindowEnds'] raise 'You cannot provide both :timeReturnWindowEnds and :time_return_window_ends' if attributes.key?(:'timeReturnWindowEnds') && attributes.key?(:'time_return_window_ends') self.time_return_window_ends = attributes[:'time_return_window_ends'] if attributes[:'time_return_window_ends'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.enclosure_type = attributes[:'enclosureType'] if attributes[:'enclosureType'] raise 'You cannot provide both :enclosureType and :enclosure_type' if attributes.key?(:'enclosureType') && attributes.key?(:'enclosure_type') self.enclosure_type = attributes[:'enclosure_type'] if attributes[:'enclosure_type'] self.lifecycle_state_details = attributes[:'lifecycleStateDetails'] if attributes[:'lifecycleStateDetails'] raise 'You cannot provide both :lifecycleStateDetails and :lifecycle_state_details' if attributes.key?(:'lifecycleStateDetails') && attributes.key?(:'lifecycle_state_details') self.lifecycle_state_details = attributes[:'lifecycle_state_details'] if attributes[:'lifecycle_state_details'] self.serial_number = attributes[:'serialNumber'] if attributes[:'serialNumber'] raise 'You cannot provide both :serialNumber and :serial_number' if attributes.key?(:'serialNumber') && attributes.key?(:'serial_number') self.serial_number = attributes[:'serial_number'] if attributes[:'serial_number'] self.oracle_shipping_tracking_url = attributes[:'oracleShippingTrackingUrl'] if attributes[:'oracleShippingTrackingUrl'] raise 'You cannot provide both :oracleShippingTrackingUrl and :oracle_shipping_tracking_url' if attributes.key?(:'oracleShippingTrackingUrl') && attributes.key?(:'oracle_shipping_tracking_url') self.oracle_shipping_tracking_url = attributes[:'oracle_shipping_tracking_url'] if attributes[:'oracle_shipping_tracking_url'] self.is_import_requested = attributes[:'isImportRequested'] unless attributes[:'isImportRequested'].nil? raise 'You cannot provide both :isImportRequested and :is_import_requested' if attributes.key?(:'isImportRequested') && attributes.key?(:'is_import_requested') self.is_import_requested = attributes[:'is_import_requested'] unless attributes[:'is_import_requested'].nil? self.import_compartment_id = attributes[:'importCompartmentId'] if attributes[:'importCompartmentId'] raise 'You cannot provide both :importCompartmentId and :import_compartment_id' if attributes.key?(:'importCompartmentId') && attributes.key?(:'import_compartment_id') self.import_compartment_id = attributes[:'import_compartment_id'] if attributes[:'import_compartment_id'] self.import_file_bucket = attributes[:'importFileBucket'] if attributes[:'importFileBucket'] raise 'You cannot provide both :importFileBucket and :import_file_bucket' if attributes.key?(:'importFileBucket') && attributes.key?(:'import_file_bucket') self.import_file_bucket = attributes[:'import_file_bucket'] if attributes[:'import_file_bucket'] self.data_validation_code = attributes[:'dataValidationCode'] if attributes[:'dataValidationCode'] raise 'You cannot provide both :dataValidationCode and :data_validation_code' if attributes.key?(:'dataValidationCode') && attributes.key?(:'data_validation_code') self.data_validation_code = attributes[:'data_validation_code'] if attributes[:'data_validation_code'] self.master_key_id = attributes[:'masterKeyId'] if attributes[:'masterKeyId'] raise 'You cannot provide both :masterKeyId and :master_key_id' if attributes.key?(:'masterKeyId') && attributes.key?(:'master_key_id') self.master_key_id = attributes[:'master_key_id'] if attributes[:'master_key_id'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the RoverNode.
35 36 37 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 35 def compartment_id @compartment_id end |
#customer_shipping_address ⇒ OCI::Rover::Models::ShippingAddress
42 43 44 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 42 def customer_shipping_address @customer_shipping_address end |
#data_validation_code ⇒ String
Validation code returned by data validation tool. Required for return shipping label generation if data import was requested.
122 123 124 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 122 def data_validation_code @data_validation_code end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
140 141 142 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 140 def @defined_tags end |
#display_name ⇒ String
**[Required]** A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
31 32 33 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 31 def display_name @display_name end |
#enclosure_type ⇒ String
The type of enclosure rover nodes in this cluster are shipped in.
94 95 96 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 94 def enclosure_type @enclosure_type end |
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
133 134 135 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 133 def @freeform_tags end |
#import_compartment_id ⇒ String
An OCID of a compartment where data will be imported to upon Rover node return.
114 115 116 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 114 def import_compartment_id @import_compartment_id end |
#import_file_bucket ⇒ String
Name of a bucket where files from NFS share will be imported to upon Rover node return.
118 119 120 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 118 def import_file_bucket @import_file_bucket end |
#is_import_requested ⇒ BOOLEAN
The flag indicating that customer requests data to be imported to OCI upon Rover node return.
110 111 112 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 110 def is_import_requested @is_import_requested end |
#lifecycle_state ⇒ String
The current state of the RoverNode.
90 91 92 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 90 def lifecycle_state @lifecycle_state end |
#lifecycle_state_details ⇒ String
A property that can contain details on the lifecycle.
98 99 100 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 98 def lifecycle_state_details @lifecycle_state_details end |
#master_key_id ⇒ String
Customer provided master key ID to encrypt secret information. If not provided, Rover's master key will be used for encryption.
126 127 128 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 126 def master_key_id @master_key_id end |
#node_workloads ⇒ Array<OCI::Rover::Models::RoverWorkload>
List of existing workloads that should be provisioned on the node.
46 47 48 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 46 def node_workloads @node_workloads end |
#oracle_shipping_tracking_url ⇒ String
Tracking Url for the shipped FmsRoverNode.
106 107 108 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 106 def oracle_shipping_tracking_url @oracle_shipping_tracking_url end |
#point_of_contact ⇒ String
Name of point of contact for this order if customer is picking up.
58 59 60 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 58 def point_of_contact @point_of_contact end |
#point_of_contact_phone_number ⇒ String
Phone number of point of contact for this order if customer is picking up.
62 63 64 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 62 def point_of_contact_phone_number @point_of_contact_phone_number end |
#public_key ⇒ String
The public key of the resource principal
78 79 80 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 78 def public_key @public_key end |
#serial_number ⇒ String
Serial number of the node.
102 103 104 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 102 def serial_number @serial_number end |
#shape ⇒ String
The shape of the node.
39 40 41 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 39 def shape @shape end |
#shipping_preference ⇒ String
Preference for device delivery.
66 67 68 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 66 def shipping_preference @shipping_preference end |
#shipping_vendor ⇒ String
Shipping vendor of choice for orace to customer shipping.
70 71 72 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 70 def shipping_vendor @shipping_vendor end |
#super_user_password ⇒ String
Root password for the rover node.
50 51 52 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 50 def super_user_password @super_user_password end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{free-tier-retain: true}`
147 148 149 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 147 def @system_tags end |
#time_pickup_expected ⇒ DateTime
Expected date when customer wants to pickup the device if they chose customer pickup.
74 75 76 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 74 def time_pickup_expected @time_pickup_expected end |
#time_return_window_ends ⇒ DateTime
End time for the window to pickup the device from customer.
86 87 88 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 86 def time_return_window_ends @time_return_window_ends end |
#time_return_window_starts ⇒ DateTime
Start time for the window to pickup the device from customer.
82 83 84 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 82 def time_return_window_starts @time_return_window_starts end |
#unlock_passphrase ⇒ String
Passphrase to unlock the rover node.
54 55 56 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 54 def unlock_passphrase @unlock_passphrase end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 150 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'compartment_id': :'compartmentId', 'shape': :'shape', 'customer_shipping_address': :'customerShippingAddress', 'node_workloads': :'nodeWorkloads', 'super_user_password': :'superUserPassword', 'unlock_passphrase': :'unlockPassphrase', 'point_of_contact': :'pointOfContact', 'point_of_contact_phone_number': :'pointOfContactPhoneNumber', 'shipping_preference': :'shippingPreference', 'shipping_vendor': :'shippingVendor', 'time_pickup_expected': :'timePickupExpected', 'public_key': :'publicKey', 'time_return_window_starts': :'timeReturnWindowStarts', 'time_return_window_ends': :'timeReturnWindowEnds', 'lifecycle_state': :'lifecycleState', 'enclosure_type': :'enclosureType', 'lifecycle_state_details': :'lifecycleStateDetails', 'serial_number': :'serialNumber', 'oracle_shipping_tracking_url': :'oracleShippingTrackingUrl', 'is_import_requested': :'isImportRequested', 'import_compartment_id': :'importCompartmentId', 'import_file_bucket': :'importFileBucket', 'data_validation_code': :'dataValidationCode', 'master_key_id': :'masterKeyId', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 186 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'compartment_id': :'String', 'shape': :'String', 'customer_shipping_address': :'OCI::Rover::Models::ShippingAddress', 'node_workloads': :'Array<OCI::Rover::Models::RoverWorkload>', 'super_user_password': :'String', 'unlock_passphrase': :'String', 'point_of_contact': :'String', 'point_of_contact_phone_number': :'String', 'shipping_preference': :'String', 'shipping_vendor': :'String', 'time_pickup_expected': :'DateTime', 'public_key': :'String', 'time_return_window_starts': :'DateTime', 'time_return_window_ends': :'DateTime', 'lifecycle_state': :'String', 'enclosure_type': :'String', 'lifecycle_state_details': :'String', 'serial_number': :'String', 'oracle_shipping_tracking_url': :'String', 'is_import_requested': :'BOOLEAN', 'import_compartment_id': :'String', 'import_file_bucket': :'String', 'data_validation_code': :'String', 'master_key_id': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 459 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && compartment_id == other.compartment_id && shape == other.shape && customer_shipping_address == other.customer_shipping_address && node_workloads == other.node_workloads && super_user_password == other.super_user_password && unlock_passphrase == other.unlock_passphrase && point_of_contact == other.point_of_contact && point_of_contact_phone_number == other.point_of_contact_phone_number && shipping_preference == other.shipping_preference && shipping_vendor == other.shipping_vendor && time_pickup_expected == other.time_pickup_expected && public_key == other.public_key && time_return_window_starts == other.time_return_window_starts && time_return_window_ends == other.time_return_window_ends && lifecycle_state == other.lifecycle_state && enclosure_type == other.enclosure_type && lifecycle_state_details == other.lifecycle_state_details && serial_number == other.serial_number && oracle_shipping_tracking_url == other.oracle_shipping_tracking_url && is_import_requested == other.is_import_requested && import_compartment_id == other.import_compartment_id && import_file_bucket == other.import_file_bucket && data_validation_code == other.data_validation_code && master_key_id == other.master_key_id && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 516 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
496 497 498 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 496 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
505 506 507 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 505 def hash [display_name, compartment_id, shape, customer_shipping_address, node_workloads, super_user_password, unlock_passphrase, point_of_contact, point_of_contact_phone_number, shipping_preference, shipping_vendor, time_pickup_expected, public_key, time_return_window_starts, time_return_window_ends, lifecycle_state, enclosure_type, lifecycle_state_details, serial_number, oracle_shipping_tracking_url, is_import_requested, import_compartment_id, import_file_bucket, data_validation_code, master_key_id, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
549 550 551 552 553 554 555 556 557 558 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 549 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
543 544 545 |
# File 'lib/oci/rover/models/create_rover_node_details.rb', line 543 def to_s to_hash.to_s end |