Class: OCI::Rover::Models::RoverNode
- Inherits:
-
Object
- Object
- OCI::Rover::Models::RoverNode
- Defined in:
- lib/oci/rover/models/rover_node.rb
Overview
Information about a RoverNode.
Constant Summary collapse
- NODE_TYPE_ENUM =
[ NODE_TYPE_STANDALONE = 'STANDALONE'.freeze, NODE_TYPE_CLUSTERED = 'CLUSTERED'.freeze, NODE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ENCLOSURE_TYPE_ENUM =
[ ENCLOSURE_TYPE_RUGGADIZED = 'RUGGADIZED'.freeze, ENCLOSURE_TYPE_NON_RUGGADIZED = 'NON_RUGGADIZED'.freeze, ENCLOSURE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SHIPPING_PREFERENCE_ENUM =
[ SHIPPING_PREFERENCE_ORACLE_SHIPPED = 'ORACLE_SHIPPED'.freeze, SHIPPING_PREFERENCE_CUSTOMER_PICKUP = 'CUSTOMER_PICKUP'.freeze, SHIPPING_PREFERENCE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
The cluster ID if the node is part of a cluster.
-
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the RoverNode.
- #customer_shipping_address ⇒ OCI::Rover::Models::ShippingAddress
-
#data_validation_code ⇒ String
Validation code returned by data validation tool.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any.
-
#delivery_tracking_info ⇒ String
Tracking information for device shipping.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#enclosure_type ⇒ String
The type of enclosure rover node is shipped in.
-
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any.
-
#id ⇒ String
[Required] The OCID of RoverNode.
-
#image_export_par ⇒ String
The link to pre-authenticated request for a bucket where image workloads are moved.
-
#import_compartment_id ⇒ String
An OCID of a compartment where data will be imported to upon Rover node return.
-
#import_file_bucket ⇒ String
Name of a bucket where files from NFS share will be imported to upon Rover node return.
-
#is_import_requested ⇒ BOOLEAN
The flag indicating that customer requests data to be imported to OCI upon Rover node return.
-
#lifecycle_state ⇒ String
[Required] The current state of the RoverNode.
-
#lifecycle_state_details ⇒ String
A property that can contain details on the lifecycle.
-
#node_type ⇒ String
The type of node indicating if it belongs to a cluster.
-
#node_workloads ⇒ Array<OCI::Rover::Models::RoverWorkload>
List of existing workloads that should be provisioned on the node.
-
#oracle_shipping_tracking_url ⇒ String
Tracking Url for the shipped RoverNode.
-
#point_of_contact ⇒ String
Name of point of contact for this order if customer is picking up.
-
#point_of_contact_phone_number ⇒ String
Phone number of point of contact for this order if customer is picking up.
-
#public_key ⇒ String
The public key of the resource principal.
-
#return_shipping_label_uri ⇒ String
Uri to download return shipping label.
-
#serial_number ⇒ String
Serial number of the node.
-
#shipping_preference ⇒ String
Preference for device delivery.
-
#shipping_vendor ⇒ String
Shipping vendor of choice for orace to customer shipping.
-
#super_user_password ⇒ String
Root password for the rover node.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
-
#tags ⇒ String
The tags associated with tagSlug.
-
#time_created ⇒ DateTime
The time the the RoverNode was created.
-
#time_customer_receieved ⇒ DateTime
Date and time when customer received tne node.
-
#time_customer_returned ⇒ DateTime
Date and time when customer returned the node.
-
#time_pickup_expected ⇒ DateTime
Expected date when customer wants to pickup the device if they chose customer pickup.
-
#time_return_window_ends ⇒ DateTime
End time for the window to pickup the device from customer.
-
#time_return_window_starts ⇒ DateTime
Start time for the window to pickup the device from customer.
-
#unlock_passphrase ⇒ String
Password to unlock the rover node.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RoverNode
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RoverNode
Initializes the object
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/oci/rover/models/rover_node.rb', line 322 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.cluster_id = attributes[:'clusterId'] if attributes[:'clusterId'] raise 'You cannot provide both :clusterId and :cluster_id' if attributes.key?(:'clusterId') && attributes.key?(:'cluster_id') self.cluster_id = attributes[:'cluster_id'] if attributes[:'cluster_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.node_type = attributes[:'nodeType'] if attributes[:'nodeType'] raise 'You cannot provide both :nodeType and :node_type' if attributes.key?(:'nodeType') && attributes.key?(:'node_type') self.node_type = attributes[:'node_type'] if attributes[:'node_type'] self.enclosure_type = attributes[:'enclosureType'] if attributes[:'enclosureType'] raise 'You cannot provide both :enclosureType and :enclosure_type' if attributes.key?(:'enclosureType') && attributes.key?(:'enclosure_type') self.enclosure_type = attributes[:'enclosure_type'] if attributes[:'enclosure_type'] self.serial_number = attributes[:'serialNumber'] if attributes[:'serialNumber'] raise 'You cannot provide both :serialNumber and :serial_number' if attributes.key?(:'serialNumber') && attributes.key?(:'serial_number') self.serial_number = attributes[:'serial_number'] if attributes[:'serial_number'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_state_details = attributes[:'lifecycleStateDetails'] if attributes[:'lifecycleStateDetails'] raise 'You cannot provide both :lifecycleStateDetails and :lifecycle_state_details' if attributes.key?(:'lifecycleStateDetails') && attributes.key?(:'lifecycle_state_details') self.lifecycle_state_details = attributes[:'lifecycle_state_details'] if attributes[:'lifecycle_state_details'] self.customer_shipping_address = attributes[:'customerShippingAddress'] if attributes[:'customerShippingAddress'] raise 'You cannot provide both :customerShippingAddress and :customer_shipping_address' if attributes.key?(:'customerShippingAddress') && attributes.key?(:'customer_shipping_address') self.customer_shipping_address = attributes[:'customer_shipping_address'] if attributes[:'customer_shipping_address'] self.node_workloads = attributes[:'nodeWorkloads'] if attributes[:'nodeWorkloads'] raise 'You cannot provide both :nodeWorkloads and :node_workloads' if attributes.key?(:'nodeWorkloads') && attributes.key?(:'node_workloads') self.node_workloads = attributes[:'node_workloads'] if attributes[:'node_workloads'] self.time_customer_receieved = attributes[:'timeCustomerReceieved'] if attributes[:'timeCustomerReceieved'] raise 'You cannot provide both :timeCustomerReceieved and :time_customer_receieved' if attributes.key?(:'timeCustomerReceieved') && attributes.key?(:'time_customer_receieved') self.time_customer_receieved = attributes[:'time_customer_receieved'] if attributes[:'time_customer_receieved'] self.time_customer_returned = attributes[:'timeCustomerReturned'] if attributes[:'timeCustomerReturned'] raise 'You cannot provide both :timeCustomerReturned and :time_customer_returned' if attributes.key?(:'timeCustomerReturned') && attributes.key?(:'time_customer_returned') self.time_customer_returned = attributes[:'time_customer_returned'] if attributes[:'time_customer_returned'] self.delivery_tracking_info = attributes[:'deliveryTrackingInfo'] if attributes[:'deliveryTrackingInfo'] raise 'You cannot provide both :deliveryTrackingInfo and :delivery_tracking_info' if attributes.key?(:'deliveryTrackingInfo') && attributes.key?(:'delivery_tracking_info') self.delivery_tracking_info = attributes[:'delivery_tracking_info'] if attributes[:'delivery_tracking_info'] self.super_user_password = attributes[:'superUserPassword'] if attributes[:'superUserPassword'] raise 'You cannot provide both :superUserPassword and :super_user_password' if attributes.key?(:'superUserPassword') && attributes.key?(:'super_user_password') self.super_user_password = attributes[:'super_user_password'] if attributes[:'super_user_password'] self.unlock_passphrase = attributes[:'unlockPassphrase'] if attributes[:'unlockPassphrase'] raise 'You cannot provide both :unlockPassphrase and :unlock_passphrase' if attributes.key?(:'unlockPassphrase') && attributes.key?(:'unlock_passphrase') self.unlock_passphrase = attributes[:'unlock_passphrase'] if attributes[:'unlock_passphrase'] self.point_of_contact = attributes[:'pointOfContact'] if attributes[:'pointOfContact'] raise 'You cannot provide both :pointOfContact and :point_of_contact' if attributes.key?(:'pointOfContact') && attributes.key?(:'point_of_contact') self.point_of_contact = attributes[:'point_of_contact'] if attributes[:'point_of_contact'] self.point_of_contact_phone_number = attributes[:'pointOfContactPhoneNumber'] if attributes[:'pointOfContactPhoneNumber'] raise 'You cannot provide both :pointOfContactPhoneNumber and :point_of_contact_phone_number' if attributes.key?(:'pointOfContactPhoneNumber') && attributes.key?(:'point_of_contact_phone_number') self.point_of_contact_phone_number = attributes[:'point_of_contact_phone_number'] if attributes[:'point_of_contact_phone_number'] self.shipping_preference = attributes[:'shippingPreference'] if attributes[:'shippingPreference'] self.shipping_preference = "ORACLE_SHIPPED" if shipping_preference.nil? && !attributes.key?(:'shippingPreference') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :shippingPreference and :shipping_preference' if attributes.key?(:'shippingPreference') && attributes.key?(:'shipping_preference') self.shipping_preference = attributes[:'shipping_preference'] if attributes[:'shipping_preference'] self.shipping_preference = "ORACLE_SHIPPED" if shipping_preference.nil? && !attributes.key?(:'shippingPreference') && !attributes.key?(:'shipping_preference') # rubocop:disable Style/StringLiterals self.shipping_vendor = attributes[:'shippingVendor'] if attributes[:'shippingVendor'] raise 'You cannot provide both :shippingVendor and :shipping_vendor' if attributes.key?(:'shippingVendor') && attributes.key?(:'shipping_vendor') self.shipping_vendor = attributes[:'shipping_vendor'] if attributes[:'shipping_vendor'] self.time_pickup_expected = attributes[:'timePickupExpected'] if attributes[:'timePickupExpected'] raise 'You cannot provide both :timePickupExpected and :time_pickup_expected' if attributes.key?(:'timePickupExpected') && attributes.key?(:'time_pickup_expected') self.time_pickup_expected = attributes[:'time_pickup_expected'] if attributes[:'time_pickup_expected'] self.time_return_window_starts = attributes[:'timeReturnWindowStarts'] if attributes[:'timeReturnWindowStarts'] raise 'You cannot provide both :timeReturnWindowStarts and :time_return_window_starts' if attributes.key?(:'timeReturnWindowStarts') && attributes.key?(:'time_return_window_starts') self.time_return_window_starts = attributes[:'time_return_window_starts'] if attributes[:'time_return_window_starts'] self.oracle_shipping_tracking_url = attributes[:'oracleShippingTrackingUrl'] if attributes[:'oracleShippingTrackingUrl'] raise 'You cannot provide both :oracleShippingTrackingUrl and :oracle_shipping_tracking_url' if attributes.key?(:'oracleShippingTrackingUrl') && attributes.key?(:'oracle_shipping_tracking_url') self.oracle_shipping_tracking_url = attributes[:'oracle_shipping_tracking_url'] if attributes[:'oracle_shipping_tracking_url'] self.time_return_window_ends = attributes[:'timeReturnWindowEnds'] if attributes[:'timeReturnWindowEnds'] raise 'You cannot provide both :timeReturnWindowEnds and :time_return_window_ends' if attributes.key?(:'timeReturnWindowEnds') && attributes.key?(:'time_return_window_ends') self.time_return_window_ends = attributes[:'time_return_window_ends'] if attributes[:'time_return_window_ends'] self.return_shipping_label_uri = attributes[:'returnShippingLabelUri'] if attributes[:'returnShippingLabelUri'] raise 'You cannot provide both :returnShippingLabelUri and :return_shipping_label_uri' if attributes.key?(:'returnShippingLabelUri') && attributes.key?(:'return_shipping_label_uri') self.return_shipping_label_uri = attributes[:'return_shipping_label_uri'] if attributes[:'return_shipping_label_uri'] self.is_import_requested = attributes[:'isImportRequested'] unless attributes[:'isImportRequested'].nil? raise 'You cannot provide both :isImportRequested and :is_import_requested' if attributes.key?(:'isImportRequested') && attributes.key?(:'is_import_requested') self.is_import_requested = attributes[:'is_import_requested'] unless attributes[:'is_import_requested'].nil? self.import_compartment_id = attributes[:'importCompartmentId'] if attributes[:'importCompartmentId'] raise 'You cannot provide both :importCompartmentId and :import_compartment_id' if attributes.key?(:'importCompartmentId') && attributes.key?(:'import_compartment_id') self.import_compartment_id = attributes[:'import_compartment_id'] if attributes[:'import_compartment_id'] self.import_file_bucket = attributes[:'importFileBucket'] if attributes[:'importFileBucket'] raise 'You cannot provide both :importFileBucket and :import_file_bucket' if attributes.key?(:'importFileBucket') && attributes.key?(:'import_file_bucket') self.import_file_bucket = attributes[:'import_file_bucket'] if attributes[:'import_file_bucket'] self.data_validation_code = attributes[:'dataValidationCode'] if attributes[:'dataValidationCode'] raise 'You cannot provide both :dataValidationCode and :data_validation_code' if attributes.key?(:'dataValidationCode') && attributes.key?(:'data_validation_code') self.data_validation_code = attributes[:'data_validation_code'] if attributes[:'data_validation_code'] self.public_key = attributes[:'publicKey'] if attributes[:'publicKey'] raise 'You cannot provide both :publicKey and :public_key' if attributes.key?(:'publicKey') && attributes.key?(:'public_key') self.public_key = attributes[:'public_key'] if attributes[:'public_key'] self.image_export_par = attributes[:'imageExportPar'] if attributes[:'imageExportPar'] raise 'You cannot provide both :imageExportPar and :image_export_par' if attributes.key?(:'imageExportPar') && attributes.key?(:'image_export_par') self.image_export_par = attributes[:'image_export_par'] if attributes[:'image_export_par'] self. = attributes[:'tags'] if attributes[:'tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#cluster_id ⇒ String
The cluster ID if the node is part of a cluster.
45 46 47 |
# File 'lib/oci/rover/models/rover_node.rb', line 45 def cluster_id @cluster_id end |
#compartment_id ⇒ String
[Required] The OCID of the compartment containing the RoverNode.
49 50 51 |
# File 'lib/oci/rover/models/rover_node.rb', line 49 def compartment_id @compartment_id end |
#customer_shipping_address ⇒ OCI::Rover::Models::ShippingAddress
80 81 82 |
# File 'lib/oci/rover/models/rover_node.rb', line 80 def customer_shipping_address @customer_shipping_address end |
#data_validation_code ⇒ String
Validation code returned by data validation tool. Required for return shipping label generation if data import was requested.
156 157 158 |
# File 'lib/oci/rover/models/rover_node.rb', line 156 def data_validation_code @data_validation_code end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{"CostCenter": "42"}`
183 184 185 |
# File 'lib/oci/rover/models/rover_node.rb', line 183 def @defined_tags end |
#delivery_tracking_info ⇒ String
Tracking information for device shipping.
96 97 98 |
# File 'lib/oci/rover/models/rover_node.rb', line 96 def delivery_tracking_info @delivery_tracking_info end |
#display_name ⇒ String
[Required] A user-friendly name. Does not have to be unique, and it’s changeable. Avoid entering confidential information.
65 66 67 |
# File 'lib/oci/rover/models/rover_node.rb', line 65 def display_name @display_name end |
#enclosure_type ⇒ String
The type of enclosure rover node is shipped in.
57 58 59 |
# File 'lib/oci/rover/models/rover_node.rb', line 57 def enclosure_type @enclosure_type end |
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘"Finance"`
176 177 178 |
# File 'lib/oci/rover/models/rover_node.rb', line 176 def @freeform_tags end |
#id ⇒ String
[Required] The OCID of RoverNode.
41 42 43 |
# File 'lib/oci/rover/models/rover_node.rb', line 41 def id @id end |
#image_export_par ⇒ String
The link to pre-authenticated request for a bucket where image workloads are moved.
164 165 166 |
# File 'lib/oci/rover/models/rover_node.rb', line 164 def image_export_par @image_export_par end |
#import_compartment_id ⇒ String
An OCID of a compartment where data will be imported to upon Rover node return.
148 149 150 |
# File 'lib/oci/rover/models/rover_node.rb', line 148 def import_compartment_id @import_compartment_id end |
#import_file_bucket ⇒ String
Name of a bucket where files from NFS share will be imported to upon Rover node return.
152 153 154 |
# File 'lib/oci/rover/models/rover_node.rb', line 152 def import_file_bucket @import_file_bucket end |
#is_import_requested ⇒ BOOLEAN
The flag indicating that customer requests data to be imported to OCI upon Rover node return.
144 145 146 |
# File 'lib/oci/rover/models/rover_node.rb', line 144 def is_import_requested @is_import_requested end |
#lifecycle_state ⇒ String
[Required] The current state of the RoverNode.
73 74 75 |
# File 'lib/oci/rover/models/rover_node.rb', line 73 def lifecycle_state @lifecycle_state end |
#lifecycle_state_details ⇒ String
A property that can contain details on the lifecycle.
77 78 79 |
# File 'lib/oci/rover/models/rover_node.rb', line 77 def lifecycle_state_details @lifecycle_state_details end |
#node_type ⇒ String
The type of node indicating if it belongs to a cluster
53 54 55 |
# File 'lib/oci/rover/models/rover_node.rb', line 53 def node_type @node_type end |
#node_workloads ⇒ Array<OCI::Rover::Models::RoverWorkload>
List of existing workloads that should be provisioned on the node.
84 85 86 |
# File 'lib/oci/rover/models/rover_node.rb', line 84 def node_workloads @node_workloads end |
#oracle_shipping_tracking_url ⇒ String
Tracking Url for the shipped RoverNode.
132 133 134 |
# File 'lib/oci/rover/models/rover_node.rb', line 132 def oracle_shipping_tracking_url @oracle_shipping_tracking_url end |
#point_of_contact ⇒ String
Name of point of contact for this order if customer is picking up.
108 109 110 |
# File 'lib/oci/rover/models/rover_node.rb', line 108 def point_of_contact @point_of_contact end |
#point_of_contact_phone_number ⇒ String
Phone number of point of contact for this order if customer is picking up.
112 113 114 |
# File 'lib/oci/rover/models/rover_node.rb', line 112 def point_of_contact_phone_number @point_of_contact_phone_number end |
#public_key ⇒ String
The public key of the resource principal
160 161 162 |
# File 'lib/oci/rover/models/rover_node.rb', line 160 def public_key @public_key end |
#return_shipping_label_uri ⇒ String
Uri to download return shipping label.
140 141 142 |
# File 'lib/oci/rover/models/rover_node.rb', line 140 def return_shipping_label_uri @return_shipping_label_uri end |
#serial_number ⇒ String
Serial number of the node.
61 62 63 |
# File 'lib/oci/rover/models/rover_node.rb', line 61 def serial_number @serial_number end |
#shipping_preference ⇒ String
Preference for device delivery.
116 117 118 |
# File 'lib/oci/rover/models/rover_node.rb', line 116 def shipping_preference @shipping_preference end |
#shipping_vendor ⇒ String
Shipping vendor of choice for orace to customer shipping.
120 121 122 |
# File 'lib/oci/rover/models/rover_node.rb', line 120 def shipping_vendor @shipping_vendor end |
#super_user_password ⇒ String
Root password for the rover node.
100 101 102 |
# File 'lib/oci/rover/models/rover_node.rb', line 100 def super_user_password @super_user_password end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{free-tier-retain: true}`
190 191 192 |
# File 'lib/oci/rover/models/rover_node.rb', line 190 def @system_tags end |
#tags ⇒ String
The tags associated with tagSlug.
169 170 171 |
# File 'lib/oci/rover/models/rover_node.rb', line 169 def @tags end |
#time_created ⇒ DateTime
The time the the RoverNode was created. An RFC3339 formatted datetime string
69 70 71 |
# File 'lib/oci/rover/models/rover_node.rb', line 69 def time_created @time_created end |
#time_customer_receieved ⇒ DateTime
Date and time when customer received tne node.
88 89 90 |
# File 'lib/oci/rover/models/rover_node.rb', line 88 def time_customer_receieved @time_customer_receieved end |
#time_customer_returned ⇒ DateTime
Date and time when customer returned the node.
92 93 94 |
# File 'lib/oci/rover/models/rover_node.rb', line 92 def time_customer_returned @time_customer_returned end |
#time_pickup_expected ⇒ DateTime
Expected date when customer wants to pickup the device if they chose customer pickup.
124 125 126 |
# File 'lib/oci/rover/models/rover_node.rb', line 124 def time_pickup_expected @time_pickup_expected end |
#time_return_window_ends ⇒ DateTime
End time for the window to pickup the device from customer.
136 137 138 |
# File 'lib/oci/rover/models/rover_node.rb', line 136 def time_return_window_ends @time_return_window_ends end |
#time_return_window_starts ⇒ DateTime
Start time for the window to pickup the device from customer.
128 129 130 |
# File 'lib/oci/rover/models/rover_node.rb', line 128 def time_return_window_starts @time_return_window_starts end |
#unlock_passphrase ⇒ String
Password to unlock the rover node.
104 105 106 |
# File 'lib/oci/rover/models/rover_node.rb', line 104 def unlock_passphrase @unlock_passphrase end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/oci/rover/models/rover_node.rb', line 193 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'cluster_id': :'clusterId', 'compartment_id': :'compartmentId', 'node_type': :'nodeType', 'enclosure_type': :'enclosureType', 'serial_number': :'serialNumber', 'display_name': :'displayName', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'lifecycle_state_details': :'lifecycleStateDetails', 'customer_shipping_address': :'customerShippingAddress', 'node_workloads': :'nodeWorkloads', 'time_customer_receieved': :'timeCustomerReceieved', 'time_customer_returned': :'timeCustomerReturned', 'delivery_tracking_info': :'deliveryTrackingInfo', 'super_user_password': :'superUserPassword', 'unlock_passphrase': :'unlockPassphrase', 'point_of_contact': :'pointOfContact', 'point_of_contact_phone_number': :'pointOfContactPhoneNumber', 'shipping_preference': :'shippingPreference', 'shipping_vendor': :'shippingVendor', 'time_pickup_expected': :'timePickupExpected', 'time_return_window_starts': :'timeReturnWindowStarts', 'oracle_shipping_tracking_url': :'oracleShippingTrackingUrl', 'time_return_window_ends': :'timeReturnWindowEnds', 'return_shipping_label_uri': :'returnShippingLabelUri', 'is_import_requested': :'isImportRequested', 'import_compartment_id': :'importCompartmentId', 'import_file_bucket': :'importFileBucket', 'data_validation_code': :'dataValidationCode', 'public_key': :'publicKey', 'image_export_par': :'imageExportPar', 'tags': :'tags', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/oci/rover/models/rover_node.rb', line 237 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'cluster_id': :'String', 'compartment_id': :'String', 'node_type': :'String', 'enclosure_type': :'String', 'serial_number': :'String', 'display_name': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_state_details': :'String', 'customer_shipping_address': :'OCI::Rover::Models::ShippingAddress', 'node_workloads': :'Array<OCI::Rover::Models::RoverWorkload>', 'time_customer_receieved': :'DateTime', 'time_customer_returned': :'DateTime', 'delivery_tracking_info': :'String', 'super_user_password': :'String', 'unlock_passphrase': :'String', 'point_of_contact': :'String', 'point_of_contact_phone_number': :'String', 'shipping_preference': :'String', 'shipping_vendor': :'String', 'time_pickup_expected': :'DateTime', 'time_return_window_starts': :'DateTime', 'oracle_shipping_tracking_url': :'String', 'time_return_window_ends': :'DateTime', 'return_shipping_label_uri': :'String', 'is_import_requested': :'BOOLEAN', 'import_compartment_id': :'String', 'import_file_bucket': :'String', 'data_validation_code': :'String', 'public_key': :'String', 'image_export_par': :'String', 'tags': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'lib/oci/rover/models/rover_node.rb', line 598 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && cluster_id == other.cluster_id && compartment_id == other.compartment_id && node_type == other.node_type && enclosure_type == other.enclosure_type && serial_number == other.serial_number && display_name == other.display_name && time_created == other.time_created && lifecycle_state == other.lifecycle_state && lifecycle_state_details == other.lifecycle_state_details && customer_shipping_address == other.customer_shipping_address && node_workloads == other.node_workloads && time_customer_receieved == other.time_customer_receieved && time_customer_returned == other.time_customer_returned && delivery_tracking_info == other.delivery_tracking_info && super_user_password == other.super_user_password && unlock_passphrase == other.unlock_passphrase && point_of_contact == other.point_of_contact && point_of_contact_phone_number == other.point_of_contact_phone_number && shipping_preference == other.shipping_preference && shipping_vendor == other.shipping_vendor && time_pickup_expected == other.time_pickup_expected && time_return_window_starts == other.time_return_window_starts && oracle_shipping_tracking_url == other.oracle_shipping_tracking_url && time_return_window_ends == other.time_return_window_ends && return_shipping_label_uri == other.return_shipping_label_uri && is_import_requested == other.is_import_requested && import_compartment_id == other.import_compartment_id && import_file_bucket == other.import_file_bucket && data_validation_code == other.data_validation_code && public_key == other.public_key && image_export_par == other.image_export_par && == other. && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/oci/rover/models/rover_node.rb', line 663 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
643 644 645 |
# File 'lib/oci/rover/models/rover_node.rb', line 643 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
652 653 654 |
# File 'lib/oci/rover/models/rover_node.rb', line 652 def hash [id, cluster_id, compartment_id, node_type, enclosure_type, serial_number, display_name, time_created, lifecycle_state, lifecycle_state_details, customer_shipping_address, node_workloads, time_customer_receieved, time_customer_returned, delivery_tracking_info, super_user_password, unlock_passphrase, point_of_contact, point_of_contact_phone_number, shipping_preference, shipping_vendor, time_pickup_expected, time_return_window_starts, oracle_shipping_tracking_url, time_return_window_ends, return_shipping_label_uri, is_import_requested, import_compartment_id, import_file_bucket, data_validation_code, public_key, image_export_par, , , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
696 697 698 699 700 701 702 703 704 705 |
# File 'lib/oci/rover/models/rover_node.rb', line 696 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
690 691 692 |
# File 'lib/oci/rover/models/rover_node.rb', line 690 def to_s to_hash.to_s end |