Class: OCI::Rover::Models::RoverNodeSummary
- Inherits:
-
Object
- Object
- OCI::Rover::Models::RoverNodeSummary
- Defined in:
- lib/oci/rover/models/rover_node_summary.rb
Overview
Summary of the RoverNode.
Constant Summary collapse
- NODE_TYPE_ENUM =
[ NODE_TYPE_STANDALONE = 'STANDALONE'.freeze, NODE_TYPE_CLUSTERED = 'CLUSTERED'.freeze, NODE_TYPE_STATION = 'STATION'.freeze, NODE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cluster_id ⇒ String
The cluster ID if the node is part of a cluster.
-
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the RoverNode.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any.
-
#id ⇒ String
**[Required]** The OCID of the RoverNode.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the RoverNode.
-
#lifecycle_state_details ⇒ String
A property that can contain details on the lifecycle.
-
#node_type ⇒ String
The type of node indicating if it belongs to a cluster.
-
#serial_number ⇒ String
Serial number of the node.
-
#shape ⇒ String
The shape of the node.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
-
#time_created ⇒ DateTime
The time the the RoverNode was created.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RoverNodeSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ RoverNodeSummary
Initializes the object
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 150 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.cluster_id = attributes[:'clusterId'] if attributes[:'clusterId'] raise 'You cannot provide both :clusterId and :cluster_id' if attributes.key?(:'clusterId') && attributes.key?(:'cluster_id') self.cluster_id = attributes[:'cluster_id'] if attributes[:'cluster_id'] self.serial_number = attributes[:'serialNumber'] if attributes[:'serialNumber'] raise 'You cannot provide both :serialNumber and :serial_number' if attributes.key?(:'serialNumber') && attributes.key?(:'serial_number') self.serial_number = attributes[:'serial_number'] if attributes[:'serial_number'] self.node_type = attributes[:'nodeType'] if attributes[:'nodeType'] raise 'You cannot provide both :nodeType and :node_type' if attributes.key?(:'nodeType') && attributes.key?(:'node_type') self.node_type = attributes[:'node_type'] if attributes[:'node_type'] self.shape = attributes[:'shape'] if attributes[:'shape'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_state_details = attributes[:'lifecycleStateDetails'] if attributes[:'lifecycleStateDetails'] raise 'You cannot provide both :lifecycleStateDetails and :lifecycle_state_details' if attributes.key?(:'lifecycleStateDetails') && attributes.key?(:'lifecycle_state_details') self.lifecycle_state_details = attributes[:'lifecycle_state_details'] if attributes[:'lifecycle_state_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#cluster_id ⇒ String
The cluster ID if the node is part of a cluster.
38 39 40 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 38 def cluster_id @cluster_id end |
#compartment_id ⇒ String
**[Required]** The OCID of the compartment containing the RoverNode.
34 35 36 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 34 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"CostCenter": "42"}`
80 81 82 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 80 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
54 55 56 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 54 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `"Finance"`
73 74 75 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 73 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of the RoverNode.
30 31 32 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 30 def id @id end |
#lifecycle_state ⇒ String
**[Required]** The current state of the RoverNode.
62 63 64 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 62 def lifecycle_state @lifecycle_state end |
#lifecycle_state_details ⇒ String
A property that can contain details on the lifecycle.
66 67 68 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 66 def lifecycle_state_details @lifecycle_state_details end |
#node_type ⇒ String
The type of node indicating if it belongs to a cluster
46 47 48 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 46 def node_type @node_type end |
#serial_number ⇒ String
Serial number of the node.
42 43 44 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 42 def serial_number @serial_number end |
#shape ⇒ String
The shape of the node.
50 51 52 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 50 def shape @shape end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{free-tier-retain: true}`
87 88 89 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 87 def @system_tags end |
#time_created ⇒ DateTime
The time the the RoverNode was created. An RFC3339 formatted datetime string
58 59 60 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 58 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 90 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'cluster_id': :'clusterId', 'serial_number': :'serialNumber', 'node_type': :'nodeType', 'shape': :'shape', 'display_name': :'displayName', 'time_created': :'timeCreated', 'lifecycle_state': :'lifecycleState', 'lifecycle_state_details': :'lifecycleStateDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 111 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'cluster_id': :'String', 'serial_number': :'String', 'node_type': :'String', 'shape': :'String', 'display_name': :'String', 'time_created': :'DateTime', 'lifecycle_state': :'String', 'lifecycle_state_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 260 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && cluster_id == other.cluster_id && serial_number == other.serial_number && node_type == other.node_type && shape == other.shape && display_name == other.display_name && time_created == other.time_created && lifecycle_state == other.lifecycle_state && lifecycle_state_details == other.lifecycle_state_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 302 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
282 283 284 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 282 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
291 292 293 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 291 def hash [id, compartment_id, cluster_id, serial_number, node_type, shape, display_name, time_created, lifecycle_state, lifecycle_state_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 344 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
329 330 331 |
# File 'lib/oci/rover/models/rover_node_summary.rb', line 329 def to_s to_hash.to_s end |