Class: OCI::Sch::Models::FunctionTaskDetails

Inherits:
TaskDetails
  • Object
show all
Defined in:
lib/oci/sch/models/function_task_details.rb

Overview

The function task. Batch input can be limited by either size or time. The first limit reached determines the boundary of the batch.

Constant Summary

Constants inherited from TaskDetails

TaskDetails::KIND_ENUM

Instance Attribute Summary collapse

Attributes inherited from TaskDetails

#kind

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from TaskDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ FunctionTaskDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :function_id (String)

    The value to assign to the #function_id property

  • :batch_size_in_kbs (Integer)

    The value to assign to the #batch_size_in_kbs property

  • :batch_time_in_sec (Integer)

    The value to assign to the #batch_time_in_sec property



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/oci/sch/models/function_task_details.rb', line 60

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['kind'] = 'function'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.function_id = attributes[:'functionId'] if attributes[:'functionId']

  raise 'You cannot provide both :functionId and :function_id' if attributes.key?(:'functionId') && attributes.key?(:'function_id')

  self.function_id = attributes[:'function_id'] if attributes[:'function_id']

  self.batch_size_in_kbs = attributes[:'batchSizeInKbs'] if attributes[:'batchSizeInKbs']

  raise 'You cannot provide both :batchSizeInKbs and :batch_size_in_kbs' if attributes.key?(:'batchSizeInKbs') && attributes.key?(:'batch_size_in_kbs')

  self.batch_size_in_kbs = attributes[:'batch_size_in_kbs'] if attributes[:'batch_size_in_kbs']

  self.batch_time_in_sec = attributes[:'batchTimeInSec'] if attributes[:'batchTimeInSec']

  raise 'You cannot provide both :batchTimeInSec and :batch_time_in_sec' if attributes.key?(:'batchTimeInSec') && attributes.key?(:'batch_time_in_sec')

  self.batch_time_in_sec = attributes[:'batch_time_in_sec'] if attributes[:'batch_time_in_sec']
end

Instance Attribute Details

#batch_size_in_kbsInteger

Size limit (kilobytes) for batch sent to invoke the function.

Returns:

  • (Integer)


20
21
22
# File 'lib/oci/sch/models/function_task_details.rb', line 20

def batch_size_in_kbs
  @batch_size_in_kbs
end

#batch_time_in_secInteger

Time limit (seconds) for batch sent to invoke the function.

Returns:

  • (Integer)


25
26
27
# File 'lib/oci/sch/models/function_task_details.rb', line 25

def batch_time_in_sec
  @batch_time_in_sec
end

#function_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the function to be used as a task.

Returns:

  • (String)


15
16
17
# File 'lib/oci/sch/models/function_task_details.rb', line 15

def function_id
  @function_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
36
37
# File 'lib/oci/sch/models/function_task_details.rb', line 28

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'kind',
    'function_id': :'functionId',
    'batch_size_in_kbs': :'batchSizeInKbs',
    'batch_time_in_sec': :'batchTimeInSec'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



40
41
42
43
44
45
46
47
48
49
# File 'lib/oci/sch/models/function_task_details.rb', line 40

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'String',
    'function_id': :'String',
    'batch_size_in_kbs': :'Integer',
    'batch_time_in_sec': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



96
97
98
99
100
101
102
103
104
# File 'lib/oci/sch/models/function_task_details.rb', line 96

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    kind == other.kind &&
    function_id == other.function_id &&
    batch_size_in_kbs == other.batch_size_in_kbs &&
    batch_time_in_sec == other.batch_time_in_sec
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/oci/sch/models/function_task_details.rb', line 129

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


109
110
111
# File 'lib/oci/sch/models/function_task_details.rb', line 109

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



118
119
120
# File 'lib/oci/sch/models/function_task_details.rb', line 118

def hash
  [kind, function_id, batch_size_in_kbs, batch_time_in_sec].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



162
163
164
165
166
167
168
169
170
171
# File 'lib/oci/sch/models/function_task_details.rb', line 162

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



156
157
158
# File 'lib/oci/sch/models/function_task_details.rb', line 156

def to_s
  to_hash.to_s
end