Class: OCI::Sch::Models::ObjectStorageTargetDetails

Inherits:
TargetDetails
  • Object
show all
Defined in:
lib/oci/sch/models/object_storage_target_details.rb

Overview

The bucket used for the Object Storage target.

Constant Summary

Constants inherited from TargetDetails

TargetDetails::KIND_ENUM

Instance Attribute Summary collapse

Attributes inherited from TargetDetails

#kind

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from TargetDetails

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ ObjectStorageTargetDetails

Initializes the object

Options Hash (attributes):

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 76

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['kind'] = 'objectStorage'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.namespace = attributes[:'namespace'] if attributes[:'namespace']

  self.bucket_name = attributes[:'bucketName'] if attributes[:'bucketName']

  raise 'You cannot provide both :bucketName and :bucket_name' if attributes.key?(:'bucketName') && attributes.key?(:'bucket_name')

  self.bucket_name = attributes[:'bucket_name'] if attributes[:'bucket_name']

  self.object_name_prefix = attributes[:'objectNamePrefix'] if attributes[:'objectNamePrefix']

  raise 'You cannot provide both :objectNamePrefix and :object_name_prefix' if attributes.key?(:'objectNamePrefix') && attributes.key?(:'object_name_prefix')

  self.object_name_prefix = attributes[:'object_name_prefix'] if attributes[:'object_name_prefix']

  self.batch_rollover_size_in_mbs = attributes[:'batchRolloverSizeInMBs'] if attributes[:'batchRolloverSizeInMBs']

  raise 'You cannot provide both :batchRolloverSizeInMBs and :batch_rollover_size_in_mbs' if attributes.key?(:'batchRolloverSizeInMBs') && attributes.key?(:'batch_rollover_size_in_mbs')

  self.batch_rollover_size_in_mbs = attributes[:'batch_rollover_size_in_mbs'] if attributes[:'batch_rollover_size_in_mbs']

  self.batch_rollover_time_in_ms = attributes[:'batchRolloverTimeInMs'] if attributes[:'batchRolloverTimeInMs']

  raise 'You cannot provide both :batchRolloverTimeInMs and :batch_rollover_time_in_ms' if attributes.key?(:'batchRolloverTimeInMs') && attributes.key?(:'batch_rollover_time_in_ms')

  self.batch_rollover_time_in_ms = attributes[:'batch_rollover_time_in_ms'] if attributes[:'batch_rollover_time_in_ms']
end

Instance Attribute Details

#batch_rollover_size_in_mbsInteger

The batch rollover size in megabytes.

Returns:



30
31
32
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 30

def batch_rollover_size_in_mbs
  @batch_rollover_size_in_mbs
end

#batch_rollover_time_in_msInteger

The batch rollover time in milliseconds.

Returns:



35
36
37
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 35

def batch_rollover_time_in_ms
  @batch_rollover_time_in_ms
end

#bucket_nameString

[Required] The name of the bucket. Avoid entering confidential information.

Returns:



20
21
22
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 20

def bucket_name
  @bucket_name
end

#namespaceString

The namespace.

Returns:



15
16
17
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 15

def namespace
  @namespace
end

#object_name_prefixString

The prefix of the objects. Avoid entering confidential information.

Returns:



25
26
27
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 25

def object_name_prefix
  @object_name_prefix
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 38

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'kind',
    'namespace': :'namespace',
    'bucket_name': :'bucketName',
    'object_name_prefix': :'objectNamePrefix',
    'batch_rollover_size_in_mbs': :'batchRolloverSizeInMBs',
    'batch_rollover_time_in_ms': :'batchRolloverTimeInMs'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 52

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'kind': :'String',
    'namespace': :'String',
    'bucket_name': :'String',
    'object_name_prefix': :'String',
    'batch_rollover_size_in_mbs': :'Integer',
    'batch_rollover_time_in_ms': :'Integer'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



120
121
122
123
124
125
126
127
128
129
130
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 120

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    kind == other.kind &&
    namespace == other.namespace &&
    bucket_name == other.bucket_name &&
    object_name_prefix == other.object_name_prefix &&
    batch_rollover_size_in_mbs == other.batch_rollover_size_in_mbs &&
    batch_rollover_time_in_ms == other.batch_rollover_time_in_ms
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 155

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • the other object to be compared

Returns:



135
136
137
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 135

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



144
145
146
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 144

def hash
  [kind, namespace, bucket_name, object_name_prefix, batch_rollover_size_in_mbs, batch_rollover_time_in_ms].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



188
189
190
191
192
193
194
195
196
197
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 188

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



182
183
184
# File 'lib/oci/sch/models/object_storage_target_details.rb', line 182

def to_s
  to_hash.to_s
end