Class: OCI::Sch::Models::ServiceConnector
- Inherits:
-
Object
- Object
- OCI::Sch::Models::ServiceConnector
- Defined in:
- lib/oci/sch/models/service_connector.rb
Overview
The configuration details of the flow defined by the service connector. For more information about flows defined by service connectors, see [Service Connector Hub Overview](docs.cloud.oracle.com/iaas/Content/service-connector-hub/overview.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the service connector.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
The description of the resource.
-
#display_name ⇒ String
[Required] A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the service connector.
-
#lifecycle_state ⇒ String
[Required] The current state of the service connector.
-
#lifecyle_details ⇒ String
A message describing the current state in more detail.
- #source ⇒ OCI::Sch::Models::SourceDetails
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any.
- #target ⇒ OCI::Sch::Models::TargetDetails
-
#tasks ⇒ Array<OCI::Sch::Models::TaskDetails>
The list of tasks.
-
#time_created ⇒ DateTime
[Required] The date and time when the service connector was created.
-
#time_updated ⇒ DateTime
[Required] The date and time when the service connector was updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ServiceConnector
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ServiceConnector
Initializes the object
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/oci/sch/models/service_connector.rb', line 166 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.description = attributes[:'description'] if attributes[:'description'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecyle_details = attributes[:'lifecyleDetails'] if attributes[:'lifecyleDetails'] raise 'You cannot provide both :lifecyleDetails and :lifecyle_details' if attributes.key?(:'lifecyleDetails') && attributes.key?(:'lifecyle_details') self.lifecyle_details = attributes[:'lifecyle_details'] if attributes[:'lifecyle_details'] self.source = attributes[:'source'] if attributes[:'source'] self.tasks = attributes[:'tasks'] if attributes[:'tasks'] self.target = attributes[:'target'] if attributes[:'target'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the service connector.
44 45 46 |
# File 'lib/oci/sch/models/service_connector.rb', line 44 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
93 94 95 |
# File 'lib/oci/sch/models/service_connector.rb', line 93 def @defined_tags end |
#description ⇒ String
The description of the resource. Avoid entering confidential information.
39 40 41 |
# File 'lib/oci/sch/models/service_connector.rb', line 39 def description @description end |
#display_name ⇒ String
[Required] A user-friendly name. It does not have to be unique, and it is changeable. Avoid entering confidential information.
34 35 36 |
# File 'lib/oci/sch/models/service_connector.rb', line 34 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
87 88 89 |
# File 'lib/oci/sch/models/service_connector.rb', line 87 def @freeform_tags end |
#id ⇒ String
[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the service connector.
28 29 30 |
# File 'lib/oci/sch/models/service_connector.rb', line 28 def id @id end |
#lifecycle_state ⇒ String
[Required] The current state of the service connector.
63 64 65 |
# File 'lib/oci/sch/models/service_connector.rb', line 63 def lifecycle_state @lifecycle_state end |
#lifecyle_details ⇒ String
A message describing the current state in more detail. For example, the message might provide actionable information for a resource in a FAILED state.
70 71 72 |
# File 'lib/oci/sch/models/service_connector.rb', line 70 def lifecyle_details @lifecyle_details end |
#source ⇒ OCI::Sch::Models::SourceDetails
73 74 75 |
# File 'lib/oci/sch/models/service_connector.rb', line 73 def source @source end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: ‘{free-tier-retain: true}`
100 101 102 |
# File 'lib/oci/sch/models/service_connector.rb', line 100 def @system_tags end |
#target ⇒ OCI::Sch::Models::TargetDetails
81 82 83 |
# File 'lib/oci/sch/models/service_connector.rb', line 81 def target @target end |
#tasks ⇒ Array<OCI::Sch::Models::TaskDetails>
The list of tasks.
78 79 80 |
# File 'lib/oci/sch/models/service_connector.rb', line 78 def tasks @tasks end |
#time_created ⇒ DateTime
[Required] The date and time when the service connector was created. Format is defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2020-01-25T21:10:29.600Z
51 52 53 |
# File 'lib/oci/sch/models/service_connector.rb', line 51 def time_created @time_created end |
#time_updated ⇒ DateTime
[Required] The date and time when the service connector was updated. Format is defined by [RFC3339](tools.ietf.org/html/rfc3339). Example: 2020-01-25T21:10:29.600Z
58 59 60 |
# File 'lib/oci/sch/models/service_connector.rb', line 58 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/oci/sch/models/service_connector.rb', line 103 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'display_name': :'displayName', 'description': :'description', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'lifecyle_details': :'lifecyleDetails', 'source': :'source', 'tasks': :'tasks', 'target': :'target', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/oci/sch/models/service_connector.rb', line 125 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'display_name': :'String', 'description': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'lifecyle_details': :'String', 'source': :'OCI::Sch::Models::SourceDetails', 'tasks': :'Array<OCI::Sch::Models::TaskDetails>', 'target': :'OCI::Sch::Models::TargetDetails', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/oci/sch/models/service_connector.rb', line 257 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && display_name == other.display_name && description == other.description && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && lifecyle_details == other.lifecyle_details && source == other.source && tasks == other.tasks && target == other.target && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/oci/sch/models/service_connector.rb', line 300 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
280 281 282 |
# File 'lib/oci/sch/models/service_connector.rb', line 280 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
289 290 291 |
# File 'lib/oci/sch/models/service_connector.rb', line 289 def hash [id, display_name, description, compartment_id, time_created, time_updated, lifecycle_state, lifecyle_details, source, tasks, target, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
333 334 335 336 337 338 339 340 341 342 |
# File 'lib/oci/sch/models/service_connector.rb', line 333 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
327 328 329 |
# File 'lib/oci/sch/models/service_connector.rb', line 327 def to_s to_hash.to_s end |