Class: OCI::ServiceCatalog::Models::ServiceCatalogAssociation
- Inherits:
-
Object
- Object
- OCI::ServiceCatalog::Models::ServiceCatalogAssociation
- Defined in:
- lib/oci/service_catalog/models/service_catalog_association.rb
Overview
The detailed model for service catalog association.
Instance Attribute Summary collapse
-
#entity_id ⇒ String
**[Required]** Identifier of the entity being associated with service catalog.
-
#entity_type ⇒ String
The type of the entity that is associated with the service catalog.
-
#id ⇒ String
**[Required]** Identifier of the association.
-
#service_catalog_id ⇒ String
**[Required]** Identifier of the service catalog.
-
#time_created ⇒ DateTime
**[Required]** Timestamp of when the resource was associated with service catalog.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ServiceCatalogAssociation
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ServiceCatalogAssociation
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 67 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.service_catalog_id = attributes[:'serviceCatalogId'] if attributes[:'serviceCatalogId'] raise 'You cannot provide both :serviceCatalogId and :service_catalog_id' if attributes.key?(:'serviceCatalogId') && attributes.key?(:'service_catalog_id') self.service_catalog_id = attributes[:'service_catalog_id'] if attributes[:'service_catalog_id'] self.entity_id = attributes[:'entityId'] if attributes[:'entityId'] raise 'You cannot provide both :entityId and :entity_id' if attributes.key?(:'entityId') && attributes.key?(:'entity_id') self.entity_id = attributes[:'entity_id'] if attributes[:'entity_id'] self.entity_type = attributes[:'entityType'] if attributes[:'entityType'] raise 'You cannot provide both :entityType and :entity_type' if attributes.key?(:'entityType') && attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] if attributes[:'entity_type'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#entity_id ⇒ String
**[Required]** Identifier of the entity being associated with service catalog.
20 21 22 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 20 def entity_id @entity_id end |
#entity_type ⇒ String
The type of the entity that is associated with the service catalog.
24 25 26 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 24 def entity_type @entity_type end |
#id ⇒ String
**[Required]** Identifier of the association.
12 13 14 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 12 def id @id end |
#service_catalog_id ⇒ String
**[Required]** Identifier of the service catalog.
16 17 18 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 16 def service_catalog_id @service_catalog_id end |
#time_created ⇒ DateTime
**[Required]** Timestamp of when the resource was associated with service catalog.
28 29 30 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 28 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 31 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'service_catalog_id': :'serviceCatalogId', 'entity_id': :'entityId', 'entity_type': :'entityType', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 44 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'service_catalog_id': :'String', 'entity_id': :'String', 'entity_type': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 107 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && service_catalog_id == other.service_catalog_id && entity_id == other.entity_id && entity_type == other.entity_type && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 141 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
121 122 123 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 121 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
130 131 132 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 130 def hash [id, service_catalog_id, entity_id, entity_type, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
168 169 170 |
# File 'lib/oci/service_catalog/models/service_catalog_association.rb', line 168 def to_s to_hash.to_s end |