Class: OCI::ServiceMesh::Models::HttpIngressGatewayTrafficRouteRule
- Inherits:
-
IngressGatewayTrafficRouteRule
- Object
- IngressGatewayTrafficRouteRule
- OCI::ServiceMesh::Models::HttpIngressGatewayTrafficRouteRule
- Defined in:
- lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb
Overview
Rule for routing incoming ingress gateway traffic with HTTP protocol
Constant Summary collapse
- PATH_TYPE_ENUM =
[ PATH_TYPE_PREFIX = 'PREFIX'.freeze, PATH_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Constants inherited from IngressGatewayTrafficRouteRule
IngressGatewayTrafficRouteRule::TYPE_ENUM
Instance Attribute Summary collapse
-
#is_grpc ⇒ BOOLEAN
If true, the rule will check that the content-type header has a application/grpc or one of the various application/grpc+ values.
-
#is_host_rewrite_enabled ⇒ BOOLEAN
If true, the hostname will be rewritten to the target virtual deployment's DNS hostname.
-
#is_path_rewrite_enabled ⇒ BOOLEAN
If true, the matched path prefix will be rewritten to '/' before being directed to the target virtual deployment.
-
#path ⇒ String
Route to match.
-
#path_type ⇒ String
Match type for the route.
Attributes inherited from IngressGatewayTrafficRouteRule
#destinations, #ingress_gateway_host, #type
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HttpIngressGatewayTrafficRouteRule
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Methods inherited from IngressGatewayTrafficRouteRule
Constructor Details
#initialize(attributes = {}) ⇒ HttpIngressGatewayTrafficRouteRule
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 86 def initialize(attributes = {}) return unless attributes.is_a?(Hash) attributes['type'] = 'HTTP' super(attributes) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.path = attributes[:'path'] if attributes[:'path'] self.path = "/" if path.nil? && !attributes.key?(:'path') # rubocop:disable Style/StringLiterals self.path_type = attributes[:'pathType'] if attributes[:'pathType'] self.path_type = "PREFIX" if path_type.nil? && !attributes.key?(:'pathType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :pathType and :path_type' if attributes.key?(:'pathType') && attributes.key?(:'path_type') self.path_type = attributes[:'path_type'] if attributes[:'path_type'] self.path_type = "PREFIX" if path_type.nil? && !attributes.key?(:'pathType') && !attributes.key?(:'path_type') # rubocop:disable Style/StringLiterals self.is_grpc = attributes[:'isGrpc'] unless attributes[:'isGrpc'].nil? self.is_grpc = false if is_grpc.nil? && !attributes.key?(:'isGrpc') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isGrpc and :is_grpc' if attributes.key?(:'isGrpc') && attributes.key?(:'is_grpc') self.is_grpc = attributes[:'is_grpc'] unless attributes[:'is_grpc'].nil? self.is_grpc = false if is_grpc.nil? && !attributes.key?(:'isGrpc') && !attributes.key?(:'is_grpc') # rubocop:disable Style/StringLiterals self.is_host_rewrite_enabled = attributes[:'isHostRewriteEnabled'] unless attributes[:'isHostRewriteEnabled'].nil? self.is_host_rewrite_enabled = false if is_host_rewrite_enabled.nil? && !attributes.key?(:'isHostRewriteEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isHostRewriteEnabled and :is_host_rewrite_enabled' if attributes.key?(:'isHostRewriteEnabled') && attributes.key?(:'is_host_rewrite_enabled') self.is_host_rewrite_enabled = attributes[:'is_host_rewrite_enabled'] unless attributes[:'is_host_rewrite_enabled'].nil? self.is_host_rewrite_enabled = false if is_host_rewrite_enabled.nil? && !attributes.key?(:'isHostRewriteEnabled') && !attributes.key?(:'is_host_rewrite_enabled') # rubocop:disable Style/StringLiterals self.is_path_rewrite_enabled = attributes[:'isPathRewriteEnabled'] unless attributes[:'isPathRewriteEnabled'].nil? self.is_path_rewrite_enabled = false if is_path_rewrite_enabled.nil? && !attributes.key?(:'isPathRewriteEnabled') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :isPathRewriteEnabled and :is_path_rewrite_enabled' if attributes.key?(:'isPathRewriteEnabled') && attributes.key?(:'is_path_rewrite_enabled') self.is_path_rewrite_enabled = attributes[:'is_path_rewrite_enabled'] unless attributes[:'is_path_rewrite_enabled'].nil? self.is_path_rewrite_enabled = false if is_path_rewrite_enabled.nil? && !attributes.key?(:'isPathRewriteEnabled') && !attributes.key?(:'is_path_rewrite_enabled') # rubocop:disable Style/StringLiterals end |
Instance Attribute Details
#is_grpc ⇒ BOOLEAN
If true, the rule will check that the content-type header has a application/grpc or one of the various application/grpc+ values.
29 30 31 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 29 def is_grpc @is_grpc end |
#is_host_rewrite_enabled ⇒ BOOLEAN
If true, the hostname will be rewritten to the target virtual deployment's DNS hostname.
34 35 36 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 34 def is_host_rewrite_enabled @is_host_rewrite_enabled end |
#is_path_rewrite_enabled ⇒ BOOLEAN
If true, the matched path prefix will be rewritten to '/' before being directed to the target virtual deployment.
39 40 41 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 39 def is_path_rewrite_enabled @is_path_rewrite_enabled end |
#path ⇒ String
Route to match
19 20 21 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 19 def path @path end |
#path_type ⇒ String
Match type for the route
23 24 25 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 23 def path_type @path_type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 42 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'type': :'type', 'ingress_gateway_host': :'ingressGatewayHost', 'destinations': :'destinations', 'path': :'path', 'path_type': :'pathType', 'is_grpc': :'isGrpc', 'is_host_rewrite_enabled': :'isHostRewriteEnabled', 'is_path_rewrite_enabled': :'isPathRewriteEnabled' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 58 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'type': :'String', 'ingress_gateway_host': :'OCI::ServiceMesh::Models::IngressGatewayHostRef', 'destinations': :'Array<OCI::ServiceMesh::Models::VirtualServiceTrafficRuleTarget>', 'path': :'String', 'path_type': :'String', 'is_grpc': :'BOOLEAN', 'is_host_rewrite_enabled': :'BOOLEAN', 'is_path_rewrite_enabled': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 152 def ==(other) return true if equal?(other) self.class == other.class && type == other.type && ingress_gateway_host == other.ingress_gateway_host && destinations == other.destinations && path == other.path && path_type == other.path_type && is_grpc == other.is_grpc && is_host_rewrite_enabled == other.is_host_rewrite_enabled && is_path_rewrite_enabled == other.is_path_rewrite_enabled end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 189 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
169 170 171 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 169 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 178 def hash [type, ingress_gateway_host, destinations, path, path_type, is_grpc, is_host_rewrite_enabled, is_path_rewrite_enabled].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/oci/service_mesh/models/http_ingress_gateway_traffic_route_rule.rb', line 216 def to_s to_hash.to_s end |