Class: OCI::ServiceMesh::Models::IngressGateway
- Inherits:
-
Object
- Object
- OCI::ServiceMesh::Models::IngressGateway
- Defined in:
- lib/oci/service_mesh/models/ingress_gateway.rb
Overview
An ingress gateway allows resources that are outside of a mesh to communicate to resources that are inside the mesh. It sits on the edge of a service mesh receiving incoming HTTP/TCP connections to the mesh.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
- #access_logging ⇒ OCI::ServiceMesh::Models::AccessLoggingConfiguration
-
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#description ⇒ String
Description of the resource.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#hosts ⇒ Array<OCI::ServiceMesh::Models::IngressGatewayHost>
**[Required]** Array of hostnames and their listener configuration that this gateway will bind to.
-
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
-
#lifecycle_details ⇒ String
A message describing the current state in more detail.
-
#lifecycle_state ⇒ String
**[Required]** The current state of the Resource.
-
#mesh_id ⇒ String
**[Required]** The OCID of the service mesh in which this ingress gateway is created.
- #mtls ⇒ OCI::ServiceMesh::Models::IngressGatewayMutualTransportLayerSecurity
-
#name ⇒ String
**[Required]** A user-friendly name.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
**[Required]** The time when this resource was created in an RFC3339 formatted datetime string.
-
#time_updated ⇒ DateTime
**[Required]** The time when this resource was updated in an RFC3339 formatted datetime string.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IngressGateway
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IngressGateway
Initializes the object
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 161 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.mesh_id = attributes[:'meshId'] if attributes[:'meshId'] raise 'You cannot provide both :meshId and :mesh_id' if attributes.key?(:'meshId') && attributes.key?(:'mesh_id') self.mesh_id = attributes[:'mesh_id'] if attributes[:'mesh_id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.hosts = attributes[:'hosts'] if attributes[:'hosts'] self.mtls = attributes[:'mtls'] if attributes[:'mtls'] self.access_logging = attributes[:'accessLogging'] if attributes[:'accessLogging'] raise 'You cannot provide both :accessLogging and :access_logging' if attributes.key?(:'accessLogging') && attributes.key?(:'access_logging') self.access_logging = attributes[:'access_logging'] if attributes[:'access_logging'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails'] raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details') self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#access_logging ⇒ OCI::ServiceMesh::Models::AccessLoggingConfiguration
66 67 68 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 66 def access_logging @access_logging end |
#compartment_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
48 49 50 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 48 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
86 87 88 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 86 def @defined_tags end |
#description ⇒ String
Description of the resource. It can be changed after creation. Avoid entering confidential information.
Example: `This is my new resource`
39 40 41 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 39 def description @description end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
80 81 82 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 80 def @freeform_tags end |
#hosts ⇒ Array<OCI::ServiceMesh::Models::IngressGatewayHost>
**[Required]** Array of hostnames and their listener configuration that this gateway will bind to.
60 61 62 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 60 def hosts @hosts end |
#id ⇒ String
**[Required]** Unique identifier that is immutable on creation.
23 24 25 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 23 def id @id end |
#lifecycle_details ⇒ String
A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in a Failed state.
74 75 76 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 74 def lifecycle_details @lifecycle_details end |
#lifecycle_state ⇒ String
**[Required]** The current state of the Resource.
70 71 72 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 70 def lifecycle_state @lifecycle_state end |
#mesh_id ⇒ String
**[Required]** The OCID of the service mesh in which this ingress gateway is created.
43 44 45 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 43 def mesh_id @mesh_id end |
#mtls ⇒ OCI::ServiceMesh::Models::IngressGatewayMutualTransportLayerSecurity
63 64 65 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 63 def mtls @mtls end |
#name ⇒ String
**[Required]** A user-friendly name. The name has to be unique within the same service mesh and cannot be changed after creation. Avoid entering confidential information.
Example: `My unique resource name`
31 32 33 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 31 def name @name end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
92 93 94 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 92 def @system_tags end |
#time_created ⇒ DateTime
**[Required]** The time when this resource was created in an RFC3339 formatted datetime string.
52 53 54 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 52 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The time when this resource was updated in an RFC3339 formatted datetime string.
56 57 58 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 56 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 95 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'name': :'name', 'description': :'description', 'mesh_id': :'meshId', 'compartment_id': :'compartmentId', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'hosts': :'hosts', 'mtls': :'mtls', 'access_logging': :'accessLogging', 'lifecycle_state': :'lifecycleState', 'lifecycle_details': :'lifecycleDetails', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 118 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'name': :'String', 'description': :'String', 'mesh_id': :'String', 'compartment_id': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'hosts': :'Array<OCI::ServiceMesh::Models::IngressGatewayHost>', 'mtls': :'OCI::ServiceMesh::Models::IngressGatewayMutualTransportLayerSecurity', 'access_logging': :'OCI::ServiceMesh::Models::AccessLoggingConfiguration', 'lifecycle_state': :'String', 'lifecycle_details': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 258 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && mesh_id == other.mesh_id && compartment_id == other.compartment_id && time_created == other.time_created && time_updated == other.time_updated && hosts == other.hosts && mtls == other.mtls && access_logging == other.access_logging && lifecycle_state == other.lifecycle_state && lifecycle_details == other.lifecycle_details && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 302 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
282 283 284 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 282 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
291 292 293 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 291 def hash [id, name, description, mesh_id, compartment_id, time_created, time_updated, hosts, mtls, access_logging, lifecycle_state, lifecycle_details, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 344 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
329 330 331 |
# File 'lib/oci/service_mesh/models/ingress_gateway.rb', line 329 def to_s to_hash.to_s end |