Class: OCI::StackMonitoring::Models::DiscoveryJobSummary
- Inherits:
-
Object
- Object
- OCI::StackMonitoring::Models::DiscoveryJobSummary
- Defined in:
- lib/oci/stack_monitoring/models/discovery_job_summary.rb
Overview
The Summary of DiscoveryJob details.
Constant Summary collapse
- RESOURCE_TYPE_ENUM =
[ RESOURCE_TYPE_WEBLOGIC_DOMAIN = 'WEBLOGIC_DOMAIN'.freeze, RESOURCE_TYPE_EBS_INSTANCE = 'EBS_INSTANCE'.freeze, RESOURCE_TYPE_ORACLE_DATABASE = 'ORACLE_DATABASE'.freeze, RESOURCE_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- DISCOVERY_TYPE_ENUM =
[ DISCOVERY_TYPE_ADD = 'ADD'.freeze, DISCOVERY_TYPE_ADD_WITH_RETRY = 'ADD_WITH_RETRY'.freeze, DISCOVERY_TYPE_REFRESH = 'REFRESH'.freeze, DISCOVERY_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_SUCCESS = 'SUCCESS'.freeze, STATUS_FAILURE = 'FAILURE'.freeze, STATUS_INPROGRESS = 'INPROGRESS'.freeze, STATUS_INACTIVE = 'INACTIVE'.freeze, STATUS_CREATED = 'CREATED'.freeze, STATUS_DELETED = 'DELETED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
The OCID of the Compartment.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#discovery_type ⇒ String
Add option submits new discovery Job.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
**[Required]** The OCID of Discovery job.
-
#lifecycle_state ⇒ String
The current state of the DiscoveryJob Resource.
-
#resource_name ⇒ String
The name of resource type.
-
#resource_type ⇒ String
Resource Type.
-
#status ⇒ String
Specifies the status of the discovery job.
-
#status_message ⇒ String
The short summary of the status of the discovery job.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#tenant_id ⇒ String
The OCID of Tenant.
-
#time_updated ⇒ DateTime
The time the discovery Job was updated.
-
#user_id ⇒ String
The OCID of user in which the job is submitted.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DiscoveryJobSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ DiscoveryJobSummary
Initializes the object
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 172 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType'] raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type'] self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName'] raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.discovery_type = attributes[:'discoveryType'] if attributes[:'discoveryType'] self.discovery_type = "ADD" if discovery_type.nil? && !attributes.key?(:'discoveryType') # rubocop:disable Style/StringLiterals raise 'You cannot provide both :discoveryType and :discovery_type' if attributes.key?(:'discoveryType') && attributes.key?(:'discovery_type') self.discovery_type = attributes[:'discovery_type'] if attributes[:'discovery_type'] self.discovery_type = "ADD" if discovery_type.nil? && !attributes.key?(:'discoveryType') && !attributes.key?(:'discovery_type') # rubocop:disable Style/StringLiterals self.status = attributes[:'status'] if attributes[:'status'] self. = attributes[:'statusMessage'] if attributes[:'statusMessage'] raise 'You cannot provide both :statusMessage and :status_message' if attributes.key?(:'statusMessage') && attributes.key?(:'status_message') self. = attributes[:'status_message'] if attributes[:'status_message'] self.tenant_id = attributes[:'tenantId'] if attributes[:'tenantId'] raise 'You cannot provide both :tenantId and :tenant_id' if attributes.key?(:'tenantId') && attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] if attributes[:'tenant_id'] self.user_id = attributes[:'userId'] if attributes[:'userId'] raise 'You cannot provide both :userId and :user_id' if attributes.key?(:'userId') && attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] if attributes[:'user_id'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
The OCID of the Compartment
59 60 61 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 59 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
100 101 102 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 100 def @defined_tags end |
#discovery_type ⇒ String
Add option submits new discovery Job. Add with retry option to re-submit failed discovery job. Refresh option refreshes the existing discovered resources.
64 65 66 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 64 def discovery_type @discovery_type end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
94 95 96 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 94 def @freeform_tags end |
#id ⇒ String
**[Required]** The OCID of Discovery job
47 48 49 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 47 def id @id end |
#lifecycle_state ⇒ String
The current state of the DiscoveryJob Resource.
88 89 90 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 88 def lifecycle_state @lifecycle_state end |
#resource_name ⇒ String
The name of resource type
55 56 57 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 55 def resource_name @resource_name end |
#resource_type ⇒ String
Resource Type
51 52 53 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 51 def resource_type @resource_type end |
#status ⇒ String
Specifies the status of the discovery job
68 69 70 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 68 def status @status end |
#status_message ⇒ String
The short summary of the status of the discovery job
72 73 74 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 72 def @status_message end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"free-tier-retained": "true"}`
106 107 108 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 106 def @system_tags end |
#tenant_id ⇒ String
The OCID of Tenant
76 77 78 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 76 def tenant_id @tenant_id end |
#time_updated ⇒ DateTime
The time the discovery Job was updated.
84 85 86 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 84 def time_updated @time_updated end |
#user_id ⇒ String
The OCID of user in which the job is submitted
80 81 82 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 80 def user_id @user_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 109 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'resource_type': :'resourceType', 'resource_name': :'resourceName', 'compartment_id': :'compartmentId', 'discovery_type': :'discoveryType', 'status': :'status', 'status_message': :'statusMessage', 'tenant_id': :'tenantId', 'user_id': :'userId', 'time_updated': :'timeUpdated', 'lifecycle_state': :'lifecycleState', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 131 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'resource_type': :'String', 'resource_name': :'String', 'compartment_id': :'String', 'discovery_type': :'String', 'status': :'String', 'status_message': :'String', 'tenant_id': :'String', 'user_id': :'String', 'time_updated': :'DateTime', 'lifecycle_state': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 316 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && resource_type == other.resource_type && resource_name == other.resource_name && compartment_id == other.compartment_id && discovery_type == other.discovery_type && status == other.status && == other. && tenant_id == other.tenant_id && user_id == other.user_id && time_updated == other.time_updated && lifecycle_state == other.lifecycle_state && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 359 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
339 340 341 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 339 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
348 349 350 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 348 def hash [id, resource_type, resource_name, compartment_id, discovery_type, status, , tenant_id, user_id, time_updated, lifecycle_state, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
392 393 394 395 396 397 398 399 400 401 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 392 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
386 387 388 |
# File 'lib/oci/stack_monitoring/models/discovery_job_summary.rb', line 386 def to_s to_hash.to_s end |