Class: OCI::TenantManagerControlPlane::Models::OrganizationTenancySummary
- Inherits:
-
Object
- Object
- OCI::TenantManagerControlPlane::Models::OrganizationTenancySummary
- Defined in:
- lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb
Overview
An organization tenancy summary entity.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_DELETING = 'DELETING'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- ROLE_ENUM =
[ ROLE_PARENT = 'PARENT'.freeze, ROLE_CHILD = 'CHILD'.freeze, ROLE_NONE = 'NONE'.freeze, ROLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#is_approved_for_transfer ⇒ BOOLEAN
Flag to indicate the tenancy is approved for transfer to another organization.
-
#lifecycle_state ⇒ String
Lifecycle state of the OrganizationTenancy.
-
#name ⇒ String
Name of the tenancy.
-
#role ⇒ String
Role of the OrganizationTenancy.
-
#tenancy_id ⇒ String
[Required] OCID of the tenancy.
-
#time_joined ⇒ DateTime
Date-time when this tenancy joined the organization.
-
#time_left ⇒ DateTime
Date-time when this tenancy left the organization.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrganizationTenancySummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ OrganizationTenancySummary
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 99 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId'] raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id') self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id'] self.name = attributes[:'name'] if attributes[:'name'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.role = attributes[:'role'] if attributes[:'role'] self.time_joined = attributes[:'timeJoined'] if attributes[:'timeJoined'] raise 'You cannot provide both :timeJoined and :time_joined' if attributes.key?(:'timeJoined') && attributes.key?(:'time_joined') self.time_joined = attributes[:'time_joined'] if attributes[:'time_joined'] self.time_left = attributes[:'timeLeft'] if attributes[:'timeLeft'] raise 'You cannot provide both :timeLeft and :time_left' if attributes.key?(:'timeLeft') && attributes.key?(:'time_left') self.time_left = attributes[:'time_left'] if attributes[:'time_left'] self.is_approved_for_transfer = attributes[:'isApprovedForTransfer'] unless attributes[:'isApprovedForTransfer'].nil? raise 'You cannot provide both :isApprovedForTransfer and :is_approved_for_transfer' if attributes.key?(:'isApprovedForTransfer') && attributes.key?(:'is_approved_for_transfer') self.is_approved_for_transfer = attributes[:'is_approved_for_transfer'] unless attributes[:'is_approved_for_transfer'].nil? end |
Instance Attribute Details
#is_approved_for_transfer ⇒ BOOLEAN
Flag to indicate the tenancy is approved for transfer to another organization.
54 55 56 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 54 def is_approved_for_transfer @is_approved_for_transfer end |
#lifecycle_state ⇒ String
Lifecycle state of the OrganizationTenancy.
38 39 40 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 38 def lifecycle_state @lifecycle_state end |
#name ⇒ String
Name of the tenancy.
34 35 36 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 34 def name @name end |
#role ⇒ String
Role of the OrganizationTenancy.
42 43 44 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 42 def role @role end |
#tenancy_id ⇒ String
[Required] OCID of the tenancy.
30 31 32 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 30 def tenancy_id @tenancy_id end |
#time_joined ⇒ DateTime
Date-time when this tenancy joined the organization.
46 47 48 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 46 def time_joined @time_joined end |
#time_left ⇒ DateTime
Date-time when this tenancy left the organization.
50 51 52 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 50 def time_left @time_left end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 57 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'tenancy_id': :'tenancyId', 'name': :'name', 'lifecycle_state': :'lifecycleState', 'role': :'role', 'time_joined': :'timeJoined', 'time_left': :'timeLeft', 'is_approved_for_transfer': :'isApprovedForTransfer' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 72 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'tenancy_id': :'String', 'name': :'String', 'lifecycle_state': :'String', 'role': :'String', 'time_joined': :'DateTime', 'time_left': :'DateTime', 'is_approved_for_transfer': :'BOOLEAN' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 173 def ==(other) return true if equal?(other) self.class == other.class && tenancy_id == other.tenancy_id && name == other.name && lifecycle_state == other.lifecycle_state && role == other.role && time_joined == other.time_joined && time_left == other.time_left && is_approved_for_transfer == other.is_approved_for_transfer end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 209 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
189 190 191 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 189 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 198 def hash [tenancy_id, name, lifecycle_state, role, time_joined, time_left, is_approved_for_transfer].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
242 243 244 245 246 247 248 249 250 251 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 242 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
236 237 238 |
# File 'lib/oci/tenant_manager_control_plane/models/organization_tenancy_summary.rb', line 236 def to_s to_hash.to_s end |