Class: OCI::TenantManagerControlPlane::Models::SenderInvitationSummary
- Inherits:
-
Object
- Object
- OCI::TenantManagerControlPlane::Models::SenderInvitationSummary
- Defined in:
- lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb
Overview
The summary of the invitation model that the sender owns.
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_CREATING = 'CREATING'.freeze, LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze, LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze, LIFECYCLE_STATE_FAILED = 'FAILED'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATUS_ENUM =
[ STATUS_PENDING = 'PENDING'.freeze, STATUS_CANCELED = 'CANCELED'.freeze, STATUS_ACCEPTED = 'ACCEPTED'.freeze, STATUS_EXPIRED = 'EXPIRED'.freeze, STATUS_FAILED = 'FAILED'.freeze, STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#compartment_id ⇒ String
[Required] OCID of the sender tenancy.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
[Required] A user-created name to describe the invitation.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
[Required] OCID of the sender invitation.
-
#lifecycle_state ⇒ String
[Required] Lifecycle state of the sender invitation.
-
#recipient_email_address ⇒ String
Email address of the recipient.
-
#recipient_invitation_id ⇒ String
OCID of the corresponding recipient invitation.
-
#recipient_tenancy_id ⇒ String
[Required] OCID of the recipient tenancy.
-
#status ⇒ String
[Required] Status of the sender invitation.
-
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys.
-
#time_created ⇒ DateTime
[Required] Date-time when this sender invitation was created.
-
#time_updated ⇒ DateTime
Date-time when this sender invitation was last updated.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SenderInvitationSummary
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SenderInvitationSummary
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 149 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.recipient_invitation_id = attributes[:'recipientInvitationId'] if attributes[:'recipientInvitationId'] raise 'You cannot provide both :recipientInvitationId and :recipient_invitation_id' if attributes.key?(:'recipientInvitationId') && attributes.key?(:'recipient_invitation_id') self.recipient_invitation_id = attributes[:'recipient_invitation_id'] if attributes[:'recipient_invitation_id'] self.recipient_tenancy_id = attributes[:'recipientTenancyId'] if attributes[:'recipientTenancyId'] raise 'You cannot provide both :recipientTenancyId and :recipient_tenancy_id' if attributes.key?(:'recipientTenancyId') && attributes.key?(:'recipient_tenancy_id') self.recipient_tenancy_id = attributes[:'recipient_tenancy_id'] if attributes[:'recipient_tenancy_id'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.status = attributes[:'status'] if attributes[:'status'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] self.recipient_email_address = attributes[:'recipientEmailAddress'] if attributes[:'recipientEmailAddress'] raise 'You cannot provide both :recipientEmailAddress and :recipient_email_address' if attributes.key?(:'recipientEmailAddress') && attributes.key?(:'recipient_email_address') self.recipient_email_address = attributes[:'recipient_email_address'] if attributes[:'recipient_email_address'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'systemTags'] if attributes[:'systemTags'] raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags') self. = attributes[:'system_tags'] if attributes[:'system_tags'] end |
Instance Attribute Details
#compartment_id ⇒ String
[Required] OCID of the sender tenancy.
36 37 38 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 36 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: ‘{"bar-key": "value"}`
80 81 82 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 80 def end |
#display_name ⇒ String
[Required] A user-created name to describe the invitation. Avoid entering confidential information.
40 41 42 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 40 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: ‘"value"`
74 75 76 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 74 def end |
#id ⇒ String
[Required] OCID of the sender invitation.
32 33 34 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 32 def id @id end |
#lifecycle_state ⇒ String
[Required] Lifecycle state of the sender invitation.
52 53 54 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 52 def lifecycle_state @lifecycle_state end |
#recipient_email_address ⇒ String
Email address of the recipient.
68 69 70 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 68 def recipient_email_address @recipient_email_address end |
#recipient_invitation_id ⇒ String
OCID of the corresponding recipient invitation.
44 45 46 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 44 def recipient_invitation_id @recipient_invitation_id end |
#recipient_tenancy_id ⇒ String
[Required] OCID of the recipient tenancy.
48 49 50 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 48 def recipient_tenancy_id @recipient_tenancy_id end |
#status ⇒ String
[Required] Status of the sender invitation.
56 57 58 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 56 def status @status end |
#system_tags ⇒ Hash<String, Hash<String, Object>>
Usage of system tag keys. These predefined keys are scoped to namespaces. Example: ‘{"free-tier-retained": "true"}`
86 87 88 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 86 def end |
#time_created ⇒ DateTime
[Required] Date-time when this sender invitation was created.
60 61 62 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 60 def time_created @time_created end |
#time_updated ⇒ DateTime
Date-time when this sender invitation was last updated.
64 65 66 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 64 def time_updated @time_updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 89 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'compartment_id': :'compartmentId', 'display_name': :'displayName', 'recipient_invitation_id': :'recipientInvitationId', 'recipient_tenancy_id': :'recipientTenancyId', 'lifecycle_state': :'lifecycleState', 'status': :'status', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated', 'recipient_email_address': :'recipientEmailAddress', 'freeform_tags': :'freeformTags', 'defined_tags': :'definedTags', 'system_tags': :'systemTags' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 110 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'compartment_id': :'String', 'display_name': :'String', 'recipient_invitation_id': :'String', 'recipient_tenancy_id': :'String', 'lifecycle_state': :'String', 'status': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime', 'recipient_email_address': :'String', 'freeform_tags': :'Hash<String, String>', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'system_tags': :'Hash<String, Hash<String, Object>>' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 259 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && compartment_id == other.compartment_id && display_name == other.display_name && recipient_invitation_id == other.recipient_invitation_id && recipient_tenancy_id == other.recipient_tenancy_id && lifecycle_state == other.lifecycle_state && status == other.status && time_created == other.time_created && time_updated == other.time_updated && recipient_email_address == other.recipient_email_address && == other. && == other. && == other. end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 301 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
281 282 283 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 281 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
290 291 292 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 290 def hash [id, compartment_id, display_name, recipient_invitation_id, recipient_tenancy_id, lifecycle_state, status, time_created, time_updated, recipient_email_address, , , ].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
334 335 336 337 338 339 340 341 342 343 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 334 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
328 329 330 |
# File 'lib/oci/tenant_manager_control_plane/models/sender_invitation_summary.rb', line 328 def to_s to_hash.to_s end |