Class: ThreatIntelligence::Models::Indicator
- Inherits:
-
Object
- Object
- ThreatIntelligence::Models::Indicator
- Defined in:
- lib/oci/threat_intelligence/models/indicator.rb
Overview
A data signature observed on a network or host that indicates a potential security threat. Indicators can be plain text or computed (hashed) values.
Constant Summary collapse
- TYPE_ENUM =
[ TYPE_DOMAIN_NAME = 'DOMAIN_NAME'.freeze, TYPE_FILE_NAME = 'FILE_NAME'.freeze, TYPE_MD5_HASH = 'MD5_HASH'.freeze, TYPE_SHA1_HASH = 'SHA1_HASH'.freeze, TYPE_SHA256_HASH = 'SHA256_HASH'.freeze, TYPE_IP_ADDRESS = 'IP_ADDRESS'.freeze, TYPE_URL = 'URL'.freeze, TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze, LIFECYCLE_STATE_DELETED = 'DELETED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#attributes ⇒ Array<OCI::ThreatIntelligence::Models::IndicatorAttribute>
**[Required]** A map of attribute name (string) to IndicatorAttribute (values and supporting data).
-
#compartment_id ⇒ String
Compartment Identifier.
-
#confidence ⇒ Integer
Confidence is an integer from 0 to 100 that provides a measure of our certainty in the maliciousness of the indicator.
-
#id ⇒ String
**[Required]** The OCID of the indicator.
-
#lifecycle_state ⇒ String
The state of the indicator.
-
#relationships ⇒ Array<OCI::ThreatIntelligence::Models::IndicatorRelationship>
**[Required]** A map of relationship name (string) to IndicatorRelationship (related entities and supporting data).
-
#threat_types ⇒ Array<OCI::ThreatIntelligence::Models::ThreatType>
**[Required]** Characteristics of the threat indicator based on previous observations or behavior.
-
#time_created ⇒ DateTime
**[Required]** The time the data was first seen for this indicator.
-
#time_updated ⇒ DateTime
**[Required]** The last time this indicator was updated.
-
#type ⇒ String
**[Required]** Type of indicator.
-
#value ⇒ String
**[Required]** The value for this indicator.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Indicator
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Indicator
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 133 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.id = attributes[:'id'] if attributes[:'id'] self.type = attributes[:'type'] if attributes[:'type'] self.value = attributes[:'value'] if attributes[:'value'] self.confidence = attributes[:'confidence'] if attributes[:'confidence'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self.threat_types = attributes[:'threatTypes'] if attributes[:'threatTypes'] raise 'You cannot provide both :threatTypes and :threat_types' if attributes.key?(:'threatTypes') && attributes.key?(:'threat_types') self.threat_types = attributes[:'threat_types'] if attributes[:'threat_types'] self.attributes = attributes[:'attributes'] if attributes[:'attributes'] self.relationships = attributes[:'relationships'] if attributes[:'relationships'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#attributes ⇒ Array<OCI::ThreatIntelligence::Models::IndicatorAttribute>
**[Required]** A map of attribute name (string) to IndicatorAttribute (values and supporting data). This provides generic storage for additional data about an indicator.
58 59 60 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 58 def attributes @attributes end |
#compartment_id ⇒ String
Compartment Identifier
48 49 50 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 48 def compartment_id @compartment_id end |
#confidence ⇒ Integer
Confidence is an integer from 0 to 100 that provides a measure of our certainty in the maliciousness of the indicator. This confidence value is aggregated from the confidence in the threat types, attributes, and relationships to create an overall value for the indicator.
44 45 46 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 44 def confidence @confidence end |
#id ⇒ String
**[Required]** The OCID of the indicator.
30 31 32 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 30 def id @id end |
#lifecycle_state ⇒ String
The state of the indicator. It will always be ACTIVE. This field is added for consistency.
68 69 70 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 68 def lifecycle_state @lifecycle_state end |
#relationships ⇒ Array<OCI::ThreatIntelligence::Models::IndicatorRelationship>
**[Required]** A map of relationship name (string) to IndicatorRelationship (related entities and supporting data). This provides generic storage for relationships between indicators or other entities.
64 65 66 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 64 def relationships @relationships end |
#threat_types ⇒ Array<OCI::ThreatIntelligence::Models::ThreatType>
**[Required]** Characteristics of the threat indicator based on previous observations or behavior. May include related tactics, techniques, and procedures.
52 53 54 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 52 def threat_types @threat_types end |
#time_created ⇒ DateTime
**[Required]** The time the data was first seen for this indicator. An RFC3339 formatted datetime string
72 73 74 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 72 def time_created @time_created end |
#time_updated ⇒ DateTime
**[Required]** The last time this indicator was updated. It starts with the same value as timeCreated and is never empty. An RFC3339 formatted datetime string
76 77 78 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 76 def time_updated @time_updated end |
#type ⇒ String
**[Required]** Type of indicator
34 35 36 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 34 def type @type end |
#value ⇒ String
**[Required]** The value for this indicator. Format is dependent upon `type`, e.g. DOMAIN_NAME "evil.example.com", MD5_HASH "44d88612fea8a8f36de82e1278abb02f", IP_ADDRESS "2001:db8::1".
40 41 42 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 40 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 79 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'id': :'id', 'type': :'type', 'value': :'value', 'confidence': :'confidence', 'compartment_id': :'compartmentId', 'threat_types': :'threatTypes', 'attributes': :'attributes', 'relationships': :'relationships', 'lifecycle_state': :'lifecycleState', 'time_created': :'timeCreated', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 98 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'id': :'String', 'type': :'String', 'value': :'String', 'confidence': :'Integer', 'compartment_id': :'String', 'threat_types': :'Array<OCI::ThreatIntelligence::Models::ThreatType>', 'attributes': :'Array<OCI::ThreatIntelligence::Models::IndicatorAttribute>', 'relationships': :'Array<OCI::ThreatIntelligence::Models::IndicatorRelationship>', 'lifecycle_state': :'String', 'time_created': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 215 def ==(other) return true if equal?(other) self.class == other.class && id == other.id && type == other.type && value == other.value && confidence == other.confidence && compartment_id == other.compartment_id && threat_types == other.threat_types && attributes == other.attributes && relationships == other.relationships && lifecycle_state == other.lifecycle_state && time_created == other.time_created && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 255 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
235 236 237 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 235 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
244 245 246 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 244 def hash [id, type, value, confidence, compartment_id, threat_types, attributes, relationships, lifecycle_state, time_created, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
282 283 284 |
# File 'lib/oci/threat_intelligence/models/indicator.rb', line 282 def to_s to_hash.to_s end |