Class: OCI::Usage::RewardsClient
- Inherits:
-
Object
- Object
- OCI::Usage::RewardsClient
- Defined in:
- lib/oci/usage/rewards_client.rb
Overview
A description of the UsageApi API.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#create_redeemable_user(create_redeemable_user_details, tenancy_id, subscription_id, opts = {}) ⇒ Response
Add list of redeemable user email ids for a subscription Id.
-
#delete_redeemable_user(email_id, tenancy_id, subscription_id, opts = {}) ⇒ Response
Delete list of redeemable user email ids for a subscription Id.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ RewardsClient
constructor
Creates a new RewardsClient.
-
#list_products(tenancy_id, subscription_id, usage_period_key, opts = {}) ⇒ Response
This API provides usage period specific product and its usage details.
-
#list_redeemable_users(tenancy_id, subscription_id, opts = {}) ⇒ Response
Provides emailids of redeemable users for the given subscriptionId.
-
#list_rewards(tenancy_id, subscription_id, opts = {}) ⇒ Response
This API returns list of rewards for a subscription Id.
-
#logger ⇒ Logger
The logger for this client.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ RewardsClient
Creates a new RewardsClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/usage/rewards_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20190111' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "RewardsClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/usage/rewards_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/usage/rewards_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/usage/rewards_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/usage/rewards_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#create_redeemable_user(create_redeemable_user_details, tenancy_id, subscription_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usage/create_redeemable_user.rb.html) to see an example of how to use create_redeemable_user API.
Add list of redeemable user email ids for a subscription Id
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/oci/usage/rewards_client.rb', line 126 def create_redeemable_user(create_redeemable_user_details, tenancy_id, subscription_id, opts = {}) logger.debug 'Calling operation RewardsClient#create_redeemable_user.' if logger raise "Missing the required parameter 'create_redeemable_user_details' when calling create_redeemable_user." if create_redeemable_user_details.nil? raise "Missing the required parameter 'tenancy_id' when calling create_redeemable_user." if tenancy_id.nil? raise "Missing the required parameter 'subscription_id' when calling create_redeemable_user." if subscription_id.nil? raise "Parameter value for 'subscription_id' must not be blank" if OCI::Internal::Util.blank_string?(subscription_id) path = '/subscriptions/{subscriptionId}/redeemableUsers'.sub('{subscriptionId}', subscription_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:tenancyId] = tenancy_id query_params[:userId] = opts[:user_id] if opts[:user_id] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_redeemable_user_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'RewardsClient#create_redeemable_user') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Usage::Models::RedeemableUserCollection' ) end # rubocop:enable Metrics/BlockLength end |
#delete_redeemable_user(email_id, tenancy_id, subscription_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usage/delete_redeemable_user.rb.html) to see an example of how to use delete_redeemable_user API.
Delete list of redeemable user email ids for a subscription Id
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/oci/usage/rewards_client.rb', line 196 def delete_redeemable_user(email_id, tenancy_id, subscription_id, opts = {}) logger.debug 'Calling operation RewardsClient#delete_redeemable_user.' if logger raise "Missing the required parameter 'email_id' when calling delete_redeemable_user." if email_id.nil? raise "Missing the required parameter 'tenancy_id' when calling delete_redeemable_user." if tenancy_id.nil? raise "Missing the required parameter 'subscription_id' when calling delete_redeemable_user." if subscription_id.nil? raise "Parameter value for 'subscription_id' must not be blank" if OCI::Internal::Util.blank_string?(subscription_id) path = '/subscriptions/{subscriptionId}/redeemableUsers'.sub('{subscriptionId}', subscription_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:emailId] = email_id query_params[:tenancyId] = tenancy_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'RewardsClient#delete_redeemable_user') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#list_products(tenancy_id, subscription_id, usage_period_key, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usage/list_products.rb.html) to see an example of how to use list_products API.
This API provides usage period specific product and its usage details.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/oci/usage/rewards_client.rb', line 265 def list_products(tenancy_id, subscription_id, usage_period_key, opts = {}) logger.debug 'Calling operation RewardsClient#list_products.' if logger raise "Missing the required parameter 'tenancy_id' when calling list_products." if tenancy_id.nil? raise "Missing the required parameter 'subscription_id' when calling list_products." if subscription_id.nil? raise "Missing the required parameter 'usage_period_key' when calling list_products." if usage_period_key.nil? if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[TIMECREATED TIMESTART].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of TIMECREATED, TIMESTART.' end if opts[:producttype] && !%w[ALL ELIGIBLE INELIGIBLE].include?(opts[:producttype]) raise 'Invalid value for "producttype", must be one of ALL, ELIGIBLE, INELIGIBLE.' end raise "Parameter value for 'subscription_id' must not be blank" if OCI::Internal::Util.blank_string?(subscription_id) path = '/subscriptions/{subscriptionId}/products'.sub('{subscriptionId}', subscription_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:tenancyId] = tenancy_id query_params[:usagePeriodKey] = usage_period_key query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:producttype] = opts[:producttype] if opts[:producttype] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'RewardsClient#list_products') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Usage::Models::ProductCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_redeemable_users(tenancy_id, subscription_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usage/list_redeemable_users.rb.html) to see an example of how to use list_redeemable_users API.
Provides emailids of redeemable users for the given subscriptionId
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/oci/usage/rewards_client.rb', line 348 def list_redeemable_users(tenancy_id, subscription_id, opts = {}) logger.debug 'Calling operation RewardsClient#list_redeemable_users.' if logger raise "Missing the required parameter 'tenancy_id' when calling list_redeemable_users." if tenancy_id.nil? raise "Missing the required parameter 'subscription_id' when calling list_redeemable_users." if subscription_id.nil? if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end if opts[:sort_by] && !%w[TIMECREATED TIMESTART].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of TIMECREATED, TIMESTART.' end raise "Parameter value for 'subscription_id' must not be blank" if OCI::Internal::Util.blank_string?(subscription_id) path = '/subscriptions/{subscriptionId}/redeemableUsers'.sub('{subscriptionId}', subscription_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:tenancyId] = tenancy_id query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'RewardsClient#list_redeemable_users') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Usage::Models::RedeemableUserCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_rewards(tenancy_id, subscription_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usage/list_rewards.rb.html) to see an example of how to use list_rewards API.
This API returns list of rewards for a subscription Id
418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 |
# File 'lib/oci/usage/rewards_client.rb', line 418 def list_rewards(tenancy_id, subscription_id, opts = {}) logger.debug 'Calling operation RewardsClient#list_rewards.' if logger raise "Missing the required parameter 'tenancy_id' when calling list_rewards." if tenancy_id.nil? raise "Missing the required parameter 'subscription_id' when calling list_rewards." if subscription_id.nil? raise "Parameter value for 'subscription_id' must not be blank" if OCI::Internal::Util.blank_string?(subscription_id) path = '/subscriptions/{subscriptionId}/rewards'.sub('{subscriptionId}', subscription_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:tenancyId] = tenancy_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'RewardsClient#list_rewards') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::Usage::Models::RewardCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
92 93 94 |
# File 'lib/oci/usage/rewards_client.rb', line 92 def logger @api_client.config.logger end |