Class: OCI::UsageApi::UsageapiClient
- Inherits:
-
Object
- Object
- OCI::UsageApi::UsageapiClient
- Defined in:
- lib/oci/usage_api/usageapi_client.rb
Overview
Use the Usage API to view your Oracle Cloud usage and costs. The API allows you to request data that meets the specified filter criteria, and to group that data by the dimension of your choosing. The Usage API is used by the Cost Analysis tool in the Console. Also see [Using the Usage API](/Content/Billing/Concepts/costanalysisoverview.htm#cost_analysis_using_the_api) for more information.
Instance Attribute Summary collapse
-
#api_client ⇒ OCI::ApiClient
readonly
Client used to make HTTP requests.
-
#endpoint ⇒ String
readonly
Fully qualified endpoint URL.
-
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
-
#retry_config ⇒ OCI::Retry::RetryConfig
readonly
The default retry configuration to apply to all operations in this service client.
Instance Method Summary collapse
-
#create_custom_table(create_custom_table_details, opts = {}) ⇒ Response
Returns the created custom table.
-
#create_query(create_query_details, opts = {}) ⇒ Response
Returns the created query.
-
#delete_custom_table(custom_table_id, opts = {}) ⇒ Response
Delete a saved custom table by the OCID.
-
#delete_query(query_id, opts = {}) ⇒ Response
Delete a saved query by the OCID.
-
#get_custom_table(custom_table_id, opts = {}) ⇒ Response
Returns the saved custom table.
-
#get_query(query_id, opts = {}) ⇒ Response
Returns the saved query.
-
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ UsageapiClient
constructor
Creates a new UsageapiClient.
-
#list_custom_tables(compartment_id, saved_report_id, opts = {}) ⇒ Response
Returns the saved custom table list.
-
#list_queries(compartment_id, opts = {}) ⇒ Response
Returns the saved query list.
-
#logger ⇒ Logger
The logger for this client.
-
#request_summarized_configurations(tenant_id, opts = {}) ⇒ Response
Returns the configurations list for the UI drop-down list.
-
#request_summarized_usages(request_summarized_usages_details, opts = {}) ⇒ Response
Returns usage for the given account.
-
#update_custom_table(update_custom_table_details, custom_table_id, opts = {}) ⇒ Response
Update a saved custom table by table id.
-
#update_query(update_query_details, query_id, opts = {}) ⇒ Response
Update a saved query by the OCID.
Constructor Details
#initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) ⇒ UsageapiClient
Creates a new UsageapiClient. Notes:
If a config is not specified, then the global OCI.config will be used.
This client is not thread-safe
Either a region or an endpoint must be specified. If an endpoint is specified, it will be used instead of the
region. A region may be specified in the config or via or the region parameter. If specified in both, then the
region parameter will be used.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 53 def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil) # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers) # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then # pass it to this constructor. # # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid # so try and load the config from the default file. config = OCI::Config.validate_and_build_config_with_signer(config, signer) signer = OCI::Signer.config_file_auth_builder(config) if signer.nil? @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings) @retry_config = retry_config if endpoint @endpoint = endpoint + '/20200107' else region ||= config.region region ||= signer.region if signer.respond_to?(:region) self.region = region end logger.info "UsageapiClient endpoint set to '#{@endpoint}'." if logger end |
Instance Attribute Details
#api_client ⇒ OCI::ApiClient (readonly)
Client used to make HTTP requests.
13 14 15 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 13 def api_client @api_client end |
#endpoint ⇒ String (readonly)
Fully qualified endpoint URL
17 18 19 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 17 def endpoint @endpoint end |
#region ⇒ String
The region, which will usually correspond to a value in Regions::REGION_ENUM.
27 28 29 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 27 def region @region end |
#retry_config ⇒ OCI::Retry::RetryConfig (readonly)
The default retry configuration to apply to all operations in this service client. This can be overridden on a per-operation basis. The default retry configuration value is nil, which means that an operation will not perform any retries
23 24 25 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 23 def retry_config @retry_config end |
Instance Method Details
#create_custom_table(create_custom_table_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/create_custom_table.rb.html) to see an example of how to use create_custom_table API.
Returns the created custom table.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 118 def create_custom_table(create_custom_table_details, opts = {}) logger.debug 'Calling operation UsageapiClient#create_custom_table.' if logger raise "Missing the required parameter 'create_custom_table_details' when calling create_custom_table." if create_custom_table_details.nil? path = '/customTables' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_custom_table_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#create_custom_table') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::UsageApi::Models::CustomTable' ) end # rubocop:enable Metrics/BlockLength end |
#create_query(create_query_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/create_query.rb.html) to see an example of how to use create_query API.
Returns the created query.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 182 def create_query(create_query_details, opts = {}) logger.debug 'Calling operation UsageapiClient#create_query.' if logger raise "Missing the required parameter 'create_query_details' when calling create_query." if create_query_details.nil? path = '/queries' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token] # rubocop:enable Style/NegatedIf header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token post_body = @api_client.object_to_http_body(create_query_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#create_query') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::UsageApi::Models::Query' ) end # rubocop:enable Metrics/BlockLength end |
#delete_custom_table(custom_table_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/delete_custom_table.rb.html) to see an example of how to use delete_custom_table API.
Delete a saved custom table by the OCID.
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 246 def delete_custom_table(custom_table_id, opts = {}) logger.debug 'Calling operation UsageapiClient#delete_custom_table.' if logger raise "Missing the required parameter 'custom_table_id' when calling delete_custom_table." if custom_table_id.nil? raise "Parameter value for 'custom_table_id' must not be blank" if OCI::Internal::Util.blank_string?(custom_table_id) path = '/customTables/{customTableId}'.sub('{customTableId}', custom_table_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#delete_custom_table') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#delete_query(query_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/delete_query.rb.html) to see an example of how to use delete_query API.
Delete a saved query by the OCID.
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 309 def delete_query(query_id, opts = {}) logger.debug 'Calling operation UsageapiClient#delete_query.' if logger raise "Missing the required parameter 'query_id' when calling delete_query." if query_id.nil? raise "Parameter value for 'query_id' must not be blank" if OCI::Internal::Util.blank_string?(query_id) path = '/queries/{queryId}'.sub('{queryId}', query_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#delete_query') do @api_client.call_api( :DELETE, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body ) end # rubocop:enable Metrics/BlockLength end |
#get_custom_table(custom_table_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/get_custom_table.rb.html) to see an example of how to use get_custom_table API.
Returns the saved custom table.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 366 def get_custom_table(custom_table_id, opts = {}) logger.debug 'Calling operation UsageapiClient#get_custom_table.' if logger raise "Missing the required parameter 'custom_table_id' when calling get_custom_table." if custom_table_id.nil? raise "Parameter value for 'custom_table_id' must not be blank" if OCI::Internal::Util.blank_string?(custom_table_id) path = '/customTables/{customTableId}'.sub('{customTableId}', custom_table_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#get_custom_table') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::UsageApi::Models::CustomTable' ) end # rubocop:enable Metrics/BlockLength end |
#get_query(query_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/get_query.rb.html) to see an example of how to use get_query API.
Returns the saved query.
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 423 def get_query(query_id, opts = {}) logger.debug 'Calling operation UsageapiClient#get_query.' if logger raise "Missing the required parameter 'query_id' when calling get_query." if query_id.nil? raise "Parameter value for 'query_id' must not be blank" if OCI::Internal::Util.blank_string?(query_id) path = '/queries/{queryId}'.sub('{queryId}', query_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#get_query') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::UsageApi::Models::Query' ) end # rubocop:enable Metrics/BlockLength end |
#list_custom_tables(compartment_id, saved_report_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/list_custom_tables.rb.html) to see an example of how to use list_custom_tables API.
Returns the saved custom table list.
Allowed values are: displayName
490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 490 def list_custom_tables(compartment_id, saved_report_id, opts = {}) logger.debug 'Calling operation UsageapiClient#list_custom_tables.' if logger raise "Missing the required parameter 'compartment_id' when calling list_custom_tables." if compartment_id.nil? raise "Missing the required parameter 'saved_report_id' when calling list_custom_tables." if saved_report_id.nil? if opts[:sort_by] && !%w[displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of displayName.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end path = '/customTables' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:savedReportId] = saved_report_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#list_custom_tables') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::UsageApi::Models::CustomTableCollection' ) end # rubocop:enable Metrics/BlockLength end |
#list_queries(compartment_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/list_queries.rb.html) to see an example of how to use list_queries API.
Returns the saved query list.
Allowed values are: displayName
570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 570 def list_queries(compartment_id, opts = {}) logger.debug 'Calling operation UsageapiClient#list_queries.' if logger raise "Missing the required parameter 'compartment_id' when calling list_queries." if compartment_id.nil? if opts[:sort_by] && !%w[displayName].include?(opts[:sort_by]) raise 'Invalid value for "sort_by", must be one of displayName.' end if opts[:sort_order] && !%w[ASC DESC].include?(opts[:sort_order]) raise 'Invalid value for "sort_order", must be one of ASC, DESC.' end path = '/queries' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:compartmentId] = compartment_id query_params[:limit] = opts[:limit] if opts[:limit] query_params[:page] = opts[:page] if opts[:page] query_params[:sortBy] = opts[:sort_by] if opts[:sort_by] query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#list_queries') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::UsageApi::Models::QueryCollection' ) end # rubocop:enable Metrics/BlockLength end |
#logger ⇒ Logger
Returns The logger for this client. May be nil.
92 93 94 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 92 def logger @api_client.config.logger end |
#request_summarized_configurations(tenant_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/request_summarized_configurations.rb.html) to see an example of how to use request_summarized_configurations API.
Returns the configurations list for the UI drop-down list.
639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 639 def request_summarized_configurations(tenant_id, opts = {}) logger.debug 'Calling operation UsageapiClient#request_summarized_configurations.' if logger raise "Missing the required parameter 'tenant_id' when calling request_summarized_configurations." if tenant_id.nil? path = '/configuration' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:tenantId] = tenant_id # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = nil # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#request_summarized_configurations') do @api_client.call_api( :GET, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::UsageApi::Models::ConfigurationAggregation' ) end # rubocop:enable Metrics/BlockLength end |
#request_summarized_usages(request_summarized_usages_details, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/request_summarized_usages.rb.html) to see an example of how to use request_summarized_usages API.
Returns usage for the given account.
701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 701 def request_summarized_usages(request_summarized_usages_details, opts = {}) logger.debug 'Calling operation UsageapiClient#request_summarized_usages.' if logger raise "Missing the required parameter 'request_summarized_usages_details' when calling request_summarized_usages." if request_summarized_usages_details.nil? path = '/usage' operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} query_params[:page] = opts[:page] if opts[:page] query_params[:limit] = opts[:limit] if opts[:limit] # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(request_summarized_usages_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#request_summarized_usages') do @api_client.call_api( :POST, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::UsageApi::Models::UsageAggregation' ) end # rubocop:enable Metrics/BlockLength end |
#update_custom_table(update_custom_table_details, custom_table_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/update_custom_table.rb.html) to see an example of how to use update_custom_table API.
Update a saved custom table by table id.
766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 766 def update_custom_table(update_custom_table_details, custom_table_id, opts = {}) logger.debug 'Calling operation UsageapiClient#update_custom_table.' if logger raise "Missing the required parameter 'update_custom_table_details' when calling update_custom_table." if update_custom_table_details.nil? raise "Missing the required parameter 'custom_table_id' when calling update_custom_table." if custom_table_id.nil? raise "Parameter value for 'custom_table_id' must not be blank" if OCI::Internal::Util.blank_string?(custom_table_id) path = '/customTables/{customTableId}'.sub('{customTableId}', custom_table_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_custom_table_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#update_custom_table') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::UsageApi::Models::CustomTable' ) end # rubocop:enable Metrics/BlockLength end |
#update_query(update_query_details, query_id, opts = {}) ⇒ Response
Click [here](docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/usageapi/update_query.rb.html) to see an example of how to use update_query API.
Update a saved query by the OCID.
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 |
# File 'lib/oci/usage_api/usageapi_client.rb', line 832 def update_query(update_query_details, query_id, opts = {}) logger.debug 'Calling operation UsageapiClient#update_query.' if logger raise "Missing the required parameter 'update_query_details' when calling update_query." if update_query_details.nil? raise "Missing the required parameter 'query_id' when calling update_query." if query_id.nil? raise "Parameter value for 'query_id' must not be blank" if OCI::Internal::Util.blank_string?(query_id) path = '/queries/{queryId}'.sub('{queryId}', query_id.to_s) operation_signing_strategy = :standard # rubocop:disable Style/NegatedIf # Query Params query_params = {} # Header Params header_params = {} header_params[:accept] = 'application/json' header_params[:'content-type'] = 'application/json' header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id] header_params[:'if-match'] = opts[:if_match] if opts[:if_match] # rubocop:enable Style/NegatedIf post_body = @api_client.object_to_http_body(update_query_details) # rubocop:disable Metrics/BlockLength OCI::Retry.(applicable_retry_config(opts), call_name: 'UsageapiClient#update_query') do @api_client.call_api( :PUT, path, endpoint, header_params: header_params, query_params: query_params, operation_signing_strategy: operation_signing_strategy, body: post_body, return_type: 'OCI::UsageApi::Models::Query' ) end # rubocop:enable Metrics/BlockLength end |