Class: OCI::VnMonitoring::Models::CreateDrgAttachmentDetails
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::CreateDrgAttachmentDetails
- Defined in:
- lib/oci/vn_monitoring/models/create_drg_attachment_details.rb
Overview
CreateDrgAttachmentDetails model.
Instance Attribute Summary collapse
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#drg_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG.
-
#drg_route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table that is assigned to this attachment.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
- #network_details ⇒ OCI::VnMonitoring::Models::DrgAttachmentNetworkCreateDetails
-
#vcn_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDrgAttachmentDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreateDrgAttachmentDetails
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 91 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self.drg_id = attributes[:'drgId'] if attributes[:'drgId'] raise 'You cannot provide both :drgId and :drg_id' if attributes.key?(:'drgId') && attributes.key?(:'drg_id') self.drg_id = attributes[:'drg_id'] if attributes[:'drg_id'] self.drg_route_table_id = attributes[:'drgRouteTableId'] if attributes[:'drgRouteTableId'] raise 'You cannot provide both :drgRouteTableId and :drg_route_table_id' if attributes.key?(:'drgRouteTableId') && attributes.key?(:'drg_route_table_id') self.drg_route_table_id = attributes[:'drg_route_table_id'] if attributes[:'drg_route_table_id'] self.network_details = attributes[:'networkDetails'] if attributes[:'networkDetails'] raise 'You cannot provide both :networkDetails and :network_details' if attributes.key?(:'networkDetails') && attributes.key?(:'network_details') self.network_details = attributes[:'network_details'] if attributes[:'network_details'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.vcn_id = attributes[:'vcnId'] if attributes[:'vcnId'] raise 'You cannot provide both :vcnId and :vcn_id' if attributes.key?(:'vcnId') && attributes.key?(:'vcn_id') self.vcn_id = attributes[:'vcn_id'] if attributes[:'vcn_id'] end |
Instance Attribute Details
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
34 35 36 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 34 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
14 15 16 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 14 def display_name @display_name end |
#drg_id ⇒ String
**[Required]** The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG.
18 19 20 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 18 def drg_id @drg_id end |
#drg_route_table_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table that is assigned to this attachment.
The DRG route table manages traffic inside the DRG.
25 26 27 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 25 def drg_route_table_id @drg_route_table_id end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
40 41 42 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 40 def @freeform_tags end |
#network_details ⇒ OCI::VnMonitoring::Models::DrgAttachmentNetworkCreateDetails
28 29 30 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 28 def network_details @network_details end |
#vcn_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN. This field is deprecated. Instead, use the `networkDetails` field to specify the [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the attached resource.
46 47 48 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 46 def vcn_id @vcn_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 49 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'display_name': :'displayName', 'drg_id': :'drgId', 'drg_route_table_id': :'drgRouteTableId', 'network_details': :'networkDetails', 'defined_tags': :'definedTags', 'freeform_tags': :'freeformTags', 'vcn_id': :'vcnId' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 64 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'display_name': :'String', 'drg_id': :'String', 'drg_route_table_id': :'String', 'network_details': :'OCI::VnMonitoring::Models::DrgAttachmentNetworkCreateDetails', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'freeform_tags': :'Hash<String, String>', 'vcn_id': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 147 def ==(other) return true if equal?(other) self.class == other.class && display_name == other.display_name && drg_id == other.drg_id && drg_route_table_id == other.drg_route_table_id && network_details == other.network_details && == other. && == other. && vcn_id == other.vcn_id end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
163 164 165 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 163 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 172 def hash [display_name, drg_id, drg_route_table_id, network_details, , , vcn_id].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/oci/vn_monitoring/models/create_drg_attachment_details.rb', line 210 def to_s to_hash.to_s end |