Class: OCI::VnMonitoring::Models::PublicIp
- Inherits:
-
Object
- Object
- OCI::VnMonitoring::Models::PublicIp
- Defined in:
- lib/oci/vn_monitoring/models/public_ip.rb
Overview
A *public IP* is a conceptual term that refers to a public IP address and related properties. The `publicIp` object is the API representation of a public IP.
There are two types of public IPs:
-
Ephemeral
-
Reserved
For more information and comparison of the two types, see [Public IP Addresses](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingpublicIPs.htm).
Constant Summary collapse
- LIFECYCLE_STATE_ENUM =
[ LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze, LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze, LIFECYCLE_STATE_ASSIGNING = 'ASSIGNING'.freeze, LIFECYCLE_STATE_ASSIGNED = 'ASSIGNED'.freeze, LIFECYCLE_STATE_UNASSIGNING = 'UNASSIGNING'.freeze, LIFECYCLE_STATE_UNASSIGNED = 'UNASSIGNED'.freeze, LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze, LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze, LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- LIFETIME_ENUM =
[ LIFETIME_EPHEMERAL = 'EPHEMERAL'.freeze, LIFETIME_RESERVED = 'RESERVED'.freeze, LIFETIME_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- SCOPE_ENUM =
[ SCOPE_REGION = 'REGION'.freeze, SCOPE_AVAILABILITY_DOMAIN = 'AVAILABILITY_DOMAIN'.freeze, SCOPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#availability_domain ⇒ String
The public IP's availability domain.
-
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the public IP.
-
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource.
-
#display_name ⇒ String
A user-friendly name.
-
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope.
-
#id ⇒ String
The public IP's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
-
#ip_address ⇒ String
The public IP address of the `publicIp` object.
-
#lifecycle_state ⇒ String
The public IP's current state.
-
#lifetime ⇒ String
Defines when the public IP is deleted and released back to Oracle's public IP pool.
-
#private_ip_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private IP that the public IP is currently assigned to, or in the process of being assigned to.
-
#scope ⇒ String
Whether the public IP is regional or specific to a particular availability domain.
-
#time_created ⇒ DateTime
The date and time the public IP was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PublicIp
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PublicIp
Initializes the object
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 192 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain'] raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain') self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain'] self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId'] raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id') self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id'] self. = attributes[:'definedTags'] if attributes[:'definedTags'] raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags') self. = attributes[:'defined_tags'] if attributes[:'defined_tags'] self.display_name = attributes[:'displayName'] if attributes[:'displayName'] raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] if attributes[:'display_name'] self. = attributes[:'freeformTags'] if attributes[:'freeformTags'] raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags') self. = attributes[:'freeform_tags'] if attributes[:'freeform_tags'] self.id = attributes[:'id'] if attributes[:'id'] self.ip_address = attributes[:'ipAddress'] if attributes[:'ipAddress'] raise 'You cannot provide both :ipAddress and :ip_address' if attributes.key?(:'ipAddress') && attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] if attributes[:'ip_address'] self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState'] raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state') self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state'] self.lifetime = attributes[:'lifetime'] if attributes[:'lifetime'] self.private_ip_id = attributes[:'privateIpId'] if attributes[:'privateIpId'] raise 'You cannot provide both :privateIpId and :private_ip_id' if attributes.key?(:'privateIpId') && attributes.key?(:'private_ip_id') self.private_ip_id = attributes[:'private_ip_id'] if attributes[:'private_ip_id'] self.scope = attributes[:'scope'] if attributes[:'scope'] self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated'] raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created') self.time_created = attributes[:'time_created'] if attributes[:'time_created'] end |
Instance Attribute Details
#availability_domain ⇒ String
The public IP's availability domain. This property is set only for ephemeral public IPs (that is, when the `scope` of the public IP is set to AVAILABILITY_DOMAIN). The value is the availability domain of the assigned private IP.
Example: `Uocm:PHX-AD-1`
51 52 53 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 51 def availability_domain @availability_domain end |
#compartment_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the public IP. For an ephemeral public IP, this is the same compartment as the private IP's. For a reserved public IP that is currently assigned, this can be a different compartment than the assigned private IP's.
58 59 60 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 58 def compartment_id @compartment_id end |
#defined_tags ⇒ Hash<String, Hash<String, Object>>
Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"bar-key": "value"}`
64 65 66 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 64 def @defined_tags end |
#display_name ⇒ String
A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
70 71 72 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 70 def display_name @display_name end |
#freeform_tags ⇒ Hash<String, String>
Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `"value"`
76 77 78 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 76 def @freeform_tags end |
#id ⇒ String
The public IP's Oracle ID ([OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
80 81 82 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 80 def id @id end |
#ip_address ⇒ String
The public IP address of the `publicIp` object.
Example: `203.0.113.2`
87 88 89 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 87 def ip_address @ip_address end |
#lifecycle_state ⇒ String
The public IP's current state.
91 92 93 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 91 def lifecycle_state @lifecycle_state end |
#lifetime ⇒ String
Defines when the public IP is deleted and released back to Oracle's public IP pool.
-
`EPHEMERAL`: The lifetime is tied to the lifetime of its assigned private IP. The
ephemeral public IP is automatically deleted when its private IP is deleted, when the VNIC is terminated, or when the instance is terminated. An ephemeral public IP must always be assigned to a private IP.
-
`RESERVED`: You control the public IP's lifetime. You can delete a reserved public IP
whenever you like. It does not need to be assigned to a private IP at all times.
For more information and comparison of the two types, see [Public IP Addresses](docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingpublicIPs.htm).
107 108 109 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 107 def lifetime @lifetime end |
#private_ip_id ⇒ String
The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private IP that the public IP is currently assigned to, or in the process of being assigned to.
113 114 115 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 113 def private_ip_id @private_ip_id end |
#scope ⇒ String
Whether the public IP is regional or specific to a particular availability domain.
-
`REGION`: The public IP exists within a region and can be assigned to a private IP
in any availability domain in the region. Reserved public IPs have `scope` = `REGION`.
-
`AVAILABILITY_DOMAIN`: The public IP exists within the availability domain of the private IP
it's assigned to, which is specified by the `availabilityDomain` property of the public IP object. Ephemeral public IPs have `scope` = `AVAILABILITY_DOMAIN`.
125 126 127 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 125 def scope @scope end |
#time_created ⇒ DateTime
The date and time the public IP was created, in the format defined by [RFC3339](tools.ietf.org/html/rfc3339).
Example: `2016-08-25T21:10:29.600Z`
132 133 134 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 132 def time_created @time_created end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 135 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'availabilityDomain', 'compartment_id': :'compartmentId', 'defined_tags': :'definedTags', 'display_name': :'displayName', 'freeform_tags': :'freeformTags', 'id': :'id', 'ip_address': :'ipAddress', 'lifecycle_state': :'lifecycleState', 'lifetime': :'lifetime', 'private_ip_id': :'privateIpId', 'scope': :'scope', 'time_created': :'timeCreated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 155 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'availability_domain': :'String', 'compartment_id': :'String', 'defined_tags': :'Hash<String, Hash<String, Object>>', 'display_name': :'String', 'freeform_tags': :'Hash<String, String>', 'id': :'String', 'ip_address': :'String', 'lifecycle_state': :'String', 'lifetime': :'String', 'private_ip_id': :'String', 'scope': :'String', 'time_created': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 305 def ==(other) return true if equal?(other) self.class == other.class && availability_domain == other.availability_domain && compartment_id == other.compartment_id && == other. && display_name == other.display_name && == other. && id == other.id && ip_address == other.ip_address && lifecycle_state == other.lifecycle_state && lifetime == other.lifetime && private_ip_id == other.private_ip_id && scope == other.scope && time_created == other.time_created end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 346 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
326 327 328 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 326 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
335 336 337 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 335 def hash [availability_domain, compartment_id, , display_name, , id, ip_address, lifecycle_state, lifetime, private_ip_id, scope, time_created].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
379 380 381 382 383 384 385 386 387 388 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 379 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
373 374 375 |
# File 'lib/oci/vn_monitoring/models/public_ip.rb', line 373 def to_s to_hash.to_s end |