Class: OCI::VulnerabilityScanning::Models::ContainerScanResultProblem
- Inherits:
-
Object
- Object
- OCI::VulnerabilityScanning::Models::ContainerScanResultProblem
- Defined in:
- lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb
Overview
A problem found in a container scan
Constant Summary collapse
- SEVERITY_ENUM =
[ SEVERITY_NONE = 'NONE'.freeze, SEVERITY_LOW = 'LOW'.freeze, SEVERITY_MEDIUM = 'MEDIUM'.freeze, SEVERITY_HIGH = 'HIGH'.freeze, SEVERITY_CRITICAL = 'CRITICAL'.freeze, SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
- STATE_ENUM =
[ STATE_OPEN = 'OPEN'.freeze, STATE_FIXED = 'FIXED'.freeze, STATE_NOT_APPLICABLE = 'NOT_APPLICABLE'.freeze, STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze ].freeze
Instance Attribute Summary collapse
-
#cve_reference ⇒ String
Reference to problem MITRE CVE ID.
-
#description ⇒ String
Problem description.
-
#name ⇒ String
[Required] Name of the problem.
-
#severity ⇒ String
[Required] Problem severity.
-
#state ⇒ String
State of the vulnerability.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContainerScanResultProblem
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ContainerScanResultProblem
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 84 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.name = attributes[:'name'] if attributes[:'name'] self.description = attributes[:'description'] if attributes[:'description'] self.severity = attributes[:'severity'] if attributes[:'severity'] self.state = attributes[:'state'] if attributes[:'state'] self.cve_reference = attributes[:'cveReference'] if attributes[:'cveReference'] raise 'You cannot provide both :cveReference and :cve_reference' if attributes.key?(:'cveReference') && attributes.key?(:'cve_reference') self.cve_reference = attributes[:'cve_reference'] if attributes[:'cve_reference'] end |
Instance Attribute Details
#cve_reference ⇒ String
Reference to problem MITRE CVE ID
45 46 47 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 45 def cve_reference @cve_reference end |
#description ⇒ String
Problem description
33 34 35 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 33 def description @description end |
#name ⇒ String
[Required] Name of the problem
29 30 31 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 29 def name @name end |
#severity ⇒ String
[Required] Problem severity
37 38 39 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 37 def severity @severity end |
#state ⇒ String
State of the vulnerability
41 42 43 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 41 def state @state end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 48 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'name': :'name', 'description': :'description', 'severity': :'severity', 'state': :'state', 'cve_reference': :'cveReference' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 61 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'name': :'String', 'description': :'String', 'severity': :'String', 'state': :'String', 'cve_reference': :'String' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 138 def ==(other) return true if equal?(other) self.class == other.class && name == other.name && description == other.description && severity == other.severity && state == other.state && cve_reference == other.cve_reference end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 172 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
152 153 154 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 152 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
161 162 163 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 161 def hash [name, description, severity, state, cve_reference].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
205 206 207 208 209 210 211 212 213 214 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 205 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
199 200 201 |
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_problem.rb', line 199 def to_s to_hash.to_s end |