Class: OCI::VulnerabilityScanning::Models::ContainerScanResultSummary

Inherits:
Object
  • Object
show all
Defined in:
lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb

Overview

A summary of a result for a container scan

Constant Summary collapse

HIGHEST_PROBLEM_SEVERITY_ENUM =
[
  HIGHEST_PROBLEM_SEVERITY_NONE = 'NONE'.freeze,
  HIGHEST_PROBLEM_SEVERITY_LOW = 'LOW'.freeze,
  HIGHEST_PROBLEM_SEVERITY_MEDIUM = 'MEDIUM'.freeze,
  HIGHEST_PROBLEM_SEVERITY_HIGH = 'HIGH'.freeze,
  HIGHEST_PROBLEM_SEVERITY_CRITICAL = 'CRITICAL'.freeze,
  HIGHEST_PROBLEM_SEVERITY_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ContainerScanResultSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):

  • :id (String)

    The value to assign to the #id property

  • :repository (String)

    The value to assign to the #repository property

  • :image (String)

    The value to assign to the #image property

  • :compartment_id (String)

    The value to assign to the #compartment_id property

  • :highest_problem_severity (String)

    The value to assign to the #highest_problem_severity property

  • :problem_count (Integer)

    The value to assign to the #problem_count property

  • :time_started (DateTime)

    The value to assign to the #time_started property

  • :time_finished (DateTime)

    The value to assign to the #time_finished property



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 98

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.id = attributes[:'id'] if attributes[:'id']

  self.repository = attributes[:'repository'] if attributes[:'repository']

  self.image = attributes[:'image'] if attributes[:'image']

  self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

  raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

  self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

  self.highest_problem_severity = attributes[:'highestProblemSeverity'] if attributes[:'highestProblemSeverity']

  raise 'You cannot provide both :highestProblemSeverity and :highest_problem_severity' if attributes.key?(:'highestProblemSeverity') && attributes.key?(:'highest_problem_severity')

  self.highest_problem_severity = attributes[:'highest_problem_severity'] if attributes[:'highest_problem_severity']

  self.problem_count = attributes[:'problemCount'] if attributes[:'problemCount']

  raise 'You cannot provide both :problemCount and :problem_count' if attributes.key?(:'problemCount') && attributes.key?(:'problem_count')

  self.problem_count = attributes[:'problem_count'] if attributes[:'problem_count']

  self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

  raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

  self.time_started = attributes[:'time_started'] if attributes[:'time_started']

  self.time_finished = attributes[:'timeFinished'] if attributes[:'timeFinished']

  raise 'You cannot provide both :timeFinished and :time_finished' if attributes.key?(:'timeFinished') && attributes.key?(:'time_finished')

  self.time_finished = attributes[:'time_finished'] if attributes[:'time_finished']
end

Instance Attribute Details

#compartment_idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container scan result’s compartment. This is set to the same as the compartmentId of the container scan target

Returns:

  • (String)


34
35
36
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 34

def compartment_id
  @compartment_id
end

#highest_problem_severityString

[Required] Highest problem severity in this report

Returns:

  • (String)


38
39
40
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 38

def highest_problem_severity
  @highest_problem_severity
end

#idString

[Required] The [OCID](docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of container scan result. Immutable and generated on creation.

Returns:

  • (String)


22
23
24
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 22

def id
  @id
end

#imageString

[Required] Image name

Returns:

  • (String)


30
31
32
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 30

def image
  @image
end

#problem_countInteger

[Required] Total number of problems found in this scan

Returns:

  • (Integer)


42
43
44
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 42

def problem_count
  @problem_count
end

#repositoryString

[Required] Repository in which the container image scanned is located

Returns:

  • (String)


26
27
28
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 26

def repository
  @repository
end

#time_finishedDateTime

[Required] Date and time the scan was completed, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)

Returns:

  • (DateTime)


50
51
52
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 50

def time_finished
  @time_finished
end

#time_startedDateTime

[Required] Date and time the scan was started, as described in [RFC 3339](tools.ietf.org/rfc/rfc3339)

Returns:

  • (DateTime)


46
47
48
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 46

def time_started
  @time_started
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 53

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'id',
    'repository': :'repository',
    'image': :'image',
    'compartment_id': :'compartmentId',
    'highest_problem_severity': :'highestProblemSeverity',
    'problem_count': :'problemCount',
    'time_started': :'timeStarted',
    'time_finished': :'timeFinished'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 69

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'id': :'String',
    'repository': :'String',
    'image': :'String',
    'compartment_id': :'String',
    'highest_problem_severity': :'String',
    'problem_count': :'Integer',
    'time_started': :'DateTime',
    'time_finished': :'DateTime'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • other (Object)

    the other object to be compared



161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 161

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    id == other.id &&
    repository == other.repository &&
    image == other.image &&
    compartment_id == other.compartment_id &&
    highest_problem_severity == other.highest_problem_severity &&
    problem_count == other.problem_count &&
    time_started == other.time_started &&
    time_finished == other.time_finished
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 198

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • other (Object)

    the other object to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 178

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



187
188
189
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 187

def hash
  [id, repository, image, compartment_id, highest_problem_severity, problem_count, time_started, time_finished].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



231
232
233
234
235
236
237
238
239
240
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 231

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



225
226
227
# File 'lib/oci/vulnerability_scanning/models/container_scan_result_summary.rb', line 225

def to_s
  to_hash.to_s
end