Class: VulnerabilityScanning::Models::CveDetails
- Inherits:
-
Object
- Object
- VulnerabilityScanning::Models::CveDetails
- Defined in:
- lib/oci/vulnerability_scanning/models/cve_details.rb
Overview
Details on a CVE
Instance Attribute Summary collapse
-
#cve_reference ⇒ String
**[Required]** CVE ID.
-
#cvss3 ⇒ String
**[Required]** CVSS 3 Score.
-
#description ⇒ String
CVE description.
-
#related_cve_reference ⇒ String
ID of related CVE, if applicable.
-
#time_published ⇒ DateTime
**[Required]** Date/time the CVE was published.
-
#time_updated ⇒ DateTime
**[Required]** Date/time the CVE was last modified.
-
#title ⇒ String
**[Required]** Vulnerability title.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CveDetails
constructor
Initializes the object.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CveDetails
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 81 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } self.cve_reference = attributes[:'cveReference'] if attributes[:'cveReference'] raise 'You cannot provide both :cveReference and :cve_reference' if attributes.key?(:'cveReference') && attributes.key?(:'cve_reference') self.cve_reference = attributes[:'cve_reference'] if attributes[:'cve_reference'] self.title = attributes[:'title'] if attributes[:'title'] self.description = attributes[:'description'] if attributes[:'description'] self. = attributes[:'relatedCveReference'] if attributes[:'relatedCveReference'] raise 'You cannot provide both :relatedCveReference and :related_cve_reference' if attributes.key?(:'relatedCveReference') && attributes.key?(:'related_cve_reference') self. = attributes[:'related_cve_reference'] if attributes[:'related_cve_reference'] self.cvss3 = attributes[:'cvss3'] if attributes[:'cvss3'] self.time_published = attributes[:'timePublished'] if attributes[:'timePublished'] raise 'You cannot provide both :timePublished and :time_published' if attributes.key?(:'timePublished') && attributes.key?(:'time_published') self.time_published = attributes[:'time_published'] if attributes[:'time_published'] self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated'] raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated'] end |
Instance Attribute Details
#cve_reference ⇒ String
**[Required]** CVE ID
12 13 14 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 12 def cve_reference @cve_reference end |
#cvss3 ⇒ String
**[Required]** CVSS 3 Score
28 29 30 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 28 def cvss3 @cvss3 end |
#description ⇒ String
CVE description
20 21 22 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 20 def description @description end |
#related_cve_reference ⇒ String
ID of related CVE, if applicable
24 25 26 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 24 def @related_cve_reference end |
#time_published ⇒ DateTime
**[Required]** Date/time the CVE was published
32 33 34 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 32 def time_published @time_published end |
#time_updated ⇒ DateTime
**[Required]** Date/time the CVE was last modified
36 37 38 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 36 def time_updated @time_updated end |
#title ⇒ String
**[Required]** Vulnerability title
16 17 18 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 16 def title @title end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 39 def self.attribute_map { # rubocop:disable Style/SymbolLiteral 'cve_reference': :'cveReference', 'title': :'title', 'description': :'description', 'related_cve_reference': :'relatedCveReference', 'cvss3': :'cvss3', 'time_published': :'timePublished', 'time_updated': :'timeUpdated' # rubocop:enable Style/SymbolLiteral } end |
.swagger_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 54 def self.swagger_types { # rubocop:disable Style/SymbolLiteral 'cve_reference': :'String', 'title': :'String', 'description': :'String', 'related_cve_reference': :'String', 'cvss3': :'String', 'time_published': :'DateTime', 'time_updated': :'DateTime' # rubocop:enable Style/SymbolLiteral } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 125 def ==(other) return true if equal?(other) self.class == other.class && cve_reference == other.cve_reference && title == other.title && description == other.description && == other. && cvss3 == other.cvss3 && time_published == other.time_published && time_updated == other.time_updated end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 161 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) public_method("#{key}=").call( attributes[self.class.attribute_map[key]] .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? public_method("#{key}=").call( OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]]) ) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
141 142 143 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 141 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 150 def hash [cve_reference, title, description, , cvss3, time_published, time_updated].hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = public_method(attr).call next if value.nil? && !instance_variable_defined?("@#{attr}") hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
188 189 190 |
# File 'lib/oci/vulnerability_scanning/models/cve_details.rb', line 188 def to_s to_hash.to_s end |