Class: OCI::Waf::Models::ProtectionRule

Inherits:
WebAppFirewallPolicyRule show all
Defined in:
lib/oci/waf/models/protection_rule.rb

Overview

Rule that represents Request/Response Protection. Only actions of the following types are allowed to be referenced in this rule:

* CHECK
* RETURN_HTTP_RESPONSE

Constant Summary

Constants inherited from WebAppFirewallPolicyRule

WebAppFirewallPolicyRule::CONDITION_LANGUAGE_ENUM, WebAppFirewallPolicyRule::TYPE_ENUM

Instance Attribute Summary collapse

Attributes inherited from WebAppFirewallPolicyRule

#action_name, #condition, #condition_language, #name, #type

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from WebAppFirewallPolicyRule

get_subtype

Constructor Details

#initialize(attributes = {}) ⇒ ProtectionRule

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash

Options Hash (attributes):



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/oci/waf/models/protection_rule.rb', line 68

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  attributes['type'] = 'PROTECTION'

  super(attributes)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  self.protection_capabilities = attributes[:'protectionCapabilities'] if attributes[:'protectionCapabilities']

  raise 'You cannot provide both :protectionCapabilities and :protection_capabilities' if attributes.key?(:'protectionCapabilities') && attributes.key?(:'protection_capabilities')

  self.protection_capabilities = attributes[:'protection_capabilities'] if attributes[:'protection_capabilities']

  self.protection_capability_settings = attributes[:'protectionCapabilitySettings'] if attributes[:'protectionCapabilitySettings']

  raise 'You cannot provide both :protectionCapabilitySettings and :protection_capability_settings' if attributes.key?(:'protectionCapabilitySettings') && attributes.key?(:'protection_capability_settings')

  self.protection_capability_settings = attributes[:'protection_capability_settings'] if attributes[:'protection_capability_settings']
end

Instance Attribute Details

#protection_capabilitiesArray<OCI::Waf::Models::ProtectionCapability>

[Required] An ordered list that references OCI-managed protection capabilities. Referenced protection capabilities are executed in order of appearance. The array cannot contain entries with the same pair of capability key and version more than once.

Returns:



21
22
23
# File 'lib/oci/waf/models/protection_rule.rb', line 21

def protection_capabilities
  @protection_capabilities
end

#protection_capability_settingsOCI::Waf::Models::ProtectionCapabilitySettings

Returns:



24
25
26
# File 'lib/oci/waf/models/protection_rule.rb', line 24

def protection_capability_settings
  @protection_capability_settings
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/oci/waf/models/protection_rule.rb', line 27

def self.attribute_map
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'type',
    'name': :'name',
    'condition_language': :'conditionLanguage',
    'condition': :'condition',
    'action_name': :'actionName',
    'protection_capabilities': :'protectionCapabilities',
    'protection_capability_settings': :'protectionCapabilitySettings'
    # rubocop:enable Style/SymbolLiteral
  }
end

.swagger_typesObject

Attribute type mapping.



42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/oci/waf/models/protection_rule.rb', line 42

def self.swagger_types
  {
    # rubocop:disable Style/SymbolLiteral
    'type': :'String',
    'name': :'String',
    'condition_language': :'String',
    'condition': :'String',
    'action_name': :'String',
    'protection_capabilities': :'Array<OCI::Waf::Models::ProtectionCapability>',
    'protection_capability_settings': :'OCI::Waf::Models::ProtectionCapabilitySettings'
    # rubocop:enable Style/SymbolLiteral
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • the other object to be compared



98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/oci/waf/models/protection_rule.rb', line 98

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    type == other.type &&
    name == other.name &&
    condition_language == other.condition_language &&
    condition == other.condition &&
    action_name == other.action_name &&
    protection_capabilities == other.protection_capabilities &&
    protection_capability_settings == other.protection_capability_settings
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/oci/waf/models/protection_rule.rb', line 134

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        public_method("#{key}=").call(
          attributes[self.class.attribute_map[key]]
            .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
        )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      public_method("#{key}=").call(
        OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
      )
    end
    # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(other) ⇒ Boolean

Parameters:

  • the other object to be compared

Returns:

See Also:

  • `==` method


114
115
116
# File 'lib/oci/waf/models/protection_rule.rb', line 114

def eql?(other)
  self == other
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



123
124
125
# File 'lib/oci/waf/models/protection_rule.rb', line 123

def hash
  [type, name, condition_language, condition, action_name, protection_capabilities, protection_capability_settings].hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



167
168
169
170
171
172
173
174
175
176
# File 'lib/oci/waf/models/protection_rule.rb', line 167

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = public_method(attr).call
    next if value.nil? && !instance_variable_defined?("@#{attr}")

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



161
162
163
# File 'lib/oci/waf/models/protection_rule.rb', line 161

def to_s
  to_hash.to_s
end